<?php

namespace Quiety\Widgets;

defined( 'ABSPATH' ) || exit; // Abort, if called directly.

use Elementor\{Widget_Base,
	Controls_Manager,
	Group_Control_Typography,
	Group_Control_Background,
	Group_Control_Border
};
class Quiety_Blockquote extends Widget_Base {

	public function get_name() {
		return 'tt-blockquote';
	}

	public function get_title() {
		return esc_html__( 'Quiety Blockquote', 'quiety-core' );
	}

	public function get_icon() {
		return 'eicon-blockquote';
	}

	public function get_categories() {
		return [ 'tt-elements' ];
	}

	protected function register_controls() {
		$this->start_controls_section( 'section_tab', [
			'label' => esc_html__( 'Blockquote', 'quiety-core' ),
		] );

		$this->add_control( 'blockquote_content', [
			'label'       => esc_html__( 'Blockquote Text', 'quiety-core' ),
			'type'        => Controls_Manager::TEXTAREA,
			'label_block' => true,
			'placeholder' => esc_html__( 'Blockquote', 'quiety-core' ),
			'default'     => __( 'There are no secrets to success. It is the result of preparation, hard work, and learning from failure.', 'quiety-core' )
		] );

		$this->add_control( 'author_name', [
			'label'       => __( 'Author Name', 'quiety-core' ),
			'type'        => Controls_Manager::TEXT,
			'placeholder' => __( 'Type your author name here', 'quiety-core' ),
		] );


		$this->add_responsive_control( 'title_align', [
			'label'     => esc_html__( 'Alignment', 'quiety-core' ),
			'type'      => Controls_Manager::CHOOSE,
			'options'   => [

				'left'    => [
					'title' => esc_html__( 'Left', 'quiety-core' ),
					'icon'  => 'fa fa-align-left',
				],
				'center'  => [
					'title' => esc_html__( 'Center', 'quiety-core' ),
					'icon'  => 'fa fa-align-center',
				],
				'right'   => [
					'title' => esc_html__( 'Right', 'quiety-core' ),
					'icon'  => 'fa fa-align-right',
				],
				'justify' => [
					'title' => esc_html__( 'Justified', 'quiety-core' ),
					'icon'  => 'fa fa-align-justify',
				],
			],
			'default'   => 'left',
			'selectors' => [
				'{{WRAPPER}} .tt-blockquote' => 'text-align: {{VALUE}};'
			],
		] );

		$this->end_controls_section();

		//Title Style Section
		$this->start_controls_section( 'section_title_style', [
			'label' => esc_html__( 'Content', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_control( 'title_color_one', [
			'label'     => esc_html__( 'color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .blockquote_content' => 'color: {{VALUE}};'
			],
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'title_typography',
			'selector' => '{{WRAPPER}} .blockquote_content',
		] );

		$this->end_controls_section();

		// Author Style Section
		$this->start_controls_section( 'section_des_style', [
			'label' => esc_html__( 'Author', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_control( 'des_color', [
			'label'     => esc_html__( 'color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} cite' => 'color: {{VALUE}};',
			],
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'des_typography',
			'selector' => '{{WRAPPER}} cite',
		] );


		$this->end_controls_section();

	}

	protected function render() {
		$settings = $this->get_settings_for_display();

		?>

		<blockquote class="tt-blockquote m-0">
			<p class="blockquote_content">
				<?php echo $settings['blockquote_content']; ?>
			</p>
			<?php if ( ! empty( $settings['author_name'] ) ) : ?>
				<footer>
					<?php if ( ! empty( $settings['author_name'] ) ) : ?>
						<cite <?php echo $this->get_render_attribute_string( 'author_name' ); ?>><?php echo $settings['author_name']; ?></cite>
					<?php endif ?>
				</footer>
			<?php endif ?>
		</blockquote>

		<?php
	}

}







