<?php

namespace Quiety\Widgets;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Elementor\{Widget_Base,
	Controls_Manager,
	Group_Control_Typography,
	Group_Control_Border,
	Group_Control_Box_Shadow
};

/**
 * Get Post.
 *
 * Retrieve Quiety Post.
 *
 * @return string Quiety Post.
 * @since 1.0.0
 * @access public
 *
 */
class Quiety_Blog extends Widget_Base {

	public $base;

	public function get_name() {
		return 'tt-blog';
	}

	public function get_title() {
		return esc_html__( 'Quiety Blog Posts', 'quiety-core' );
	}

	public function get_icon() {
		return 'eicon-posts-grid';
	}

	public function get_categories() {
		return [ 'tt-elements' ];
	}


    /**
     * Name: register_controls
     * Desc: Register controls for these widgets
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @quiety
     * Author: Themetags
     */
    protected function register_controls() {
        $this-> elementor_content_control();
        $this-> elementor_style_control();
    }

    
    /**
     * Name: elementor_content_control
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @quiety
     * Author: Themetags
     */
    public function elementor_content_control() {
        //=================== Start Query Post Filter ======================//
        $this->start_controls_section( 'section_tab', [
            'label' => esc_html__( 'Blog Post', 'quiety-core' ),
        ] );

        $this->add_control( 'layout', [
            'label'   => esc_html__( 'Blog Style', 'quiety-core' ),
            'type'    => Controls_Manager::SELECT,
            'options' => [
                '1' => esc_html__( 'Style One', 'quiety-core' ),
                '2' => esc_html__( 'Style Two', 'quiety-core' ),
                '3' => esc_html__( 'Style Three', 'quiety-core' ),
                '4' => esc_html__( 'Style Four', 'quiety-core' ),
                '5' => esc_html__( 'Style Five', 'quiety-core' ),
                '6' => esc_html__( 'Style Six', 'quiety-core' ),
            ],
            'default' => '1',
        ] );

        $this->add_control( 'post_count', [
            'label'   => esc_html__( 'Post count', 'quiety-core' ),
            'type'    => Controls_Manager::NUMBER,
            'default' => esc_html__( '3', 'quiety-core' ),
        ] );

        $this->add_control( 'count_col', [
            'label'   => esc_html__( 'Select Column', 'quiety-core' ),
            'type'    => Controls_Manager::SELECT,
            'default' => 4,
            'options' => [
                '6' => esc_html__( '2 Column', 'quiety-core' ),
                '4' => esc_html__( '3 Column', 'quiety-core' ),
            ],
        ] );

        $this->add_control( 'post_cat', [
            'label'       => esc_html__( 'Select category', 'quiety-core' ),
            'type'        => Controls_Manager::SELECT2,
            'multiple'    => true,
            'label_block' => true,
            'options'     => \Quiety_Helper::categories_suggester(),
            'default'     => '0'
        ] );

        $this->add_control( 'word_limit', [
            'label'   => __( 'Word Limit', 'quiety-core' ),
            'type'    => \Elementor\Controls_Manager::NUMBER,
            'min'     => 5,
            'max'     => 30,
            'step'    => 5,
            'default' => 10,
        ] );


        $this->end_controls_section(); //End Query Post Filter


        //====================== Button ====================//
        $this->start_controls_section( 'buttons_sec', [
            'label' => esc_html__( 'Button', 'quiety-core' ),
        ] );

        $this->add_control( 'btn_title', [
            'label'   => esc_html__( 'Button Title', 'quiety-core' ),
            'type'    => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => esc_html__( 'Read More', 'quiety-core' ),
        ] );

        $this->end_controls_section(); //End Button
    }

    
    /**
     * Name: elementor_style_control
     * Desc: Register style content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @quiety
     * Author: Themetags
     */
    public function elementor_style_control() {


        //================== Style Item Title ======================//
        $this->start_controls_section( 'section_subtitle_style', [
            'label' => esc_html__( 'Title', 'quiety-core' ),
            'tab'   => Controls_Manager::TAB_STYLE,
        ] );

        $this->add_control( 'blog_title_color', [
            'label'     => __( 'Color', 'quiety-core' ),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .post-grid .blog-content .entry-title a' => 'color: {{VALUE}}',
                '{{WRAPPER}} .single_blog_post .post_content h4 a' => 'color: {{VALUE}}',
                '{{WRAPPER}} .__title' => 'color: {{VALUE}}',
            ],
        ]);

        $this->add_control( 'blog_title_color_hover', [
            'label'     => __( 'Hover Color', 'quiety-core' ),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .post-grid .blog-content .entry-title a:hover' => 'color: {{VALUE}}',
                '{{WRAPPER}} .single_blog_post .post_content h4 a:hover' => 'color: {{VALUE}}',
                '{{WRAPPER}} .__title:hover' => 'color: {{VALUE}}',
            ],
        ] );

        $this->add_group_control( Group_Control_Typography::get_type(), [
            'name'     => 'title_typography',
            'label'    => __( 'Typography', 'quiety-core' ),
            'selector' => '{{WRAPPER}} .entry-title, {{WRAPPER}} .__title',
        ] );

        $this->end_controls_section(); //End Item Title


        //========================= Meta ===============================//
        $this->start_controls_section( 'background_shape', [
            'label' => __( 'Meta', 'quiety-core' ),
            'tab'   => Controls_Manager::TAB_STYLE,
        ] );

        $this->add_group_control( Group_Control_Typography::get_type(), [
            'name'     => 'meta_typography',
            'label'    => __( 'Typography', 'quiety-core' ),
            'selector' => '{{WRAPPER}} .single_blog_post .date h2',
        ] );

        $this->add_control( 'meta_show', [
            'label'        => __( 'Post meta', 'quiety-core' ),
            'type'         => Controls_Manager::SWITCHER,
            'label_on'     => __( 'Yes', 'quiety-core' ),
            'label_off'    => __( 'No', 'quiety-core' ),
            'return_value' => 'yes',
            'default'      => 'yes',
        ] );

        $this->add_control( 'title_color', [
            'label'     => __( 'Color', 'quiety-core' ),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .post-meta li, {{WRAPPER}} .post-meta li.author a' => 'color: {{VALUE}}',
            ],
        ] );

        $this->add_control( 'title_color_hover', [
            'label'     => __( 'Hover Color', 'quiety-core' ),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .post-meta li.author a:hover' => 'color: {{VALUE}}',
            ],
        ] );

        $this->end_controls_section(); //End Meta

    }


    /**
     * Name: render
     * Desc: Widgets Render
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @quiety
     * Author: Themetags
     */
	protected function render() {
		$settings   = $this->get_settings_for_display();
		$style      = $settings['layout'];
		$post_cat   = $settings['post_cat'];
		$count_col  = $settings['count_col'];
		$post_count = $settings['post_count'];


		$paged = 1;
		if ( get_query_var( 'paged' ) ) {
			$paged = get_query_var( 'paged' );
		}
		if ( get_query_var( 'page' ) ) {
			$paged = get_query_var( 'page' );
		}

		$_tax_query = array();

		if ( $post_cat ) {
			$_tax_query = array(
				array(
					'taxonomy' => 'category',
					'field'    => 'slug',
					'terms'    => $post_cat,
				)
			);
		}

		$query = array(
			'post_type'      => 'post',
			'post_status'    => 'publish',
			'posts_per_page' => $post_count,
			'tax_query'      => $_tax_query,
			'paged'          => $paged,
		);

		$quiety_query = new \WP_Query( $query );

		if ( $quiety_query->have_posts() ):
			?>
			<div class="tt-blog-posts">
                <?php
                $ant = 0.3;
                echo '<div class="row">';

                while ( $quiety_query->have_posts() ) :
                    $quiety_query->the_post();

                    require __DIR__ . '/templates/blog/style-' . $style . '.php';

                    $ant = $ant + 0.2;
                    wp_reset_postdata();
                endwhile;
                echo '</div>';
                ?>
			</div>
		    <?php
		endif;
		wp_reset_postdata();
	}
}