<?php

namespace Quiety\Widgets;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Elementor\{Widget_Base,
	Controls_Manager,
	Group_Control_Typography,
	Group_Control_Border,
	Group_Control_Box_Shadow
};

/**
 * Get Post.
 *
 * Retrieve Quiety Post.
 *
 * @return string Quiety Post.
 * @since 1.0.0
 * @access public
 *
 */
class Quiety_Blog_Slider extends Widget_Base {

	public $base;

	public function get_name() {
		return 'tt-blog-slider';
	}

	public function get_title() {
		return esc_html__( 'Quiety Posts Slider', 'quiety-core' );
	}

	public function get_icon() {
		return 'eicon-posts-grid';
	}

	public function get_categories() {
		return [ 'tt-elements' ];
	}

	protected function register_controls() {

		$this->start_controls_section( 'section_tab', [
			'label' => esc_html__( 'Blog Post Slider', 'quiety-core' ),
		] );

		$this->add_control( 'post_count', [
			'label'   => esc_html__( 'Post count', 'quiety-core' ),
			'type'    => Controls_Manager::NUMBER,
			'default' => esc_html__( '3', 'quiety-core' ),
		] );


		$this->add_control( 'post_cat', [
			'label'       => esc_html__( 'Select category', 'quiety-core' ),
			'type'        => Controls_Manager::SELECT2,
			'multiple'    => true,
			'label_block' => true,
			'options'     => \Quiety_Helper::categories_suggester(),
			'default'     => '0'
		] );

		$this->add_control( 'content_show', [
			'label'        => esc_html__( 'Content Show', 'quiety-core' ),
			'type'         => Controls_Manager::SWITCHER,
			'label_on'     => esc_html__( 'Show', 'quiety-core' ),
			'label_off'    => esc_html__( 'Hide', 'quiety-core' ),
			'return_value' => 'yes',
			'default'      => 'no'
		] );

		$this->add_control( 'word_limit', [
			'label'   => __( 'Word Limit', 'quiety-core' ),
			'type'    => \Elementor\Controls_Manager::NUMBER,
			'min'     => 5,
			'max'     => 30,
			'step'    => 5,
			'default' => 10,
			'condition' => ['content_show' => 'yes']
		] );

		$this->add_control( 'button_text', [
			'label'   => esc_html__( 'Button Txt', 'quiety-core' ),
			'type'    => Controls_Manager::TEXT,
			'default' => esc_html__( 'Read More', 'quiety-core' ),
		] );

		$this->end_controls_section();

		// Slider Control
		//=====================
		$this->start_controls_section( 'settingd_section', [
			'label' => esc_html__( 'Slider Control', 'quiety-core' ),
		] );

		$this->add_control( 'navigation', [
			'label'        => esc_html__( 'Navigation', 'quiety-core' ),
			'type'         => Controls_Manager::SWITCHER,
			'label_on'     => esc_html__( 'Show', 'quiety-core' ),
			'label_off'    => esc_html__( 'Hide', 'quiety-core' ),
			'return_value' => 'yes',
			'default'      => 'yes'
		] );


		$this->add_control( 'loop', [
			'label'        => esc_html__( 'Loop', 'quiety-core' ),
			'type'         => Controls_Manager::SWITCHER,
			'label_on'     => esc_html__( 'On', 'quiety-core' ),
			'label_off'    => esc_html__( 'Off', 'quiety-core' ),
			'return_value' => 'yes',
			'default'      => 'yes'
		] );

		$this->add_control( 'speed', [
			'label'   => __( 'Speed', 'quiety-core' ),
			'type'    => Controls_Manager::NUMBER,
			'default' => 700,
		] );

		$this->add_control( 'autoplay', [
			'label'        => esc_html__( 'Autoplay', 'quiety-core' ),
			'type'         => Controls_Manager::SWITCHER,
			'label_on'     => esc_html__( 'On', 'quiety-core' ),
			'label_off'    => esc_html__( 'Off', 'quiety-core' ),
			'return_value' => 'yes',
			'default'      => 'yes'
		] );

		$this->add_control( 'autoplay_time', [
			'label'   => __( 'Autoplay Time', 'quiety-core' ),
			'type'    => Controls_Manager::NUMBER,
			'default' => 3000,
			'condition' => [
				'autoplay' => 'yes'
			]
		] );

		$this->end_controls_section();

		$this->start_controls_section( 'section_subtitle_style', [
			'label' => esc_html__( 'Title', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_control( 'blog_title_color', [
			'label'     => __( 'Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .post-grid .blog-content .entry-title a, 
                    {{WRAPPER}}  .single_blog_post .post_content h4 a' => 'color: {{VALUE}}',
			],
		] );

		$this->add_control( 'blog_title_color_hover', [
			'label'     => __( 'Hover Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .post-grid .blog-content .entry-title a:hover, 
                    {{WRAPPER}}  .single_blog_post .post_content h4 a:hover' => 'color: {{VALUE}}',
			],
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'title_typography',
			'label'    => __( 'Typography', 'quiety-core' ),
			'selector' => '{{WRAPPER}} .entry-title',
		] );

		$this->end_controls_section();

		$this->start_controls_section( 'background_shape', [
			'label' => __( 'Meta', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'meta_typography',
			'label'    => __( 'Typography', 'quiety-core' ),
			'selector' => '{{WRAPPER}} .single_blog_post .date h2',
		] );


		$this->add_control( 'meta_show', [
			'label'        => __( 'Post meta', 'quiety-core' ),
			'type'         => Controls_Manager::SWITCHER,
			'label_on'     => __( 'Yes', 'quiety-core' ),
			'label_off'    => __( 'No', 'quiety-core' ),
			'return_value' => 'yes',
			'default'      => 'yes',
		] );

		$this->add_control( 'title_color', [
			'label'     => __( 'Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .post-meta li, {{WRAPPER}} .post-meta li.author a' => 'color: {{VALUE}}',
			],
		] );

		$this->add_control( 'title_color_hover', [
			'label'     => __( 'Hover Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .post-meta li.author a:hover' => 'color: {{VALUE}}',
			],
		] );


		$this->end_controls_section();
	}

	protected function render() {
		$settings   = $this->get_settings_for_display();
		$post_cat   = $settings['post_cat'];
		$post_count = $settings['post_count'];

		$slider_options = $this->get_slider_options( $settings );
		$this->add_render_attribute( 'wrapper', 'data-blog', wp_json_encode( $slider_options ) );

		$this->add_render_attribute( 'wrapper', 'class', [
			'swiper-container',
			'tt-post-slider',
		] );


		$paged = 1;
		if ( get_query_var( 'paged' ) ) {
			$paged = get_query_var( 'paged' );
		}
		if ( get_query_var( 'page' ) ) {
			$paged = get_query_var( 'page' );
		}

		$_tax_query = array();

		if ( $post_cat ) {
			$_tax_query = array(
				array(
					'taxonomy' => 'category',
					'field'    => 'slug',
					'terms'    => $post_cat,
				)
			);
		}

		$query = array(
			'post_type'      => 'post',
			'post_status'    => 'publish',
			'posts_per_page' => $post_count,
			'tax_query'      => $_tax_query,
			'paged'          => $paged,
		);

		$quiety_query = new \WP_Query( $query );

		if ( $quiety_query->have_posts() ) : ?>
			<div class="tt-blog-posts-slider">
				<div <?php $this->print_render_attribute_string( 'wrapper' ); ?>>
					<div class="swiper-wrapper">
						<?php
						while ( $quiety_query->have_posts() ) :
							$quiety_query->the_post();
							?>
                            <div class="swiper-slide">
                                <div class="post-slider">
                                    <?php if ( has_post_thumbnail() ): ?>
                                        <div class="feature-image">
                                            <a href="<?php the_permalink(); ?>" class="feature-image-block">
                                                <?php the_post_thumbnail( 'quiety_blog_330x250', array( 'class' => 'img-fluid' ) ) ?>
                                            </a>
                                        </div>
                                    <?php endif; ?>
                                    <div class="blog-content">
                                        <div class="entry-header">
                                            <ul class="post-meta">
                                                <li class="author-simple">
                                                    <i class="feather-user"></i>
                                                    <?php \Quiety_Theme_Helper::quiety_entry_meta_small(); ?>
                                                </li>
                                                <li class="meta-date">
                                                    <i class="feather-calendar"></i>
                                                    <?php \Quiety_Theme_Helper::quiety_posted_on(); ?>
                                                </li>
                                            </ul>
                                            <h3 class="entry-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
                                            <?php if ( 'yes' == $settings['content_show']) :?>
                                                <p><?php echo \Quiety_Theme_Helper::quiety_substring( get_the_content(), $settings['word_limit'], '...' ) ?></p>
                                            <?php endif; ?>
                                            <a href="<?php the_permalink(); ?>" class="read-more-text"><?php echo esc_html($settings['button_text']) ?> <i class="feather-arrow-right"></i></a>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <?php
						endwhile;
						?>
					</div>

					<div class="blog-swiper-pagination"></div>

				</div>
			</div>
		<?php
		endif;
		wp_reset_postdata();
	}

	protected function get_slider_options( array $settings ) {

		// Loop
		if ( $settings['loop'] == 'yes' ) {
			$slider_options['loop'] = true;
		}

		// Speed
		if ( ! empty( $settings['speed'] ) ) {
			$slider_options['speed'] = $settings['speed'];
		}

		// Breakpoints
		$slider_options['breakpoints'] = [
			'992' => [
				'slidesPerView' => '3',
			],

			'767' => [
				'slidesPerView' => '2',
			],

			'320' => [
				'slidesPerView' => 1,
			],
		];

		// Auto Play
		if ( $settings['autoplay'] == 'yes' ) {
			$slider_options['autoplay'] = [
				'delay' => $settings['autoplay_time'],
				'disableOnInteraction' => false
			];
		} else {
			$slider_options['autoplay'] = [
				'delay' => '99999999999',
			];
		}

		if ( $settings['navigation'] == 'yes' ) {
			$slider_options['navigation'] = [
				'nextEl' => '.blog-next',
				'prevEl' => '.blog-prev'
			];
		}

		$slider_options['pagination'] = [
			'el'   => '.blog-swiper-pagination',
			'clickable' => true,
		];

		$slider_options['spaceBetween'] = (int) '30';

		return $slider_options;
	}
}