<?php

namespace Quiety\Widgets;

defined( 'ABSPATH' ) || exit; // Abort, if called directly.

use Elementor\{Widget_Base,
	Controls_Manager,
	Group_Control_Typography,
	Group_Control_Background,
	Group_Control_Border
};

class Quiety_Call_To_Action extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve button widget name.
	 *
	 * @return string Widget name.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_name() {
		return 'tt-call-to-action';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve button widget title.
	 *
	 * @return string Widget title.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_title() {
		return __('Quiety Call To Action', 'quiety-core');
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve button widget icon.
	 *
	 * @return string Widget icon.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_icon() {
		return 'eicon-call-to-action';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the icon box widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * @return array Widget categories.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_categories() {
		return ['tt-elements'];
	}

	/**
	 * Register button widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function register_controls() {
		$this->start_controls_section(
			'section_button',
			[
				'label' => __('Call To Action', 'quiety-core'),
			]
        );

		$this->add_control(
			'title',
			[
				'label' => __('Title', 'quiety-core'),
				'type' => Controls_Manager::TEXT,
				'default' => __('Got New Project?', 'quiety-core'),
				'placeholder' => __('Title', 'quiety-core'),
				'label_block' => true,
				'rows' => 3
			]
        );

        $this->add_control(
			'description',
			[
				'label' => __('Description', 'quiety-core'),
				'type' => Controls_Manager::TEXTAREA,
				'default' => __('Call us for fast support to this number.', 'quiety-core'),
                'placeholder' => __('Description', 'quiety-core'),
				'label_block' => true
			]
        );

		$this->add_control(
			'call_title',
			[
				'label' => __('Call Title', 'quiety-core'),
				'type' => Controls_Manager::TEXTAREA,
				'default' => __('Call Now', 'quiety-core'),
				'placeholder' => __('Title', 'quiety-core'),
				'label_block' => true
			]
		);

		$this->add_control(
			'phone_number',
			[
				'label' => __('Phone Number', 'quiety-core'),
				'type' => Controls_Manager::TEXTAREA,
				'default' => __('(+008) 548 426  894', 'quiety-core'),
				'placeholder' => __('Title', 'quiety-core'),
				'label_block' => true
			]
		);

		$this->add_control(
			'phone_link',
			[
				'label' => __('Phone Link', 'quiety-core'),
				'type' => Controls_Manager::URL,
				'placeholder' => 'http://your-link.com',
				'default' => [
					'url' => '#',
				],
			]
		);

		$this->add_control(
			'btn_text',
			[
				'label' => __('Button Text', 'quiety-core'),
				'type' => Controls_Manager::TEXT,
				'default' => __('Send Message', 'quiety-core'),
				'placeholder' => __('Button text', 'quiety-core'),
			]
		);

		$this->add_control(
			'link',
			[
				'label' => __('Link', 'quiety-core'),
				'type' => Controls_Manager::URL,
				'placeholder' => 'http://your-link.com',
				'default' => [
					'url' => '#',
				],
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label' => __('Alignment', 'quiety-core'),
				'type' => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => __('Left', 'quiety-core'),
						'icon' => 'fa fa-align-left',
					],
					'center' => [
						'title' => __('Center', 'quiety-core'),
						'icon' => 'fa fa-align-center',
					],
					'right' => [
						'title' => __('Right', 'quiety-core'),
						'icon' => 'fa fa-align-right',
					],
					'justify' => [
						'title' => __('Justified', 'quiety-core'),
						'icon' => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'default' => '',
			]
		);


        $this->end_controls_section();

        $this->start_controls_section(
			'section_style',
			[
				'label' => __('Style', 'quiety-core'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
        );

        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'label' => __( 'Title Typography', 'quiety-core' ),
				'selector' => '{{WRAPPER}} .actions-content .action-title',
			]
        );

        $this->add_control(
			'title_color',
			[
				'label' => __( 'Title Color', 'quiety-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .actions-content .action-title' => 'color: {{VALUE}}',
				],
			]
        );

        $this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'des_typography',
				'label' => __( 'Description Typography', 'quiety-core' ),
                'selector' => '{{WRAPPER}} .actions-content .description',

			]
        );

        $this->add_control(
			'des_color',
			[
				'label' => __( 'Description Color', 'quiety-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .actions-content .description' => 'color: {{VALUE}}',
				],
			]
		);


		$this->end_controls_section();

		$this->start_controls_section(
			'section_button_style',
			[
				'label' => __('Button', 'quiety-core'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'typography',
				'label' => __('Typography', 'quiety-core'),
				'selector' => '{{WRAPPER}} .tt-btn',
			]
		);

		$this->start_controls_tabs('tabs_button_style');

		$this->start_controls_tab(
			'tab_button_normal',
			[
				'label' => __('Normal', 'quiety-core'),
			]
		);

		$this->add_control(
			'button_text_color',
			[
				'label' => __('Color', 'quiety-core'),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .tt-btn' => 'color: {{VALUE}};',
				],
			]
        );

		$this->add_control(
			'button_bg_color',
			[
				'label' => __('Background', 'quiety-core'),
				'type' => Controls_Manager::COLOR,
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .tt-btn' => 'background-color: {{VALUE}};',
				],
			]
        );

		$this->add_control(
			'border_color',
			[
				'label' => __('Border Color', 'quiety-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tt-btn' => 'border-color: {{VALUE}};',
				],
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'tab_button_hover',
			[
				'label' => __('Hover', 'quiety-core'),
			]
		);

		$this->add_control(
			'hover_color',
			[
				'label' => __('Color', 'quiety-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tt-btn:hover' => 'color: {{VALUE}};',
				],
			]
        );

        $this->add_control(
			'background_color',
			[
				'label' => __('Background', 'quiety-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tt-btn:after' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'border_color_hover',
			[
				'label' => __('Border Color', 'quiety-core'),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .tt-btn:hover' => 'border-color: {{VALUE}};',
				],
			]
		);



		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'border_hover',
				'label' => __('Border', 'quiety-core'),
				'placeholder' => '1px',
				'default' => '1px',
				'selectors' => [
					'{{WRAPPER}} .tt-btn:hover'
				],
				'separator' => 'before',
			]
		);



		$this->end_controls_tab();
		$this->end_controls_tabs();

		$this->add_control(
			'border_radius',
			[
				'label' => __('Border Radius', 'quiety-core'),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', '%'],
				'selectors' => [
					'{{WRAPPER}} .tt-btn' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);


		$this->add_control(
			'text_padding',
			[
				'label' => __('Text Padding', 'quiety-core'),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => ['px', 'em', '%'],
				'selectors' => [
					'{{WRAPPER}} .tt-btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'separator' => 'before',
			]
		);

        $this->end_controls_section();

        $this->start_controls_section(
			'section_background',
			[
				'label' => __('Background', 'quiety-core'),
				'tab' => Controls_Manager::TAB_STYLE,
			]
        );

        $this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'ac_background',
				'label' => __( 'Background', 'quiety-core' ),
				'types' => [ 'classic', 'gradient'],
				'selector' => '{{WRAPPER}} .call-to-action',

			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'ac_background_two',
				'label' => __( 'Background', 'quiety-core' ),
				'types' => [ 'classic', 'gradient'],
				'selector' => '{{WRAPPER}} .call-to-action-two',
				'condition' => [
					'layout' => '2'
				]
			]
        );

        $this->add_responsive_control(
			'section_padding',
			[
				'label' => __( 'Padding', 'quiety-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .cta_part .cta_part_iner' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'animated_image',
			[
				'label' => __( 'Parallax Image', 'quiety-core' ),
                'tab' => Controls_Manager::TAB_CONTENT,
                'condition' => [
                    'layout' => '3'
                ]
			]
		);

		$this->add_control(
			'parallax_switch',
			[
				'label' => __( 'Show Parallax Image', 'quiety-core' ),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'quiety-core' ),
				'label_off' => __( 'Hide', 'quiety-core' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);


		$this->add_control(
			'shape_one',
			[
				'label' => __( 'Choose Left Image Shape', 'quiety-core' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => plugins_url( 'images/4.png', __FILE__ ),
                ],

			]
		);

		$this->add_control(
			'shape_two',
			[
				'label' => __( 'Choose Right Image Shape', 'quiety-core' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => plugins_url( 'images/5.png', __FILE__ ),
                ],

			]
		);

        $this->end_controls_section();
	}

	/**
	 * Render button widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {
        $settings = $this->get_settings_for_display();

        $target = $settings['link']['is_external'] ? ' target="_blank"' : '';
		$nofollow = $settings['link']['nofollow'] ? ' rel="nofollow"' : '';


        require __DIR__ . '/templates/call-to-action/layout-2.php';
	}

	/**
	 * Render button widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _content_template()	{}


}