<?php
namespace Quiety\Widgets;

if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

use Elementor\{Controls_Manager,
    Group_Control_Background,
    Group_Control_Box_Shadow,
    Widget_Base,
    Group_Control_Typography,
    Repeater,
    Utils};

class quiety_client_logo extends Widget_Base {

    public function get_name() {
        return 'quiety_client_logo';
    }

    public function get_title() {
        return esc_html__( 'Quiety Client Logo', 'quiety-core' );
    }

    public function get_icon() {
        return 'eicon-logo';
    }

    public function get_categories() {
        return [ 'quiety-elements' ];
    }

    /**
     * Name: register_controls
     * Desc: Register controls for these widgets
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @quiety
     * Author: Themetags
     */
    protected function register_controls() {
        $this-> elementor_content_control();
        $this-> elementor_style_control();
    }


    /**
     * Name: quiety_elementor_content_control
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @quiety
     * Author: Themetags
     */
    public function elementor_content_control() {


        //==================== Select Layout ==========================//
        $this->start_controls_section(
            'select_layout', [
                'label' => __( 'Layout', 'quiety-core' ),
            ]
        );

        $this->add_control(
            'layout', [
                'label'   => esc_html__( 'Layout', 'quiety-core' ),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    '1' => esc_html__( '01: Carousel Slider', 'quiety-core' ),
                ],
                'default' => '1',
            ]
        );

        $this->end_controls_section(); //End Layout


        //==================== Client Logos ==========================//
        $this->start_controls_section(
            'sec_client_logo', [
                'label' => __( 'Client Logo', 'quiety-core' ),
            ]
        );

        $client_logo = new \Elementor\Repeater();
        $client_logo->add_control(
            'align_items', [
                'type'    => Controls_Manager::HIDDEN,
            ]
        );

        $client_logo->add_control(
            'logo', [
                'label'   => esc_html__( 'Logo', 'quiety-core' ),
                'type'    => Controls_Manager::MEDIA,
            ]
        );

        $this->add_control(
            'client_logos', [
                'label'   => esc_html__( 'Logo', 'quiety-core' ),
                'type'    => Controls_Manager::REPEATER,
                'fields'  => $client_logo->get_controls(),
                'title_field' => '{{{ align_items }}}',
                'prevent_empty' => false
            ]
        );

        $this->end_controls_section(); //End Client Logos

    }


    /**
     * Name: quiety_elementor_style_control
     * Desc: Register style content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @quiety
     * Author: Themetags
     */
    public function elementor_style_control() {


        //=============================== Slider Control Section =========================//
        $this->start_controls_section(
            'slider_control_sec', [
                'label' => esc_html__( 'Slider Control', 'quiety-core' ),
                'tab'   => \Elementor\Controls_Manager::TAB_STYLE
            ]
        );

        $this->add_control(
            'slide_per_view_desktop', [
                'label'   => __( 'Slide Per View', 'quiety-core' ),
                'type'    => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    '3' => __( '3', 'quiety-core' ),
                    '4' => __( '4', 'quiety-core' ),
                    '5' => __( '5', 'quiety-core' ),
                    '6' => __( '6', 'quiety-core' ),
                ],
                'default' => '3',
            ]
        );

        $this->add_control(
            'space_between', [
                'label'   => __( 'SpaceBetween', 'quiety-core' ),
                'type'    => Controls_Manager::NUMBER,
                'default' => 10,
            ]
        );

        $this->add_control(
            'loop', [
                'label'        => esc_html__( 'Loop', 'quiety-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'On', 'quiety-core' ),
                'label_off'    => esc_html__( 'Off', 'quiety-core' ),
                'return_value' => 'yes',
                'default'      => 'yes'
            ]
        );

        $this->add_control(
            'speed', [
                'label'   => __( 'Speed', 'quiety-core' ),
                'type'    => Controls_Manager::NUMBER,
                'default' => 700,
            ]
        );

        $this->add_control(
            'autoplay', [
                'label'        => esc_html__( 'Autoplay', 'quiety-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => esc_html__( 'On', 'quiety-core' ),
                'label_off'    => esc_html__( 'Off', 'quiety-core' ),
                'return_value' => 'yes',
                'default'      => 'yes'
            ]
        );

        $this->add_control(
            'autoplay_time', [
                'label'   => __( 'Autoplay Time', 'quiety-core' ),
                'type'    => Controls_Manager::NUMBER,
                'default' => 3000,
            ]
        );

        $this->end_controls_section(); //End Slider Control Section

    }


    /**
     * Name: render
     * Desc: Widgets Render
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @quiety
     * Author: Themetags
     */
    protected function render() {
        $settings     = $this->get_settings_for_display();
        extract( $settings );

        $slider_options = quiety_get_el_swiper_slider_options( $settings );

        $this->add_render_attribute( 'wrapper', 'class', ['swiper-container', 'ins-brand-slider']);
        $this->add_render_attribute( 'wrapper', 'data-swiper', json_encode( $slider_options ) );

        //=============== Template Parts ================//
        require __DIR__ . '/templates/client-logo/layout-'.$layout.'.php';

    }

}