<?php

namespace Quiety\Widgets;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Elementor\{Controls_Manager,
	Group_Control_Border,
	Group_Control_Box_Shadow,
	Group_Control_Typography,
	Repeater,
	Widget_Base};


/**
 * History Tab
 *
 * History widget.
 *
 * @since 2.0.0
 */
class Quiety_Content_Tab extends Widget_Base {

	public function get_name() {
		return 'tt-content-tabs';
	}

	public function get_title() {
		return __( 'Quiety Content Tab', 'quiety-core' );
	}

	public function get_icon() {
		return 'eicon-tabs';
	}

	public function get_categories() {
		return [ 'tt-elements' ];
	}

	protected function register_controls() {

		// ------------------------------ Feature list ------------------------------
		$this->start_controls_section( 'section_tab', [
			'label' => __( 'Tab Content', 'quiety-core' ),
		] );

		$this->add_control( 'layout', [
			'label'   => esc_html__( 'Layout', 'quiety-core' ),
			'type'    => Controls_Manager::SELECT,
			'options' => [
				'one' => esc_html__( 'Layout 1', 'quiety-core' ),
				'two' => esc_html__( 'Layout 2', 'quiety-core' ),
			],
			'default' => 'one',
		] );


		$repeater = new Repeater();

		$repeater->add_control( 'tab_label', [
			'label'       => __( 'Tab Label', 'quiety-core' ),
			'type'        => Controls_Manager::TEXT,
			'label_block' => true,
		] );

		$repeater->add_control(
			'tab_icon',
			[
				'label' => esc_html__( 'Icon', 'plugin-name' ),
				'type' => \Elementor\Controls_Manager::ICONS,
				'default' => [
					'value' => 'fas fa-star',
					'library' => 'solid',
				],
			]
		);

		$repeater->add_control( 'tab_image', [
			'label'   => __( 'Tab Feature Image', 'quiety-core' ),
			'type'    => Controls_Manager::MEDIA,
			'default' => [
				'url' => plugin_dir_url( __DIR__ ) . 'assets/images/tab1.png'
			],
		] );

		$repeater->add_responsive_control( 'image_position', [
			'label'   => __( 'Image Position', 'quiety-core' ),
			'type'    => Controls_Manager::CHOOSE,
			'options' => [
				'left'  => [
					'title' => __( 'Left', 'quiety-core' ),
					'icon'  => 'eicon-h-align-left',
				],
				'right' => [
					'title' => __( 'Right', 'quiety-core' ),
					'icon'  => 'eicon-h-align-right',
				],
			],
			'default' => 'left',
			'toggle'  => false,
		] );

		$repeater->add_control( 'title', [
			'label'       => __( 'Title', 'quiety-core' ),
			'type'        => Controls_Manager::TEXT,
			'label_block' => true,
			'separator' => 'before'
		] );

		$repeater->add_control( 'description', [
			'label'      => __( 'Content', 'quiety-core' ),
			'type'       => Controls_Manager::WYSIWYG,
			'show_label' => false,
		] );

		$repeater->add_control( 'button_text', [
			'label'       => __( 'Button Text', 'quiety-core' ),
			'type'        => Controls_Manager::TEXT,
			'label_block' => true,
			'default'     => __( 'Know More About Us', 'quiety-core' ),
		] );

		$repeater->add_control( 'btn_link', [
			'label'         => __( 'Link', 'quiety-core' ),
			'type'          => Controls_Manager::URL,
			'placeholder'   => __( 'https://your-link.com', 'quiety-core' ),
			'default'       => [
				'url'         => '#',
			],
		] );

		$this->add_control( 'advance_tab', [
			'label'       => __( 'Tab Lists', 'quiety-core' ),
			'type'        => Controls_Manager::REPEATER,
			'fields'      => $repeater->get_controls(),
			'default'     => [
				[
					'tab_label'   => __( ' AI & Data Science', 'quiety-core' ),
					'title' => __( 'AI & Data Science', 'quiety-core' ),
					'description' => __( 'Continually network effective bandwidth whereas goal-oriented schemas. Intrinsicly incentivize corporate synergy with accurate task bricks-and-clicks leadership skills.', 'quiety-core' ),
					'button_text' => __( 'Know More About Us', 'quiety-core' ),
				],
				[
					'tab_label'   => __( 'Automation Power', 'quiety-core' ),
					'title'       => __( 'Automation Power', 'quiety-core' ),
					'description' => __( 'Continually network effective bandwidth whereas goal-oriented schemas. Intrinsicly incentivize corporate synergy with accurate task bricks-and-clicks leadership skills.', 'quiety-core' ),
					'button_text' => __( 'Know More About Us', 'quiety-core' ),
				],
				[
					'tab_label'   => __( 'Advanced Technology', 'quiety-core' ),
					'title'       => __( 'Advanced Technology', 'quiety-core' ),
					'description' => __( 'Continually network effective bandwidth whereas goal-oriented schemas. Intrinsicly incentivize corporate synergy with accurate task bricks-and-clicks leadership skills.', 'quiety-core' ),
					'button_text' => __( 'Know More About Us', 'quiety-core' ),

				],
			],
			'title_field' => '{{{ tab_label }}}',
		] );

		$this->end_controls_section(); // End Buttons


		// Tab Label Style
		// =========================
		$this->start_controls_section( 'label_style_section', [
			'label' => __( 'Tab Label', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_control( 'border_color', [
			'label'     => __( 'Border Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} #content-tabs-nav' => 'border-bottom-color: {{VALUE}}',
			],
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'label_typography',
			'label'    => __( 'Typography', 'quiety-core' ),
			'selector' => '{{WRAPPER}} #content-tabs-nav li a',
		] );

		$this->add_control(
			'label_padding',
			[
				'label' => __( 'Padding', 'quiety-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} #content-tabs-nav li a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'label_border-radius',
			[
				'label' => __( 'Border Radius', 'quiety-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} #content-tabs-nav li a' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->start_controls_tabs('tabs_label_style');

		$this->start_controls_tab(
			'tab_label_normal',
			[
				'label' => __('Normal', 'quiety-core'),
			]
		);

		$this->add_control( 'label_color', [
			'label'     => __( ' Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} #content-tabs-nav li:not(.active) a' => 'color: {{VALUE}}',
			],
		] );

		$this->add_control( 'label_bg_color', [
			'label'     => __( 'Background Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} #content-tabs-nav li:not(.active) a' => 'background-color: {{VALUE}}',
			],
		] );

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'label_border',
				'label' => __('Border', 'quiety-core'),
				'selector' => '{{WRAPPER}} #content-tabs-nav li:not(.active) a',
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'label_box_shadow',
				'label' => __( 'Box Shadow', 'quiety-core' ),
				'selector' => '{{WRAPPER}} #content-tabs-nav li:not(.active) a',
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'tab_label_active',
			[
				'label' => __('Active', 'quiety-core'),
			]
		);

		$this->add_control( 'label_active_color', [
			'label'     => __( 'Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} #content-tabs-nav li.active a' => 'color: {{VALUE}}',
			],
		] );

		$this->add_control( 'label_bg_active_color', [
			'label'     => __( 'Background Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} #content-tabs-nav li.active a' => 'background-color: {{VALUE}}',
			],
		] );

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'label_border_active',
				'label' => __('Border', 'quiety-core'),
				'selector' => '{{WRAPPER}} #content-tabs-nav li.active a',
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'label_active_box_shadow',
				'label' => __( 'Box Shadow', 'quiety-core' ),
				'selector' => '{{WRAPPER}} #content-tabs-nav li.active a',
			]
		);

		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();


		// Title Style
		// =========================
		$this->start_controls_section( 'title_style', [
			'label' => __( 'Title', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_control( 'title_color', [
			'label'     => __( ' Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tabs-content .title' => 'color: {{VALUE}}',
			],
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'title_typography',
			'label'    => __( 'Typography', 'quiety-core' ),
			'selector' => '{{WRAPPER}} .tabs-content .title',
		] );

		$this->end_controls_section();


		// Description Style
		// =========================
		$this->start_controls_section( 'description_style', [
			'label' => __( 'Description', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_control( 'description_color', [
			'label'     => __( ' Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .content-description' => 'color: {{VALUE}}',
			],
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'des_typography',
			'label'    => __( 'Typography', 'quiety-core' ),
			'selector' => '{{WRAPPER}} .content-description',
		] );

		$this->end_controls_section();

		// Link Style Section
		// =========================
		$this->start_controls_section( 'link_style', [
			'label' => __( 'Link', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_control( 'link_color', [
			'label'     => __( ' Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .read-more-link' => 'color: {{VALUE}}',
			],
		] );

		$this->add_control( 'link_hover_color', [
			'label'     => __( 'Hover Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .read-more-link:hover' => 'color: {{VALUE}}',
			],
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'link_typography',
			'label'    => __( 'Typography', 'quiety-core' ),
			'selector' => '{{WRAPPER}} .read-more-link',
		] );

		$this->end_controls_section();

	}

	protected function render() {

		$settings    = $this->get_settings();
		$advance_tab = isset( $settings['advance_tab'] ) ? $settings['advance_tab'] : '';

		?>

		<div id="tt-tabs" class="tt-tabs content-tabs">

			<ul id="content-tabs-nav" class="style-<?php echo esc_attr( $settings['layout']); ?>">
				<?php
				$id_int = 'tabs-id-' . substr( $this->get_id_int(), 0, 3 );
				foreach ( $advance_tab as $key => $tabitem ) :
					$active = $key == '0' ? 'active' : '';
					?>

					<li class="elementor-repeater-item-<?php echo esc_attr( $tabitem['_id'] ); ?> <?php echo esc_attr( $active ); ?>">
						<a href="#<?php echo esc_attr( $id_int . '-' . $key ); ?>">
							<?php \Elementor\Icons_Manager::render_icon( $tabitem['tab_icon'], [ 'aria-hidden' => 'true' ] ); ?>
							<span><?php echo esc_html( $tabitem['tab_label'] ); ?></span>
						</a>
					</li>
				<?php endforeach; ?>
			</ul>

			<div id="tt-content-tabs-content" class="tt-tabs-wrapper style-<?php echo esc_attr( $settings['layout']); ?>">
				<?php foreach ( $advance_tab as $key => $tabitem ) :
					$target = $tabitem['btn_link']['is_external'] ? ' target="_blank"' : '';
					$nofollow = $tabitem['btn_link']['nofollow'] ? ' rel="nofollow"' : '';

					if ( $tabitem['image_position'] == 'right' ) {
						$image_order = 'tt-image-order-2';
					} else {
						$image_order = '';
					}
					?>

					<div id="<?php echo esc_attr( $id_int . '-' . $key ); ?>" class="content">
						<div class="content-tab-contents">
							<div class="row align-items-center">
								<div class="col-md-6 <?php echo esc_attr( $image_order ); ?>">
									<?php if ( ! empty( $tabitem['tab_image']['url'] ) ) { ?>
										<div class="content-tab-image">
											<img src="<?php echo esc_url( $tabitem['tab_image']['url'] ) ?>" alt="<?php echo esc_attr( $tabitem['title'] ) ?>">
										</div>
									<?php } ?>
								</div>
								<!-- /.col-md-6 -->
								<div class="col-md-6">
									<div class="tabs-content">
										<h3 class="title"><?php echo $tabitem['title']; ?></h3>

										<?php if ( ! empty( $tabitem['description'] ) ) : ?>
											<div class="content-description"><?php echo $tabitem['description']; ?></div>
										<?php endif; ?>

										<a href="<?php echo esc_url( $tabitem['btn_link']['url'] ); ?>" class="read-more-link" <?php esc_attr( $target . ' ' . $nofollow ); ?>><?php echo esc_html( $tabitem['button_text'] ); ?><i class="fas fa-arrow-right"></i></a>
									</div>
								</div>
								<!-- /.col-md-6 -->
							</div>
							<!-- /.row -->
						</div>
					</div>

				<?php endforeach; ?>

			</div>
			<!-- quiety-tabs-content -->

		</div>

		<?php
	}
}