<?php

namespace Quiety\Widgets;

defined( 'ABSPATH' ) || exit; // Abort, if called directly.

use Elementor\{Utils,
	Widget_Base,
	Controls_Manager,
	Group_Control_Typography,
	Group_Control_Background,
	Group_Control_Box_Shadow,
	Icons_Manager};

class Quiety_Count_Info extends Widget_Base {

	public function get_name() {
		return 'tt-count-info';
	}

	public function get_title() {
		return esc_html__( 'Quiety Count Info', 'quiety-core' );
	}

	public function get_icon() {
		return 'eicon-icon-box';
	}

	public function get_categories() {
		return [ 'tt-elements' ];
	}

	protected function register_controls() {
		$this->start_controls_section( 'section_tab', [
			'label' => esc_html__( 'Count Info', 'quiety-core' ),
		] );


		$this->add_control(
			'selected_icon',
			[
				'label' => __( 'Icon', 'quiety-core' ),
				'type' => Controls_Manager::ICONS,
				'fa4compatibility' => 'icon',
				'default' => [
					'value' => 'fas fa-star',
					'library' => 'fa-solid',
				],
			]
		);

		$this->add_control( 'count_title', [
			'label'       => esc_html__( 'Count Title', 'quiety-core' ),
			'type'        => Controls_Manager::TEXT,
			'label_block' => true,
			'default'     => __( '10x', 'quiety-core' ),
			'placeholder' => esc_html__( 'Title', 'quiety-core' ),
		] );

		$this->add_control( 'description', [
			'label'       => esc_html__( 'Description', 'quiety-core' ),
			'type'        => Controls_Manager::TEXTAREA,
			'label_block' => true,
			'default'     => esc_html__( 'Embrace distinctive best practices after syndicate backend internal or whereas edge process improvements.', 'quiety-core' ),
		] );

		$this->add_control(
			'logo_image',
			[
				'label' => __( 'Choose logo Image', 'quiety-core' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => plugin_dir_url(__DIR__) . '/assets/images/client-logo-4.svg',
				],
			]
		);

		$this->end_controls_section();

		//Title Style Section
		$this->start_controls_section( 'section_title_style', [
			'label' => esc_html__( 'Count Title', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_control( 'title_color', [
			'label'     => esc_html__( 'Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-count-info__title' => 'color: {{VALUE}};'
			],
		] );


		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'title_typography',
			'selector' => '{{WRAPPER}} .tt-count-info__title',
		] );

		$this->end_controls_section();

		//Address Style Section
		$this->start_controls_section( 'section_subtitle_style', [
			'label' => esc_html__( 'Description', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_control( 'subtitle_color', [
			'label'     => esc_html__( 'Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-count-info__description' => 'color: {{VALUE}};',
			],
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'sdes_typography',
			'selector' => '{{WRAPPER}} .tt-count-info__description',
		] );

		$this->end_controls_section();


		$this->start_controls_section( 'box_section', [
			'label' => __( 'Box', 'quiety-option' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_group_control( Group_Control_Background::get_type(), [
			'name'     => 'box_background',
			'label'    => __( 'Background', 'quiety-option' ),
			'types'    => [
				'classic',
				'gradient'
			],
			'selector' => '{{WRAPPER}} .tt-count-info',
		] );


		$this->add_group_control( Group_Control_Box_Shadow::get_type(), [
			'name'     => 'info_box_shadow',
			'label'    => __( 'Box Shadow', 'quiety-option' ),
			'selector' => '{{WRAPPER}} .tt-count-info',
		] );

		$this->add_responsive_control( 'border-radius', [
			'label'      => __( 'Border Radius', 'quiety-option' ),
			'type'       => Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%', 'em' ],
			'selectors'  => [
				'{{WRAPPER}} .tt-count-info' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		] );

		$this->add_responsive_control( 'margin', [
			'label'      => __( 'Margin', 'quiety-option' ),
			'type'       => Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%', 'em' ],
			'selectors'  => [
				'{{WRAPPER}} .tt-count-info' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		] );

		$this->add_responsive_control( 'padding', [
			'label'      => __( 'Padding', 'quiety-option' ),
			'type'       => Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%', 'em' ],
			'selectors'  => [
				'{{WRAPPER}} .tt-count-info' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		] );

		$this->end_controls_section();
	}

	protected function render() {
		$settings = $this->get_settings_for_display();

		if ( ! isset( $settings['icon'] ) && ! Icons_Manager::is_migration_allowed() ) {
			// add old default
			$settings['icon'] = 'fa fa-star';
		}

		$has_icon = ! empty( $settings['icon'] );

		if ( $has_icon ) {
			$this->add_render_attribute( 'i', 'class', $settings['icon'] );
			$this->add_render_attribute( 'i', 'aria-hidden', 'true' );
		}

		if ( ! $has_icon && ! empty( $settings['selected_icon']['value'] ) ) {
			$has_icon = true;
		}
		$migrated = isset( $settings['__fa4_migrated']['selected_icon'] );
		$is_new = ! isset( $settings['icon'] ) && Icons_Manager::is_migration_allowed();

		?>
			<div class="tt-count-info">
				<?php if ( ! empty( $settings['count_title'] || $settings['selected_icon'] ) ) : ?>
					<div class="tt-count-info__icon">
						<?php if ( $is_new || $migrated ) {
							Icons_Manager::render_icon( $settings['selected_icon'], [ 'aria-hidden' => 'true' ] );
						} elseif ( ! empty( $settings['icon'] ) ) {
							?><i <?php $this->print_render_attribute_string( 'i' ); ?>></i><?php
						} ?>

						<?php if ( ! empty( $settings['count_title'] ) ) : ?>
							<h3 class="tt-count-info__title"><?php echo wp_kses_post( $settings['count_title'] ); ?></h3>
						<?php endif; ?>

					</div>
				<?php endif; ?>

				<div class="tt-count-info__content">
					<?php if ( ! empty( $settings['description'] ) ) : ?>
						<p class="tt-count-info__description">
							<?php echo wp_kses_post( $settings['description'] ); ?>
						</p>
					<?php endif; ?>

					<?php if ( ! empty ( $settings['logo_image']['url'] ) ) : ?>
						<div class="tt-count-info__logo">
							<img src="<?php echo esc_url( $settings['logo_image']['url'] ); ?>"	alt="<?php echo esc_attr( $settings['count_title'] ); ?>">
						</div>
					<?php endif; ?>
				</div>
				<!-- /.tt-count-info__content -->
			</div>
			<!-- /.tt-count-info -->
		<?php
	}

}



