<?php

namespace Quiety\Widgets;

defined( 'ABSPATH' ) || exit; // Abort, if called directly.

use Elementor\{Group_Control_Background,
	Group_Control_Border,
	Group_Control_Box_Shadow,
	Widget_Base,
	Controls_Manager,
	Group_Control_Typography,
};

if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly

class Quiety_Countdown extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve alert widget name.
	 *
	 * @return string Widget name.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_name() {
		return 'tt-countdown';
	}

	public function get_title() {
		return __( 'Quiety Count Down', 'quiety-core' );
	}

	public function get_icon() {
		return 'eicon-social-icons';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the widget categories.
	 *
	 * @return array Widget categories.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_categories() {
		return [ 'tt-elements' ];
	}

	/**
	 * Retrieve the list of scripts the image widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @return array Widget scripts dependencies.
	 * @since 1.3.0
	 * @access public
	 *
	 */
	public function get_script_depends() {
		return [ 'countdown' ];
	}

	protected function register_controls() {

		$this->start_controls_section( 'section_content', [
			'label' => __( 'Content', 'quiety-core' ),
		] );

		$this->add_control( 'year', [
			'label'       => __( 'Year', 'quiety-core' ),
			'type'        => Controls_Manager::TEXT,
			'label_block' => true,
			'default'     => '2022',
		] );

		$this->add_control( 'month', [
			'label'   => __( 'Month', 'quiety-core' ),
			'type'    => \Elementor\Controls_Manager::SELECT,
			'default' => '1',
			'options' => [
				"1"  => __( "January", 'quiety-core' ),
				"2"  => __( "February", 'quiety-core' ),
				"3"  => __( "March", 'quiety-core' ),
				"4"  => __( "April", 'quiety-core' ),
				"5"  => __( "May", 'quiety-core' ),
				"6"  => __( "June", 'quiety-core' ),
				"7"  => __( "July", 'quiety-core' ),
				"8"  => __( "August", 'quiety-core' ),
				"9"  => __( "September", 'quiety-core' ),
				"10" => __( "October", 'quiety-core' ),
				"11" => __( "November", 'quiety-core' ),
				"12" => __( "December", 'quiety-core' )
			],
		] );

		$this->add_control( 'day', [
			'label'   => __( 'Day', 'quiety-core' ),
			'type'    => \Elementor\Controls_Manager::NUMBER,
			'min'     => 1,
			'max'     => 31,
			'step'    => 1,
			'default' => 10,
		] );

		$this->add_control( 'title', [
			'label'       => __( 'Progressbar Title', 'quiety-core' ),
			'type'        => Controls_Manager::TEXT,
			'label_block' => true,
			'default'     => __( '$35, 356 543  Contribution Received', 'quiety-core' ),
		] );

		$this->add_control(
			'progress_percent',
			[
				'label' => esc_html__( 'Progressbar Percent', 'plugin-name' ),
				'type' => \Elementor\Controls_Manager::NUMBER,
				'min' => 0,
				'max' => 100,
				'step' => 1,
				'default' => 75,
			]
		);

		$this->add_control(
			'image_align',
			[
				'label' => esc_html__( 'Alignment', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'options' => [
					'flex-start'    => [
						'title' => esc_html__( 'Left', 'quiety-core' ),
						'icon'  => 'eicon-text-align-left',
					],
					'center'  => [
						'title' => esc_html__( 'Center', 'quiety-core' ),
						'icon'  => 'eicon-text-align-center',
					],
					'flex-end'   => [
						'title' => esc_html__( 'Right', 'quiety-core' ),
						'icon'  => 'eicon-text-align-right',
					],
				],
				'default' => 'center',
				'toggle' => true,
				'selectors' => [
					'{{WRAPPER}} .countdown' => 'justify-content: {{VALUE}};'
				],
			]
		);

		$this->end_controls_section();

		/**
		 * Style
		 */

		/* Title */
		$this->start_controls_section( 'title_style_section', [
			'label' => __( 'Title', 'quiety-core' ),
			'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
		] );

		$this->add_control( 'title_color', [
			'label'     => __( 'Color', 'quiety-core' ),
			'type'      => \Elementor\Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .progress-title' => 'color: {{VALUE}}'
			],
		] );

		$this->add_group_control( \Elementor\Group_Control_Typography::get_type(), [
			'name'     => 'title_typography',
			'label'    => __( 'Typography', 'quiety-core' ),
			'selector' => '{{WRAPPER}} .progress-title',
		] );

		$this->end_controls_section();


		/* Time Style */
		$this->start_controls_section( 'time_section', [
			'label' => __( 'Time', 'quiety-core' ),
			'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
		] );

		$this->add_control( 'count_color', [
			'label'     => __( 'Time Count color', 'quiety-core' ),
			'type'      => \Elementor\Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .CountdownContent:not(label)' => 'color: {{VALUE}}'
			],
		] );

		$this->add_group_control( \Elementor\Group_Control_Typography::get_type(), [
			'name'     => 'count_typography',
			'label'    => __( 'Typography', 'quiety-core' ),
			'selector' => '{{WRAPPER}} .CountdownContent:not(label)',
		] );

		$this->end_controls_section();


		$this->start_controls_section( 'time_label_section', [
			'label' => __( 'Time Label', 'quiety-core' ),
			'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
		] );

		$this->add_control( 'label_color', [
			'label'     => __( 'Time Count color', 'quiety-core' ),
			'type'      => \Elementor\Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .CountdownLabel' => 'color: {{VALUE}}'
			],
		] );

		$this->add_group_control( \Elementor\Group_Control_Typography::get_type(), [
			'name'     => 'label_typography',
			'label'    => __( 'Typography', 'quiety-core' ),
			'selector' => '{{WRAPPER}} .CountdownLabel',
		] );

		$this->add_control( 'bg_color', [
			'label'     => __( 'Background Color', 'quiety-core' ),
			'type'      => \Elementor\Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .counting' => 'background-color: {{VALUE}}'
			],
		] );

		$this->end_controls_section();

		$this->start_controls_section( 'box_style_section', [
			'label' => __( 'Countdown Box', 'quiety-core' ),
			'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
		] );

		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'box_background',
				'label' => esc_html__( 'Background', 'quiety-core' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .counting',
			]
		);

		$this->add_control(
			'box_padding',
			[
				'label' => esc_html__( 'Padding', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .counting' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control(
			'box_bprder_radius',
			[
				'label' => esc_html__( 'Border Radius', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .counting' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Border::get_type(),
			[
				'name' => 'box_border',
				'label' => esc_html__( 'Border', 'quiety-core' ),
				'selector' => '{{WRAPPER}} .counting',
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'box_boxshadow',
				'label' => esc_html__( 'Box Shadow', 'quiety-core' ),
				'selector' => '{{WRAPPER}} .counting',
			]
		);

		$this->end_controls_section();

		$this->start_controls_section( 'box_progress_style', [
			'label' => __( 'Progressbar', 'quiety-core' ),
			'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
		] );

		$this->add_control( 'progress_bg_color', [
			'label'     => __( 'Background Color', 'quiety-core' ),
			'type'      => \Elementor\Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .progressbar-wrapper .progress' => 'background-color: {{VALUE}}'
			],
		] );

		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'progress_active',
				'label' => esc_html__( 'Background', 'quiety-core' ),
				'types' => [ 'classic', 'gradient' ],
				'exclude' => ['image'],
				'selector' => '{{WRAPPER}} .progressbar-wrapper .progress-bar',
			]
		);

		$this->end_controls_section();
	}

	protected function render() {
		$settings       = $this->get_settings_for_display();
		$starting_year  = $settings['year'];
		$starting_month = $settings['month'];
		$starting_day   = $settings['day'];


		require __DIR__ . '/templates/countdown/countdown.php';
	}

}
