<?php

namespace Quiety\Widgets;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Elementor\{Controls_Manager,
	Group_Control_Background,
	Group_Control_Border,
	Group_Control_Box_Shadow,
	Widget_Base,
	Repeater,
	Group_Control_Typography,
	Icons_Manager};


class Quiety_Counter extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve alert widget name.
	 *
	 * @return string Widget name.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_name() {
		return 'tt-counter';
	}


	public function get_title() {
		return __( 'Quiety Counter', 'quiety-core' );
	}

	public function get_icon() {
		return 'eicon-counter';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the widget categories.
	 *
	 * @return array Widget categories.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_categories() {
		return [ 'tt-elements' ];
	}

	public function get_script_depends() {
		return [
			'countUp',
			'appear-js'
		];
	}

	protected function register_controls() {

		$this->start_controls_section( 'section_content', [
			'label' => __( 'Counter Content', 'quiety-core' ),
		] );

		$this->add_control( 'style', [
			'label'   => __( 'Style', 'quiety-core' ),
			'type'    => Controls_Manager::SELECT,
			'default' => 'style-one',
			'options' => [
				'style-one' => __( 'Style One', 'quiety-core' ),
				'style-two' => __( 'Style Two', 'quiety-core' ),
				'style-three' => __( 'Style Three', 'quiety-core' ),
			],
		] );


		$this->add_control( 'count_title', [
			'label'       => __( 'Title', 'quiety-core' ),
			'type'        => Controls_Manager::TEXT,
			'default'     => __( 'Completed Projects', 'quiety-core' ),
			'label_block' => true,
		] );

		$this->add_control( 'count_number', [
			'label'       => __( 'Counting Number', 'quiety-core' ),
			'type'        => Controls_Manager::TEXT,
			'default'     => __( '150', 'quiety-core' ),
			'label_block' => true,
		] );

		$this->add_control( 'suffix_before', [
			'label'       => __( 'Suffix Before', 'quiety-core' ),
			'type'        => Controls_Manager::TEXT,
		] );

		$this->add_control( 'suffix_after', [
			'label'       => __( 'Suffix After', 'quiety-core' ),
			'type'        => Controls_Manager::TEXT,
			'default'     => '+',
		] );

		$this->add_control( 'count_description', [
			'label'       => __( 'Description', 'quiety-core' ),
			'type'        => Controls_Manager::TEXTAREA,
			'label_block' => true,
		] );

		$this->add_responsive_control( 'align', [
			'label'     => __( 'Alignment', 'quiety-core' ),
			'type'      => Controls_Manager::CHOOSE,
			'options'   => [
				'left'   => [
					'title' => __( 'Left', 'quiety-core' ),
					'icon'  => 'fa fa-align-left',
				],
				'center' => [
					'title' => __( 'Center', 'quiety-core' ),
					'icon'  => 'fa fa-align-center',
				],
				'right'  => [
					'title' => __( 'Right', 'quiety-core' ),
					'icon'  => 'fa fa-align-right',
				]
			],
			'default'   => 'left',
			'selectors' => [
				'{{WRAPPER}} .tt-countdown' => 'text-align: {{VALUE}};',
			],

		] );

		$this->end_controls_section();

		// Countdown Style
		//============================
		$this->start_controls_section( 'countdown_section', [
			'label' => __( 'Countdown Number', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_control( 'counter_color', [
			'label'     => esc_html__( 'Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-countdown__number' => 'color: {{VALUE}};',
			],
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'counter_typography',
			'label'    => __( 'Typography', 'quiety-core' ),
			'selector' => '{{WRAPPER}} .tt-countdown__number',
		] );

		$this->end_controls_section();

		// Title Style
		//============================

		$this->start_controls_section( 'title_section', [
			'label' => __( 'Title', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_control( 'counter_title_color', [
			'label'     => esc_html__( 'Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-countdown__title' => 'color: {{VALUE}};',
			],
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'counter_title_typography',
			'label'    => __( 'Title Typography', 'quiety-core' ),
			'selector' => '{{WRAPPER}} .tt-countdown__title',
		] );

		$this->add_control(
			'title_bottom_spacing',
			[
				'label' => __( 'Width', 'plugin-domain' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
						'step' => 1,
					]
				],

				'selectors' => [
					'{{WRAPPER}} .tt-countdown__number' => 'margin-bottom: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section( 'section_style_description', [
			'label' => __( 'Description', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_control( 'description_color', [
			'label'     => esc_html__( 'Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-countdown__description' => 'color: {{VALUE}};',
			],
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'description_typography',
			'label'    => __( 'Typography', 'quiety-core' ),
			'selector' => '{{WRAPPER}} .tt-countdown__description',
		] );

		$this->end_controls_section();

		$this->start_controls_section( 'section_style_box', [
			'label' => __( 'Box Container', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'background',
				'label' => __( 'Background', 'quiety-core' ),
				'types' => [ 'classic', 'gradient', 'video' ],
				'selector' => '{{WRAPPER}} .tt-countdown',
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'border',
				'label' => __( 'Border', 'quiety-core' ),
				'selector' => '{{WRAPPER}} .tt-countdown',
			]
		);

		$this->add_control(
			'box_border_radius',
			[
				'label' => __( 'Border Radius', 'quiety-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .tt-countdown' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'box_shadow',
				'label' => __( 'Box Shadow', 'quiety-core' ),
				'selector' => '{{WRAPPER}} .tt-countdown',
			]
		);

		$this->add_control(
			'padding',
			[
				'label' => __( 'Padding', 'quiety-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .tt-countdown' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_control( 'box_translate_hover', [
			'label'      => __( 'Hover Translate (Y)', 'quiety-core' ),
			'type'       => Controls_Manager::SLIDER,
			'size_units' => 'px',
			'range'      => [
				'px' => [
					'min'  => - 50,
					'max'  => 100,
					'step' => 1,
				],
			],
			'selectors'  => [
				'{{WRAPPER}} .tt-countdown:hover' => 'transform: translateY({{SIZE}}{{UNIT}});',
			],
		] );

		$this->end_controls_section();

	}

	protected function render() {
		$settings = $this->get_settings_for_display();
		$align    = $settings['align'];
		$style    = $settings['style'];

		?>
			<div class="tt-countdown <?php echo esc_attr($style  ); ?>">
				<?php if ( ! empty( $settings['count_number'] ) ) :  ?>
					<div class="tt-countdown__number">
						<?php if ( ! empty( $settings['suffix_before'] )):  ?>
							<span class="suffix">
								<?php echo $settings['suffix_before']; ?>
							</span>
						<?php endif; ?>

						<span class="counter" data-counter="<?php echo esc_attr( $settings['count_number'] ) ?>">
							<?php echo $settings['count_number']; ?>
						</span>

						<?php if( ! empty( $settings['suffix_after'] )) : ?>
							<span class="suffix"><?php echo $settings['suffix_after']; ?></span>
						<?php endif; ?>
					</div>
					<!-- /.counter-wrap -->
				<?php endif; ?>
				<div class="count-info-wrapper">
					<?php if ( ! empty( $settings['count_title'] ) ) :  ?>
						<h3 class="tt-countdown__title"><?php echo $settings['count_title']; ?></h3>
					<?php endif; ?>

					<?php if ( ! empty( $settings['count_description'] ) ) :  ?>
						<p class="tt-countdown__description"><?php echo $settings['count_description']; ?></p>
					<?php endif; ?>
				</div>
				<!-- /.count-info-wrapper -->

			</div>
		<?php

	}
}

