<?php
namespace Quiety\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * Event Schedule Tabs
 */
class quiety_event_schedule extends Widget_Base {

    public function get_name() {
        return 'quiety_event_schedule';
    }

    public function get_title() {
        return __( 'Event Schedule Tabs', 'saasland-core' );
    }

    public function get_icon() {
        return 'eicon-calendar';
    }

    public function get_categories() {
        return [ 'tt-elements' ];
    }

    public function get_style_depends() {
        return [ 'event-schedule' ];
    }

    protected function register_controls() {
        $this->register_content();
        $this->register_style();
    }

    /**
     * @return void
     * Register contents tab fields
     */
    public function register_content() {

        // ------------------------------------------- Event Schedule list -----------------------------------------
        $this->start_controls_section(
            'event_schedule_sec', [
                'label' => __( 'Event Schedule', 'saasland-core' ),
            ]
        );

        $repeater = new \Elementor\Repeater();
        $repeater->add_control(
            'tab_title', [
                'label' => __( 'Schedule Title', 'saasland-core' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'speaker_img', [
                'label' => __( 'Speaker Image', 'saasland-core' ),
                'type' => Controls_Manager::MEDIA,
            ]
        );

        $repeater->add_control(
            'name', [
                'label' => __( 'Name', 'saasland-core' ),
                'type' => Controls_Manager::TEXT,
                'default' => 'Thorsten Gerber'
            ]
        );

        $repeater->add_control(
            'designation', [
                'label' => __( 'Designation', 'saasland-core' ),
                'type' => Controls_Manager::TEXT,
                'default' => 'Creative Director'
            ]
        );

        $repeater->add_control(
            'title', [
                'label' => __( 'Event Title', 'saasland-core' ),
                'type' => Controls_Manager::TEXTAREA,
                'label_block' => true,
                'default' => 'Registration & Breakfast',
                'separator' => 'before'
            ]
        );

        $repeater->add_control(
            'contents', [
                'label' => __( 'Contents', 'saasland-core' ),
                'type' => Controls_Manager::TEXTAREA,
            ]
        );

        $this->add_control(
            'event_tabs', [
                'label' => __( 'Tabs', 'saasland-core' ),
                'type' => Controls_Manager::REPEATER,
                'prevent_empty' => false,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ tab_title }}}',
            ]
        );

        $this->end_controls_section(); //End Event Schedule

    }


    /**
     * @return void
     * Register style tab fields
     */
    public function register_style() {

        //-------------------------------- Tab Title Style -----------------------------//
        $this->start_controls_section(
            'tab_title_style', [
                'label' => __( 'Tab Title', 'saasland-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        //---------------------------- Normal and Hover ---------------------------//
        $this->start_controls_tabs(
            'style_tabs_title'
        );

        // Normal Color
        $this->start_controls_tab(
            'normal_tabs_title_style', [
                'label' => __( 'Normal', 'saasland-core' ),
            ]
        );

        $this->add_control(
            'normal_tab_title_text_color', [
                'label' => __( 'Text Color', 'saasland-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ev-schedule ul li .nav-link' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'normal_tab_title_bg_color', [
                'label' => __( 'Background Color', 'saasland-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ev-schedule ul li .nav-link' => 'background: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'normal_tab_title_border_color', [
                'label' => __( 'Border Color', 'saasland-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ev-schedule ul li .nav-link' => 'border-color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_tab();


        // Hover Color
        $this->start_controls_tab(
            'hover_tabs_title_style', [
                'label' => __( 'Active', 'saasland-core' ),
            ]
        );

        $this->add_control(
            'hover_tab_title_text_color', [
                'label' => __( 'Text Color', 'saasland-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ev-schedule ul li .nav-link.active' => 'color: {{VALUE}}',
                ]
            ]
        );

        $this->add_control(
            'hover_tab_title_bg_color', [
                'label' => __( 'Background Color', 'saasland-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ev-schedule ul li .nav-link.active' => 'background: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'hover_tab_title_border_color', [
                'label' => __( 'Border Color', 'saasland-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .ev-schedule ul li .nav-link.active' => 'border-color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section(); //End Event Title
    }


    protected function render() {
        $settings = $this->get_settings();
        $event_tabs = !empty($settings['event_tabs']) ? $settings['event_tabs'] : '';
        $cats       = array_column( $event_tabs, 'tab_title' );
        $getCats    = array_unique( $cats );
        $tab_data   = Quiety_Core_Helper()->return_tab_data( $getCats , $event_tabs );
        ?>
        <section class="event_schedule_area">
            <div class="ev-schedule mt--50 ptb-100 rounded-top">
                <div class="row justify-content-center">
                    <div class="col-lg-6">
                        <div class="text-center ev-schedule-btn mb-5">
                            <ul class="nav list-unstyled d-flex justify-content-center" id="pills-tab" role="tablist">
                                <?php
                                if ( is_array( $event_tabs )) {
                                    $i = 1;
                                    foreach ( $getCats as $cat ){
                                        $catForFilter = sanitize_title_with_dashes( $cat );
                                        $catForFilter = str_replace( '-', '', $catForFilter );
                                        $active = $i == 1 ? ' active' : '';
                                        $aria_selected = $i == 1 ? 'true' : 'false';
                                        ?>
                                        <li class="nav-item mb-3 mb-lg-0" role="presentation">
                                            <button class="nav-link<?php echo esc_attr($active) ?>" id="pills-<?php echo esc_attr($catForFilter) ?>-tab" data-bs-toggle="pill"
                                                data-bs-target="#pills-<?php echo esc_attr($catForFilter) ?>" type="button" role="tab"
                                                aria-controls="pills-<?php echo esc_attr($catForFilter) ?>" aria-selected="<?php echo esc_attr($aria_selected) ?>">
                                                <?php echo esc_html($cat) ?>
                                            </button>
                                        </li>
                                        <?php
                                        ++$i;
                                    }
                                }
                                ?>
                            </ul>
                        </div>
                    </div>
                </div>
                <div class="row justify-content-center">
                    <div class="col-lg-10">
                        <div class="tab-content" id="pills-tabContent">
                            <?php
                            if ( !empty( $tab_data ) ){
                                $i = 0;
                                foreach ($tab_data as $key => $val) {
                                    $tagforfilter = sanitize_title_with_dashes($key);
                                    $catForFilter = str_replace( '-', '', $tagforfilter );
                                    $i++;
                                    $active = $i == 1 ? ' active show' : '';
                                    ?>
                                    <div class="tab-pane fade<?php echo esc_attr($active) ?>" id="pills-<?php echo esc_attr($catForFilter) ?>" role="tabpanel" aria-labelledby="pills-<?php echo esc_attr($catForFilter) ?>-tab">
                                        <?php
                                        foreach ( $val as $data ) {
                                            ?>
                                            <div class="single-eve-session py-5 rounded px-4 px-lg-0 mb-4">
                                                <div class="row align-items-center">
                                                    <div class="col-lg-3">
                                                        <div class="text-lg-center speaker-info mb-3 mb-lg-0 py-3 md-py-0">
                                                            <?php
                                                            if ( !empty( $data['speaker_img']['id'] ) ) {
                                                                echo wp_get_attachment_image( $data['speaker_img']['id'], 'full', '', array( 'class' => 'mb-3' ) );
                                                            }
                                                            if ( !empty( $data['name'] ) ) { ?>
                                                                <h5 class="h6 m-0 name"><?php echo esc_html($data['name']) ?></h5>
                                                                <?php
                                                            }
                                                            if ( !empty( $data['designation'] ) ) { ?>
                                                                <span class="small designation"><?php echo esc_html($data['designation']) ?></span>
                                                                <?php
                                                            }
                                                            ?>
                                                        </div>
                                                    </div>
                                                    <div class="col-lg-9">
                                                        <div class="single-ev px-lg-4">
                                                            <?php
                                                            if ( !empty( $data['title'] ) ) { ?>
                                                                <h5 class="mb-3 h6 title"><?php echo esc_html($data['title']) ?></h5>
                                                                <?php
                                                            }
                                                            if ( !empty( $data['contents'] ) ) { ?>
                                                                <p class="mb-3 contents"><?php echo esc_html($data['contents']) ?></p>
                                                                <?php
                                                            }
                                                            ?>
                                                        </div>
                                                    </div>
                                                </div>
                                            </div>
                                            <?php
                                        }
                                        ?>
                                    </div>
                                    <?php
                                }
                            }
                            ?>
                        </div>
                    </div>
                </div>
                    <ul class="circel-shape list-unstyled d-none d-lg-block mb-0">
                        <li></li>
                        <li></li>
                        <li></li>
                    </ul>
                </div>
        </section>
        <?php
    }
}