<?php

namespace Quiety\Widgets;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Repeater;
use Elementor\Widget_Base;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly

class Quiety_Faq_List extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve alert widget name.
	 *
	 * @return string Widget name.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_name() {
		return 'tt-faq-list';
	}


	public function get_title() {
		return __( 'Faq List', 'quiety-core' );
	}

	public function get_icon() {

		return 'eicon-bullet-list';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the widget categories.
	 *
	 * @return array Widget categories.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_categories() {
		return [ 'tt-elements' ];
	}

	protected function register_controls() {

		$this->start_controls_section( 'faq_content', [
			'label' => __( 'Faq', 'quiety-core' ),
		] );


		$repeater = new Repeater();

		$repeater->add_control(
			'icon_type',
			[
				'label' => __( 'Number/Icon', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'number',
				'options' => [
					'none' => __( 'None', 'quiety-core' ),
					'number'  => __( 'Number', 'quiety-core' ),
					'icons' => __( 'Icon', 'quiety-core' ),
				],
			]
		);

		$repeater->add_control(
			'faq_icon',
			[
				'label' => __( 'Icon', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::ICONS,
				'default' => [
					'value' => 'fas fa-star',
					'library' => 'solid',
				],
				'condition' => ['icon_type'=> 'icons']
			]
		);

		$repeater->add_control( 'number', [
			'label'       => __( 'Number', 'quiety-core' ),
			'type'        => Controls_Manager::TEXT,
			'condition' => ['icon_type'=> 'number']
		] );

		$repeater->add_control( 'question', [
			'label'       => __( 'Question', 'quiety-core' ),
			'type'        => Controls_Manager::TEXT,
			'label_block' => true,
		] );

		$repeater->add_control( 'answer', [
			'label'       => __( 'Answer', 'quiety-core' ),
			'type'        => Controls_Manager::TEXTAREA,
			'label_block' => true,
		] );


		$this->add_control( 'faq_lists', [
			'label'       => __( 'Faq List', 'quiety-core' ),
			'type'        => Controls_Manager::REPEATER,
			'fields'      => $repeater->get_controls(),
			'default'     => [
				[
					'question'    => __( ' How does back pricing work?', 'quiety-core' ),
					'answer' => __( 'Progressively e-enable collaborative inexpensive supply chains. Efficiently maintain economically methods of empowerment for synergistic sound scenarios.', 'quiety-core' ),
				],
				[
					'question'    => __( 'How do I calculate how much price?', 'quiety-core' ),
					'answer' => __( 'Globally benchmark customized mindshare before clicks-and-mortar partnerships. Efficiently maintain economically sound scenarios and whereas client-based progressively.', 'quiety-core' ),
				],
				[
					'question'    => __( 'Can you show me an example?', 'quiety-core' ),
					'answer' => __( 'Dynamically visualize whereas competitive relationships. Progressively benchmark customized partnerships generate interdependent benefits rather sound scenarios and robust alignments.', 'quiety-core' ),
				],
			],
			'title_field' => '{{{ question }}}',
		] );


		$this->end_controls_section();

		$this->start_controls_section( 'social_style_section', [
			'label' => __( 'Style', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );


		$this->add_control( 'question_color', [
			'label'     => __( 'Question Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-faq-list .tt-faq-list__title' => 'color: {{VALUE}}',
			],
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'question_typography',
			'label'    => __( 'Faq Typography', 'quiety-core' ),
			'selector' => '{{WRAPPER}} .tt-faq-list .tt-faq-list__title',
		] );

		$this->add_control( 'ans_color', [
			'label'     => __( 'Faq Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-faq-list .tt-faq-list__answer' => 'color: {{VALUE}}',
			],
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'ans_typography',
			'label'    => __( 'Faq Typography', 'quiety-core' ),
			'selector' => '{{WRAPPER}} .tt-faq-list .tt-faq-list__answer',
		] );


		$this->end_controls_section();

	}

	protected function render() {
		$settings = $this->get_settings_for_display();

		if ( $settings['faq_lists'] ) { ?>
			<?php foreach ( $settings['faq_lists'] as $item ) { ?>
				<div class="tt-faq-list <?php  echo $item['icon_type'] == 'icons' ? 'left-icon' : '' ;?>">

					<?php if ( $item['icon_type'] == 'icons') : ?>
						<?php \Elementor\Icons_Manager::render_icon( $item['faq_icon'], [ 'aria-hidden' => 'true' ] ); ?>
					<?php endif; ?>

					<div class="tt-faq-list-content">
						<?php if ( ! empty( $item['question'] ) ) : ?>
							<h4 class="tt-faq-list__title">
								<?php if ( $item['icon_type'] == 'number' ) : ?>
									<span class="tt-faq-list__number"><?php echo esc_html($item['number']) ?></span>
								<?php endif; ?>

								<?php echo $item['question']; ?>
							</h4>
						<?php endif; ?>

						<?php if ( ! empty( $item['answer'] ) ) : ?>
							<p class="tt-faq-list__answer"><?php echo $item['answer']; ?></p>
						<?php endif; ?>
					</div>
					<!-- /.tt-faq-list-content -->
				</div>
			<?php }

		}
	}

}