<?php

namespace Quiety\Widgets;

defined( 'ABSPATH' ) || exit; // Abort, if called directly.

use Elementor\{Group_Control_Border,
	Group_Control_Box_Shadow,
	Widget_Base,
	Controls_Manager,
	Group_Control_Typography,
	Group_Control_Background,
	Utils,
	Repeater
};

class Quiety_Hero extends Widget_Base {

	public function get_name() {
		return 'tt-hero-static';
	}

	public function get_title() {
		return __( 'Quiety Hero', 'quiety-core' );
	}

	public function get_icon() {
		return 'eicon-photo-library';
	}

	public function get_script_depends() {
		return ['jquery-parallax', ''];
	}

	public function get_categories() {
		return [ 'tt-elements' ];
	}

    /**
     * Name: register_controls
     * Desc: Register controls for these widgets
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @quiety
     * Author: Themetags
     */
    protected function register_controls() {
        $this-> elementor_content_control();
        $this-> elementor_style_control();
    }

    /**
     * Name: quiety_elementor_content_control
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @quiety
     * Author: Themetags
     */
    public function elementor_content_control() {

        //====================== Hero Layout =======================//
        $this->start_controls_section( 'section_hero', [
            'label' => __( 'Quiety Hero Static', 'quiety-core' ),
        ] );

        $this->add_control( 'layout', [
            'label'   => esc_html__( 'Layout', 'quiety-core' ),
            'type'    => Controls_Manager::SELECT,
            'options' => [
                '1' => esc_html__( 'Layout 1', 'quiety-core' ),
                '2' => esc_html__( 'Layout 2', 'quiety-core' ),
                '3' => esc_html__( 'Layout 3', 'quiety-core' ),
                '4' => esc_html__( 'Layout 4', 'quiety-core' ),
                '5' => esc_html__( 'Layout 5', 'quiety-core' ),
                '6' => esc_html__( 'Layout 6', 'quiety-core' ),
                '7' => esc_html__( 'Layout 7', 'quiety-core' ),
                '8' => esc_html__( 'Layout 8', 'quiety-core' ),
                '9' => esc_html__( 'Layout 9', 'quiety-core' ),
            ],
            'default' => '1',
        ] );

        $this->end_controls_section(); //End Hero Layout


        //========================= Contents ===========================//
        $this->start_controls_section( 'section_content', [
            'label' => esc_html__( 'Contents', 'quiety-core' ),
        ] );

        $this->add_control( 'subtitle', [
            'label'       => __( 'Sub Title', 'quiety-core' ),
            'type'        => Controls_Manager::TEXT,
            'label_block' => true,
            'description' => __( "Type your title here.", 'quiety-core' ),
            'condition'   => [
                'layout!' => [ '9']
            ]
        ] );

        $this->add_control( 'title', [
            'label'       => __( 'Title', 'quiety-core' ),
            'type'        => Controls_Manager::TEXTAREA,
            'default'     => __( 'Get Fully Control and Visibility your Company', 'quiety-core' ),
            'label_block' => true,
            'description' => __( "Type banner title here.", 'quiety-core' ),

        ] );

        $this->add_control( 'description', [
            'label'       => __( 'Description', 'quiety-core' ),
            'type'        => Controls_Manager::TEXTAREA,
            'default'     => __( 'Proactively coordinate quality quality vectors vis-a-vis supply chains. Quickly engage client-centric web services.', 'quiety-core' ),
            'label_block' => true,
        ] );

        $this->end_controls_section(); // End Contents


        // ===================== Buttons ================//
        $this->start_controls_section( 'button_section', [
            'label' => esc_html__( 'Button', 'quiety-core' ),
        ] );

        $this->add_control( 'btn_text', [
            'label'       => __( 'Button Label', 'quiety-core' ),
            'type'        => Controls_Manager::TEXT,
            'placeholder' => __( 'Type your button label here', 'quiety-core' ),
            'default'     => __( 'Request For Demo', 'quiety-core' ),
        ] );

        $this->add_control( 'btn_link', [
            'label'       => __( 'Button Link', 'quiety-core' ),
            'type'        => Controls_Manager::URL,
            'placeholder' => __( 'https://your-link.com', 'quiety-core' ),
            'default'     => [
                'url' => '#',
            ],
        ] );

        $this->add_control( 'play_btn_text', [
            'label'       => __( 'Play Button Label', 'quiety-core' ),
            'type'        => Controls_Manager::TEXT,
            'placeholder' => __( 'Type your button label here', 'quiety-core' ),
            'default'     => __( 'How It Works', 'quiety-core' ),
            'condition'   => [
                'layout' => ['1', '6', '7']
            ],
            'separator'   => 'before'
        ] );

        $this->add_control( 'play_btn_link', [
            'label'       => __( 'Play Button Link', 'quiety-core' ),
            'type'        => Controls_Manager::URL,
            'placeholder' => __( 'https://your-link.com', 'quiety-core' ),
            'default'     => [
                'url' => '#',
            ],
            'condition'   => [
                'layout' => [ '1', '6', '7', '8', '9' ]
            ],
        ] );

        $this->add_control(
            'secondary_button_options', [
                'label' => __( 'Secondary Button', 'quiety-core' ),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_control( 'sec_btn_text', [
            'label'       => __( 'Secondary Button Label', 'quiety-core' ),
            'type'        => Controls_Manager::TEXT,
            'placeholder' => __( 'Type your button label here', 'quiety-core' ),
            'default'     => __( 'How It Works', 'quiety-core' ),
            'condition'   => [
                'layout' => ['2', '4', '8']
            ],
        ] );

        $this->add_control( 'sec_btn_link', [
            'label'       => __( 'Secondary Button Link', 'quiety-core' ),
            'type'        => Controls_Manager::URL,
            'placeholder' => __( 'https://your-link.com', 'quiety-core' ),
            'default'     => [
                'url' => '#',
            ],
            'condition'   => [
                'layout' => ['2', '4', '8']
            ],
        ] );

        $this->end_controls_section(); //End Buttons


        //================== Brand Logo =================//
        $this->start_controls_section( 'brand_logo_section', [
            'label' => __( 'Brand Logo', 'quiety-core' ),
            'tab'   => Controls_Manager::TAB_CONTENT,
            'condition' => [
                'layout' => ['1', '3', '4', '7']
            ]
        ] );

        $this->add_control(
            'show_brand_logo', [
                'label' => esc_html__( 'Show Brand Logo', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Show', 'your-plugin' ),
                'label_off' => esc_html__( 'Hide', 'your-plugin' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_responsive_control(
            'logo_spacing', [
                'label' => __( 'Spacing (Margin Top)', 'plugin-domain' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 200,
                        'step' => 5,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .banner__brand-logo-wrapper' => 'margin-top: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control( 'brand_title', [
            'label'       => __( 'Title', 'quiety-core' ),
            'type'        => Controls_Manager::TEXT,
            'default' => __('Our Top Clients:', 'quiety-core'),
            'label_block' => true,
        ] );

        $repeater = new Repeater();

        $repeater->add_control( 'brand_name', [
            'label'       => __( 'Brand Title', 'quiety-core' ),
            'type'        => Controls_Manager::TEXT,
            'label_block' => true,
        ] );

        $repeater->add_control( 'brand_image', [
            'label'   => __( 'Choose Image', 'quiety-core' ),
            'type'    => Controls_Manager::MEDIA,
            'default' => [
                'url' => Utils::get_placeholder_image_src(),
            ],
        ] );


        $this->add_control( 'logo_lists', [
            'label'       => __( 'Logo List', 'quiety-core' ),
            'type'        => Controls_Manager::REPEATER,
            'fields'      => $repeater->get_controls(),
            'default'     => [
                [
                    'brand_name'  => __( 'Brand #1', 'quiety-core' ),
                    'brand_image' => [
                        'url' => Utils::get_placeholder_image_src(),
                    ]
                ],
                [
                    'brand_name'  => __( 'Brande #2', 'quiety-core' ),
                    'brand_image' => [
                        'url' => Utils::get_placeholder_image_src(),
                    ]
                ],
                [
                    'brand_name'  => __( 'Brande #2', 'quiety-core' ),
                    'brand_image' => [
                        'url' => Utils::get_placeholder_image_src(),
                    ]
                ],
            ],
            'title_field' => '{{{ brand_name }}}',
        ] );

        $this->end_controls_section();


        // ===================== Feature Image ===================//
        $this->start_controls_section( 'feature_image_section', [
            'label' => __( 'Featured Image', 'quiety-core' ),
        ] );

        $this->add_control( 'feature_image', [
            'label'   => __( 'Choose Image', 'quiety-core' ),
            'type'    => Controls_Manager::MEDIA,
            'default' => [
                'url' => plugin_dir_url( __DIR__ ) . 'assets/images/banner/banner1.png'
            ],
            'condition' => [
                'layout' => [ '1', '8', '9' ]
            ]
        ] );

        $this->add_control(
            'feature_shape', [
                'label' => __( 'Show Shape Image', 'quiety-core' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'quiety-core' ),
                'label_off' => __( 'Hide', 'quiety-core' ),
                'return_value' => 'yes',
                'default' => 'yes',
                'condition' => [
                    'layout' => [ '1', '2', '3', '4', '5', '6', '7' ]
                ]
            ]
        );

        $this->add_control( 'feature_image_shape', [
            'label'   => __( 'Bg Shape Image', 'quiety-core' ),
            'type'    => Controls_Manager::MEDIA,
            'condition' => [
                'layout' => '1',
                'feature_shape' => 'yes'
            ]
        ] );

        $this->add_control( 'feature_image_two', [
            'label'     => __( 'Choose Image', 'quiety-core' ),
            'type'      => Controls_Manager::MEDIA,
            'default'   => [
                'url' => plugin_dir_url( __DIR__ ) . 'assets/images/banner2.png'
            ],
            'condition' => [
                'layout' => '2'
            ]
        ] );

        $this->add_control( 'feature_image_three', [
            'label'     => __( 'Choose Image', 'quiety-core' ),
            'type'      => Controls_Manager::MEDIA,
            'default'   => [
                'url' => plugin_dir_url( __DIR__ ) . 'assets/images/banner3.png'
            ],
            'condition' => [
                'layout' => '3'
            ]
        ] );

        $this->add_control( 'feature_image_four', [
            'label'     => __( 'Choose Image', 'quiety-core' ),
            'type'      => Controls_Manager::MEDIA,
            'default'   => [
                'url' => plugin_dir_url( __DIR__ ) . 'assets/images/banner4.png'
            ],
            'condition' => [
                'layout' => '4'
            ]
        ] );

        $this->add_control( 'feature_image_five', [
            'label'     => __( 'Choose Image', 'quiety-core' ),
            'type'      => Controls_Manager::MEDIA,
            'default'   => [
                'url' => plugin_dir_url( __DIR__ ) . 'assets/images/banner5.png'
            ],
            'condition' => [
                'layout' => '5'
            ]
        ] );

        $this->add_control( 'feature_image_six', [
            'label'     => __( 'Choose Image', 'quiety-core' ),
            'type'      => Controls_Manager::MEDIA,
            'default'   => [
                'url' => plugin_dir_url( __DIR__ ) . 'assets/images/banner/banner_image.png'
            ],
            'condition' => [
                'layout' => '6'
            ]
        ] );

        $this->add_control( 'feature_image_seven', [
            'label'     => __( 'Choose Image', 'quiety-core' ),
            'type'      => Controls_Manager::MEDIA,
            'default'   => [
                'url' => plugin_dir_url( __DIR__ ) . 'assets/images/banner/banner7.png'
            ],
            'condition' => [
                'layout' => '7'
            ]
        ] );

        $this->add_control( 'feature_image_three_secondary', [
            'label'     => __( 'Choose Image', 'quiety-core' ),
            'type'      => Controls_Manager::MEDIA,
            'default'   => [
                'url' => plugin_dir_url( __DIR__ ) . 'assets/images/banner/phone-screen.png'
            ],
            'condition' => [
                'layout' => '3'
            ]
        ] );

        $this->add_control(
            'show_parallax_image', [
                'label' => __( 'Show Parallax Image', 'quiety-core' ),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'quiety-core' ),
                'label_off' => __( 'Hide', 'quiety-core' ),
                'return_value' => 'yes',
                'default' => 'yes',
                'condition' => [
                    'layout' => [ '1', '2', '3', '4', '5', '6', '7' ]
                ]
            ]
        );


        //======================= Multi Feature Image ===============================//
        $repeater = new Repeater();
        $repeater->add_control( 'image_one', [
            'label' => __( 'Choose Image', 'quiety-core' ),
            'type'  => Controls_Manager::MEDIA,
        ] );

        $repeater->add_responsive_control( 'animation_name', [
            'label'   => esc_html__( 'Animation', 'quiety-core' ),
            'type'    => Controls_Manager::SELECT2,
            'default' => 'fadeIn',
            'options' => [
                ''                   => 'none',
                'bounce'             => 'bounce',
                'ttfadeInUp'         => 'ttfadeInUp',
                'ttfadeInDown'       => 'ttfadeInDown',
                'flash'              => 'flash',
                'pulse'              => 'pulse',
                'rubberBand'         => 'rubberBand',
                'shake'              => 'shake',
                'swing'              => 'swing',
                'tada'               => 'tada',
                'wobble'             => 'wobble',
                'jello'              => 'jello',
                'bounceIn'           => 'bounceIn',
                'bounceInDown'       => 'bounceInDown',
                'bounceInUp'         => 'bounceInUp',
                'bounceOut'          => 'bounceOut',
                'bounceOutDown'      => 'bounceOutDown',
                'bounceOutLeft'      => 'bounceOutLeft',
                'bounceOutRight'     => 'bounceOutRight',
                'bounceOutUp'        => 'bounceOutUp',
                'fadeIn'             => 'fadeIn',
                'fadeInDown'         => 'fadeInDown',
                'fadeInDownBig'      => 'fadeInDownBig',
                'fadeInLeft'         => 'fadeInLeft',
                'fadeInRight'        => 'fadeInRight',
                'fadeInLeftBig'      => 'fadeInLeftBig',
                'fadeInRightBig'     => 'fadeInRightBig',
                'fadeInUp'           => 'fadeInUp',
                'fadeInUpBig'        => 'fadeInUpBig',
                'fadeOut'            => 'fadeOut',
                'fadeOutDownBig'     => 'fadeOutDownBig',
                'fadeOutLeft'        => 'fadeOutLeft',
                'fadeOutLeftBig'     => 'fadeOutLeftBig',
                'fadeOutRightBig'    => 'fadeOutRightBig',
                'fadeOutUp'          => 'fadeOutUp',
                'fadeOutUpBig'       => 'fadeOutUpBig',
                'flip'               => 'flip',
                'flipInX'            => 'flipInX',
                'flipInY'            => 'flipInY',
                'flipOutX'           => 'flipOutX',
                'flipOutY'           => 'flipOutY',
                'fadeOutDown'        => 'fadeOutDown',
                'lightSpeedIn'       => 'lightSpeedIn',
                'lightSpeedOut'      => 'lightSpeedOut',
                'rotateIn'           => 'rotateIn',
                'rotateInDownLeft'   => 'rotateInDownLeft',
                'rotateInDownRight'  => 'rotateInDownRight',
                'rotateInUpLeft'     => 'rotateInUpLeft',
                'rotateInUpRight'    => 'rotateInUpRight',
                'rotateOut'          => 'rotateOut',
                'rotateOutDownLeft'  => 'rotateOutDownLeft',
                'rotateOutDownRight' => 'rotateOutDownRight',
                'rotateOutUpLeft'    => 'rotateOutUpLeft',
                'rotateOutUpRight'   => 'rotateOutUpRight',
                'slideInUp'          => 'slideInUp',
                'slideInDown'        => 'slideInDown',
                'slideInLeft'        => 'slideInLeft',
                'slideInRight'       => 'slideInRight',
                'slideOutUp'         => 'slideOutUp',
                'slideOutDown'       => 'slideOutDown',
                'slideOutLeft'       => 'slideOutLeft',
                'slideOutRight'      => 'slideOutRight',
                'zoomIn'             => 'zoomIn',
                'zoomInDown'         => 'zoomInDown',
                'zoomInLeft'         => 'zoomInLeft',
                'zoomInRight'        => 'zoomInRight',
                'zoomInUp'           => 'zoomInUp',
                'zoomOut'            => 'zoomOut',
                'zoomOutDown'        => 'zoomOutDown',
                'zoomOutLeft'        => 'zoomOutLeft',
                'zoomOutUp'          => 'zoomOutUp',
                'hinge'              => 'hinge',
                'rollIn'             => 'rollIn',
                'rollOut'            => 'rollOut',
            ],
        ] );

        $repeater->add_control( 'animation_delay', [
            'label' => __( 'Animation Delay (ms)', 'quiety-core' ),
            'type'  => Controls_Manager::NUMBER,
            'min'   => 100,
            'max'   => 2000,
            'step'  => 100,
        ] );

        $repeater->add_control( 'parallax_factor', [
            'label'       => esc_html__( 'Parallax Factor', 'quiety-core' ),
            'type'        => Controls_Manager::NUMBER,
            'min'         => - 3,
            'max'         => 3,
            'step'        => 0.01,
            'default'     => '0.01',
            'description' => esc_html__( 'Set elements offset and speed. It can be positive (0.3) or negative (-0.3). Less means slower.', 'quiety-core' ),
        ] );


        $repeater->add_control( 'alt_text', [
            'label'       => __( 'Alt Text', 'quiety-core' ),
            'type'        => Controls_Manager::TEXT,
            'placeholder' => __( 'alt test', 'quiety-core' ),
            'default'     => __( 'Quiety', 'quiety-core' ),
        ] );

        $repeater->add_responsive_control( 'position_top', [
            'label'       => esc_html__( 'Top Offset', 'quiety-core' ),
            'type'        => Controls_Manager::SLIDER,
            'size_units'  => [ '%', 'px' ],
            'range'       => [
                '%'  => [ 'min' => - 100, 'max' => 100 ],
                'px' => [ 'min' => - 200, 'max' => 1000, 'step' => 5 ],
            ],
            'default'     => [ 'unit' => '%' ],
            'description' => esc_html__( 'Set figure vertical offset from top.', 'quiety-core' ),
            'selectors'   => [
                "{{WRAPPER}} .banner__image-lists {{CURRENT_ITEM}} .inner" => 'top: {{SIZE}}{{UNIT}} !important',
            ],
        ] );

        $repeater->add_responsive_control( 'position_left', [
            'label'       => esc_html__( 'Left Offset', 'quiety-core' ),
            'type'        => Controls_Manager::SLIDER,
            'size_units'  => [ '%', 'px' ],
            'range'       => [
                '%'  => [
                    'min' => - 100,
                    'max' => 100,
                ],
                'px' => [
                    'min'  => - 200,
                    'max'  => 1000,
                    'step' => 5,
                ],
            ],
            'default'     => [
                'unit' => '%',
            ],
            'description' => esc_html__( 'Set figure horizontal offset from left.', 'quiety-core' ),
            'selectors'   => [
                "{{WRAPPER}} .banner__image-lists {{CURRENT_ITEM}} .inner" => 'left: {{SIZE}}{{UNIT}}',
            ],
        ] );

        $repeater->add_responsive_control( 'wrapper_width', [
            'label'       => esc_html__( 'Image wrapper width', 'quiety-core' ),
            'type'        => Controls_Manager::SLIDER,
            'size_units'  => [ '%', 'px' ],
            'range'       => [
                '%'  => [ 'min' => 5, 'max' => 100 ],
                'px' => [ 'min' => 80, 'max' => 500, 'step' => 5 ],
            ],
            'default'     => [ 'unit' => 'px' ],
            'description' => esc_html__( 'Set Image wrapper max width.', 'quiety-core' ),
            'selectors'   => [
                "{{WRAPPER}} .banner__image-lists {{CURRENT_ITEM}} .inner" => 'width: {{SIZE}}{{UNIT}}',
            ],
        ] );

        $this->add_control( 'image_lists', [
            'label'       => __( 'Image List', 'quiety-core' ),
            'type'        => Controls_Manager::REPEATER,
            'fields'      => $repeater->get_controls(),
            'condition'   => [
                'layout' => ['2'],
                'show_parallax_image' => 'yes'
            ],
            'default'     => [
                [
                    'alt_text'  => __( 'Quiety #1', 'quiety-core' ),
                    'image_one' => [
                        'url' => plugin_dir_url( __DIR__ ) . 'assets/images/banner_p1.png'
                    ]
                ],
                [
                    'alt_text'  => __( 'Quiety #2', 'quiety-core' ),
                    'image_one' => [
                        'url' => plugin_dir_url( __DIR__ ) . 'assets/images/banner_p2.png'
                    ],
                ],

            ],
            'title_field' => '{{{ alt_text }}}',
        ] );


        $this->add_responsive_control( 'image_margin', [
            'label'      => __( 'Margin', 'quiety-core' ),
            'type'       => Controls_Manager::DIMENSIONS,
            'size_units' => [ 'px', '%', 'em' ],
            'selectors'  => [
                '{{WRAPPER}} .banner__feature-image' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
            'condition' => [
                'layout' => [ '1', '2', '3', '4', '5', '6', '7' ]
            ]
        ] );

        $this->end_controls_section();

        // Animated Image for Banner One
        // ================================
        $this->start_controls_section( 'parallax_image_section', [
            'label'     => esc_html__( 'Animated Image', 'quiety-core' ),
            'condition' => [
                'layout' => ['1', '4']
            ]
        ] );

        $this->add_control(
            'animate_element',
            [
                'label' => __( 'Show Shape Image', 'quiety-core' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'quiety-core' ),
                'label_off' => __( 'Hide', 'quiety-core' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control( 'parallax_image', [
            'label' => __( 'Choose Image', 'quiety-core' ),
            'type'  => Controls_Manager::MEDIA,
        ] );

        $repeater->add_responsive_control( 'animation_name', [
            'label'   => esc_html__( 'Animation', 'quiety-core' ),
            'type'    => Controls_Manager::SELECT2,
            'default' => 'fadeIn',
            'options' => [
                ''                   => 'none',
                'bounce'             => 'bounce',
                'flash'              => 'flash',
                'pulse'              => 'pulse',
                'shake'              => 'shake',
                'swing'              => 'swing',
                'bounceIn'           => 'bounceIn',
                'bounceInDown'       => 'bounceInDown',
                'bounceInUp'         => 'bounceInUp',
                'fadeIn'             => 'fadeIn',
                'fadeInDown'         => 'fadeInDown',
                'fadeInDownBig'      => 'fadeInDownBig',
                'fadeInLeft'         => 'fadeInLeft',
                'fadeInRight'        => 'fadeInRight',
                'fadeInLeftBig'      => 'fadeInLeftBig',
                'fadeInRightBig'     => 'fadeInRightBig',
                'fadeInUp'           => 'fadeInUp',
                'flip'               => 'flip',
                'flipInX'            => 'flipInX',
                'flipInY'            => 'flipInY',
                'flipOutX'           => 'flipOutX',
                'flipOutY'           => 'flipOutY',
                'fadeOutDown'        => 'fadeOutDown',
                'lightSpeedIn'       => 'lightSpeedIn',
                'lightSpeedOut'      => 'lightSpeedOut',
                'rotateIn'           => 'rotateIn',
                'zoomIn'             => 'zoomIn',
                'zoomInDown'         => 'zoomInDown',
                'zoomInLeft'         => 'zoomInLeft',
                'zoomInRight'        => 'zoomInRight',
                'zoomInUp'           => 'zoomInUp',
            ],
        ] );

        $repeater->add_control( 'animation_delay', [
            'label' => __( 'Animation Delay (ms)', 'quiety-core' ),
            'type'  => Controls_Manager::NUMBER,
            'min'   => 100,
            'max'   => 2000,
            'step'  => 100,
        ] );

        $repeater->add_control( 'parallax_factor', [
            'label'       => esc_html__( 'Parallax Factor', 'quiety-core' ),
            'type'        => Controls_Manager::NUMBER,
            'min'         => - 3,
            'max'         => 3,
            'step'        => 0.01,
            'default'     => '0.01',
            'description' => esc_html__( 'Set elements offset and speed. It can be positive (0.3) or negative (-0.3). Less means slower.', 'quiety-core' ),
        ] );

        $repeater->add_control( 'element_opacity', [
            'label'       => esc_html__( 'Opacity', 'quiety-core' ),
            'type'        => Controls_Manager::NUMBER,
            'min'         => 0,
            'max'         => 1,
            'step'        => 0.1,
            'default'     => '0.6',
            'description' => esc_html__( 'Set elements opacity.', 'quiety-core' ),
            'selectors'   => [
                "{{WRAPPER}} {{CURRENT_ITEM}} .inner" => 'opacity: {{SIZE}}',
            ],
        ] );

        $repeater->add_control( 'alt_text', [
            'label'       => __( 'Alt Text', 'quiety-core' ),
            'type'        => Controls_Manager::TEXT,
            'placeholder' => __( 'alt test', 'quiety-core' ),
            'default'     => __( 'Parallax', 'quiety-core' ),
        ] );

        $repeater->add_responsive_control( 'position_top', [
            'label'       => esc_html__( 'Top Offset', 'quiety-core' ),
            'type'        => Controls_Manager::SLIDER,
            'size_units'  => [ '%', 'px' ],
            'range'       => [
                '%'  => [ 'min' => - 100, 'max' => 100 ],
                'px' => [ 'min' => - 200, 'max' => 1000, 'step' => 5 ],
            ],
            'default'     => [ 'unit' => '%' ],
            'description' => esc_html__( 'Set figure vertical offset from top.', 'quiety-core' ),
            'selectors'   => [
                "{{WRAPPER}} {{CURRENT_ITEM}} .inner" => 'top: {{SIZE}}{{UNIT}}',
            ],
        ] );

        $repeater->add_responsive_control( 'position_left', [
            'label'       => esc_html__( 'Left Offset', 'quiety-core' ),
            'type'        => Controls_Manager::SLIDER,
            'size_units'  => [ '%', 'px' ],
            'range'       => [
                '%'  => [
                    'min' => - 100,
                    'max' => 100,
                ],
                'px' => [
                    'min'  => - 200,
                    'max'  => 1000,
                    'step' => 5,
                ],
            ],
            'default'     => [
                'unit' => '%',
            ],
            'description' => esc_html__( 'Set figure horizontal offset from left.', 'quiety-core' ),
            'selectors'   => [
                "{{WRAPPER}} {{CURRENT_ITEM}} .inner" => 'left: {{SIZE}}{{UNIT}}',
            ],
        ] );

        $repeater->add_responsive_control( 'wrapper_width', [
            'label'       => esc_html__( 'Image wrapper width', 'quiety-core' ),
            'type'        => Controls_Manager::SLIDER,
            'size_units'  => [ '%', 'px' ],
            'range'       => [
                '%'  => [ 'min' => 5, 'max' => 100 ],
                'px' => [ 'min' => 80, 'max' => 700, 'step' => 5 ],
            ],
            'default'     => [ 'unit' => 'px' ],
            'description' => esc_html__( 'Set Image wrapper max width.', 'quiety-core' ),
            'selectors'   => [
                "{{WRAPPER}} {{CURRENT_ITEM}} .inner" => 'width: {{SIZE}}{{UNIT}}',
            ],
        ] );

        $this->add_control( 'parallax_images', [
            'label'       => __( 'Image List', 'quiety-core' ),
            'type'        => Controls_Manager::REPEATER,
            'fields'      => $repeater->get_controls(),
            'condition'   => [
                'layout' => '1'
            ],
            'default'     => [
                [
                    'alt_text'  => __( 'Parallax', 'quiety-core' ),
                    'parallax_image' => [
                        'url' => plugin_dir_url( __DIR__ ) . 'assets/images/banner/circle-1.svg'
                    ]
                ],
                [
                    'alt_text'  => __( 'Parallax', 'quiety-core' ),
                    'parallax_image' => [
                        'url' => plugin_dir_url( __DIR__ ) . 'assets/images/banner/circle-1.svg'
                    ],
                ],
                [
                    'alt_text'  => __( 'Parallax', 'quiety-core' ),
                    'parallax_image' => [
                        'url' => plugin_dir_url( __DIR__ ) . 'assets/images/banner/circle-1.svg'
                    ],
                ],
                [
                    'alt_text'  => __( 'Parallax', 'quiety-core' ),
                    'parallax_image' => [
                        'url' => plugin_dir_url( __DIR__ ) . 'assets/images/banner/circle-1.svg'
                    ],
                ],
                [
                    'alt_text'  => __( 'Parallax', 'quiety-core' ),
                    'parallax_image' => [
                        'url' => plugin_dir_url( __DIR__ ) . 'assets/images/banner/circle-1.svg'
                    ],
                ],
                [
                    'alt_text'  => __( 'Parallax', 'quiety-core' ),
                    'parallax_image' => [
                        'url' => plugin_dir_url( __DIR__ ) . 'assets/images/banner/circle-1.svg'
                    ],
                ]
            ],
            'title_field' => '{{{ alt_text }}}',
        ] );

        $this->end_controls_section();


        // Animated Image for Banner Three
        // ================================
        $this->start_controls_section( 'parallax_image_three_section', [
            'label'     => esc_html__( 'Animated Image', 'quiety-core' ),
            'condition' => [
                'layout' => '3'
            ]
        ] );

        $this->add_control(
            'animate_element_two',
            [
                'label' => __( 'Show Shape Image', 'quiety-core' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'quiety-core' ),
                'label_off' => __( 'Hide', 'quiety-core' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control( 'parallax_image_two', [
            'label' => __( 'Choose Image', 'quiety-core' ),
            'type'  => Controls_Manager::MEDIA,
        ] );

        $repeater->add_control( 'animation_delay', [
            'label' => __( 'Animation Delay (ms)', 'quiety-core' ),
            'type'  => Controls_Manager::NUMBER,
            'min'   => 100,
            'max'   => 2000,
            'step'  => 100,
        ] );

        $repeater->add_control( 'parallax_factor', [
            'label'       => esc_html__( 'Parallax Factor', 'quiety-core' ),
            'type'        => Controls_Manager::NUMBER,
            'min'         => - 3,
            'max'         => 3,
            'step'        => 0.01,
            'default'     => '0.01',
            'description' => esc_html__( 'Set elements offset and speed. It can be positive (0.3) or negative (-0.3). Less means slower.', 'quiety-core' ),
        ] );

        $repeater->add_control( 'alt_text_two', [
            'label'       => __( 'Alt Text', 'quiety-core' ),
            'type'        => Controls_Manager::TEXT,
            'placeholder' => __( 'alt test', 'quiety-core' ),
            'default'     => __( 'Parallax', 'quiety-core' ),
        ] );

        $repeater->add_responsive_control( 'position_top', [
            'label'       => esc_html__( 'Top Offset', 'quiety-core' ),
            'type'        => Controls_Manager::SLIDER,
            'size_units'  => [ '%', 'px' ],
            'range'       => [
                '%'  => [ 'min' => - 100, 'max' => 100 ],
                'px' => [ 'min' => - 200, 'max' => 1000, 'step' => 5 ],
            ],
            'default'     => [ 'unit' => '%' ],
            'description' => esc_html__( 'Set figure vertical offset from top.', 'quiety-core' ),
            'selectors'   => [
                "{{WRAPPER}} {{CURRENT_ITEM}} .inner" => 'top: {{SIZE}}{{UNIT}}',
            ],
        ] );

        $repeater->add_responsive_control( 'position_left', [
            'label'       => esc_html__( 'Left Offset', 'quiety-core' ),
            'type'        => Controls_Manager::SLIDER,
            'size_units'  => [ '%', 'px' ],
            'range'       => [
                '%'  => [
                    'min' => - 100,
                    'max' => 100,
                ],
                'px' => [
                    'min'  => - 200,
                    'max'  => 1000,
                    'step' => 5,
                ],
            ],
            'default'     => [
                'unit' => '%',
            ],
            'description' => esc_html__( 'Set figure horizontal offset from left.', 'quiety-core' ),
            'selectors'   => [
                "{{WRAPPER}} {{CURRENT_ITEM}} .inner" => 'left: {{SIZE}}{{UNIT}}',
            ],
        ] );

        $repeater->add_responsive_control( 'wrapper_width', [
            'label'       => esc_html__( 'Image wrapper width', 'quiety-core' ),
            'type'        => Controls_Manager::SLIDER,
            'size_units'  => [ '%', 'px' ],
            'range'       => [
                '%'  => [ 'min' => 5, 'max' => 100 ],
                'px' => [ 'min' => 80, 'max' => 700, 'step' => 5 ],
            ],
            'default'     => [ 'unit' => 'px' ],
            'description' => esc_html__( 'Set Image wrapper max width.', 'quiety-core' ),
            'selectors'   => [
                "{{WRAPPER}} {{CURRENT_ITEM}} .inner" => 'width: {{SIZE}}{{UNIT}}',
            ],
        ] );

        $this->add_control( 'parallax_two_images', [
            'label'       => __( 'Image List', 'quiety-core' ),
            'type'        => Controls_Manager::REPEATER,
            'fields'      => $repeater->get_controls(),
            'condition'   => [
                'layout' => '3'
            ],
            'default'     => [
                [
                    'alt_text'  => __( 'Parallax', 'quiety-core' ),
                    'parallax_image_two' => [
                        'url' => plugin_dir_url( __DIR__ ) . 'assets/images/banner/shape-1.svg'
                    ]
                ],
                [
                    'alt_text'  => __( 'Parallax', 'quiety-core' ),
                    'parallax_image_two' => [
                        'url' => plugin_dir_url( __DIR__ ) . 'assets/images/banner/shape-2.svg'
                    ],
                ],
                [
                    'alt_text'  => __( 'Parallax', 'quiety-core' ),
                    'parallax_image_two' => [
                        'url' => plugin_dir_url( __DIR__ ) . 'assets/images/banner/shape-3.svg'
                    ],
                ]
            ],
            'title_field' => '{{{ alt_text_two }}}',
        ] );

        $this->end_controls_section();


        // Animated Image for Banner Four
        // ================================
        $this->start_controls_section( 'parallax_image_two_section', [
            'label'     => esc_html__( 'Animated Image', 'quiety-core' ),
            'condition' => [
                'layout' => '4'
            ]
        ] );

        $this->add_control(
            'animate_element_three',
            [
                'label' => __( 'Show Shape Image', 'quiety-core' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'quiety-core' ),
                'label_off' => __( 'Hide', 'quiety-core' ),
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control( 'parallax_image_three', [
            'label' => __( 'Choose Image', 'quiety-core' ),
            'type'  => Controls_Manager::MEDIA,
        ] );

        $repeater->add_control( 'animation_delay', [
            'label' => __( 'Animation Delay (ms)', 'quiety-core' ),
            'type'  => Controls_Manager::NUMBER,
            'min'   => 100,
            'max'   => 2000,
            'step'  => 100,
        ] );

        $repeater->add_control( 'parallax_factor', [
            'label'       => esc_html__( 'Parallax Factor', 'quiety-core' ),
            'type'        => Controls_Manager::NUMBER,
            'min'         => - 3,
            'max'         => 3,
            'step'        => 0.01,
            'default'     => '0.01',
            'description' => esc_html__( 'Set elements offset and speed. It can be positive (0.3) or negative (-0.3). Less means slower.', 'quiety-core' ),
        ] );

        $repeater->add_control( 'alt_text_three', [
            'label'       => __( 'Alt Text', 'quiety-core' ),
            'type'        => Controls_Manager::TEXT,
            'placeholder' => __( 'alt test', 'quiety-core' ),
            'default'     => __( 'Parallax', 'quiety-core' ),
        ] );

        $repeater->add_responsive_control( 'position_top', [
            'label'       => esc_html__( 'Top Offset', 'quiety-core' ),
            'type'        => Controls_Manager::SLIDER,
            'size_units'  => [ '%', 'px' ],
            'range'       => [
                '%'  => [ 'min' => - 100, 'max' => 100 ],
                'px' => [ 'min' => - 200, 'max' => 1000, 'step' => 5 ],
            ],
            'default'     => [ 'unit' => '%' ],
            'description' => esc_html__( 'Set figure vertical offset from top.', 'quiety-core' ),
            'selectors'   => [
                "{{WRAPPER}} {{CURRENT_ITEM}}" => 'top: {{SIZE}}{{UNIT}}',
            ],
        ] );

        $repeater->add_responsive_control( 'position_left', [
            'label'       => esc_html__( 'Left Offset', 'quiety-core' ),
            'type'        => Controls_Manager::SLIDER,
            'size_units'  => [ '%', 'px' ],
            'range'       => [
                '%'  => [
                    'min' => - 100,
                    'max' => 100,
                ],
                'px' => [
                    'min'  => - 200,
                    'max'  => 1000,
                    'step' => 5,
                ],
            ],
            'default'     => [
                'unit' => '%',
            ],
            'description' => esc_html__( 'Set figure horizontal offset from left.', 'quiety-core' ),
            'selectors'   => [
                "{{WRAPPER}} {{CURRENT_ITEM}}" => 'left: {{SIZE}}{{UNIT}}',
            ],
        ] );

        $repeater->add_responsive_control( 'wrapper_width', [
            'label'       => esc_html__( 'Image wrapper width', 'quiety-core' ),
            'type'        => Controls_Manager::SLIDER,
            'size_units'  => [ '%', 'px' ],
            'range'       => [
                '%'  => [ 'min' => 5, 'max' => 100 ],
                'px' => [ 'min' => 80, 'max' => 500, 'step' => 5 ],
            ],
            'default'     => [ 'unit' => 'px' ],
            'description' => esc_html__( 'Set Image wrapper max width.', 'quiety-core' ),
            'selectors'   => [
                "{{WRAPPER}} {{CURRENT_ITEM}}" => 'width: {{SIZE}}{{UNIT}}',
            ],
        ] );

        $this->add_control( 'parallax_three_images', [
            'label'       => __( 'Image List', 'quiety-core' ),
            'type'        => Controls_Manager::REPEATER,
            'fields'      => $repeater->get_controls(),
            'condition'   => [
                'layout' => '4'
            ],
            'default'     => [
                [
                    'alt_text'  => __( 'Parallax', 'quiety-core' ),
                    'parallax_image_three' => [
                        'url' => plugin_dir_url( __DIR__ ) . 'assets/images/banner3_shape.svg'
                    ],
                    'parallax_factor' => [
                        'default' => '0.00'
                    ]
                ],
                [
                    'alt_text'  => __( 'Parallax', 'quiety-core' ),
                    'parallax_image_three' => [
                        'url' => plugin_dir_url( __DIR__ ) . 'assets/images/banner3_shape2.svg'
                    ],
                ],
                [
                    'alt_text'  => __( 'Parallax', 'quiety-core' ),
                    'parallax_image_three' => [
                        'url' => plugin_dir_url( __DIR__ ) . 'assets/images/banner/shape-2.svg'
                    ],
                ],
                [
                    'alt_text'  => __( 'Parallax', 'quiety-core' ),
                    'parallax_image_three' => [
                        'url' => plugin_dir_url( __DIR__ ) . 'assets/images/feature-3.svg'
                    ],
                ],
            ],
            'title_field' => '{{{ alt_text_three }}}',
        ] );

        $this->end_controls_section();

        // Newsletter
        // =====================
        $this->start_controls_section( 'form_section', [
            'label'     => esc_html__( 'Newsletter', 'quiety-core' ),
            'condition' => [
                'layout' => '3'
            ]
        ] );

        $this->add_control( 'subscribe_text', [
            'label'       => esc_html__( 'Button Text', 'quiety-core' ),
            'type'        => Controls_Manager::TEXT,
            'label_block' => true,
            'default'     => __( 'Try It Now', 'quiety-core' ),
            'separator'   => 'before',
        ] );

        $this->add_control( 'placeholder', [
            'label'       => esc_html__( 'Placeholder', 'quiety-core' ),
            'type'        => Controls_Manager::TEXT,
            'label_block' => true,
            'default'     => __( 'Enter your email...', 'quiety-core' ),
            'separator'   => 'before',
        ] );

        $this->end_controls_section();


        // Info List Section
        // =====================
        $this->start_controls_section( 'list_item_section', [
            'label' => __( 'Info List', 'quiety-core' ),
            'tab'   => Controls_Manager::TAB_CONTENT,
            'condition'   => [
                'layout' => '3'
            ],
        ] );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control( 'list_title', [
            'label'       => __( 'Title', 'quiety-core' ),
            'type'        => \Elementor\Controls_Manager::TEXT,
            'default'     => __( 'List Title', 'quiety-core' ),
            'label_block' => true,
        ] );

        $this->add_control(
            'list_item',
            [
                'label' => __( 'List', 'quiety-core' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'list_title' => __( 'Free 14-day trial', 'quiety-core' ),
                    ],
                    [
                        'list_title' => __( 'No credit card required', 'quiety-core' ),
                    ],
                ],
                'title_field' => '{{{ list_title }}}',
            ]
        );

        $this->end_controls_section();

    }


    /**
     * Name: quiety_elementor_style_control
     * Desc: Register style content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @quiety
     * Author: Themetags
     */
    public function elementor_style_control() {

        // ===================== Title ======================//
        $this->start_controls_section( 'title_style', [
            'label' => __( 'Title', 'quiety-core' ),
            'tab'   => Controls_Manager::TAB_STYLE,
        ] );

        $this->add_group_control( Group_Control_Typography::get_type(), [
            'name'     => 'title_typography',
            'label'    => __( 'Typography', 'quiety-core' ),
            'selector' => '
                {{WRAPPER}} .banner__title,
                {{WRAPPER}} .__title
            ',
        ] );


        $this->add_control( 'title_color', [
            'label'     => __( 'Color', 'quiety-core' ),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .banner__title' => 'color: {{VALUE}}',
                '{{WRAPPER}} .__title' => 'color: {{VALUE}}',
            ],
        ] );

        $this->end_controls_section(); //End Title Style


        // ===================== Subtitle Style ========================//
        $this->start_controls_section( 'sub_title_style', [
            'label' => __( 'Sub Title', 'quiety-core' ),
            'tab'   => Controls_Manager::TAB_STYLE,
            'condition' => [
                'layout!' => [ '9' ],
            ]
        ] );

        $this->add_group_control( Group_Control_Typography::get_type(), [
            'name'     => 'title_sub_typography',
            'label'    => __( 'Typography', 'quiety-core' ),
            'selector' => '{{WRAPPER}} .banner__subtitle',
        ] );

        $this->add_control( 'sub_title_color', [
            'label'     => __( 'Title Color', 'quiety-core' ),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .banner__subtitle' => 'color: {{VALUE}}',
            ],

        ] );

        $this->end_controls_section(); //End Subtitle Style


        // ===================== Description ======================//
        $this->start_controls_section( 'description_section', [
            'label' => __( 'Description', 'quiety-core' ),
            'tab'   => Controls_Manager::TAB_STYLE,
        ] );

        $this->add_group_control( Group_Control_Typography::get_type(), [
            'name'     => 'desc_typography',
            'selector' => '
                {{WRAPPER}} .banner__description,
                {{WRAPPER}} .__description
            ',
        ] );

        $this->add_control( 'des_color', [
            'label'     => __( 'Color', 'quiety-core' ),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .banner__description' => 'color: {{VALUE}}',
                '{{WRAPPER}} .__description' => 'color: {{VALUE}}',
            ],
        ] );

        $this->end_controls_section(); //End Description


        // ===================== Feature List Style =====================//
        $this->start_controls_section( 'feature_style_section', [
            'label' => __( 'Feature List', 'quiety-core' ),
            'tab'   => Controls_Manager::TAB_STYLE,
            'condition' => [
                'layout' => ['1', '2', '3', '4', '5', '6', '7']
            ]
        ] );

        $this->add_group_control( Group_Control_Typography::get_type(), [
            'name'     => 'feature_list_typography',
            'selector' => '{{WRAPPER}} .banner__feature li',
        ] );

        $this->add_control( 'feature_list_color', [
            'label'     => __( 'Color', 'quiety-core' ),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .banner__feature li' => 'color: {{VALUE}}',
            ],
        ] );

        $this->add_control( 'feature_icon_color', [
            'label'     => __( 'Icon Color', 'quiety-core' ),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .banner__feature li i' => 'color: {{VALUE}}',
            ],
            'separator' => 'before'
        ] );

        $this->add_control( 'feature_icon_bg_color', [
            'label'     => __( 'Background Color', 'quiety-core' ),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .banner__feature li i' => 'background-color: {{VALUE}}',
            ],
        ] );

        $this->end_controls_section(); //End Feature List Style


        //===================== Button Style ==================//
        $this->start_controls_section( 'style_button', [
            'label' => __( 'Button', 'quiety-core' ),
            'tab'   => Controls_Manager::TAB_STYLE,
        ] );


        $this->start_controls_tabs( 'tabs_button_style' );

        // Button Normal Tab
        $this->start_controls_tab( 'tab_button_normal', [
            'label' => __( 'Normal', 'quiety-core' ),
        ] );

        $this->add_control( 'button_text_color', [
            'label'     => __( 'Text Color', 'quiety-core' ),
            'type'      => Controls_Manager::COLOR,
            'default'   => '',
            'selectors' => [
                '{{WRAPPER}} .banner-btn' => 'color: {{VALUE}};',
                '{{WRAPPER}} .__btn' => 'color: {{VALUE}};',
            ],
        ]);

        $this->add_control( 'button_bg_color', [
            'label'     => __( 'Background Color', 'quiety-core' ),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .banner-btn' => 'background-color: {{VALUE}};',
                '{{WRAPPER}} .__btn' => 'background-color: {{VALUE}};',
            ],
        ] );

        $this->add_group_control( Group_Control_Border::get_type(), [
            'name'     => 'button_border',
            'label'    => __( 'Border', 'quiety-core' ),
            'selector' => '
                {{WRAPPER}} .banner-btn,
                {{WRAPPER}} .__btn
            ',
        ] );

        $this->add_group_control( Group_Control_Box_Shadow::get_type(), [
            'name'     => 'button_box_shadow',
            'label'    => __( 'Box Shadow', 'quiety-core' ),
            'selector' => '
                {{WRAPPER}} .banner-btn,
                {{WRAPPER}} .__btn
            ',
        ] );

        $this->end_controls_tab(); //End Button Normal Tab


        // Button Hover Tab
        $this->start_controls_tab( 'tab_button_hover', [
            'label' => __( 'Hover', 'quiety-core' ),
        ] );

        $this->add_control( 'hover_color', [
            'label'     => __( 'Color', 'quiety-core' ),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .banner-btn:hover' => 'color: {{VALUE}};',
                '{{WRAPPER}} .__btn:hover' => 'color: {{VALUE}};',
            ],
        ] );

        $this->add_control( 'button_hover_bg_color', [
            'label'     => __( 'Background Color', 'quiety-core' ),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .banner-btn:hover' => 'background-color: {{VALUE}};',
                '{{WRAPPER}} .__btn:hover' => 'background-color: {{VALUE}};',
            ]
        ] );

        $this->add_group_control( Group_Control_Border::get_type(), [
            'name'     => 'button_hover_border',
            'label'    => __( 'Border', 'quiety-core' ),
            'selector' => '{{WRAPPER}} .banner-btn:hover, {{WRAPPER}} .__btn:hover',
        ] );

        $this->add_group_control( Group_Control_Box_Shadow::get_type(), [
            'name'     => 'button_box_shadow_hover',
            'label'    => __( 'Box Shadow', 'quiety-core' ),
            'selector' => '{{WRAPPER}} .banner-btn, {{WRAPPER}} .__btn',
        ] );

        $this->end_controls_tab(); //End Button Hover Tab
        $this->end_controls_tabs(); //End Button Tab

        $this->add_group_control( Group_Control_Typography::get_type(), [
            'name'      => 'button_typography',
            'label'     => __( 'Typography', 'quiety-core' ),
            'selector'  => '{{WRAPPER}} .banner-btn, {{WRAPPER}} .__btn',
            'separator' => 'before'
        ] );

        $this->add_control( 'padding', [
            'label'      => __( 'Padding', 'quiety-core' ),
            'type'       => Controls_Manager::DIMENSIONS,
            'size_units' => [ 'px', '%', 'em' ],
            'selectors'  => [
                '{{WRAPPER}} .banner-btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                '{{WRAPPER}} .__btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ] );

        $this->add_control( 'border-radius', [
            'label'      => __( 'Border Radius', 'quiety-core' ),
            'type'       => Controls_Manager::DIMENSIONS,
            'size_units' => [ 'px', '%', 'em' ],
            'selectors'  => [
                '{{WRAPPER}} .banner-btn' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                '{{WRAPPER}} .__btn' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ] );

        $this->end_controls_section(); //End Buttons


        //======================= Video Button Style ====================//
        $this->start_controls_section(
            'video_button_style', [
                'label' => __( 'Popup Video Button', 'quiety-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'name' => 'video_button_typography',
                'selector' => '
				    {{WRAPPER}} .play-button,
				    {{WRAPPER}} .popup-youtube
                ',
            ]
        );

        $this->add_control(
            'video_border_radius', [
                'label' => esc_html__( 'Icon Border Radius', 'quiety-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .play-button i' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .popup-youtube i' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'video_text_padding', [
                'label' => esc_html__( 'Icon Padding', 'quiety-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .play-button i' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .popup-youtube i' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator' => 'before',
            ]
        );

        $this->start_controls_tabs( 'tabs_video_style' );

        $this->start_controls_tab(
            'tab_button_video_normal', [
                'label' => esc_html__( 'Normal', 'quiety-core' ),
            ]
        );

        $this->add_control(
            'video_button_color', [
                'label' => esc_html__( 'Color', 'quiety-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .play-button' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .popup-youtube' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'video_button_icon_color',
            [
                'label' => esc_html__( 'Icon Color', 'quiety-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .play-button i' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .popup-youtube i' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(), [
                'name' => 'play_button_background',
                'label' => esc_html__( 'Icon Background', 'quiety-core' ),
                'types' => [ 'classic', 'gradient' ],
                'exclude' => [ 'image' ],
                'selector' => '
				    {{WRAPPER}} .play-button i,
				    {{WRAPPER}} .popup-youtube i
                ',
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(), [
                'name' => 'play_button_border',
                'selector' => '{{WRAPPER}} .play-button i, .popup-youtube i',
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(), [
                'name' => 'video_button_box_shadow',
                'selector' => '{{WRAPPER}} .play-button i, .popup-youtube i',
            ]
        );
        $this->end_controls_tab();

        $this->start_controls_tab(
            'tab_video_button_hover', [
                'label' => esc_html__( 'Hover', 'quiety-core' ),
            ]
        );

        $this->add_control(
            'video_button_hover_color', [
                'label' => esc_html__( 'Color', 'quiety-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .play-button:hover, {{WRAPPER}} .play-button:focus' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .popup-youtube:hover, {{WRAPPER}} .popup-youtube:focus' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'video_button_hover_icon_color', [
                'label' => esc_html__( 'Icon Color', 'quiety-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .play-button:hover i, {{WRAPPER}} .play-button:focus i' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .popup-youtube:hover i, {{WRAPPER}} .popup-youtube:focus i' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(), [
                'name' => 'play_button_background_hover',
                'label' => esc_html__( 'Icon Background', 'quiety-core' ),
                'types' => [ 'classic', 'gradient' ],
                'exclude' => [ 'image' ],
                'selector' => '{{WRAPPER}} .play-button:hover i, .play-button:focus i, .popup-youtube:hover i, .popup-youtube:focus i',
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'play_button_border_hover',
                'selector' => '{{WRAPPER}} .play-button:hover i, .popup-youtube:hover i',
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(), [
                'name' => 'video_button_hover_box_shadow',
                'selector' => '{{WRAPPER}} .play-button:hover i, .popup-youtube:hover i',
            ]
        );

        $this->end_controls_tab();
        $this->end_controls_tabs();
        $this->end_controls_section();


        // ===================== Newsletter Form =======================//
        $this->start_controls_section( 'form_style_section', [
            'label'     => esc_html__( 'Newsletter Form', 'quiety-core' ),
            'tab' => Controls_Manager::TAB_STYLE,
            'condition' => [
                'layout' => '3'
            ]
        ] );

        $this->add_control(
            'form_input_color', [
                'label' => esc_html__( 'Input Color', 'quiety-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} input:not([type=checkbox]):not([type=submit])' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'form_input_placeholder_color', [
                'label' => esc_html__( 'Input Placeholder Color', 'quiety-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} input:not([type=checkbox]):not([type=submit])::placeholder' => 'color: {{VALUE}};',
                ],
            ]
        );


        $this->add_control(
            'form_input_bg_color', [
                'label' => esc_html__( 'Input BG Color', 'quiety-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} input:not([type=checkbox]):not([type=submit])' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(), [
                'name' => 'form_input_border',
                'selector' => '{{WRAPPER}} .banner__newsletter-form .newsletter-inner input[type=email]',
            ]
        );

        $this->start_controls_tabs( 'tabs_form_button_style' );

        $this->start_controls_tab( 'tab_form_button_normal', [
            'label' => __( 'Normal', 'quiety-core' ),
        ] );

        $this->add_control( 'form_button_text_color', [
            'label'     => __( 'Text Color', 'quiety-core' ),
            'type'      => Controls_Manager::COLOR,
            'default'   => '',
            'selectors' => [
                '{{WRAPPER}} .newsletter-submit' => 'color: {{VALUE}};',
            ],
        ] );

        $this->add_control( 'form_button_bg_color', [
            'label'     => __( 'Background Color', 'quiety-core' ),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .newsletter-submit' => 'background-color: {{VALUE}};',
            ],
        ] );

        $this->add_group_control( Group_Control_Border::get_type(), [
            'name'     => 'form_button_border',
            'label'    => __( 'Border', 'quiety-core' ),
            'selector' => '{{WRAPPER}} .newsletter-submit',
        ] );

        $this->add_group_control( Group_Control_Box_Shadow::get_type(), [
            'name'     => 'form_button_box_shadow',
            'label'    => __( 'Box Shadow', 'quiety-core' ),
            'selector' => '{{WRAPPER}} .newsletter-submit',
        ] );

        $this->end_controls_tab();

        $this->start_controls_tab( 'tab_form_button_hover', [
            'label' => __( 'Hover', 'quiety-core' ),
        ] );

        $this->add_control( 'form_hover_color', [
            'label'     => __( 'Color', 'quiety-core' ),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .newsletter-submit:hover' => 'color: {{VALUE}};',
            ],

        ] );

        $this->add_control( 'form_button_hover_bg_color', [
            'label'     => __( 'Background Color', 'quiety-core' ),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .newsletter-submit:hover' => 'background-color: {{VALUE}};',
            ]
        ] );

        $this->add_group_control( Group_Control_Border::get_type(), [
            'name'     => 'form_button_hover_border',
            'label'    => __( 'Border', 'quiety-core' ),
            'selector' => '{{WRAPPER}} .newsletter-submit:hover',
        ] );

        $this->add_group_control( Group_Control_Box_Shadow::get_type(), [
            'name'     => 'form_button_box_shadow_hover',
            'label'    => __( 'Box Shadow', 'quiety-core' ),
            'selector' => '{{WRAPPER}} .newsletter-submit:hover',
        ] );

        $this->end_controls_tab();
        $this->end_controls_tabs();

        $this->add_group_control( Group_Control_Typography::get_type(), [
            'name'      => 'form_button_typography',
            'label'     => __( 'Typography', 'quiety-core' ),
            'selector'  => '{{WRAPPER}} .newsletter-submit',
            'separator' => 'before'
        ] );

        $this->add_control( 'form_padding', [
            'label'      => __( 'Padding', 'quiety-core' ),
            'type'       => Controls_Manager::DIMENSIONS,
            'size_units' => [ 'px', '%', 'em' ],
            'selectors'  => [
                '{{WRAPPER}} .newsletter-submit' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ] );

        $this->add_control( 'form_border-radius', [
            'label'      => __( 'Border Radius', 'quiety-core' ),
            'type'       => Controls_Manager::DIMENSIONS,
            'size_units' => [ 'px', '%', 'em' ],
            'selectors'  => [
                '{{WRAPPER}} .newsletter-submit' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ] );

        $this->end_controls_section();


        //========================== Shape Images ==========================//
        $this->start_controls_section( 'shape_images_sec', [
            'label' => __( 'Shape Images', 'quiety-core' ),
            'tab'   => Controls_Manager::TAB_STYLE,
            'condition' => [
                'layout' => [ '8', '9' ]
            ]
        ] );

        $this->add_control( 'shape1', [
            'label'      => __( 'Shape 01', 'quiety-core' ),
            'type'       => Controls_Manager::MEDIA,
            'condition' => [
                'layout' => [ '8', '9' ]
            ]
        ] );

        $this->add_control( 'shape2', [
            'label'      => __( 'Shape 02', 'quiety-core' ),
            'type'       => Controls_Manager::MEDIA,
            'condition' => [
                'layout' => [ '8', '9' ]
            ]
        ] );

        $this->add_control( 'shape3', [
            'label'      => __( 'Shape 03', 'quiety-core' ),
            'type'       => Controls_Manager::MEDIA,
            'condition' => [
                'layout' => [ '9' ]
            ]
        ] );

        $this->add_control( 'shape4', [
            'label'      => __( 'Shape 04', 'quiety-core' ),
            'type'       => Controls_Manager::MEDIA,
            'condition' => [
                'layout' => [ '9' ]
            ]
        ] );

        $this->add_control( 'shape5', [
            'label'      => __( 'Shape 05', 'quiety-core' ),
            'type'       => Controls_Manager::MEDIA,
            'condition' => [
                'layout' => [ '9' ]
            ]
        ] );

        $this->end_controls_section(); //End Shape Images


        // Background Settings
        // =====================
        $this->start_controls_section( 'style_background', [
            'label' => __( 'Background', 'quiety-core' ),
            'tab'   => Controls_Manager::TAB_STYLE,
        ] );

        $this->add_responsive_control(
            'sec_margin', [
                'label' => esc_html__( 'Margin', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .quiety_sec' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .banner' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .event-hero' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'sec_padding', [
                'label' => esc_html__( 'Padding', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .quiety_sec' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .banner' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .event-hero' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control( Group_Control_Background::get_type(), [
            'name' => 'background',
            'label' => esc_html__( 'Background', 'plugin-name' ),
            'types' => [ 'classic', 'gradient' ],
            'selector' => '
			    {{WRAPPER}} .quiety_sec,
			    {{WRAPPER}} .banner,
			    {{WRAPPER}} .event-hero
            ',
        ] );

        $this->end_controls_section();

    }


    /**
     * Name: render
     * Desc: Widgets Render
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @quiety
     * Author: Themetags
     */
	protected function render() {
		$settings = $this->get_settings_for_display();
        extract($settings); //Array to variable conversation

		$layout   = $settings['layout'];

		if ( ! empty( $settings['btn_link']['url'] ) ) {
			$this->add_link_attributes( 'button', $settings['btn_link'] );
		}

		$this->add_render_attribute( 'button', 'class', 'tt-btn banner-btn' );

		$play_btn_link = $settings['play_btn_link'];
		$play_btn_text = $settings['play_btn_text'];


		if ( $settings['layout'] == '5' ) {
			$this->add_render_attribute( 'button', 'class', 'btn-light btn-outline' );
		}


		$this->add_render_attribute( 'secondary_button', 'class', 'tt-btn btn-outline banner-btn'  );

		if ( ! empty( $settings['sec_btn_link']['url'] ) ) {
			$this->add_link_attributes( 'secondary_button', $settings['sec_btn_link'] );
			$this->add_render_attribute( 'secondary_button', 'class', 'tt-btn banner-btn btn-outline' );
		}

        //===================== Template file =====================//
		require __DIR__ . '/templates/hero/layout-' . $layout . '.php';

	}
}