<?php

namespace Quiety\Widgets;

defined( 'ABSPATH' ) || exit; // Abort, if called directly.

use Elementor\Group_Control_Background;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;


use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Group_Control_Typography;


class Quiety_Icon_Box extends Widget_Base {

	public function get_name() {
		return 'tt-icon-box';
	}

	public function get_title() {
		return esc_html__( 'Quiety Icon Box', 'quiety-core' );
	}

	public function get_icon() {
		return 'eicon-icon-box';
	}

	public function get_categories() {
		return [ 'tt-elements' ];
	}

    protected function register_controls() {
        $this->register_content();
        $this->register_style();
    }

    /**
     * @return void
     * Register contents tab fields
     */
	public function register_content() {
		$this->start_controls_section( 'general_section', [
			'label' => esc_html__( 'Preset', 'quiety-core' ),
		] );

		$this->add_control( 'style', [
			'label'   => __( 'Layout', 'quiety-core' ),
			'type'    => \Elementor\Controls_Manager::SELECT,
			'default' => '1',
			'options' => [
				'1' => __( 'Default', 'quiety-core' ),
				'2'     => __( 'Layout Two', 'quiety-core' ),
			],
		] );

		$this->add_control(
			'enable_equal_height', [
				'label'     => esc_html__( 'Equal Height?', 'elementskit-lite' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => [
					'disable' => esc_html__( 'Disable', 'elementskit-lite' ),
					'enable' => esc_html__( 'Enable', 'elementskit-lite' ),
				],
				'default'   => 'disable',
				'prefix_class'  => 'tt-equal-height-',
				'selectors' => [
					'{{WRAPPER}}.tt-equal-height-enable, {{WRAPPER}}.tt-equal-height-enable .elementor-widget-container, {{WRAPPER}}.tt-equal-height-enable .tt-icon-box' => 'height: 100%;',
				],
                'separator' => 'before',
                'condition' => [
                    'style' => '1'
                ]
			]
		);

		$this->end_controls_section();


		// Icon and Image
		//==================
		$this->start_controls_section( 'section_tab', [
			'label' => esc_html__( 'Icon and Image', 'quiety-core' ),
            'condition' => [
                'style' => '1'
            ]
		] );

		$this->add_control( 'icon_type', [
			'label'       => esc_html__( 'Add Icon/Image', 'quiety-core' ),
			'type'        => Controls_Manager::CHOOSE,
			'label_block' => false,
			'options'     => [
				'none'       => [
					'title' => esc_html__( 'None', 'quiety-core' ),
					'icon'  => 'eicon-ban',
				],
				'type_icon'  => [
					'title' => esc_html__( 'Icon', 'quiety-core' ),
					'icon'  => 'eicon-paint-brush',
				],
				'type_image' => [
					'title' => esc_html__( 'Image', 'quiety-core' ),
					'icon'  => 'eicon-image-bold',
				]
			],
			'default'     => 'type_icon',
		] );

		$this->add_control( 'icon_pack', [
			'label'     => esc_html__( 'Icon Pack', 'quiety-core' ),
			'type'      => Controls_Manager::SELECT,
			'condition' => [
				'icon_type' => 'type_icon',
			],
			'options'   => [
				'fontawesome' => esc_html__( 'Fontawesome', 'quiety-core' ),
				'feather'     => esc_html__( 'Feather', 'quiety-core' ),
			],
			'default'   => 'fontawesome',
		] );

		$this->add_control( 'box_icon', [
			'label'     => __( 'Icon', 'quiety-core' ),
			'type'      => Controls_Manager::ICONS,
			'default'   => [
				'value'   => 'fas fa-star',
				'library' => 'solid',
			],
			'condition' => [
				'icon_pack' => 'fontawesome',
				'icon_type' => 'type_icon',
			]
		] );

		$this->add_control( 'feather_icon', [
			'label'       => __( 'Choose Icon', 'quiety-core' ),
			'type'        => Controls_Manager::ICON,
			'options'     => tt_feather_icon(),
			'include'     => tt_include_feather_icons(),
			'default'     => 'feather-box',
			'condition'   => [
				'icon_pack' => 'feather',
				'icon_type' => 'type_icon',
			],
			'label_block' => true,
		] );


		$this->add_control( 'icon_image', [
			'label'     => __( 'Choose Image', 'quiety-core' ),
			'type'      => Controls_Manager::MEDIA,
			'default'   => [
				'url' => Utils::get_placeholder_image_src(),
			],
			'condition' => [
				'icon_type' => 'type_image'
			]
		] );

		$this->add_control( 'icon_view', [
			'label'        => __( 'View', 'quiety-core' ),
			'type'         => Controls_Manager::SELECT,
			'default'      => 'stacked',
			'options'      => [
				'none'    => __( 'None', 'quiety-core' ),
				'stacked' => __( 'Stacked', 'quiety-core' ),
				'framed'  => __( 'Framed', 'quiety-core' ),
			],
			'prefix_class' => 'tt-view-',
		] );

		$this->add_control( 'icon_shape', [
			'label'        => __( 'Shape', 'quiety-core' ),
			'type'         => Controls_Manager::SELECT,
			'default'      => 'rounded',
			'options'      => [
				'rounded' => __( 'Rounded', 'quiety-core' ),
				'circle'  => __( 'Circle', 'quiety-core' ),
				'square'  => __( 'Square', 'quiety-core' ),

			],
			'condition'    => [
				'icon_view' => [ 'stacked', 'framed' ],
			],
			'prefix_class' => 'tt-shape-',
		] );

		$this->add_responsive_control( 'icon_position', [
			'label'   => __( 'Icon Position', 'quiety-core' ),
			'type'    => Controls_Manager::CHOOSE,
			'options' => [
				'left'  => [
					'title' => __( 'Left', 'quiety-core' ),
					'icon'  => 'eicon-h-align-left',
				],
				'top'   => [
					'title' => __( 'Center', 'quiety-core' ),
					'icon'  => 'eicon-v-align-top',
				],
				'right' => [
					'title' => __( 'Right', 'quiety-core' ),
					'icon'  => 'eicon-h-align-right',
				],
			],
			'default' => 'top',
			'toggle'  => false,
		] );

		$this->add_responsive_control( 'icon_vertically_position', [
			'label'   => __( 'Icon Vertically Position', 'quiety-core' ),
			'type'    => Controls_Manager::CHOOSE,
			'options' => [
				'start'  => [
					'top' => __( 'Top', 'quiety-core' ),
					'icon'  => ' eicon-v-align-top',
				],
				'center'   => [
					'title' => __( 'Center', 'quiety-core' ),
					'icon'  => 'eicon-v-align-middle',
				],
				'end' => [
					'title' => __( 'Bottom', 'quiety-core' ),
					'icon'  => 'eicon-v-align-bottom',
				],
			],
			'default' => 'top',
			'toggle'  => false,
			'condition' => [
				'icon_position!' => 'top'
			]
		] );

		$this->add_control( 'icon_fixed_height', [
			'label'        => __( 'Enable Icon Fixed Height?', 'quiety-core' ),
			'type'         => \Elementor\Controls_Manager::SWITCHER,
			'label_on'     => __( 'Show', 'quiety-core' ),
			'label_off'    => __( 'Hide', 'quiety-core' ),
			'return_value' => 'yes',
			'default'      => 'yes',
		] );

		$this->add_control( 'fixed_height', [
			'label'     => __( 'Icon Container Height', 'quiety-core' ),
			'type'      => \Elementor\Controls_Manager::NUMBER,
			'min'       => 20,
			'max'       => 300,
			'step'      => 5,
			'default'   => 60,
			'condition' => [
				'icon_fixed_height' => 'yes',
				'icon_type'         => 'type_image'
			],
			'selectors' => [
				'{{WRAPPER}} .tt-icon-box__icon-container img' => 'height: {{VALUE}}px;'
			],
		] );

		$this->end_controls_section();

		// Content Section
		//=================
		$this->start_controls_section( 'icon_box_content_section', [
			'label' => esc_html__( 'Content', 'quiety-core' ),
            'condition' => [
                'style' => '1'
            ]
		] );

		$this->add_control( 'box_title', [
			'label'       => esc_html__( 'Box Title', 'quiety-core' ),
			'type'        => Controls_Manager::TEXT,
			'label_block' => true,
			'placeholder' => esc_html__( 'Title', 'quiety-core' ),
			'default'     => esc_html__( 'Feature Heading', 'quiety-core' ),
			'dynamic'     => [
				'active' => true,
			],
		] );

		$this->add_control( 'title_link', [
			'label'         => __( 'Link', 'quiety-core' ),
			'type'          => \Elementor\Controls_Manager::URL,
			'placeholder'   => __( 'https://your-link.com', 'quiety-core' ),
			'dynamic'     => [
				'active' => true,
			],
		] );

		$this->add_control( 'title_size', [
			'label'   => __( 'Title HTML Tag', 'quiety-core' ),
			'type'    => Controls_Manager::SELECT,
			'options' => [
				'h1'   => 'H1',
				'h2'   => 'H2',
				'h3'   => 'H3',
				'h4'   => 'H4',
				'h5'   => 'H5',
				'h6'   => 'H6',
				'div'  => 'div',
				'span' => 'span',
				'p'    => 'p',
			],
			'default' => 'h3',
		] );

		$this->add_control( 'description', [
			'label'       => esc_html__( 'Description', 'quiety-core' ),
			'type'        => Controls_Manager::TEXTAREA,
			'label_block' => true,
			'placeholder' => esc_html__( 'Description', 'quiety-core' ),
			'default'     => __( 'There are many variations of the passages of Lorem Ipsum is an available the done.', 'quiety-core' ),
			'separator'   => 'before',
			'dynamic'     => [
				'active' => true,
			],
		] );

		$this->add_responsive_control( 'title_align', [
			'label'     => esc_html__( 'Alignment', 'quiety-core' ),
			'type'      => Controls_Manager::CHOOSE,
			'options'   => [

				'left'    => [
					'title' => esc_html__( 'Left', 'quiety-core' ),
					'icon'  => 'fa fa-align-left',
				],
				'center'  => [
					'title' => esc_html__( 'Center', 'quiety-core' ),
					'icon'  => 'fa fa-align-center',
				],
				'right'   => [
					'title' => esc_html__( 'Right', 'quiety-core' ),
					'icon'  => 'fa fa-align-right',
				],
				'justify' => [
					'title' => esc_html__( 'Justified', 'quiety-core' ),
					'icon'  => 'fa fa-align-justify',
				],
			],
			'selectors' => [
				'{{WRAPPER}} .tt-icon-box' => 'text-align: {{VALUE}};'
			],
		] );

		$this->end_controls_section();


		// Button Section
		//==========================
		$this->start_controls_section( 'section_button', [
			'label' => __( 'Button', 'decent-elements' ),
            'condition' => [
                'style' => '1'
            ]
		] );

		$this->add_control( 'show_button', [
			'label'        => __( 'Show Button', 'decent-elements' ),
			'type'         => Controls_Manager::SWITCHER,
			'label_on'     => __( 'Show', 'decent-elements' ),
			'label_off'    => __( 'Hide', 'decent-elements' ),
			'return_value' => 'yes',
			'default'      => 'no',
		] );

		$this->add_control( 'button_type', [
			'label'     => __( 'Button Type', 'decent-elements' ),
			'type'      => Controls_Manager::SELECT,
			'default'   => 'de-icon-box__link',
			'options'   => [
				'de-icon-box__link' => __( 'Link', 'decent-elements' ),
				'tt-btn'         => __( 'Button', 'decent-elements' ),
			],
			'condition' => [
				'show_button' => 'yes'
			]
		] );

		$this->add_control( 'btn_text', [
			'label'       => __( 'Button Text', 'decent-elements' ),
			'type'        => Controls_Manager::TEXT,
			'label_block' => true,
			'placeholder' => __( 'Button Text', 'decent-elements' ),
			'default'     => __( 'Click here', 'decent-elements' ),
			'dynamic'     => [
				'active' => true,
			],
			'condition'   => [
				'show_button' => 'yes'
			],
		] );

		$this->add_control( 'button_link', [
			'label'       => __( 'Link', 'decent-elements' ),
			'type'        => Controls_Manager::URL,
			'placeholder' => __( 'https://your-link.com', 'decent-elements' ),
			'dynamic'     => [
				'active' => true,
			],
			'default'     => [
				'url' => '#',
			],
			'condition'   => [
				'show_button' => 'yes'
			]
		] );

		$this->add_control( 'show_button_icon', [
			'label'        => __( 'Show Button Icon', 'decent-elements' ),
			'type'         => Controls_Manager::SWITCHER,
			'label_on'     => __( 'Show', 'decent-elements' ),
			'label_off'    => __( 'Hide', 'decent-elements' ),
			'return_value' => 'yes',
			'default'      => 'no',
		] );

		$this->add_control( 'button_icon', [
			'label'     => __( 'Icon', 'quiety-core' ),
			'type'      => Controls_Manager::ICONS,
			'default'   => [
				'value'   => 'fas fa-arrow-right',
				'library' => 'solid',
			],
			'condition' => [ 'show_button_icon' => 'yes' ]
		] );

		$this->add_control( 'icon_align', [
			'label'     => esc_html__( 'Icon Position', 'quiety-core' ),
			'type'      => Controls_Manager::SELECT,
			'default'   => 'right',
			'options'   => [
				'left'  => esc_html__( 'Before', 'quiety-core' ),
				'right' => esc_html__( 'After', 'quiety-core' ),
			],
			'condition' => [ 'show_button_icon' => 'yes' ]
		] );

		$this->add_control( 'icon_indent', [
			'label'     => esc_html__( 'Icon Spacing', 'quiety-core' ),
			'type'      => Controls_Manager::SLIDER,
			'range'     => [
				'px' => [
					'max' => 50,
				],
			],
			'selectors' => [
				'{{WRAPPER}} .tt-icon-box__button .tt-align-icon-right' => 'margin-left: {{SIZE}}{{UNIT}};',
				'{{WRAPPER}} .tt-icon-box__button .tt-align-icon-left'  => 'margin-right: {{SIZE}}{{UNIT}};',
				'condition' => [ 'show_button_icon' => 'yes' ]
			],

		] );

		$this->add_responsive_control( 'button_space', [
			'label'     => esc_html__( 'Button Spacing Margin Top', 'quiety-core' ),
			'type'      => Controls_Manager::SLIDER,
			'range'     => [
				'px' => [
					'min' => 0,
					'max' => 100,
				],
			],
			'selectors' => [
				'{{WRAPPER}} .tt-icon-box__button' => 'margin-top: {{SIZE}}{{UNIT}};',
			],
		] );

		$this->end_controls_section();

		// Badge
		//===================
		$this->start_controls_section( 'badge_section', [
			'label' => esc_html__( 'Badge', 'quiety-core' ),
            'condition' => [
                'style' => '1'
            ]
		] );

		$this->add_control( 'badge_enable', [
			'label'        => __( 'Enable Badge?', 'quiety-core' ),
			'type'         => \Elementor\Controls_Manager::SWITCHER,
			'label_on'     => __( 'Show', 'quiety-core' ),
			'label_off'    => __( 'Hide', 'quiety-core' ),
			'return_value' => 'yes',
			'default'      => 'no',
		] );

		$this->add_control( 'badge_text', [
			'label'       => esc_html__( 'Badge Text', 'quiety-core' ),
			'type'        => Controls_Manager::TEXT,
			'label_block' => true,
			'placeholder' => esc_html__( 'Badge Text', 'quiety-core' ),
			'default'     => __( 'Badge', 'quiety-core' ),
			'condition'   => [
				'badge_enable' => 'yes'
			]
		] );


		$this->add_control( 'border_popover_toggle', [
			'label'        => __( 'Position', 'decent-elements' ),
			'type'         => Controls_Manager::POPOVER_TOGGLE,
			'label_off'    => __( 'Default', 'decent-elements' ),
			'label_on'     => __( 'Custom', 'decent-elements' ),
			'return_value' => 'yes',
			'condition'    => [
				'badge_enable' => 'yes'
			]
		] );

		$this->start_popover();

		$this->add_responsive_control( 'de_bg_text_horizontal_position', [
			'label'      => __( 'Horizontal Position', 'decent-elements' ),
			'type'       => Controls_Manager::SLIDER,
			'size_units' => [ 'px', '%' ],
			'default'    => [
				'unit' => '%',
			],
			'range'      => [
				'%' => [
					'min' => - 20,
					'max' => 100,
				],
			],
			'selectors'  => [
				'{{WRAPPER}} .tt-icon-box__badge' => 'left: {{SIZE}}{{UNIT}};',
			],
		] );

		$this->add_responsive_control( 'de_bg_text_vertical_position', [
			'label'      => __( 'Vertical Position', 'decent-elements' ),
			'type'       => Controls_Manager::SLIDER,
			'size_units' => [ 'px', '%' ],
			'default'    => [
				'unit' => '%',
			],
			'range'      => [
				'%' => [
					'min' => - 100,
					'max' => 100,
				],
			],
			'selectors'  => [
				'{{WRAPPER}} .tt-icon-box__badge' => 'top: {{SIZE}}{{UNIT}};',
			],
		] );

		$this->end_popover();

		$this->end_controls_section();



        //================= Icon Boxes Repeater ========================//
        $this->start_controls_section(
            'icon_box_sec', [
                'label' => esc_html__( 'Content', 'plugin-name' ),
            ]
        );

        $repeater = new \Elementor\Repeater();
        $repeater->add_control(
            'icon_img', [
                'label' => esc_html__( 'Image', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );

        $repeater->add_control(
            'step_no', [
                'label' => esc_html__( 'Step Number', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => 'Step 1',
            ]
        );

        $repeater->add_control(
            'title', [
                'label' => esc_html__( 'Title', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Social Media Content Plan',
            ]
        );

        $repeater->add_control(
            'contents', [
                'label' => esc_html__( 'Content', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
            ]
        );

        $this->add_control(
            'icon_boxes', [
                'label' => esc_html__( 'Add Icon Box', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ step_no }}}',
            ]
        );

        $this->end_controls_section();// End Icon Boxes Repeater

	}



    /**
     * @return void
     * Register style tab fields
     */
    public function register_style() {
        /**
         * Style Sections
         */

        $this->start_controls_section( 'section_icon_style', [
            'label' => esc_html__( 'Icon and Image', 'quiety-core' ),
            'tab'   => Controls_Manager::TAB_STYLE,
            'condition' => [
                'style' => '1'
            ]
        ] );


        $this->start_controls_tabs( 'tabs_icon_style' );

        $this->start_controls_tab( 'tab_icon_normal', [
            'label' => __( 'Normal', 'quiety-core' ),
        ] );

        $this->add_control( 'icon_color', [
            'label'     => esc_html__( 'Color', 'quiety-core' ),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .tt-icon-box__icon-container' => 'color: {{VALUE}};'
            ],
        ] );

        $this->add_control( 'icon_border_color', [
            'label'     => esc_html__( 'Border Color', 'quiety-core' ),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .tt-icon-box__icon-container' => 'border-color: {{VALUE}};'
            ],
        ] );

        $this->add_control( 'icon_color_bg', [
            'label'     => esc_html__( 'Background Color', 'quiety-core' ),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .tt-icon-box__icon-container' => 'background-color: {{VALUE}}; border-color: {{VALUE}};'
            ],
        ] );

        $this->add_group_control( Group_Control_Box_Shadow::get_type(), [
            'name'     => 'icon_shadow',
            'label'    => __( 'Box Shadow', 'quiety-core' ),
            'selector' => '{{WRAPPER}} .tt-icon-box__icon-container',
        ] );

        $this->end_controls_tab();

        $this->start_controls_tab( 'tab_icon_hover', [
            'label' => __( 'Hover', 'quiety-core' ),
        ] );

        $this->add_control( 'icon_color_hover', [
            'label'     => esc_html__( 'Color', 'quiety-core' ),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .tt-icon-box:hover .tt-icon-box__icon-container:hover' => 'color: {{VALUE}}; border-color: {{VALUE}};'
            ],
        ] );

        $this->add_control( 'icon_hover_border_color', [
            'label'     => esc_html__( 'Border Color', 'quiety-core' ),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .tt-icon-box:hover .tt-icon-box__icon-container:hover' => 'border-color: {{VALUE}};'
            ],
        ] );

        $this->add_control( 'icon_hover_bg_color', [
            'label'     => esc_html__( 'Background Color', 'quiety-core' ),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .tt-icon-box:hover .tt-icon-box__icon-container:hover' => 'background-color: {{VALUE}}'
            ],
        ] );

        $this->end_controls_tab();
        $this->end_controls_tabs();


        $this->add_responsive_control( 'icon_space', [
            'label'     => esc_html__( 'Spacing', 'quiety-core' ),
            'type'      => Controls_Manager::SLIDER,
            'range'     => [
                'px' => [
                    'min' => 0,
                    'max' => 100,
                ],
            ],
            'selectors' => [
                '{{WRAPPER}} .icon--right .tt-icon-box__icon-container' => 'margin-left: {{SIZE}}{{UNIT}};',
                '{{WRAPPER}} .icon--left .tt-icon-box__icon-container'  => 'margin-right: {{SIZE}}{{UNIT}};',
                '{{WRAPPER}} .icon--top .tt-icon-box__icon-container'   => 'margin-bottom: {{SIZE}}{{UNIT}};',
                '(mobile){{WRAPPER}} .tt-icon-box__icon-container'      => 'margin-bottom: {{SIZE}}{{UNIT}};',
            ],
        ] );

        $this->add_responsive_control( 'icon_size', [
            'label'     => esc_html__( 'Size', 'quiety-core' ),
            'type'      => Controls_Manager::SLIDER,
            'range'     => [
                'px' => [
                    'min' => 6,
                    'max' => 300,
                ],
            ],
            'selectors' => [
                '{{WRAPPER}} .tt-icon-box__icon-container' => 'font-size: {{SIZE}}{{UNIT}};',
            ],
        ] );

        $this->add_control( 'icon_padding', [
            'label'     => esc_html__( 'Padding', 'quiety-core' ),
            'type'      => Controls_Manager::SLIDER,
            'selectors' => [
                '{{WRAPPER}} .tt-icon-box__icon-container' => 'padding: {{SIZE}}{{UNIT}};',
            ],
            'range'     => [
                'em' => [
                    'min' => 0,
                    'max' => 5,
                ],
            ],
            'condition' => [
                'icon_view!' => 'default',
            ],
        ] );

        $this->add_control( 'rotate', [
            'label'     => esc_html__( 'Rotate', 'quiety-core' ),
            'type'      => Controls_Manager::SLIDER,
            'default'   => [
                'size' => 0,
                'unit' => 'deg',
            ],
            'selectors' => [
                '{{WRAPPER}} .tt-icon-box__icon-container i' => 'transform: rotate({{SIZE}}{{UNIT}});',
            ],
        ] );

        $this->add_control( 'icon_border_width', [
            'label'     => esc_html__( 'Border Width', 'quiety-core' ),
            'type'      => Controls_Manager::DIMENSIONS,
            'selectors' => [
                '{{WRAPPER}} .tt-icon-box__icon-container' => 'border-width: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
            'condition' => [
                'icon_view' => 'framed',
            ],
        ] );

        $this->add_control( 'border_radius', [
            'label'      => esc_html__( 'Border Radius', 'quiety-core' ),
            'type'       => Controls_Manager::DIMENSIONS,
            'size_units' => [ 'px', '%' ],
            'selectors'  => [
                '{{WRAPPER}} .tt-icon-box__icon-container' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
            'condition'  => [
                'icon_view!' => 'none',
            ],
        ] );

        $this->end_controls_section();

        //Title Style Section
        //======================
        $this->start_controls_section( 'section_title_style', [
            'label' => esc_html__( 'Title', 'quiety-core' ),
            'tab'   => Controls_Manager::TAB_STYLE,
        ] );

        $this->add_control( 'title_color', [
            'label'     => esc_html__( 'Color', 'quiety-core' ),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .tt-icon-box .tt-icon-box__title' => 'color: {{VALUE}}',
                '{{WRAPPER}} .tt-icon-box .tt-icon-box__title a' => 'color: {{VALUE}}',
                '{{WRAPPER}} .title' => 'color: {{VALUE}}',
            ],
        ] );

        $this->add_control( 'title_color_hover', [
            'label'     => esc_html__( 'Hover Color', 'quiety-core' ),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .tt-icon-box .tt-icon-box__title:hover,
				{{WRAPPER}} .tt-icon-box .tt-icon-box__title a:hover' => 'color: {{VALUE}};'
            ],
            'condition' => [
                'style' => '1'
            ]
        ] );

        $this->add_group_control( Group_Control_Typography::get_type(), [
            'name'     => 'title_typography',
            'selector' => '
                {{WRAPPER}} .tt-icon-box .tt-icon-box__title,
                {{WRAPPER}} .title
            ',
        ] );

        $this->add_responsive_control( 'title_space', [
            'label'     => esc_html__( 'Spacing', 'quiety-core' ),
            'type'      => Controls_Manager::SLIDER,
            'range'     => [
                'px' => [
                    'min' => 0,
                    'max' => 100,
                ],
            ],
            'selectors' => [
                '{{WRAPPER}} .tt-icon-box__title' => 'margin-bottom: {{SIZE}}{{UNIT}};',
            ],
            'condition' => [
                'style' => '1'
            ]
        ] );

        $this->end_controls_section();

        // Description Style Section
        //=============================
        $this->start_controls_section( 'section_description_style', [
            'label' => esc_html__( 'Description', 'quiety-core' ),
            'tab'   => Controls_Manager::TAB_STYLE,
        ] );

        $this->add_control( 'description_color', [
            'label'     => esc_html__( 'Color', 'quiety-core' ),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .tt-icon-box .tt-icon-box__description' => 'color: {{VALUE}};',
                '{{WRAPPER}} .contents' => 'color: {{VALUE}};',
            ],
        ] );

        $this->add_group_control( Group_Control_Typography::get_type(), [
            'name'     => 'description_typography',
            'selector' => '
                {{WRAPPER}} .tt-icon-box .tt-icon-box__description,
                {{WRAPPER}} .contents
            ',
        ] );

        $this->add_responsive_control( 'description_space', [
            'label'     => esc_html__( 'Spacing', 'quiety-core' ),
            'type'      => Controls_Manager::SLIDER,
            'range'     => [
                'px' => [
                    'min' => 0,
                    'max' => 100,
                ],
            ],
            'selectors' => [
                '{{WRAPPER}} .tt-icon-box__description' => 'margin-bottom: {{SIZE}}{{UNIT}};',
            ],
            'condition' => [
                'style' => '1'
            ]
        ] );

        $this->end_controls_section();

        // Badge style section
        //======================
        $this->start_controls_section( 'section_badge_style', [
            'label' => esc_html__( 'Badge', 'quiety-core' ),
            'tab'   => Controls_Manager::TAB_STYLE,
            'condition' => [
                'style' => '1'
            ]
        ] );

        $this->add_control( 'badge_color', [
            'label'     => esc_html__( 'Color', 'quiety-core' ),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .tt-icon-box__badge' => 'color: {{VALUE}};',
            ],
        ] );

        $this->add_control( 'badge_bg_color', [
            'label'     => esc_html__( 'BG Color', 'quiety-core' ),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .tt-icon-box__badge' => 'background-color: {{VALUE}};',
            ],
        ] );

        $this->add_control( 'badge_hover_color', [
            'label'     => esc_html__( 'Color', 'quiety-core' ),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .tt-icon-box__badge:hover' => 'color: {{VALUE}};',
            ],
            'separator' => 'before'
        ] );

        $this->add_control( 'badge_hover_bg_color', [
            'label'     => esc_html__( 'Hover BG Color', 'quiety-core' ),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .tt-icon-box__badge:hover' => 'background-color: {{VALUE}};',
            ],
        ] );

        $this->end_controls_section();


        // Button Style
        // =====================
        $this->start_controls_section( 'style_button', [
            'label' => __( 'Button', 'quiety-core' ),
            'tab'   => Controls_Manager::TAB_STYLE,
            'condition' => [
                'style' => '1'
            ]
        ] );

        $this->start_controls_tabs( 'tabs_button_style' );

        $this->start_controls_tab( 'tab_button_normal', [
            'label' => __( 'Normal', 'quiety-core' ),
        ] );

        $this->add_control( 'button_text_color', [
            'label'     => __( 'Text Color', 'quiety-core' ),
            'type'      => Controls_Manager::COLOR,
            'default'   => '',
            'selectors' => [
                '{{WRAPPER}} .tt-icon-box__button' => 'color: {{VALUE}};',
            ],
        ] );

        $this->add_control( 'button_bg_color', [
            'label'     => __( 'Background Color', 'quiety-core' ),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .tt-icon-box__button' => 'background-color: {{VALUE}};',
            ],
        ] );

        $this->add_group_control( Group_Control_Border::get_type(), [
            'name'     => 'button_border',
            'label'    => __( 'Border', 'quiety-core' ),
            'selector' => '{{WRAPPER}} .tt-icon-box__button',
        ] );

        $this->add_group_control( Group_Control_Box_Shadow::get_type(), [
            'name'     => 'button_box_shadow',
            'label'    => __( 'Box Shadow', 'quiety-core' ),
            'selector' => '{{WRAPPER}} .tt-icon-box__button',
        ] );

        $this->end_controls_tab();

        $this->start_controls_tab( 'tab_button_hover', [
            'label' => __( 'Hover', 'quiety-core' ),
        ] );

        $this->add_control( 'hover_color', [
            'label'     => __( 'Color', 'quiety-core' ),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .tt-icon-box__button:hover' => 'color: {{VALUE}};',
            ],

        ] );

        $this->add_control( 'button_hover_bg_color', [
            'label'     => __( 'Background Color', 'quiety-core' ),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .tt-icon-box__button:hover' => 'background-color: {{VALUE}};',
            ]
        ] );

        $this->add_group_control( Group_Control_Border::get_type(), [
            'name'     => 'button_hover_border',
            'label'    => __( 'Border', 'quiety-core' ),
            'selector' => '{{WRAPPER}} .tt-icon-box__button:hover',
        ] );

        $this->add_group_control( Group_Control_Box_Shadow::get_type(), [
            'name'     => 'button_box_shadow_hover',
            'label'    => __( 'Box Shadow', 'quiety-core' ),
            'selector' => '{{WRAPPER}} .tt-icon-box__button',
        ] );

        $this->end_controls_tab();
        $this->end_controls_tabs();

        $this->add_group_control( Group_Control_Typography::get_type(), [
            'name'      => 'button_typography',
            'label'     => __( 'Typography', 'quiety-core' ),
            'selector'  => '{{WRAPPER}} .tt-icon-box__button',
            'separator' => 'before'
        ] );

        $this->add_control( 'padding', [
            'label'      => __( 'Padding', 'quiety-core' ),
            'type'       => Controls_Manager::DIMENSIONS,
            'size_units' => [ 'px', '%', 'em' ],
            'selectors'  => [
                '{{WRAPPER}} .tt-icon-box__button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ] );

        $this->add_control( 'border-radius', [
            'label'      => __( 'Border Radius', 'quiety-core' ),
            'type'       => Controls_Manager::DIMENSIONS,
            'size_units' => [ 'px', '%', 'em' ],
            'selectors'  => [
                '{{WRAPPER}} .tt-icon-box__button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ] );

        $this->end_controls_section();


        //Box Style Section
        $this->start_controls_section( 'section_box_style', [
            'label' => esc_html__( 'Box Container', 'quiety-core' ),
            'tab'   => Controls_Manager::TAB_STYLE,
        ] );

        $this->add_control(
            'box_overflow', [
                'label' => esc_html__( 'Box Overflow', 'quiety-core' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => 'default',
                'options' => [
                    'default'  => esc_html__( 'Default', 'quiety-core' ),
                    'hidden' => esc_html__( 'Hidden', 'quiety-core' ),
                ],

                'selectors_dictionary' => [
                    'hidden'   => 'overflow: hidden',
                ],
                'selectors'            => [
                    '{{WRAPPER}} .tt-icon-box' => '{{VALUE}};',
                ],
                'condition' => [
                    'style' => '1'
                ]
            ]
        );

        $this->add_responsive_control( 'box_padding', [
            'label'      => __( 'Padding', 'quiety-core' ),
            'type'       => Controls_Manager::DIMENSIONS,
            'size_units' => [ 'px', '%', 'em' ],
            'selectors'  => [
                '{{WRAPPER}} .tt-icon-box' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                '{{WRAPPER}} .digi-how-works' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ] );

        $this->add_responsive_control( 'box_margin', [
            'label'      => __( 'Margin', 'quiety-core' ),
            'type'       => Controls_Manager::DIMENSIONS,
            'size_units' => [ 'px', '%', 'em' ],
            'selectors'  => [
                '{{WRAPPER}} .tt-icon-box' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                '{{WRAPPER}} .digi-how-works' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ] );

        $this->add_control( 'box_border_radius', [
            'label'      => __( 'Border Radius', 'quiety-core' ),
            'type'       => Controls_Manager::DIMENSIONS,
            'size_units' => [ 'px', '%', 'em' ],
            'selectors'  => [
                '{{WRAPPER}} .tt-icon-box' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                '{{WRAPPER}} .digi-how-works' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ] );

        $this->start_controls_tabs( 'tabs_box_style' );

        $this->start_controls_tab( 'tab_box_normal', [
            'label' => __( 'Normal', 'quiety-core' ),
            'condition' => [
                'style' => '1'
            ]
        ] );

        $this->add_group_control( Group_Control_Background::get_type(), [
            'name'     => 'box_background',
            'label'    => __( 'Background', 'quiety-core' ),
            'types'    => [ 'classic', 'gradient' ],
            'selector' => '
                {{WRAPPER}} .tt-icon-box,
                {{WRAPPER}} .digi-how-works
            ',
        ] );

        $this->add_group_control( Group_Control_Border::get_type(), [
            'name'     => 'box_border',
            'label'    => __( 'Border', 'quiety-core' ),
            'selector' => '{{WRAPPER}} .tt-icon-box',
            'condition' => [
                'style' => '1'
            ]
        ] );

        $this->add_group_control( \Elementor\Group_Control_Box_Shadow::get_type(), [
            'name'     => 'icon_box_shadow',
            'label'    => __( 'Box Shadow', 'quiety-core' ),
            'selector' => '{{WRAPPER}} .tt-icon-box',
            'condition' => [
                'style' => '1'
            ]
        ] );

        $this->add_control( 'box_translate_x', [
            'label'      => __( 'Translate (X)', 'quiety-core' ),
            'type'       => Controls_Manager::SLIDER,
            'size_units' => 'px',
            'range'      => [
                'px' => [
                    'min'  => - 50,
                    'max'  => 100,
                    'step' => 1,
                ],
            ],
            'selectors'  => [
                '{{WRAPPER}} .tt-icon-box' => 'transform: translateX({{SIZE}}{{UNIT}});',
            ],
            'condition' => [
                'style' => '1'
            ]
        ] );

        $this->add_control( 'box_translate', [
            'label'      => __( 'Translate (Y)', 'quiety-core' ),
            'type'       => Controls_Manager::SLIDER,
            'size_units' => 'px',
            'range'      => [
                'px' => [
                    'min'  => - 50,
                    'max'  => 100,
                    'step' => 1,
                ],
            ],
            'selectors'  => [
                '{{WRAPPER}} .tt-icon-box' => 'transform: translateY({{SIZE}}{{UNIT}});',
            ],
            'condition' => [
                'style' => '1'
            ]
        ] );

        $this->end_controls_tab();

        $this->start_controls_tab( 'tab_box_hover', [
            'label' => __( 'Hover', 'quiety-core' ),
            'condition' => [
                'style' => '1'
            ]
        ] );

        $this->add_group_control( Group_Control_Background::get_type(), [
            'name'     => 'box_background_hover',
            'label'    => __( 'Background', 'quiety-core' ),
            'types'    => [ 'classic', 'gradient' ],
            'selector' => '{{WRAPPER}} .tt-icon-box:hover',
            'condition' => [
                'style' => '1'
            ]
        ] );

        $this->add_group_control( Group_Control_Border::get_type(), [
            'name'     => 'box_border_hover',
            'label'    => __( 'Border', 'quiety-core' ),
            'selector' => '{{WRAPPER}} .tt-icon-box:hover',
        ] );

        $this->add_group_control( \Elementor\Group_Control_Box_Shadow::get_type(), [
            'name'     => 'icon_box_shadow_hover',
            'label'    => __( 'Box Shadow', 'quiety-core' ),
            'selector' => '{{WRAPPER}} .tt-icon-box:hover',
            'condition' => [
                'style' => '1'
            ]
        ] );


        $this->add_control( 'box_translate_x_hover', [
            'label'      => __( 'Translate (X)', 'quiety-core' ),
            'type'       => Controls_Manager::SLIDER,
            'size_units' => 'px',
            'range'      => [
                'px' => [
                    'min'  => - 50,
                    'max'  => 100,
                    'step' => 1,
                ],
            ],
            'selectors'  => [
                '{{WRAPPER}} .tt-icon-box:hover' => 'transform: translateX({{SIZE}}{{UNIT}});',
            ],
            'condition' => [
                'style' => '1'
            ]
        ] );

        $this->add_control( 'box_translate_hover', [
            'label'      => __( 'Translate (Y)', 'quiety-core' ),
            'type'       => Controls_Manager::SLIDER,
            'size_units' => 'px',
            'range'      => [
                'px' => [
                    'min'  => - 50,
                    'max'  => 100,
                    'step' => 1,
                ],
            ],
            'selectors'  => [
                '{{WRAPPER}} .tt-icon-box:hover' => 'transform: translateY({{SIZE}}{{UNIT}});',
            ],
            'condition' => [
                'style' => '1'
            ]
        ] );

        $this->end_controls_tab();
        $this->end_controls_tabs();
        $this->end_controls_section();
    }



	protected function render() {
		$settings = $this->get_settings_for_display();
		$target   = !empty($settings['title_link']['is_external']) ? ' target="_blank"' : '';
		$nofollow = !empty($settings['title_link']['nofollow']) ? ' rel="nofollow"' : '';

		$this->add_render_attribute( 'button', 'class', 'tt-icon-box__button'  );

		$this->add_render_attribute( 'button', 'class', $settings['button_type']  );

		if ( ! empty( $settings['button_link']['url'] ) ) {
			$this->add_link_attributes( 'button', $settings['button_link'] );
		}

		$this->add_render_attribute( 'box_wrapper', 'class', 'tt-icon-box' );

		if ( ! empty( $settings['icon_vertically_position'] )) {
			$this->add_render_attribute( 'box_wrapper', 'class', 'align-items-' . $settings['icon_vertically_position'] );
		}

		if ( ! empty( $settings['preset'] )) {
			$this->add_render_attribute( 'box_wrapper', 'class', 'style--' . $settings['preset'] );
		}

		if ( ! empty( $settings['icon_position'] )) {
			$this->add_render_attribute( 'box_wrapper', 'class', 'icon--' . $settings['icon_position'] );
		}


		$this->add_render_attribute( [
			 'icon_align' => [
				 'class' => [
					 'tt-button-icon',
					 'tt-align-icon-' . $settings['icon_align'],
				 ],
			 ],
			 'btn_text' => [
				 'class' => 'de-button-text',
			 ],
		 ] );


		$this->add_render_attribute( 'box_title', 'class', 'tt-icon-box__title' );



        //Template File part
        include "templates/icon-box/layout-{$settings['style']}.php";

	}

}



