<?php

namespace Quiety\Widgets;

defined( 'ABSPATH' ) || exit; // Abort, if called directly.

use Elementor\{Widget_Base,
	Controls_Manager,
	Utils
};

class Quiety_Image extends Widget_Base {

	public function get_name() {
		return 'tt-image';
	}

	public function get_title() {
		return __( 'Quiety Image', 'quiety-core' );
	}

	public function get_icon() {
		return 'eicon-image';
	}

	public function get_categories() {
		return [ 'tt-elements' ];
	}

	public function get_script_depends() {
		return [ 'jquery-magnific-popup' ];
	}


    protected function register_controls() {
        $this->register_content();
        $this->register_style();
    }

    /**
     * @return void
     * Register contents tab fields
     */
    public function register_content() {


        //===================== Select Style ====================//
        $this->start_controls_section(
        'style_sec', [
                'label' => __( 'Style', 'quiety-core' ),
            ]
        );

        $this->add_control(
            'style', [
                'label' => esc_html__( 'Style', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    '1'  => esc_html__( '01: Default', 'plugin-name' ),
                    '2' => esc_html__( '02: Multiple Image', 'plugin-name' ),
                    '3' => esc_html__( '03: Multiple Image', 'plugin-name' ),
                    '4' => esc_html__( '04: Multiple Image', 'plugin-name' ),
                ],
                'default' => '1',
            ]
        );

        $this->end_controls_section(); //End Style


        $this->start_controls_section(
        'section_content', [
                'label' => __( 'Content', 'quiety-core' ),
            ]
        );

        $this->add_control( 'image', [
            'label'   => __( 'Choose Image', 'quiety-core' ),
            'type'    => Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->add_control(
            'show_btn_video', [
                'label'        => __( 'Show video button', 'quiety-core' ),
                'type'         => Controls_Manager::SWITCHER,
                'default'      => 'no',
                'label_on'     => __( 'Show', 'quiety-core' ),
                'label_off'    => __( 'Hide', 'quiety-core' ),
                'return_value' => 'yes',
                'condition' => [
                    'style' => '1'
                ]
            ]
        );

        $this->add_control(
            'link_video', [
                'label'     => __( 'URL Video', 'quiety-core' ),
                'type'      => Controls_Manager::URL,
                'default'   => [
                    'url'         => '#',
                    'is_external' => '',
                ],
                'condition' => [
                    'show_btn_video' => 'yes',
                    'style' => '1'
                ],
            ]
        );

        $this->add_responsive_control( 'align', [
            'label'     => __( 'Alignment', 'elementor' ),
            'type'      => Controls_Manager::CHOOSE,
            'options'   => [
                'left'   => [
                    'title' => __( 'Left', 'elementor' ),
                    'icon'  => 'fa fa-align-left',
                ],
                'center' => [
                    'title' => __( 'Center', 'elementor' ),
                    'icon'  => 'fa fa-align-center',
                ],
                'right'  => [
                    'title' => __( 'Right', 'elementor' ),
                    'icon'  => 'fa fa-align-right',
                ],
            ],
            'default'   => 'center',
            'selectors' => [
                '{{WRAPPER}}' => 'text-align: {{VALUE}};',
            ],
        ] );

        $this->add_control( 'show_title_image', [
            'label'        => __( 'Show Image Title', 'quiety-core' ),
            'type'         => Controls_Manager::SWITCHER,
            'default'      => 'no',
            'label_on'     => __( 'Show', 'quiety-core' ),
            'label_off'    => __( 'Hide', 'quiety-core' ),
            'return_value' => 'yes',
            'condition' => [
                'style' => '1'
            ]
        ] );

        $this->add_control( 'title', [
            'label'     => __( 'Title', 'quiety-core' ),
            'type'      => Controls_Manager::TEXT,
            'default'   => 'Demo',
            'condition' => [
                'show_title_image' => 'yes',
                'style' => '1'
            ],
        ] );

        $this->add_control( 'link', [
            'label'     => __( 'URL', 'quiety-core' ),
            'type'      => Controls_Manager::URL,
            'default'   => [
                'url'         => '#',
                'is_external' => '',
            ],
            'condition' => [
                'show_title_image' => 'yes',
                'style' => '1'
            ],
        ] );

        $this->add_control( 'is_external', [
            'label'        => __( 'Is External Links', 'quiety-core' ),
            'type'         => Controls_Manager::SWITCHER,
            'default'      => 'yes',
            'label_on'     => __( 'Show', 'quiety-core' ),
            'label_off'    => __( 'Hide', 'quiety-core' ),
            'return_value' => 'yes',
            'condition'    => [
                'show_title_image' => 'yes',
                'style' => '1'
            ],
        ] );

        $this->end_controls_section();



        //==================== Features Shape Images Style 02, 03 ================//
        $this->start_controls_section(
            'features_shape_image_sec', [
                'label' => esc_html__( 'Shapes', 'plugin-name' ),
                'condition' => [
                    'style' => [ '2', '3', '4' ]
                ]
            ]
        );

        $repeater = new \Elementor\Repeater();
        $repeater->add_control(
            'align_items', [
                'type' => \Elementor\Controls_Manager::HIDDEN,
            ]
        );

        $repeater->add_control(
            'shape', [
                'label' => esc_html__( 'Shape', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
            ]
        );


        //=============== Horizontal Position ================//
        $repeater->add_control(
            'hr_position', [
                'label' => esc_html__( 'Horizontal Position', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'plugin-name' ),
                        'icon' => 'eicon-h-align-left',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'plugin-name' ),
                        'icon' => 'eicon-h-align-right',
                    ],
                ],
                'toggle' => true,
            ]
        );

        $repeater->add_responsive_control(
            'hr_left_position', [
                'label' => esc_html__( 'Left', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => -1000,
                        'max' => 1000,
                    ],
                    '%' => [
                        'min' => -100,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => '',
                ],
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}' => 'left: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'hr_position' => 'left'
                ]
            ]
        );

        $repeater->add_responsive_control(
            'hr_right_position', [
                'label' => esc_html__( 'Right', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => -1000,
                        'max' => 1000,
                    ],
                    '%' => [
                        'min' => -100,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => '',
                ],
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}' => 'right: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'hr_position' => 'right'
                ]
            ]
        ); //End Horizontal Position

        //=============== Vertical Position ================//
        $repeater->add_control(
            'vr_position', [
                'label' => esc_html__( 'Vertical Position', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'options' => [
                    'top' => [
                        'title' => esc_html__( 'Top', 'plugin-name' ),
                        'icon' => 'eicon-v-align-top',
                    ],
                    'bottom' => [
                        'title' => esc_html__( 'Bottom', 'plugin-name' ),
                        'icon' => 'eicon-v-align-bottom',
                    ],
                ],
                'toggle' => true,
                'separator' => 'before'
            ]
        );

        $repeater->add_responsive_control(
            'vr_top_position', [
                'label' => esc_html__( 'Top', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => -1000,
                        'max' => 1000,
                    ],
                    '%' => [
                        'min' => -100,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => '',
                ],
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}' => 'top: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'vr_position' => 'top',
                ]
            ]
        );

        $repeater->add_responsive_control(
            'vr_bottom_position', [
                'label' => esc_html__( 'Bottom', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => -1000,
                        'max' => 1000,
                    ],
                    '%' => [
                        'min' => -100,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => '',
                ],
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}' => 'bottom: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'vr_position' => 'bottom',
                ],
            ]
        ); //End Vertical Position

        $repeater->add_group_control(
            \Elementor\Group_Control_Box_Shadow::get_type(), [
                'name' => 'shape_img_box_shadow',
                'label' => esc_html__( 'Box Shadow', 'plugin-name' ),
                'selector' => '{{WRAPPER}} {{CURRENT_ITEM}} img',
                'separator' => 'before'
            ]
        );

        $this->add_control(
            'shape_images', [
                'label' => esc_html__( 'Add Image', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ align_items }}}',
            ]
        );

        $this->end_controls_section(); //End Features Images


    }

    /**
     * @return void
     * Register style tab fields
     */
    public function register_style() {

        $this->start_controls_section( 'content_section', [
            'label' => esc_html__( 'Style', 'quiety-core' ),
            'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
        ] );


        $this->add_responsive_control('min_height', [
            'label'      => esc_html__( 'Image Min Height', 'quiety-core' ),
            'type'       => \Elementor\Controls_Manager::SLIDER,
            'size_units' => [ 'px'],
            'range'      => [
                'px' => [
                    'min'  => 0,
                    'max'  => 1000,
                    'step' => 1,
                ],
            ],
            'selectors'  => [
                '{{WRAPPER}} .image-wrapper img' => 'min-height: {{SIZE}}{{UNIT}};',
            ],
        ] );

        $this->add_control( 'width', [
            'label'      => esc_html__( 'Width', 'quiety-core' ),
            'type'       => \Elementor\Controls_Manager::SLIDER,
            'size_units' => [ 'px', '%' ],
            'range'      => [
                'px' => [
                    'min'  => 0,
                    'max'  => 200,
                    'step' => 1,
                ],
            ],
            'selectors'  => [
                '{{WRAPPER}} .popup-play-btn' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}}; line-height: {{SIZE}}{{UNIT}};',
            ],
        ] );

        $this->add_control( 'font_size', [
            'label'      => esc_html__( 'Font Size', 'quiety-core' ),
            'type'       => \Elementor\Controls_Manager::SLIDER,
            'size_units' => [ 'px', '%' ],
            'range'      => [
                'px' => [
                    'min'  => 0,
                    'max'  => 50,
                    'step' => 1,
                ],
            ],
            'selectors'  => [
                '{{WRAPPER}} .popup-play-btn' => 'font-size: {{SIZE}}{{UNIT}};',
            ],
        ] );

        $this->add_control( 'icon_color', [
            'label'     => esc_html__( 'Button Icon Color', 'quiety-core' ),
            'type'      => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .popup-play-btn' => 'color: {{VALUE}}',
            ],
        ] );

        $this->add_control( 'icon_bg_color', [
            'label'     => esc_html__( 'Button Background Color', 'quiety-core' ),
            'type'      => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .popup-play-btn' => 'background-color: {{VALUE}}',
            ],
        ] );

        $this->add_control( 'icon_color_hover', [
            'label'     => esc_html__( 'Button Hover Icon Color', 'quiety-core' ),
            'type'      => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .popup-play-btn:hover' => 'color: {{VALUE}}',
            ],
        ] );

        $this->add_control( 'icon_hoverbg_color', [
            'label'     => esc_html__( 'Button Hover Background Color', 'quiety-core' ),
            'type'      => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .popup-play-btn:hover' => 'background-color: {{VALUE}}',
            ],
        ] );

        $this->add_control( 'overlay_bg_color', [
            'label'     => esc_html__( 'Overlay Background Color', 'quiety-core' ),
            'type'      => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .image-wrapper .overlay-bg' => 'background-color: {{VALUE}}',
            ],
            'separator' => 'before'
        ] );

        $this->add_group_control( \Elementor\Group_Control_Box_Shadow::get_type(), [
            'name'     => 'image_box_shadow',
            'label'    => esc_html__( 'Box Shadow', 'quiety-core' ),
            'selector' => '{{WRAPPER}} .image-wrapper',
        ] );

        $this->add_control( 'image_border_radius', [
            'label'      => __( 'Image Border Radius', 'quiety-core' ),
            'type'       => Controls_Manager::DIMENSIONS,
            'size_units' => [ 'px', '%', 'em' ],
            'selectors'  => [
                '{{WRAPPER}} .image-wrapper' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
        ] );

        $this->end_controls_section();



        //====================== Box =====================//
        $this->start_controls_section(
            'circle_box_sec', [
                'label' => esc_html__( 'Circle Box', 'plugin-name' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
                'condition' => [
                    'style' => [ '3', '4' ]
                ]
            ]
        );

        $this->add_responsive_control(
            'box_width', [
                'label' => esc_html__( 'Circle Width', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 5,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .payment-feature-img .payment-feature-mockup::before' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}}',
                    '{{WRAPPER}} .payment-news-letter .p-cta-right::before' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}}',
                ],
                'separator' => 'after'
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(), [
                'name' => 'circle_box_bg',
                'label' => esc_html__( 'Background', 'plugin-name' ),
                'types' => [ 'classic', 'gradient' ],
                'exclude' => [ 'image' ],
                'selector' => '{{WRAPPER}} .payment-feature-img .payment-feature-mockup::before',
            ]
        );

        $this->end_controls_section();

    }


    /**
     * @return void
     * Render HTML
     */
	protected function render() {

		$settings   = $this->get_settings();
		$image      = $settings['image'];
		$title      = $settings['title'];
		$link       = $settings['link'];
		$link_video = $settings['link_video'];
		$target     = $settings['is_external'] == 'yes' ? ' target="_blank"' : '';

		$css_wrap = "image-wrapper";
		$css_img  = "";
		if ( $settings['show_btn_video'] === 'yes' ) {
			$css_wrap .= " p-relative img-video";
			$css_img  .= "feature-image";
		}
		if ( $settings['show_title_image'] === 'yes' ) {
			$css_wrap .= " img-show-title";
			$css_img  .= "title-bg";
		}
		if ( $settings['show_btn_video'] === 'yes' && $settings['show_title_image'] === 'yes' ) {
			$css_wrap .= " p-relative img-show-title-video";
			$css_img  .= "video-image";
		}

        //============= Template Path
        include "templates/image/image-{$settings['style']}.php";

	}
}
