<?php

namespace Quiety\Widgets;

defined('ABSPATH') || exit; // Abort, if called directly.

use Elementor\{
	Widget_Base,
	Controls_Manager,
	Utils,
	Group_Control_Typography
};

class Quiety_Image_Overlay_Box extends Widget_Base {

	public function get_name() {
		return 'tt-image-overlay-box';
	}

	public function get_title() {
		return esc_html__( 'Quiety Image Overlay Box', 'quiety-core' );
	}

	public function get_icon() {
		return 'eicon-icon-box';
	}

	public function get_categories() {
		return [ 'tt-elements' ];
	}

	protected function register_controls() {
		$this->start_controls_section( 'section_tab', [
			'label' => esc_html__( 'Image Overlay Box', 'quiety-core' ),
		] );

		$this->add_control( 'box_image', [
			'label'   => __( 'Choose Image', 'quiety-core' ),
			'type'    => Controls_Manager::MEDIA,
			'default' => [
				'url' => Utils::get_placeholder_image_src(),
			],
		] );

		$this->add_control( 'box_title', [
			'label'       => esc_html__( 'Title', 'quiety-core' ),
			'type'        => Controls_Manager::TEXT,
			'label_block' => true,
			'placeholder' => esc_html__( 'Title', 'quiety-core' ),
			'default'     => __( 'Heading', 'quiety-core' ),
		] );

		$this->add_control( 'description', [
			'label'       => esc_html__( 'Description', 'quiety-core' ),
			'type'        => Controls_Manager::TEXTAREA,
			'label_block' => true,
			'placeholder' => esc_html__( 'Description', 'quiety-core' ),
			'default'     => __( 'There are many variations of passages of Lorem Ipsum available the majority have suffered that alteration.', 'quiety-core' ),
			'separator'   => 'none',
		] );

		$this->add_control( 'link', [
			'label'         => __( 'Link', 'quiety-core' ),
			'type'          => Controls_Manager::URL,
			'placeholder'   => __( 'https://your-link.com', 'quiety-core' ),
		] );

		$this->add_responsive_control( 'box_align', [
			'label'   => esc_html__( 'Alignment', 'quiety-core' ),
			'type'    => Controls_Manager::CHOOSE,
			'options' => [
				'left'  => [
					'title' => esc_html__( 'Left', 'quiety-core' ),
					'icon'  => 'fa fa-align-left',
				],
				'center' => [
					'title' => esc_html__( 'Right', 'quiety-core' ),
					'icon'  => 'fa fa-align-right',
				],

				'right' => [
					'title' => esc_html__( 'Right', 'quiety-core' ),
					'icon'  => 'fa fa-align-right',
				],
			],
			'default' => 'left',
			'toggle'  => false,
		] );

		$this->end_controls_section();

		//Title Style Section
		$this->start_controls_section( 'section_title_style', [
			'label' => esc_html__( 'Title', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_control( 'title_color_one', [
			'label'     => esc_html__( 'Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-image-overlay__title' => 'color: {{VALUE}};'
			],
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'title_typography',
			'selector' => '{{WRAPPER}} .tt-image-overlay__title',
		] );

		$this->end_controls_section();

		//Description Style Section
		$this->start_controls_section( 'section_subtitle_style', [
			'label' => esc_html__( 'Description', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_control( 'subtitle_color', [
			'label'     => esc_html__( 'Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-image-overlay__description' => 'color: {{VALUE}};',
			],
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'sdes_typography',
			'selector' => '{{WRAPPER}} .tt-image-overlay__description',
		] );

		$this->end_controls_section();

		//Description Style Section
		$this->start_controls_section( 'section_box_style', [
			'label' => esc_html__( 'Box Container', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_control(
			'custom_height',
			[
				'label' => __( 'Custom Height? ', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => __( 'Show', 'quiety-core' ),
				'label_off' => __( 'Hide', 'quiety-core' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);

		$this->add_control(
			'height',
			[
				'label' => __( 'Height', 'quiety-core' ),
				'type' => Controls_Manager::NUMBER,
				'min' => 100,
				'max' => 700,
				'step' => 5,
				'condition' => [
					'custom_height' => 'yes'
				],
				'selectors' => [
					'{{WRAPPER}} .tt-image-overlay' => 'height: {{UNIT}}px;',
				],
			]
		);

		$this->add_control( 'overlay_color', [
			'label'     => esc_html__( 'Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-image-overlay:before' => 'background-color: {{VALUE}};',
			],
		] );

		$this->add_control(
			'border_radius',
			[
				'label' => __( 'Margin', 'quiety-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .tt-image-overlay' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();
	}

	protected function render() {
		$settings    = $this->get_settings_for_display();
		$image       = $settings['box_image'];
		$title       = $settings['box_title'];
		$description = $settings['description'];
		if ( ! empty( $settings['link']['url'] ) ) {
			$this->add_link_attributes( 'link', $settings['link'] );
		}
		?>
		<div class="tt-image-overlay">
			<?php if ( ! empty( $image['url'] ) ) : ?>
				<img src="<?php echo esc_url( $image['url'] ) ?>" alt="<?php echo esc_attr( $title ); ?>">
			<?php endif; ?>

			<div class="tt-image-overlay__content">
				<?php if ( ! empty( $title ) ) : ?>
					<h3 class="tt-image-overlay__title"><?php echo $title ?></h3>
				<?php endif; ?>

				<?php if ( ! empty( $description ) ) : ?>
					<p class="tt-image-overlay__description"><?php echo $description ?></p>
				<?php endif; ?>
			</div>
			<?php if ( !empty( $settings['link']['url'] )) : ?>
				<a <?php $this->print_render_attribute_string( 'link' ); ?>></a>
			<?php endif; ?>


		</div>
		<!-- /.tt-image-overlay -->
		<?php
	}
}



