<?php

namespace Quiety\Widgets;

defined( 'ABSPATH' ) || exit; // Abort, if called directly.

use Elementor\{Widget_Base,
	Controls_Manager,
	Utils
};

class Quiety_Integrations extends Widget_Base {

	public function get_name() {
		return 'quiety-integrations';
	}

	public function get_title() {
		return __( 'Quiety integrations', 'quiety-core' );
	}

	public function get_icon() {
		return 'eicon-integration';
	}

	public function get_categories() {
		return [ 'tt-elements' ];
	}

    protected function register_controls() {
        $this->register_content();
        $this->register_style();
    }

    /**
     * @return void
     * Register contents tab fields
     */
    public function register_content() {


        //================ Featured Image ================//
        $this->start_controls_section(
        'featured_images_sec', [
                'label' => __( 'Featured Image', 'quiety-core' ),
            ]
        );

        $this->add_control(
            'fimage', [
                'label' => esc_html__( 'Choose Image', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
            ]
        );

        $this->end_controls_section(); //End Featured Images


        //==================== Integrations Items ========================//
        $this->start_controls_section(
            'integrations_items_sec', [
                'label' => esc_html__( 'Integrations Item', 'plugin-name' ),
            ]
        );

        $repeater = new \Elementor\Repeater();

        $repeater->add_control(
            'title', [
                'label' => esc_html__( 'Title', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__( 'List Title' , 'plugin-name' ),
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'subtitle', [
                'label' => esc_html__( 'Content', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => esc_html__( 'List Content' , 'plugin-name' ),
                'label_block' => true,
            ]
        );

        $repeater->add_control(
            'title_color', [
                'label' => esc_html__( 'Title Color', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}} .title' => 'color: {{VALUE}}',
                ],
                'separator' => 'before'
            ]
        );

        $this->add_control(
            'integrations', [
                'label' => esc_html__( 'Add Item', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '{{{ title }}}',
                'prevent_empty' => false
            ]
        );

        $this->end_controls_section();


    }


    /**
     * @return void
     * Register contents tab fields
     */
    public function register_style() {

        //======================= Integration Item =======================//
        $this->start_controls_section(
            'integration_item_style', [
                'label' => esc_html__( 'Integration Item', 'plugin-name' ),
                'tab' => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );

        //======= Title Options
        $this->add_control(
            'title_heading', [
                'label' => esc_html__( 'Title Options', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
                'name' => 'title_type',
                'selector' => '{{WRAPPER}} .title',
            ]
        );

        //========== Subtitle Options
        $this->add_control(
            'subtitle_heading', [
                'label' => esc_html__( 'Subtitle Options', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );

        $this->add_control(
            'subtitle_color', [
                'label' => esc_html__( 'Subtitle Color', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .subtitle' => 'color: {{VALUE}}',
                ],
                'separator' => 'before'
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Typography::get_type(), [
                'name' => 'subtitle_typo',
                'selector' => '{{WRAPPER}} .subtitle',
            ]
        );

        $this->end_controls_section(); // End Integration Item

    }


    /**
     * @return void
     * Render HTML
     */
	protected function render() {
        $settings  = $this->get_settings_for_display();
        ?>
        <section class="payment-counter">
            <div class="card-shape position-relative">
                <div class="card-img">
                    <?php echo wp_get_attachment_image($settings['fimage']['id'], 'full', '', ['class' => 'img-fluid' ]) ?>
                </div>
                <ul class="list-unstyled m-0">
                    <?php
                    if ( !empty($settings['integrations']) ) {
                        foreach ( $settings['integrations'] as $integration ) {
                            ?>
                            <li>
                                <div class="counter-circle elementor-repeater-item-<?php echo esc_attr($integration['_id']) ?>">
                                    <?php
                                    if ( !empty($integration['title']) ) { ?>
                                        <h4 class="title m-0"><?php echo esc_html($integration['title']) ?></h4>
                                        <?php
                                    }
                                    if ( !empty($integration['subtitle']) ) { ?>
                                        <small class="subtitle"><?php echo esc_html($integration['subtitle']) ?></small>
                                        <?php
                                    }
                                    ?>
                                </div>
                            </li>
                            <?php
                        }
                    }
                    ?>
                </ul>
            </div>
        </section>
        <?php
	}
}
