<?php

namespace Quiety\Widgets;

defined( 'ABSPATH' ) || exit; // Abort, if called directly.

use Elementor\{Group_Control_Image_Size,
	Utils,
	Widget_Base,
	Controls_Manager

};

class Quiety_Job extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve alert widget name.
	 *
	 * @return string Widget name.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_name() {
		return 'tt-job-box';
	}

	public function get_title() {
		return __( 'Quiety Job', 'quiety-core' );
	}

	public function get_icon() {
		// Icon name from the Elementor font file, as per http://dtbaker.net/web-development/creating-your-own-custom-elementor-widgets/
		return 'eicon-photo-library';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the widget categories.
	 *
	 * @return array Widget categories.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_categories() {
		return [ 'tt-elements' ];
	}

	protected function register_controls() {

		$this->start_controls_section( 'section_query', [
			'label' => __( 'Job', 'quiety-core' ),
		] );

		$this->add_control( 'thumbnail_default_size', [
			'label'        => esc_html__( 'Use Default Thumbnail Size', 'quiety-core' ),
			'type'         => Controls_Manager::SWITCHER,
			'default'      => '1',
			'return_value' => '1',
			'separator'    => 'before',
		] );

		$this->add_group_control( Group_Control_Image_Size::get_type(), [
			'name'      => 'thumbnail',
			'default'   => 'full',
			'condition' => [
				'thumbnail_default_size!' => '1',
			],
		] );


		$this->add_control( 'ids', [
			'label'       => __( 'Enter Work IDs', 'quiety-core' ),
			'type'        => Controls_Manager::TEXT,
			'default'     => '',
			'label_block' => true,
			'description' => __( "Enter Work ids to show, separated by a comma. Leave empty to show all.", 'quiety-core' )

		] );
		$this->add_control( 'ids_not', [
			'label'       => __( 'Or Work IDs to Exclude', 'quiety-core' ),
			'type'        => Controls_Manager::TEXT,
			'default'     => '',
			'label_block' => true,
			'description' => __( "Enter Work ids to exclude, separated by a comma (,). Use if the field above is empty.", 'quiety-core' )

		] );

		$this->add_control( 'order_by', [
			'label'       => __( 'Order by', 'quiety-core' ),
			'type'        => Controls_Manager::SELECT,
			'options'     => [
				'date'          => esc_html__( 'Date', 'quiety-core' ),
				'ID'            => esc_html__( 'ID', 'quiety-core' ),
				'author'        => esc_html__( 'Author', 'quiety-core' ),
				'title'         => esc_html__( 'Title', 'quiety-core' ),
				'modified'      => esc_html__( 'Modified', 'quiety-core' ),
				'rand'          => esc_html__( 'Random', 'quiety-core' ),
				'comment_count' => esc_html__( 'Comment Count', 'quiety-core' ),
				'menu_order'    => esc_html__( 'Menu Order', 'quiety-core' ),
			],
			'default'     => 'date',
			'separator'   => 'before',
			'description' => esc_html__( "Select how to sort retrieved posts. More at ", 'quiety-core' ) . '<a href="http://codex.wordpress.org/Class_Reference/WP_Query#Order_.26_Orderby_Parameters" target="_blank">WordPress codex</a>.',
		] );

		$this->add_control( 'order', [
			'label'       => __( 'Sort Order', 'quiety-core' ),
			'type'        => Controls_Manager::SELECT,
			'options'     => [
				'ASC'  => esc_html__( 'Ascending', 'quiety-core' ),
				'DESC' => esc_html__( 'Descending', 'quiety-core' ),
			],
			'default'     => 'DESC',
			'separator'   => 'before',
			'description' => esc_html__( "Select Ascending or Descending order. More at", 'quiety-core' ) . '<a href="http://codex.wordpress.org/Class_Reference/WP_Query#Order_.26_Orderby_Parameters" target="_blank">WordPress codex</a>.',
		] );

		$this->add_control( 'posts_per_page', [
			'label'       => __( 'Work to show', 'quiety-core' ),
			'type'        => Controls_Manager::NUMBER,
			'default'     => '4',
			'description' => esc_html__( "Number of work to show (-1 for all).", 'quiety-core' ),
			'min'         => 1,
		] );

		$this->end_controls_section();
	}

	protected function render() {

		$settings = $this->get_settings();

		$this->add_render_attribute( 'wrapper', 'class', [
			'tt-job-post-wrapper'
		] );

		$args  = array(
			'hide_empty' => true,
			'taxonomy'   => 'quiety_job_cat',
		);
		$terms = get_terms( $args );
		?>

		<div <?php $this->print_render_attribute_string( 'wrapper' ); ?>>
			<div class="row">

				<?php
				$paged      = ( get_query_var( 'paged' ) ) ? get_query_var( 'paged' ) : 1;
				$args       = array(
					'post_type'      => 'quiety_job',
					'paged'          => $paged,
					'order'          => $settings['order'],
					'orderby'        => $settings['order_by'],
					'posts_per_page' => $settings['posts_per_page'],
				);
				$quiety_job = new \WP_Query( $args );


				if ( $quiety_job->have_posts() ) :
					while ( $quiety_job->have_posts() ) :
						$quiety_job->the_post();
						$meta = get_post_meta( get_the_ID(), 'quiety_job_options', true );
						?>

						<div class="col-md-6">
							<div <?php post_class( 'tt-job' ); ?>>
								<?php if ( ! empty( $meta['job_type'] )) : ?>
									<p class="tt-job__type">
										<i class="fas fa-briefcase"></i>
										<span class="tt-job__type-text"><?php echo esc_html( $meta['job_type'] ); ?></span>
									</p>
								 <?php endif; ?>

								<h3 class="tt-job__title">
									<a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
								</h3>

								<ul class="tt-job__info">
									<?php if ( ! empty( $meta['company_name'] )) : ?>
										<li>
											<i class="fas fa-building"></i>
											<span class="tt-job__info-text"><?php echo esc_html( $meta['company_name'] ); ?></span>
										</li>
									<?php endif; ?>

									<?php if ( ! empty( $meta['company_location'] )) : ?>
										<li>
											<i class="fas fa-map-marker-alt"></i>
											<span class="tt-job__info-text"><?php echo esc_html( $meta['company_location'] ); ?></span>
										</li>
									<?php endif; ?>
									<?php if ( ! empty( $meta['salary'] )) : ?>
										<li>
											<i class="fas fa-wallet"></i>
											<span class="tt-job__info-text"><?php echo esc_html( $meta['salary'] ); ?></span>
										</li>
									<?php endif; ?>

								</ul>

								<div class="tt-job__categories">
									<?php
									$terms = get_the_terms( get_the_ID(), 'quiety_job_cat' );
									if ( $terms && ! is_wp_error( $terms ) ) :
										foreach ( $terms as $term ) { ?>
											<span class="tt-job__category"><?php echo $term->name; ?></span>
										<?php } ?>
									<?php endif; ?>
								</div>

								<a href="<?php echo esc_url( the_permalink() ) ?>"	class="tt-btn btn-outline">Apply Now</a>
							</div>
						</div>
						<!-- /.col-md-6 -->
					<?php endwhile;
					wp_reset_postdata();
				endif; ?>
			</div>
		</div>
		<!-- /.tt-job-post-wrapper -->

	<?php }

}
