<?php
namespace Quiety\Widgets;

if (!defined('ABSPATH')) exit;

use Elementor\{
	Controls_Manager,
	Group_Control_Box_Shadow,
	Group_Control_Typography,
	Repeater,
	Widget_Base,
	Utils
};


class Quiety_Logo_Carousel extends Widget_Base {

	public function get_name() {
		return 'tt-logo-carousel';
	}

	public function get_title() {
		return esc_html__( 'Quiety Logo Carousel', 'quiety-core' );
	}

	public function get_icon() {
		return 'eicon-carousel';
	}

	public function get_categories() {
		return [ 'tt-elements' ];
	}

	protected function register_controls() {

		$this->start_controls_section(
			'section_logo',
			[
				'label' => esc_html__('Logo Carousel', 'quiety-core'),
			]
		);

		$this->add_control( 'layout', [
			'type'    => Controls_Manager::SELECT,
			'label'   => __( 'Layout', 'quiety-core' ),
			'default' => 'style-one',
			'options' => [
				'style-one' => __( 'Style One', 'quiety-core' ),
				'style-two' => __( 'Style Two', 'quiety-core' ),
			],
		] );

		$repeater = new Repeater();

		$repeater->add_control(
			'image',
			[
				'label' => __( 'Logo', 'quiety-core' ),
				'type' => Controls_Manager::MEDIA,
				'default' => [
					'url' => Utils::get_placeholder_image_src(),
				],

			]
		);

		$repeater->add_control(
			'link',
			[
				'label' => __( 'Link', 'quiety-core' ),
				'type' => Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'quiety-core' ),
				'show_external' => true,
				'default' => [
					'url' => '#',
					'is_external' => true,
					'nofollow' => true,
				],
			]
		);

		$repeater->add_control(
			'name',
			[
				'label' => __( 'Title', 'quiety-core' ),
				'type' => Controls_Manager::TEXT,
				'default' => __( 'Brand Name', 'quiety-core' ),
				'placeholder' => __( 'Type brand name here', 'quiety-core' ),
			]
		);


		$this->add_control(
			'logos',
			[
				'label' => __( 'Logo List', 'quiety-core' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
				'default' => [
					[
						'image' => [
							'url' => Utils::get_placeholder_image_src(),
						],
						'name' => __('Brand Name', 'quiety-core')

					],
					[
						'image' =>  [
							'url' => Utils::get_placeholder_image_src(),
							'name' => __('Brand Name', 'quiety-core')
						]
					],
					[
						'image' =>  [
							'url' => Utils::get_placeholder_image_src(),
							'name' => __('Brand Name', 'quiety-core')
						]
					],
					[
						'image' =>  [
							'url' => Utils::get_placeholder_image_src(),
							'name' => __('Brand Name', 'quiety-core')
						]
					],
					[
						'image' =>  [
							'url' => Utils::get_placeholder_image_src(),
							'name' => __('Brand Name', 'quiety-core')
						]
					],
				],
				'title_field' => '{{{ name }}}',
			]
		);

		$this->end_controls_section();


		// Slider Control
		//=====================
		$this->start_controls_section( 'settingd_section', [
			'label' => esc_html__( 'Slider Control', 'quiety-core' ),
		] );

		$this->add_control(
			'perview',
			[
				'label' => __('Desktop Per View', 'quiety-core'),
				'type' => Controls_Manager::NUMBER,
				'default' => 5,
			]
		);

		$this->add_control(
			'perview_tablet',
			[
				'label' => __('Tablet Per View', 'quiety-core'),
				'type' => Controls_Manager::NUMBER,
				'default' => 3,
			]
		);

		$this->add_control(
			'perview_mobile',
			[
				'label' => __('Mobile Per View', 'quiety-core'),
				'type' => Controls_Manager::NUMBER,
				'default' => 2,
			]
		);

		$this->add_control(
			'loop',
			[
				'label' => esc_html__('Loop', 'quiety-core'),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__('On', 'quiety-core'),
				'label_off' => esc_html__('Off', 'quiety-core'),
				'return_value' => 'true',
				'default' => 'yes'
			]
		);

		$this->add_control(
			'speed',
			[
				'label' => __('Speed', 'quiety-core'),
				'type' => Controls_Manager::NUMBER,
				'default' => 700,
			]
		);

		$this->add_control(
			'autoplay',
			[
				'label' => esc_html__('Autoplay', 'quiety-core'),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__('On', 'quiety-core'),
				'label_off' => esc_html__('Off', 'quiety-core'),
				'return_value' => 'true',
				'default' => 'yes'
			]
		);

		$this->add_control(
			'autoplay_time',
			[
				'label' => __('Autoplay Time', 'quiety-core'),
				'type' => Controls_Manager::NUMBER,
				'default' => 3000,
			]
		);

		$this->end_controls_section();

	}

	protected function render( ) {

		$settings = $this->get_settings_for_display();
		$logos = $settings['logos'];


		$this->add_render_attribute( 'wrapper', 'class', [
			'swiper-container',
			'tt-client-logo',
		] );

		if ( $settings['layout'] == 'style-two' ) {
			$this->add_render_attribute( 'wrapper', 'class', 'style-two' );
		}


		$slider_options = $this->get_slider_options( $settings );

		$this->add_render_attribute( 'wrapper', 'data-logo', wp_json_encode( $slider_options ) );
		?>

		<div class="tt-logo-carousel">
			<div <?php $this->print_render_attribute_string( 'wrapper' ); ?>>
				<div class="swiper-wrapper">
					<?php if ( is_array( $logos )) :
						foreach( $logos as $logo ) : ?>
							<?php if( $logo[ 'image' ] != '' ){
								$img = $logo[ 'image' ][ 'url' ];
							} ?>
							<div class="swiper-slide">
								<div class="client-logo text-center" title="<?php echo esc_attr( $logo['name'] ); ?>">
									<?php if( !empty( $img ) ): ?>
										<?php if (! empty( $logo['link']['url'])) : ?>
											<a href="<?php echo esc_url( $logo['link']['url'] ); ?>">
										<?php endif; ?>
										<img src="<?php echo esc_url($img) ?>"  alt="<?php echo esc_attr__( 'Brand logo', 'quiety-core' ) ?>">
										<?php if (! empty( $logo['link']['url'])) : ?>
											</a>
										<?php endif; ?>
									<?php endif; ?>
								</div>
							</div>
							<!-- /.swiper-slide -->
						<?php
						endforeach;
					endif;
					?>
				</div>
				<!-- /.swiper-wrapper -->
			</div>
			<!-- /.swiper-container -->
		</div>
		<!-- /.at-logo-carousel -->
		<?php
	}

	protected function _content_template() { }

	protected function get_slider_options( array $settings ) {

		// Per View.

		$slider_options['breakpoints'] = [
			'992' => [
				'slidesPerView' => $settings['perview'],
				'spaceBetween' => '30'
			],

			'620' => [
				'slidesPerView' => $settings['perview_tablet'],
				'spaceBetween' => '30'
			],

			'320' => [
				'slidesPerView' => $settings['perview_mobile'],
				'spaceBetween' => '20'
			],
		];


		// Loop
		if ( $settings['loop'] == 'yes' ) {
			$slider_options['loop'] = true;
		}

		// Speed
		if ( ! empty( $settings['speed'] ) ) {
			$slider_options['speed'] = $settings['speed'];
		}
		if ( $settings['autoplay'] ) {
			$slider_options['autoplay'] = true;
		}

		if ( $settings['autoplay'] == 'yes' ) {
			$slider_options['autoplay'] = [
				'delay' => $settings['autoplay_time']
			];
		}

		return $slider_options;
	}
}