<?php

namespace Quiety\Widgets;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Typography;
use Elementor\Repeater;
use Elementor\Utils;
use Elementor\Widget_Base;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly

class Quiety_Logo_List extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve alert widget name.
	 *
	 * @return string Widget name.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_name() {
		return 'tt-logo-lists';
	}


	public function get_title() {
		return __( 'Logo List', 'quiety-core' );
	}

	public function get_icon() {

		return 'eicon-logo';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the widget categories.
	 *
	 * @return array Widget categories.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_categories() {
		return [ 'tt-elements' ];
	}

	protected function register_controls() {

		$this->start_controls_section( 'faq_content', [
			'label' => __( 'Logo List', 'quiety-core' ),
		] );

		$this->add_control( 'layout', [
			'label'   => __( 'Layout', 'quiety-core' ),
			'type'    => \Elementor\Controls_Manager::SELECT,
			'default' => 'style_one',
			'options' => [
				'style_one'     => __( 'Layout One', 'quiety-core' ),
				'style_two'     => __( 'Layout Two', 'quiety-core' ),
			],
		] );


		$this->add_control( 'column', [
			'label'   => __( 'Column', 'quiety-core' ),
			'type'    => Controls_Manager::SELECT,
			'default' => 'column__six',
			'options' => [
				'column__three' => __( 'Three', 'quiety-core' ),
				'column__four'  => __( 'Four', 'quiety-core' ),
				'column__five'  => __( 'Five', 'quiety-core' ),
				'column__six'   => __( 'Six', 'quiety-core' ),
			],
		] );


		$repeater = new Repeater();

		$repeater->add_control( 'logo_image', [
			'label'   => __( 'Choose Logo Image', 'quiety-core' ),
			'type'    => Controls_Manager::MEDIA,
			'default' => [
				'url' => Utils::get_placeholder_image_src(),
			],
		] );

		$repeater->add_control( 'brand_name', [
			'label'       => __( 'Brand Name', 'quiety-core' ),
			'type'        => Controls_Manager::TEXT,
			'label_block' => true,
		] );

		$this->add_control(
			'link',
			[
				'label' => __( 'Link', 'quiety-core' ),
				'type' => Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'quiety-core' ),
				'show_external' => true,
				'default' => [
					'url' => '#',
				],
			]
		);

		$this->add_control( 'logo_lists', [
			'label'       => __( 'Logo List', 'quiety-core' ),
			'type'        => Controls_Manager::REPEATER,
			'fields'      => $repeater->get_controls(),
			'default'     => [
				[
					'brand_name' => __( 'Brand Name', 'quiety-core' ),
					'logo_image' => [
						'url' => plugin_dir_url( __DIR__ ) . '/assets/images/logo1.png'
					]
				],
				[
					'brand_name' => __( 'Brand Name', 'quiety-core' ),
					'logo_image' => [
						'url' => plugin_dir_url( __DIR__ ) . '/assets/images/logo2.png'
					]
				],
				[
					'brand_name' => __( 'Brand Name', 'quiety-core' ),
					'logo_image' => [
						'url' => plugin_dir_url( __DIR__ ) . '/assets/images/logo3.png'
					]
				],
				[
					'brand_name' => __( 'Brand Name', 'quiety-core' ),
					'logo_image' => [
						'url' => plugin_dir_url( __DIR__ ) . '/assets/images/logo4.png'
					]
				],
				[
					'brand_name' => __( 'Brand Name', 'quiety-core' ),
					'logo_image' => [
						'url' => plugin_dir_url( __DIR__ ) . '/assets/images/logo5.png'
					]
				],
				[
					'brand_name' => __( 'Brand Name', 'quiety-core' ),
					'logo_image' => [
						'url' => plugin_dir_url( __DIR__ ) . '/assets/images/logo6.png'
					]
				],
			],
			'title_field' => '{{{ brand_name }}}',
		] );


		$this->end_controls_section();

		$this->start_controls_section( 'brand_style_section', [
			'label' => __( 'Brand Name', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_control( 'title_style', [
			'label'     => __( 'Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-logo-list__brand-name' => 'color: {{VALUE}}',
			],
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'question_typography',
			'label'    => __( 'Typography', 'quiety-core' ),
			'selector' => '{{WRAPPER}} .tt-logo-list__brand-name',
		] );

		$this->end_controls_section();

		// Style Box  Container
		//==========================
		$this->start_controls_section( 'brand_container_section', [
			'label' => __( 'Box Container', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );


		$this->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'background',
				'label' => __( 'Background', 'quiety-core' ),
				'types' => [ 'classic', 'gradient'],
				'exclude' => ['.image'],
				'selector' => '{{WRAPPER}} .tt-logo-list__item',
			]
		);


		$this->add_group_control( Group_Control_Box_Shadow::get_type(), [
			'name'     => 'info_box_shadow',
			'label'    => __( 'Box Shadow', 'quiety-option' ),
			'selector' => '{{WRAPPER}} .tt-logo-list__item',
		] );

		$this->add_responsive_control( 'border-radius', [
			'label'      => __( 'Border Radius', 'quiety-option' ),
			'type'       => Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%', 'em' ],
			'selectors'  => [
				'{{WRAPPER}} .tt-logo-list__item' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		] );

		$this->add_responsive_control( 'padding', [
			'label'      => __( 'Padding', 'quiety-option' ),
			'type'       => Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%', 'em' ],
			'selectors'  => [
				'{{WRAPPER}} .tt-logo-list__item' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		] );


		$this->end_controls_section();

	}

	protected function render() {
		$settings = $this->get_settings_for_display();

		$this->add_render_attribute( 'logos', 'class', 'tt-logo-list'  );

		if ( ! empty( $settings['layout'] )) {
			$this->add_render_attribute( 'logos', 'class', $settings['layout'] );
		}

		if ( ! empty( $settings['column'] )) {
			$this->add_render_attribute( 'logos', 'class', $settings['column'] );
		}



		if ( $settings['logo_lists'] ) { ?>
			<ul <?php $this->print_render_attribute_string( 'logos' ); ?>">
				<?php foreach ( $settings['logo_lists'] as $item ) { ?>
					<li>
						<div class="tt-logo-list__item">
							<img src="<?php echo esc_url( $item['logo_image']['url'] ); ?>"	alt="<?php echo esc_attr( $item['brand_name'] ) ?>" >
							<?php if ( ! empty( $item['brand_name'] ) && $settings['layout'] == 'style_one' ) : ?>
								<h4 class="tt-logo-list__brand-name"><?php echo esc_html( $item['brand_name'] ) ?></h4>
							<?php endif; ?>
						</div>
						<!-- /.tt-logo-list__item -->
					</li>
				<?php } ?>
			</ul>
			<?php
		}
	}
}