<?php

namespace Quiety\Widgets;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Typography;
use Elementor\Repeater;
use Elementor\Utils;
use Elementor\Widget_Base;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly

class Quiety_Logo_List_Two extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve alert widget name.
	 *
	 * @return string Widget name.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_name() {
		return 'tt-logo-lists_two';
	}


	public function get_title() {
		return __( 'Logo List Two', 'quiety-core' );
	}

	public function get_icon() {

		return 'eicon-logo';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the widget categories.
	 *
	 * @return array Widget categories.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_categories() {
		return [ 'tt-elements' ];
	}

	protected function register_controls() {

		$this->start_controls_section( 'faq_content', [
			'label' => __( 'Logo List', 'quiety-core' ),
		] );

		$this->add_responsive_control( 'align', [
			'label'   => esc_html__( 'Align', 'quiety-core' ),
			'type'    => Controls_Manager::SELECT,
			'options' => [
				'align-left' => esc_html__( 'Left', 'quiety-core' ),
				'align-center' => esc_html__( 'Center', 'quiety-core' ),
				'align-right' => esc_html__( 'Right', 'quiety-core' ),
			],
			'default' => 'align-left',
		] );


		$repeater = new Repeater();

		$repeater->add_control( 'logo_image', [
			'label'   => __( 'Choose Logo Image', 'quiety-core' ),
			'type'    => Controls_Manager::MEDIA,
			'default' => [
				'url' => Utils::get_placeholder_image_src(),
			],
		] );

		$repeater->add_control( 'brand_name', [
			'label'       => __( 'Brand Name', 'quiety-core' ),
			'type'        => Controls_Manager::TEXT,
			'label_block' => true,
		] );


        //=============== Horizontal Position ================//
        $repeater->add_control(
            'hr_position', [
                'label' => esc_html__( 'Horizontal Position', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'plugin-name' ),
                        'icon' => 'eicon-h-align-left',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'plugin-name' ),
                        'icon' => 'eicon-h-align-right',
                    ],
                ],
                'toggle' => true,
            ]
        );

        $repeater->add_responsive_control(
            'hr_left_position', [
                'label' => esc_html__( 'Left', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => -1000,
                        'max' => 1000,
                    ],
                    '%' => [
                        'min' => -100,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => '',
                ],
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}' => 'left: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'hr_position' => 'left'
                ]
            ]
        );

        $repeater->add_responsive_control(
            'hr_right_position', [
                'label' => esc_html__( 'Right', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => -1000,
                        'max' => 1000,
                    ],
                    '%' => [
                        'min' => -100,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => '',
                ],
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}' => 'right: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'hr_position' => 'right'
                ]
            ]
        ); //End Horizontal Position

        //=============== Vertical Position ================//
        $repeater->add_control(
            'vr_position', [
                'label' => esc_html__( 'Vertical Position', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'options' => [
                    'top' => [
                        'title' => esc_html__( 'Top', 'plugin-name' ),
                        'icon' => 'eicon-v-align-top',
                    ],
                    'bottom' => [
                        'title' => esc_html__( 'Bottom', 'plugin-name' ),
                        'icon' => 'eicon-v-align-bottom',
                    ],
                ],
                'toggle' => true,
                'separator' => 'before'
            ]
        );

        $repeater->add_responsive_control(
            'vr_top_position', [
                'label' => esc_html__( 'Top', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => -1000,
                        'max' => 1000,
                    ],
                    '%' => [
                        'min' => -100,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => '',
                ],
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}' => 'top: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'vr_position' => 'top',
                ]
            ]
        );

        $repeater->add_responsive_control(
            'vr_bottom_position', [
                'label' => esc_html__( 'Bottom', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => -1000,
                        'max' => 1000,
                    ],
                    '%' => [
                        'min' => -100,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => '',
                ],
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}' => 'bottom: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'vr_position' => 'bottom',
                ],
            ]
        ); //End Vertical Position


        $repeater->add_responsive_control(
            'logo_size', [
                'label' => esc_html__( 'Logo Width', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => 1,
                        'max' => 1000,
                    ],
                    '%' => [
                        'min' => 1,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => '',
                ],
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}} .tt-logo-list-two__item img' => 'width: {{SIZE}}{{UNIT}};',
                ],
                'separator' => 'before'
            ]
        );

        $repeater->add_responsive_control(
            'logo_box_size', [
                'label' => esc_html__( 'Box Size', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => 1,
                        'max' => 1000,
                    ],
                    '%' => [
                        'min' => 1,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => '',
                ],
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}' => 'width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}};',
                ],
                'separator' => 'before'
            ]
        );


		$this->add_control( 'logo_lists', [
			'label'       => __( 'Logo List', 'quiety-core' ),
			'type'        => Controls_Manager::REPEATER,
			'fields'      => $repeater->get_controls(),
			'default'     => [
				[
					'brand_name' => __( 'Brand Name', 'quiety-core' ),
					'logo_image' => [
						'url' => plugin_dir_url( __DIR__ ) . '/assets/images/logo1.png'
					]
				],
				[
					'brand_name' => __( 'Brand Name', 'quiety-core' ),
					'logo_image' => [
						'url' => plugin_dir_url( __DIR__ ) . '/assets/images/logo2.png'
					]
				],
				[
					'brand_name' => __( 'Brand Name', 'quiety-core' ),
					'logo_image' => [
						'url' => plugin_dir_url( __DIR__ ) . '/assets/images/logo3.png'
					]
				],
				[
					'brand_name' => __( 'Brand Name', 'quiety-core' ),
					'logo_image' => [
						'url' => plugin_dir_url( __DIR__ ) . '/assets/images/logo4.png'
					]
				],
				[
					'brand_name' => __( 'Brand Name', 'quiety-core' ),
					'logo_image' => [
						'url' => plugin_dir_url( __DIR__ ) . '/assets/images/logo5.png'
					]
				],
				[
					'brand_name' => __( 'Brand Name', 'quiety-core' ),
					'logo_image' => [
						'url' => plugin_dir_url( __DIR__ ) . '/assets/images/logo6.png'
					]
				],
			],
			'title_field' => '{{{ brand_name }}}',
		] );


		$this->end_controls_section();

		$this->start_controls_section( 'brand_style_section', [
			'label' => __( 'Brand Name', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_control( 'title_style', [
			'label'     => __( 'Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-logo-list__brand-name' => 'color: {{VALUE}}',
			],
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'question_typography',
			'label'    => __( 'Typography', 'quiety-core' ),
			'selector' => '{{WRAPPER}} .tt-logo-list__brand-name',
		] );

		$this->end_controls_section();

		// Style Box  Container
		//==========================
		$this->start_controls_section( 'brand_container_section', [
			'label' => __( 'Box Container', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_group_control( Group_Control_Box_Shadow::get_type(), [
			'name'     => 'info_box_shadow',
			'label'    => __( 'Box Shadow', 'quiety-option' ),
			'selector' => '{{WRAPPER}} .tt-logo-list-two li',
		] );

		$this->add_responsive_control( 'border-radius', [
			'label'      => __( 'Border Radius', 'quiety-option' ),
			'type'       => Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%', 'em' ],
			'selectors'  => [
				'{{WRAPPER}} .tt-logo-list__item' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		] );

        $this->add_control( 'bg_item_color', [
            'label'     => __( 'Box Color', 'quiety-core' ),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .tt-logo-list-two li' => 'background-color: {{VALUE}}',
            ],
            'separator' => 'before'
        ] );


		$this->end_controls_section();

	}

	protected function render() {
		$settings = $this->get_settings_for_display();
        extract($settings);

		if ( !empty( $settings['logo_lists'] ) ) {
            ?>
			<ul class="tt-logo-list-two <?php echo esc_attr( $settings['align'] ); ?>">
				<?php
                foreach ( $settings['logo_lists'] as $item ) {
                    ?>
					<li data-bs-original-title="<?php echo esc_attr( $item['brand_name'] ) ?>" class="elementor-repeater-item-<?php echo esc_attr($item['_id']) ?>">
						<div class="tt-logo-list-two__item">
							<img src="<?php echo esc_url( $item['logo_image']['url'] ); ?>"	alt="<?php echo esc_attr( $item['brand_name'] ) ?>" width="40">
						</div>
					</li>
				    <?php
                }
                ?>
			</ul>
			<?php
		}
	}
}