<?php

namespace Quiety\Widgets;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Elementor\{Controls_Manager,
	Icons_Manager,
	Repeater,
	Widget_Base,
	Group_Control_Typography
};


if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Quiety_Menu_Item extends Widget_Base {

	public function get_name() {
		return 'tt-menu-item';
	}

	public function get_title() {
		return esc_html__( 'Quiety Mega Menu Item', 'quiety-core' );
	}

	public function get_icon() {
		return 'eicon-icon-box';
	}

	public function get_categories() {
		return [ 'tt-elements' ];
	}

	protected function register_controls() {
		$this->start_controls_section( 'section_tab', [
			'label' => esc_html__( 'Menu Item', 'quiety-core' ),
		] );

		$this->add_control(
			'border_style',
			[
				'label' => __( 'Select Icon/Number', 'plugin-domain' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'icon',
				'options' => [
					'icon'  => __( 'Icon', 'plugin-domain' ),
					'number' => __( 'Number', 'plugin-domain' ),
				],
			]
		);


		$this->add_control( 'box_icon', [
			'label'       => esc_html__( 'Icon', 'quiety-core' ),
			'type'        => Controls_Manager::ICONS,
			'label_block' => true,
			'default'     => [
				'value'   => 'fas fa-star',
				'library' => 'solid',
			],
			'description' => esc_html__( 'Select icon from Fontawesome library.', 'quiety-core' ),
			'condition' => ['border_style' => 'icon']
		] );

		$this->add_control( 'serial_number', [
			'label'       => esc_html__( 'Number', 'quiety-core' ),
			'type'        => Controls_Manager::TEXT,
			'placeholder' => esc_html__( 'Title', 'quiety-core' ),
			'default'     => '1',
			'condition' => ['border_style' => 'number']
		] );


		$this->add_control( 'box_title', [
			'label'       => esc_html__( 'Menu Title', 'quiety-core' ),
			'type'        => Controls_Manager::TEXT,
			'label_block' => true,
			'placeholder' => esc_html__( 'Title', 'quiety-core' ),
			'default'     => esc_html__( 'Feature Heading', 'quiety-core' ),
		] );

		$this->add_control( 'description', [
			'label'       => esc_html__( 'Description', 'quiety-core' ),
			'type'        => Controls_Manager::TEXTAREA,
			'label_block' => true,
			'placeholder' => esc_html__( 'Description', 'quiety-core' ),
			'default'     => __( 'Product Landing Page Template', 'quiety-core' ),
			'separator'   => 'none',
			'rows' => '3'
		] );

		$this->add_control( 'menu_page_link', [
			'label'         => __( 'Link', 'quiety-core' ),
			'type'          => \Elementor\Controls_Manager::URL,
			'placeholder'   => __( 'https://your-link.com', 'quiety-core' ),
			'default'       => [
				'url'         => '#',
			],
		] );
		$this->end_controls_section();


		$this->start_controls_section( 'section_spacing_style', [
			'label' => esc_html__( 'Spacing', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_CONTENT,
		] );

		$this->add_control( 'box_padding', [
			'label'      => __( 'Padding', 'qhost-core' ),
			'type'       => Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%', 'em' ],
			'selectors'  => [
				'{{WRAPPER}} .tt-menu-item' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		] );

		$this->add_control( 'box_margin', [
			'label'      => __( 'Margin', 'qhost-core' ),
			'type'       => Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%', 'em' ],
			'selectors'  => [
				'{{WRAPPER}} .tt-menu-item' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		] );

		$this->end_controls_section();

		//Icon Style
		$this->start_controls_section( 'section_icon_style', [
			'label' => esc_html__( 'Icon', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_control( 'title_color_one', [
			'label'     => esc_html__( 'Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-menu-item .icon-container' => 'color: {{VALUE}};'
			],
		] );

		$this->add_control( 'icon_border_color', [
			'label'     => esc_html__( 'Border Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-menu-item .icon-container' => 'border-color: {{VALUE}};'
			],
		] );

		$this->add_control( 'icon_bg_color', [
			'label'     => esc_html__( 'Background', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-menu-item .icon-container' => 'background: {{VALUE}};'
			],
		] );

		$this->end_controls_section();

		//Title Style Section
		$this->start_controls_section( 'section_title_style', [
			'label' => esc_html__( 'Title', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_control( 'title_color_two', [
			'label'     => esc_html__( 'Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-menu-item .box-title,
					{{WRAPPER}} .tt-menu-item .box-title a' => 'color: {{VALUE}};'
			],
		] );
		$this->add_control( 'title_color_two_hover', [
			'label'     => esc_html__( 'Hover Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-menu-item .box-title:hover,
					{{WRAPPER}} .tt-menu-item .box-title a:hover' => 'color: {{VALUE}};'
			],
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'title_typography',
			'selector' => '{{WRAPPER}} .tt-menu-item .box-title',
		] );

		$this->end_controls_section();

		//Subtitle Style Section
		$this->start_controls_section( 'section_subtitle_style', [
			'label' => esc_html__( 'Description', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_control( 'subtitle_color', [
			'label'     => esc_html__( 'color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-menu-item .description' => 'color: {{VALUE}};',
			],
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'subtitle_typography',
			'selector' => '{{WRAPPER}} .tt-menu-item .description',
		] );

		$this->end_controls_section();
	}

	protected function render() {
		$settings = $this->get_settings_for_display();
		$target   = $settings['menu_page_link']['is_external'] ? ' target="_blank"' : '';
		$nofollow = $settings['menu_page_link']['nofollow'] ? ' rel="nofollow"' : '';

		require __DIR__ . '/templates/menu-item/menu-item.php';
	}
}
