<?php

namespace Quiety\Widgets;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Elementor\{Group_Control_Box_Shadow,
	Widget_Base,
	Controls_Manager,
	Group_Control_Typography,
	Group_Control_Border,
	Group_Control_Background};


class Quiety_Newsletter extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve alert widget name.
	 *
	 * @return string Widget name.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_name() {
		return 'tt-newsletter';
	}

	public function get_title() {
		return __( 'Quiety Newsletter', 'quiety-core' );
	}

	public function get_icon() {
		return 'eicon-mail';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the widget categories.
	 *
	 * @return array Widget categories.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_categories() {
		return [ 'tt-elements' ];
	}

    protected function register_controls() {
        $this->register_content();
        $this->register_style();
    }

    /**
     * @return void
     * Register contents tab fields
     */
    public function register_content() {

        //===================== Select Style ====================//
        $this->start_controls_section(
            'style_sec', [
                'label' => __( 'Style', 'quiety-core' ),
            ]
        );

        $this->add_control(
            'style', [
                'label' => esc_html__( 'Style', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    '1'  => esc_html__( 'Style 01', 'plugin-name' ),
                    '2' => esc_html__( 'Style 02', 'plugin-name' ),
                ],
                'default' => '1',
            ]
        );

        $this->end_controls_section(); //End Style


        //=================== Newsletter Contents ===================//
        $this->start_controls_section(
            'section_content', [
                'label' => __( 'Newsletter', 'quiety-core' ),
            ]
        );

        $this->add_control(
            'input_placeholder', [
                'label'       => esc_html__( 'Input Placeholder', 'quiety-core' ),
                'type'        => Controls_Manager::TEXT,
                'default'     => __( 'Enter your email', 'quiety-core' ),
                'label_block' => true,
            ]
        );

        $this->add_control(
            'subscribe_text', [
                'label'       => esc_html__( 'Button Text', 'quiety-core' ),
                'type'        => Controls_Manager::TEXT,
                'label_block' => true,
                'default'     => __( 'SUBSCRIBE', 'quiety-core' ),
                'separator'   => 'before',
            ]
        );

        $this->end_controls_section();

    }


    /**
     * @return void
     * Register style tab fields
     */
    public function register_style() {

        $this->start_controls_section( 'section_style_field', [
            'label' => __( 'Email Field', 'quiety-core' ),
            'tab' => Controls_Manager::TAB_STYLE,
        ] );

        $this->add_control(
            'placeholder_field_color', [
                'label' => __('Placeholder Color', 'quiety-core'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .newsletter-form input::placeholder' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'field_color', [
                'label' => __('Color', 'quiety-core'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .newsletter-form input:not([type=checkbox]):not([type=submit])' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'field_bg_color', [
                'label' => __('Background', 'quiety-core'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .newsletter-form input:not([type=checkbox]):not([type=submit])' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'field_typography',
                'label' => __('Typography', 'quiety-core'),
                'selector' => '{{WRAPPER}} .newsletter-form input:not([type=checkbox]):not([type=submit])',
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'border_field',
                'label' => __('Border', 'quiety-core'),
                'selector' => '{{WRAPPER}} .newsletter-form input:not([type=checkbox]):not([type=submit])'
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'box_field_shadow',
                'label' => __( 'Box Shadow', 'quiety-core' ),
                'selector' => '{{WRAPPER}} .newsletter-form input:not([type=checkbox]):not([type=submit])',
            ]
        );

        $this->add_control(
            'border_radius_field',
            [
                'label' => __('Border Radius', 'quiety-core'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .newsletter-form input:not([type=checkbox]):not([type=submit])' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'field_bg_color_focus',
            [
                'label' => __('Focus Background', 'quiety-core'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .newsletter-form input:not([type=checkbox]):not([type=submit]):focus' => 'background-color: {{VALUE}};',
                ],
                'separator' => 'before'
            ]
        );


        $this->add_group_control(
            Group_Control_Border::get_type(), [
                'name' => 'border_field_focus',
                'label' => __('Focus Border', 'quiety-core'),
                'selector' => '{{WRAPPER}} .newsletter-form input:not([type=checkbox]):not([type=submit]):focus'
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'box_field_shadow_focus',
                'label' => __( 'Focus Box Shadow', 'quiety-core' ),
                'selector' => '{{WRAPPER}} .newsletter-form input:not([type=checkbox]):not([type=submit]):focus',
            ]
        );

        $this->end_controls_section(); //End Style


        //================ Button Style =================//
        $this->start_controls_section(
            'section_style', [
                'label' => __('Button', 'quiety-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(), [
                'name' => 'typography',
                'label' => __('Typography', 'quiety-core'),
                'selector' => '{{WRAPPER}} .tt-btn',
            ]
        );

        $this->add_control(
            'border_radius', [
                'label' => __('Border Radius', 'quiety-core'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} a.tt-btn, {{WRAPPER}} .tt-btn' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );


        $this->add_responsive_control(
            'text_padding', [
                'label' => __('Padding', 'quiety-core'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} a.tt-btn, {{WRAPPER}} .tt-btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator' => 'before',
            ]
        );


        $this->start_controls_tabs('tabs_button_style');

        $this->start_controls_tab(
            'tab_button_normal',
            [
                'label' => __('Normal', 'quiety-core'),
            ]
        );

        $this->add_control(
            'button_text_color',
            [
                'label' => __('Color', 'quiety-core'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} a.tt-btn, {{WRAPPER}} .tt-btn' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'background_color', [
                'label' => __('Background Color', 'quiety-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tt-btn' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'border',
                'label' => __('Border', 'quiety-core'),
                'selector' => '{{WRAPPER}} .tt-btn',
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'box_shadow',
                'label' => __( 'Box Shadow', 'quiety-core' ),
                'selector' => '{{WRAPPER}} .tt-btn',
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'tab_button_hover',
            [
                'label' => __('Hover', 'quiety-core'),
            ]
        );

        $this->add_control(
            'hover_color',
            [
                'label' => __('Color', 'quiety-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tt-btn:hover' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'background_color_hover',
            [
                'label' => __('Background Color', 'quiety-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tt-btn:hover' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'border_hover',
                'label' => __('Border', 'quiety-core'),
                'selector' => '{{WRAPPER}} .tt-btn:hover'
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'box_shadow_hover',
                'label' => __( 'Box Shadow', 'quiety-core' ),
                'selector' => '{{WRAPPER}} .tt-btn:hover',
            ]
        );

        $this->end_controls_tab();
        $this->end_controls_tabs();
        $this->end_controls_section();

    }


	protected function render() {
		$settings  = $this->get_settings_for_display();


        //Template File Path
        include "templates/newsletter/newsletter-{$settings['style']}.php";

	}
}