<?php

namespace Quiety\Widgets;

use Elementor\{Controls_Manager, Group_Control_Box_Shadow, Widget_Base, Group_Control_Typography};

if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly

class Quiety_Portfolio extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve alert widget name.
	 *
	 * @return string Widget name.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_name() {
		return 'tt-portfolios';
	}

	public function get_title() {
		return __( 'Quiety Portfolio', 'quiety-core' );
	}

	public function get_icon() {
		// Icon name from the Elementor font file, as per http://dtbaker.net/web-development/creating-your-own-custom-elementor-widgets/
		return 'eicon-photo-library';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the widget categories.
	 *
	 * @return array Widget categories.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_categories() {
		return [ 'tt-elements' ];
	}

	protected function register_controls() {

		$this->start_controls_section( 'section_query', [
			'label' => __( 'Portfolio', 'quiety-core' ),
		] );

		$this->add_control( 'column', [
			'label'   => __( 'Columns Work', 'quiety-core' ),
			'type'    => Controls_Manager::SELECT,
			'options' => [
				'2 ' => __( 'Two Column', 'quiety-core' ),
				'3'  => __( 'Three Column', 'quiety-core' ),
				'4'  => __( 'Four Column', 'quiety-core' ),

			],
			'default' => '2 ',
		] );

		$this->add_control( 'ids', [
			'label'       => __( 'Enter Work IDs', 'quiety-core' ),
			'type'        => Controls_Manager::TEXT,
			'default'     => '',
			'label_block' => true,
			'description' => __( "Enter Work ids to show, separated by a comma. Leave empty to show all.", 'quiety-core' )

		] );
		$this->add_control( 'ids_not', [
			'label'       => __( 'Or Work IDs to Exclude', 'quiety-core' ),
			'type'        => Controls_Manager::TEXT,
			'default'     => '',
			'label_block' => true,
			'description' => __( "Enter Work ids to exclude, separated by a comma (,). Use if the field above is empty.", 'quiety-core' )

		] );

		$this->add_control( 'order_by', [
			'label'       => __( 'Order by', 'quiety-core' ),
			'type'        => Controls_Manager::SELECT,
			'options'     => [
				'date'          => esc_html__( 'Date', 'quiety-core' ),
				'ID'            => esc_html__( 'ID', 'quiety-core' ),
				'author'        => esc_html__( 'Author', 'quiety-core' ),
				'title'         => esc_html__( 'Title', 'quiety-core' ),
				'modified'      => esc_html__( 'Modified', 'quiety-core' ),
				'rand'          => esc_html__( 'Random', 'quiety-core' ),
				'comment_count' => esc_html__( 'Comment Count', 'quiety-core' ),
				'menu_order'    => esc_html__( 'Menu Order', 'quiety-core' ),
			],
			'default'     => 'date',
			'separator'   => 'before',
			'description' => esc_html__( "Select how to sort retrieved posts. More at ", 'quiety-core' ) . '<a href="http://codex.wordpress.org/Class_Reference/WP_Query#Order_.26_Orderby_Parameters" target="_blank">WordPress codex</a>.',
		] );

		$this->add_control( 'order', [
			'label'       => __( 'Sort Order', 'quiety-core' ),
			'type'        => Controls_Manager::SELECT,
			'options'     => [
				'ASC'  => esc_html__( 'Ascending', 'quiety-core' ),
				'DESC' => esc_html__( 'Descending', 'quiety-core' ),
			],
			'default'     => 'DESC',
			'separator'   => 'before',
			'description' => esc_html__( "Select Ascending or Descending order. More at", 'quiety-core' ) . '<a href="http://codex.wordpress.org/Class_Reference/WP_Query#Order_.26_Orderby_Parameters" target="_blank">WordPress codex</a>.',
		] );

		$this->add_control( 'posts_per_page', [
			'label'       => __( 'Work to show', 'quiety-core' ),
			'type'        => Controls_Manager::NUMBER,
			'default'     => '6',
			'description' => esc_html__( "Number of work to show (-1 for all).", 'quiety-core' ),
			'min'         => 1,
		] );


		$this->end_controls_section();

	}

	protected function render() {

		$settings = $this->get_settings_for_display();


		if ( is_admin() ){
			echo "<script>
	      if ((typeof jQuery.fn.imagesLoaded !== 'undefined') && (typeof jQuery.fn.isotope !== 'undefined')) {

                jQuery('.portfolio-items').imagesLoaded(function () {
                    var container = jQuery('.portfolio-items');

                    container.isotope({
                        itemSelector: '.quiety-portfolio-item',
                        layoutMode: 'masonry',
                    });

                    jQuery('.portfolio-filter a').on('click', function () {
                        jQuery('.portfolio-filter').find('.current').removeClass('current');
                        jQuery(this).parent().addClass('current');

                        var selector = jQuery(this).attr('data-filter');

                        container.isotope({
                            filter: selector
                        });

                        return false;
                    });
                });
            }

	         </script>";
		}

		$args  = array(
			'hide_empty' => true,
			'taxonomy'   => 'portfolio_cat',
		);

		$terms = get_terms( $args );

		?>

		<div class="quiety-portfolio-filter">
			<ul class="portfolio-filter" role="tablist">
				<li class="current">
					<a href="javascript:void(0)" data-filter="*"><?php esc_html_e( 'All', 'quiety-core' ) ?></a>
				</li>
				<?php foreach ( $terms as $term ) { ?>
					<li>
						<a href="javascript:void(0)" data-filter="<?php echo '.portfolio_cat-' . $term->slug; ?>"><?php echo $term->name; ?></a>
					</li>
				<?php } ?>
			</ul>
		</div>

		<div class="portfolio-items column-<?php echo $settings['column']; ?>">
			<?php
			$paged   = ( get_query_var( 'paged' ) ) ? get_query_var( 'paged' ) : 1;
			$args    = array(
				'post_type'      => 'portfolio',
				'paged'          => $paged,
				'order'          => $settings['order'],
				'orderby'        => $settings['order_by'],
				'post_per_page'  => 3,
				'posts_per_page' => $settings['posts_per_page'],
			);

			$portfolio = new \WP_Query( $args );

			$image_size = '';

			if ( $settings['column'] == '2' ) {
				$image_size = 'quiety-portfolio_600x600';
			} else {
				$image_size = 'quiety-portfolio_400x370';
			}

			if ( $portfolio->have_posts() ) :
				while ( $portfolio->have_posts() ) :
					$portfolio->the_post();
					?>

					<div <?php post_class( 'quiety-portfolio-item' ); ?>>
						<div class="quiety-portfolio-img">
							<?php the_post_thumbnail( $image_size ); ?>
							<div class="quiety-portfolio-info">
								<h3 class="quiety-portfolio-title">
									<a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
								</h3>
								<div class="quiety-portfolio-categories">
									<?php
									$terms = get_the_terms( get_the_ID(), 'portfolio_cat' );
									if ( $terms && ! is_wp_error( $terms ) ) :
										foreach ( $terms as $term ) { ?>
											<span class="portfolio-categories"><?php echo $term->name; ?></span>
										<?php } ?>
									<?php endif; ?>
								</div>

							</div>
						</div>
					</div>

				<?php
				endwhile;
				wp_reset_postdata();
			endif;
			?>
		</div>
		<?php
	}
}
