<?php

namespace Quiety\Widgets;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Elementor\{Controls_Manager,
	Widget_Base,
	Group_Control_Typography,
	Repeater,
	Utils
};

if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly

class Quiety_Portfolio_Info extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve alert widget name.
	 *
	 * @return string Widget name.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_name() {
		return 'tt-portfolio-info';
	}


	public function get_title() {
		return __( 'Portfolio Info', 'quiety-core' );
	}

	public function get_icon() {

		return 'eicon-form-vertical';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the widget categories.
	 *
	 * @return array Widget categories.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_categories() {
		return [ 'tt-elements' ];
	}

	protected function register_controls() {

		$this->start_controls_section( 'faq_content', [
			'label' => __( 'Portfolio Info', 'quiety-core' ),
		] );

		$repeater = new Repeater();

		$repeater->add_control( 'title', [
			'label'       => __( 'Title', 'quiety-core' ),
			'type'        => Controls_Manager::TEXT,
			'plaseholder' => __( 'title', 'quiety-core' ),
			'label_block' => true,
		] );

		$repeater->add_control( 'info', [
			'label'       => __( 'Description', 'quiety-core' ),
			'type'        => Controls_Manager::TEXTAREA,
			'plaseholder' => __( 'description', 'quiety-core' ),
			'label_block' => true,
		] );


		$this->add_control( 'info-list', [
			'label'       => __( 'Info List', 'quiety-core' ),
			'type'        => Controls_Manager::REPEATER,
			'fields'      => $repeater->get_controls(),
			'default'     => [
				[
					'title' => __( 'Client', 'quiety-core' ),
					'info'  => __( 'ThemeTags Creative Agency', 'quiety-core' ),
				],
				[
					'title' => __( 'Category', 'quiety-core' ),
					'info'  => __( 'Design and Development', 'quiety-core' ),
				],
				[
					'title' => __( 'Team', 'quiety-core' ),
					'info'  => __( 'Maria - Designer David Lee - Developer', 'quiety-core' ),
				],
			],
			'title_field' => '{{{ title }}}',
		] );


		$this->end_controls_section();

		$this->start_controls_section( 'info_style_section', [
			'label' => __( 'Style', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );


		$this->add_control( 'title_color', [
			'label'     => __( 'Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .portfolio-info-item .title' => 'color: {{VALUE}}',
			],
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'info_typography',
			'label'    => __( 'Info Typography', 'quiety-core' ),
			'selector' => '{{WRAPPER}} .portfolio-info-item .title',
			'separator' => 'before'
		] );

		$this->add_control( 'info_color', [
			'label'     => __( 'Info Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .portfolio-info-item .info' => 'color: {{VALUE}}',
			],
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'ans_typography',
			'label'    => __( 'Info Typography', 'quiety-core' ),
			'selector' => '{{WRAPPER}} .portfolio-info-item .info',
		] );

		$this->end_controls_section();

	}

	protected function render() {
		$settings = $this->get_settings_for_display();

		if ( $settings['info-list'] ) { ?>
			<div class="portfolio-info-wrapper">
				<?php foreach ( $settings['info-list'] as $item ) { ?>
					<div class="portfolio-info-item">
						<?php if ( ! empty( $item['title'] ) ) : ?>
							<h4 class="title"><?php echo $item['title']; ?></h4>
						<?php endif; ?>

						<?php if ( ! empty( $item['info'] ) ) : ?>
							<p class="info"><?php echo $item['info']; ?></p>
						<?php endif; ?>
					</div>
				<?php } ?>
			</div>
			<!-- /.project-info-wrapper -->
		<?php }
	}

}

