<?php

namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly

class Quiety_Portfolio_Slider extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve alert widget name.
	 *
	 * @return string Widget name.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_name() {
		return 'at-job-slider';
	}

	// public function get_id() {
	//    	return 'header-search';
	// }

	public function get_title() {
		return __( 'Quiety Portfolio Slider', 'quiety-core' );
	}

	public function get_icon() {
		// Icon name from the Elementor font file, as per http://dtbaker.net/web-development/creating-your-own-custom-elementor-widgets/
		return 'eicon-photo-library';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the widget categories.
	 *
	 * @return array Widget categories.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_categories() {
		return [ 'at-elements' ];
	}

	protected function register_controls() {

		$this->start_controls_section(
			'section_query', [
				'label' => __( 'Portfolio Slider', 'quiety-core' ),
			]
		);

		$this->add_control(
			'layout',
			[
				'label' => __('Style', 'quiety-core'),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'style-one',
				'options' => [
					'style-one' => __('Style One', 'quiety-core'),
					'style-two' => __('Style Two', 'quiety-core'),
				],
			]
		);

		$this->add_control( 'thumbnail_default_size', [
			'label'        => esc_html__( 'Use Default Thumbnail Size', 'quiety-core' ),
			'type'         => Controls_Manager::SWITCHER,
			'default'      => '1',
			'return_value' => '1',
			'separator'    => 'before',
		] );

		$this->add_group_control( Group_Control_Image_Size::get_type(), [
			'name'      => 'thumbnail',
			'default'   => 'full',
			'condition' => [
				'thumbnail_default_size!' => '1',
			],
		] );


		$this->add_control(
			'ids',
			[
				'label'       => __( 'Enter Work IDs', 'quiety-core' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => '',
				'label_block' => true,
				'description' => __( "Enter Work ids to show, separated by a comma. Leave empty to show all.", 'quiety-core' )

			]
		);
		$this->add_control(
			'ids_not',
			[
				'label'       => __( 'Or Work IDs to Exclude', 'quiety-core' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => '',
				'label_block' => true,
				'description' => __( "Enter Work ids to exclude, separated by a comma (,). Use if the field above is empty.", 'quiety-core' )

			]
		);

		$this->add_control(
			'order_by',
			[
				'label'       => __( 'Order by', 'quiety-core' ),
				'type'        => Controls_Manager::SELECT,
				'options'     => [
					'date'          => esc_html__( 'Date', 'quiety-core' ),
					'ID'            => esc_html__( 'ID', 'quiety-core' ),
					'author'        => esc_html__( 'Author', 'quiety-core' ),
					'title'         => esc_html__( 'Title', 'quiety-core' ),
					'modified'      => esc_html__( 'Modified', 'quiety-core' ),
					'rand'          => esc_html__( 'Random', 'quiety-core' ),
					'comment_count' => esc_html__( 'Comment Count', 'quiety-core' ),
					'menu_order'    => esc_html__( 'Menu Order', 'quiety-core' ),
				],
				'default'     => 'date',
				'separator'   => 'before',
				'description' => esc_html__( "Select how to sort retrieved posts. More at ", 'quiety-core' ) . '<a href="http://codex.wordpress.org/Class_Reference/WP_Query#Order_.26_Orderby_Parameters" target="_blank">WordPress codex</a>.',
			]
		);

		$this->add_control(
			'order',
			[
				'label'       => __( 'Sort Order', 'quiety-core' ),
				'type'        => Controls_Manager::SELECT,
				'options'     => [
					'ASC'  => esc_html__( 'Ascending', 'quiety-core' ),
					'DESC' => esc_html__( 'Descending', 'quiety-core' ),
				],
				'default'     => 'DESC',
				'separator'   => 'before',
				'description' => esc_html__( "Select Ascending or Descending order. More at", 'quiety-core' ) . '<a href="http://codex.wordpress.org/Class_Reference/WP_Query#Order_.26_Orderby_Parameters" target="_blank">WordPress codex</a>.',
			]
		);

		$this->add_control(
			'posts_per_page',
			[
				'label'       => __( 'Work to show', 'quiety-core' ),
				'type'        => Controls_Manager::NUMBER,
				'default'     => '6',
				'description' => esc_html__( "Number of work to show (-1 for all).", 'quiety-core' ),
				'min'         => 1,
			]
		);


		$this->end_controls_section();

		$this->start_controls_section( 'settingd_section', [
			'label' => esc_html__( 'Slider Control', 'quiety-core' ),
		] );

		$this->add_control(
			'slide_view',
			[
				'label'   => __( 'Slide Per View', 'quiety-core' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'default' => '3',
				'options' => [
					'3' => __( '3', 'quiety-core' ),
					'4' => __( '4', 'quiety-core' ),
					'5' => __( '5', 'quiety-core' ),
					'6' => __( '6', 'quiety-core' ),
				],
			]
		);

		$this->add_control(
			'slider_gap',
			[
				'label'   => __( 'Slider Gap', 'quiety-core' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 30,
			]
		);

		$this->add_control(
			'slider_navigation',
			[
				'label' => esc_html__('Navigation', 'quiety-core'),
				'type' => Controls_Manager::SWITCHER,
				'label_on' => esc_html__('Show', 'quiety-core'),
				'label_off' => esc_html__('Hide', 'quiety-core'),
				'return_value' => 'yes',
				'default' => 'yes'
			]
		);


		$this->add_control(
			'loop',
			[
				'label'        => esc_html__( 'Loop', 'quiety-core' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'On', 'quiety-core' ),
				'label_off'    => esc_html__( 'Off', 'quiety-core' ),
				'return_value' => 'true',
				'default'      => 'yes'
			]
		);

		$this->add_control(
			'speed',
			[
				'label'   => __( 'Speed', 'quiety-core' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 700,
			]
		);



		$this->add_control(
			'autoplay',
			[
				'label'        => esc_html__( 'Autoplay', 'quiety-core' ),
				'type'         => Controls_Manager::SWITCHER,
				'label_on'     => esc_html__( 'On', 'quiety-core' ),
				'label_off'    => esc_html__( 'Off', 'quiety-core' ),
				'return_value' => 'true',
				'default'      => 'yes'
			]
		);

		$this->add_control(
			'autoplay_time',
			[
				'label'   => __( 'Autoplay Time', 'quiety-core' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 3000,
			]
		);

		$this->add_control(
			'slide_gap',
			[
				'label'   => __( 'Slider Gap', 'quiety-core' ),
				'type'    => Controls_Manager::NUMBER,
				'default' => 30,
			]
		);

		$this->end_controls_section();

	}

	protected function render() {

		$settings = $this->get_settings();

		$this->add_render_attribute( 'wrapper', 'class', [
			'swiper-container',
			'at-job-slider'
		] );


		$slider_options = $this->get_slider_options( $settings );

		$this->add_render_attribute( 'wrapper', 'data-swiper', wp_json_encode( $slider_options ) );


		$args  = array(
			'hide_empty' => true,
			'taxonomy'   => 'portfolio_cat',
		);
		$terms = get_terms( $args );

		?>


		<div class="protfolio-slider-wrap">


			<div <?php $this->print_render_attribute_string( 'wrapper' ); ?>>
				<div class="swiper-wrapper">
					<!-- <div class="grid-sizer"></div> -->
					<?php
					$paged     = ( get_query_var( 'paged' ) ) ? get_query_var( 'paged' ) : 1;
					$args      = array(
						'post_type'      => 'job',
						'paged'          => $paged,
						'order'          => $settings['order'],
						'orderby'        => $settings['order_by'],
						'posts_per_page' => $settings['posts_per_page'],
					);
					$portfolio = new \WP_Query( $args );


					if ( $portfolio->have_posts() ) :
						while ( $portfolio->have_posts() ) : $portfolio->the_post(); ?>
							<div <?php post_class( 'swiper-slide' ); ?>>
								<div class="portfolio-slider <?php echo $settings['layout']; ?>">
									<?php if ( has_post_thumbnail() ) { ?>
										<div class="post-thumbnail">
											<?php $size = \Quiety_Image::elementor_parse_image_size( $settings, '540x700' ); ?>
											<?php \Quiety_Image::the_post_thumbnail( array( 'size' => $size ) ); ?>
										</div>
									<?php } ?>


									<div class="portfolio-info">
										<h3 class="portfolio-title">
											<a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
										</h3>
										<div class="portfolio-cat">
											<?php
											$terms = get_the_terms( get_the_ID(), 'portfolio_cat' );
											if ( $terms && ! is_wp_error( $terms ) ) :
												foreach ( $terms as $term ) { ?>
													<span class="cat"><?php echo $term->name; ?></span>
												<?php } ?>
											<?php endif; ?>
										</div>

									</div>
								</div>

							</div>
						<?php endwhile;
						wp_reset_postdata();
					endif; ?>
				</div>
			</div>

			<?php if ( $settings['slider_navigation'] == 'yes') : ?>
				<div class="slider-control">
					<div class="quiety-next">
						<i class="fas fa-chevron-right"></i>
					</div>

					<div class="quiety-prev">
						<i class="fas fa-chevron-left"></i>
					</div>
				</div>
				<!-- /.slider-control -->
			<?php endif; ?>

		</div>
		<!-- /.protfolio-slider-wrap -->

	<?php }

	protected function _content_template() {
	}

	protected function get_slider_options( array $settings ) {

		// Loop
		if ( $settings['loop'] ) {
			$slider_options['loop'] = (bool) $settings['loop'];

		}

		if ( $settings['slider_gap']) {
			$slider_options['spaceBetween'] = (int)$settings['slider_gap'];
		}

		// Speed
		if ( ! empty( $settings['speed'] ) ) {
			$slider_options['speed'] = $settings['speed'];
		}
		if ( $settings['autoplay'] ) {
			$slider_options['autoplay'] = (bool) $settings['autoplay'];
		}

		if ( $settings['autoplay'] ) {
			$slider_options['autoplay'] = [
				'delay' => $settings['autoplay_time']
			];
		}

		//		if ( $settings['pagination'] ) {
		//			$slider_options['pagination'] = [
		//				'el' => '.swiper-pagination',
		//                'clickable' => true
		//			];
		//		}

		$slider_options['breakpoints'] = [
			'992' => [
				'slidesPerView' => (int) $settings['slide_view'],
			],

			'767' => [
				'slidesPerView' => 3,
			],

			'576' => [
				'slidesPerView' => 2,
			],

			'320' => [
				'slidesPerView' => 1,
			],
		];

		$slider_options['navigation'] = [
			'nextEl' => '.quiety-next',
			'prevEl' => '.quiety-prev',
		];

		if ( $settings['slide_gap'] ) {
			$slider_options['spaceBetween'] = (int) $settings['slide_gap'];

		}

		return $slider_options;
	}

}
