<?php

namespace Quiety\Widgets;

if (!defined('ABSPATH')) {
	exit;
}

use Elementor\{
	Controls_Manager,
	Group_Control_Background,
	Widget_Base,
	Group_Control_Typography,
	Group_Control_Box_Shadow,
	Group_Control_Border
};

class Quiety_Pricing_Single extends Widget_Base
{

	public function get_name()
	{
		return 'tt-pricing-table-single';
	}

	public function get_title()
	{
		return __('Quiety Pricing Single', 'quiety-core');
	}

	public function get_icon()
	{
		return 'eicon-price-table';
	}

	public function get_categories()
	{
		return ['tt-elements'];
	}

	protected function register_controls()
	{

		$this->start_controls_section('pricing', [
			'label' => __('Pricing', 'quiety-core'),
		]);

		$this->add_control('layout', [
			'type'    => Controls_Manager::SELECT,
			'label'   => __('Layout', 'quiety-core'),
			'default' => 'style-one',
			'options' => [
				'style-one'  => __('Style One', 'quiety-core'),
				'style-two'  => __('Style Two', 'quiety-core'),
				'style-three' => __('Style Three', 'quiety-core'),
				'style-four' => __('Style Four', 'quiety-core'),
			],
		]);

		$this->end_controls_section();

		$this->start_controls_section('pricing_plane', [
			'label' => __('Pricing Plans', 'quiety-core'),
			'tab'   => Controls_Manager::TAB_CONTENT,
		]);

		$this->add_control('featured_table', [
			'label'        => __('Do you want to feature it?', 'quiety-core'),
			'type'         => Controls_Manager::SWITCHER,
			'label_on'     => __('Yes', 'your-plugin'),
			'label_off'    => __('No', 'your-plugin'),
			'return_value' => 'yes',
			'default'      => 'no',
		]);

		$this->add_control('table_title', [
			'label'       => __('Table Title', 'quiety-core'),
			'type'        => Controls_Manager::TEXT,
			'label_block' => true,
			'default'     => __('Standard', 'quiety-core')
		]);

		$this->add_control('price_feature_img', [
			'label'       => __('Feature Image', 'quiety-core'),
			'type'        => Controls_Manager::MEDIA,
			'condition'	  => [
				'layout'	=> 'style-four'
			]
		]);

		$this->add_control('table_price', [
			'label'       => __('Price', 'quiety-core'),
			'type'        => Controls_Manager::TEXT,
			'label_block' => true,
			'default'     => __('29', 'quiety-core')
		]);

		$this->add_control('currency', [
			'label'       => __('Currency', 'quiety-core'),
			'type'        => Controls_Manager::TEXT,
			'label_block' => false,
			'default'     => '$'
		]);

		$this->add_control('period', [
			'label'       => __('Period', 'quiety-core'),
			'type'        => Controls_Manager::TEXT,
			'label_block' => true,
			'default'     => __('/month', 'quiety-core')
		]);

		$this->add_control('short_desc', [
			'label'       => __('Short Description', 'quiety-core'),
			'type'        => Controls_Manager::TEXTAREA,
			'label_block' => true,
			'default'     => '',
			'condition'	  => [
				'layout'	=> 'style-four'
			]
		]);

		$repeater = new \Elementor\Repeater();

		$repeater->add_control('feature', [
			'label'       => __('Feature Title', 'quiety-core'),
			'type'        => \Elementor\Controls_Manager::TEXT,
			'label_block' => true,
		]);

		$repeater->add_control('feature_before', [
			'label'   => __('Feature Before', 'quiety-core'),
			'type'    => Controls_Manager::SELECT,
			'default' => 'bullet',
			'options' => [
				'bullet'  => __('Bullet', 'quiety-core'),
				'include' => __('Include', 'quiety-core'),
				'exclude' => __('Exclude', 'quiety-core'),
				'check'	  => __('Check', 'quiety-core'),
			],
		]);

		$this->add_control('features', [
			'label'       => __('Repeater List', 'quiety-core'),
			'type'        => \Elementor\Controls_Manager::REPEATER,
			'fields'      => $repeater->get_controls(),
			'default'     => [
				[
					'feature' => __('1 Team', 'quiety-core'),
				],
				[
					'feature' => __('1 Installed Agent', 'quiety-core'),
				],
				[
					'feature' => __('Real-Time Feedback', 'quiety-core'),
				],
				[
					'feature' => __('Video Dedicated Support', 'quiety-core'),
				],
				[
					'feature' => __('1 Attacked Targets Per Month', 'quiety-core'),
				],
				[
					'feature' => __('Team Collaboration Tools', 'quiety-core'),
				],
				[
					'feature' => __('Automated Updated Features', 'quiety-core'),
				],
				[
					'feature' => __('24/7 Life time Support', 'quiety-core'),
				],
			],
			'title_field' => '{{{ feature }}}',
		]);

		$this->add_control('button_text', [
			'label'       => __('Button Text', 'quiety-core'),
			'type'        => Controls_Manager::TEXT,
			'default'     => __('Buy Now', 'quiety-core'),
			'label_block' => true,
		]);

		$this->add_control('btn_url', [
			'label'         => __('Button URL', 'quiety-core'),
			'type'          => Controls_Manager::URL,
			'placeholder'   => __('https://your-link.com', 'quiety-core'),
			'default'       => [
				'url'         => '#',
			],
		]);

		$this->end_controls_section();


		/**
		 * Pricing Style
		 */
		$this->start_controls_section('section_title_style', [
			'label' => __('Pricing Header', 'quiety-core'),
			'tab'   => Controls_Manager::TAB_STYLE,
		]);

		$this->add_control('title_color', [
			'label'     => __('Title Color', 'quiety-core'),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-pricing__title' => 'color: {{VALUE}};',
				'{{WRAPPER}} .single-game-price .pricing_table_header .table_title' => 'color: {{VALUE}};',
			],
		]);

		$this->add_group_control(Group_Control_Typography::get_type(), [
			'name'     => 'title_typography',
			'label'    => __('Typography', 'quiety-core'),
			'selector' => '
				{{WRAPPER}} .tt-pricing__title,
				{{WRAPPER}} .single-game-price .pricing_table_header .table_title
			',
		]);

		$this->add_responsive_control('title_space', [
			'label'     => esc_html__('Spacing', 'quiety-core'),
			'type'      => Controls_Manager::SLIDER,
			'range'     => [
				'px' => [
					'min' => 0,
					'max' => 100,
				],
			],
			'selectors' => [
				'{{WRAPPER}} .tt-pricing__title' => 'margin-bottom: {{SIZE}}{{UNIT}};',
				'{{WRAPPER}} .single-game-price .pricing_table_header .table_title' => 'margin-bottom: {{SIZE}}{{UNIT}};',
			],
		]);

		$this->add_control('price_style', [
			'label'     => __('Price', 'quiety-core'),
			'type'      => Controls_Manager::HEADING,
			'separator' => 'before',
		]);

		$this->add_control('price_color', [
			'label'     => __('Price Label Color', 'quiety-core'),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-pricing__price-wrap' => 'color: {{VALUE}} !important;',
				'{{WRAPPER}} .single-game-price .pricing_table_header span' => 'color: {{VALUE}} ',
			],
		]);

		$this->add_group_control(Group_Control_Typography::get_type(), [
			'name'     => 'price_typography',
			'label'    => __('Typography', 'quiety-core'),
			'selector' => '
				{{WRAPPER}} .tt-pricing__price-wrap,
				{{WRAPPER}} .single-game-price .pricing_table_header span	
			',
		]);

		$this->add_control('period_color', [
			'label'     => __('Period Color', 'quiety-core'),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-pricing__period' => 'color: {{VALUE}} !important;',
			],
			'separator' => 'before',
			'condition'	=> [
				'layout!' => 'style-four'
			]
		]);

		$this->add_group_control(Group_Control_Typography::get_type(), [
			'name'     => 'period_typography',
			'label'    => __('Period Typography', 'quiety-core'),
			'selector' => '{{WRAPPER}} .tt-pricing__period',
			'condition'	=> [
				'layout!' => 'style-four'
			]
		]);

		$this->add_control('short_des_style', [
			'label'     => __('Short Description', 'quiety-core'),
			'type'      => Controls_Manager::HEADING,
			'separator' => 'before',
			'condition'	=> [
				'layout' => 'style-four'
			]
		]);

		$this->add_control('short_desc_color', [
			'label'     => __('Description  Color', 'quiety-core'),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .single-game-price p' => 'color: {{VALUE}} ',
			],
			'condition'	=> [
				'layout' => 'style-four'
			]
		]);

		$this->add_group_control(Group_Control_Typography::get_type(), [
			'name'     => 'short_desc_typography',
			'label'    => __('Typography', 'quiety-core'),
			'selector' => '
				{{WRAPPER}} .single-game-price p
			',
			'condition'	=> [
				'layout' => 'style-four'
			]
		]);

		$this->end_controls_section();


		/**
		 * Feature Pricing Table Style
		 */
		$this->start_controls_section('section_fea_style', [
			'label' => __('Pricing Feature', 'quiety-core'),
			'tab'   => Controls_Manager::TAB_STYLE,
		]);

		$this->add_control('feature_color', [
			'label'     => __('Color', 'quiety-core'),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-pricing__feature-list li' => 'color: {{VALUE}};',
				'{{WRAPPER}} .single-game-price ul li' => 'color: {{VALUE}};',
			],
		]);

		$this->add_group_control(Group_Control_Typography::get_type(), [
			'name'     => 'feature_typography',
			'label'    => __('Typography', 'quiety-core'),
			'selector' => '{{WRAPPER}} .tt-pricing__feature-list li',
			'selector' => '{{WRAPPER}} .single-game-price ul li'
		]);

		$this->add_control('bullet_color', [
			'label'     => __('Bullet Color', 'quiety-core'),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .bullet' => 'background-color: {{VALUE}};',
			],
		]);

		$this->add_control('include_color', [
			'label'     => __('Include Icon Color', 'quiety-core'),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .ei-icon_check' => 'color: {{VALUE}};',
			],
		]);

		$this->add_control('exclude_color', [
			'label'     => __('Exclude Icon Color', 'quiety-core'),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .ei-icon_close' => 'color: {{VALUE}};',
			],
		]);

		$this->add_group_control(Group_Control_Box_Shadow::get_type(), [
			'name'     => 'table_box_shadow_fea',
			'label'    => __('Box Shadow Hover', 'quiety-core'),
			'selector' => '{{WRAPPER}} .single_pricing_plan.active:hover',
		]);

		$this->add_responsive_control('feature_space', [
			'label'     => esc_html__('Gap', 'quiety-core'),
			'type'      => Controls_Manager::SLIDER,
			'range'     => [
				'px' => [
					'min' => 0,
					'max' => 20,
				],
			],
			'selectors' => [
				'{{WRAPPER}} .tt-pricing__feature-list li:not(:last-child)' => 'margin-bottom: {{SIZE}}{{UNIT}};',
				'{{WRAPPER}} .single-game-price ul li:not(:last-child)' => 'margin-bottom: {{SIZE}}{{UNIT}};',
			],
		]);

		$this->end_controls_section();

		// Button Style
		// =====================
		$this->start_controls_section('style_button', [
			'label' => __('Button', 'quiety-core'),
			'tab'   => Controls_Manager::TAB_STYLE,
		]);

		$this->start_controls_tabs('tabs_button_style');

		$this->start_controls_tab('tab_button_normal', [
			'label' => __('Normal', 'quiety-core'),
		]);

		$this->add_control('button_text_color', [
			'label'     => __('Text Color', 'quiety-core'),
			'type'      => Controls_Manager::COLOR,
			'default'   => '',
			'selectors' => [
				'{{WRAPPER}} .tt-btn' => 'color: {{VALUE}};',
			],
		]);

		$this->add_control('button_bg_color', [
			'label'     => __('Background Color', 'quiety-core'),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-btn' => 'background-color: {{VALUE}};',
			],
		]);

		$this->add_group_control(Group_Control_Border::get_type(), [
			'name'     => 'button_border',
			'label'    => __('Border', 'quiety-core'),
			'selector' => '{{WRAPPER}} .tt-btn',
		]);

		$this->add_group_control(Group_Control_Box_Shadow::get_type(), [
			'name'     => 'button_box_shadow',
			'label'    => __('Box Shadow', 'quiety-core'),
			'selector' => '{{WRAPPER}} .tt-btn',
		]);

		$this->end_controls_tab();

		$this->start_controls_tab('tab_button_hover', [
			'label' => __('Hover', 'quiety-core'),
		]);

		$this->add_control('hover_color', [
			'label'     => __('Color', 'quiety-core'),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-btn:hover' => 'color: {{VALUE}};',
			],
		]);

		$this->add_control('button_hover_bg_color', [
			'label'     => __('Background Color', 'quiety-core'),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-btn:hover' => 'background-color: {{VALUE}};',
			]
		]);

		$this->add_group_control(Group_Control_Border::get_type(), [
			'name'     => 'button_hover_border',
			'label'    => __('Border', 'quiety-core'),
			'selector' => '{{WRAPPER}} .tt-btn:hover',
		]);

		$this->add_group_control(Group_Control_Box_Shadow::get_type(), [
			'name'     => 'button_box_shadow_hover',
			'label'    => __('Box Shadow', 'quiety-core'),
			'selector' => '{{WRAPPER}} .tt-btn',
		]);

		$this->end_controls_tab();
		$this->end_controls_tabs();

		$this->add_group_control(Group_Control_Typography::get_type(), [
			'name'      => 'button_typography',
			'label'     => __('Typography', 'quiety-core'),
			'selector'  => '{{WRAPPER}} .tt-btn',
			'separator' => 'before'
		]);

		$this->add_control('padding', [
			'label'      => __('Padding', 'quiety-core'),
			'type'       => Controls_Manager::DIMENSIONS,
			'size_units' => ['px', '%', 'em'],
			'selectors'  => [
				'{{WRAPPER}} .tt-btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		]);

		$this->add_control('border-radius', [
			'label'      => __('Border Radius', 'quiety-core'),
			'type'       => Controls_Manager::DIMENSIONS,
			'size_units' => ['px', '%', 'em'],
			'selectors'  => [
				'{{WRAPPER}} .tt-btn' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		]);

		$this->end_controls_section();


		$this->start_controls_section('style_pricing_box', [
			'label' => __('Pricing Box', 'quiety-core'),
			'tab'   => Controls_Manager::TAB_STYLE,
		]);

		$this->start_controls_tabs('tabs_pricing_style');

		$this->start_controls_tab('tab_pricing_normal', [
			'label' => __('Normal', 'quiety-core'),
		]);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'pricing_background',
				'label' => __('Background', 'quiety-core'),
				'types' => ['classic', 'gradient', 'video'],
				'selector' => '{{WRAPPER}} .tt-pricing ',
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'pricing_box_shadow',
				'label' => __('Box Shadow', 'quiety-core'),
				'selector' => '{{WRAPPER}} .tt-pricing',
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab('tab_pricing_hover', [
			'label' => __('Hover', 'quiety-core'),
		]);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'pricing_background_hover',
				'label' => __('Background', 'quiety-core'),
				'types' => ['classic', 'gradient', 'video'],
				'selector' => '{{WRAPPER}} .tt-pricing:hover',
			]
		);

		$this->add_group_control(
			\Elementor\Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'pricing_hover_box_shadow',
				'label' => __('Box Shadow', 'quiety-core'),
				'selector' => '{{WRAPPER}} .tt-pricing:hover',
			]
		);

		$this->end_controls_tab();
		$this->end_controls_tabs();

		$this->add_control('pricing_padding', [
			'label'      => __('Padding', 'quiety-core'),
			'type'       => Controls_Manager::DIMENSIONS,
			'size_units' => ['px', '%', 'em'],
			'selectors'  => [
				'{{WRAPPER}} .tt-btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		]);

		$this->add_control('pricing_border-radius', [
			'label'      => __('Border Radius', 'quiety-core'),
			'type'       => Controls_Manager::DIMENSIONS,
			'size_units' => ['px', '%', 'em'],
			'selectors'  => [
				'{{WRAPPER}} .tt-btn' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		]);

		$this->end_controls_section();
	}

	protected function render()
	{
		$settings = $this->get_settings();

		if ($settings['layout'] == 'style-four') { 
			$is_featured = $settings['featured_table'] == 'yes' ? 'active' : '';
			?>
			<div class="single-game-price mb-4 mb-lg-0 <?php echo esc_html( $is_featured )?>">
				<div class="d-flex align-items-center">
					<?php
					if ( !empty( $settings['price_feature_img']['id'] ) ) { ?>
						<div class="price-icon me-3 flex-shrink-0">
							<?php echo wp_get_attachment_image($settings['price_feature_img']['id'] ); ?>
						</div>
					<?php
					}
					?>
					<div class="pricing_table_header">
						<?php
						if (!empty($settings['table_title'])) {
							echo '<h5 class="table_title mb-1">' . esc_html($settings['table_title']) . '</h5>';
						}
						if (!empty($settings['table_price'])) {
							echo '<span class="text-off-white">' . esc_html__('Starting at ', 'quiety-core') . esc_html($settings['currency']) . esc_html($settings['table_price']) . esc_html($settings['period']) . '</span>';
						}
						?>
					</div>
				</div>
				<?php
				if (!empty($settings['short_desc'])) {
					echo '<p class="py-3 m-0">' . esc_html($settings['short_desc']) . '</p>';
				}
				?>

				<ul class="list-unstyled">
					<?php
					if (is_array($settings['features'])) {
						foreach ($settings['features'] as $item) { ?>
							<li class="pb-2">
								<?php
								if ($item['feature_before'] == 'check') { ?>
									<i class="fas fa-check me-2"></i>
								<?php
								}
								?>
								<span><?php echo esc_html($item['feature']) ?></span>
							</li>
					<?php
						}
					}
					?>
				</ul>
				<?php
				if (!empty($settings['button_text'])) {
					echo '<div class="game-price-btn"><a href="' . esc_url($settings['btn_url']['url']) . '" class="mt-4">' . esc_html($settings['button_text']) . '</a></div>';
				}
				?>
			</div>
		<?php
		} else {
			$this->add_render_attribute('wrapper', 'class', 'tt-pricing');

			if ($settings['featured_table'] == 'yes') {
				$this->add_render_attribute('wrapper', 'class', 'featured');
			}

			if (!empty($settings['layout'])) {
				$this->add_render_attribute('wrapper', 'class', $settings['layout']);
			}

		?>

			<div <?php $this->print_render_attribute_string('wrapper'); ?>>

				<?php if ($settings['featured_table'] == 'yes') { ?>
					<span class="feature-star">
						<svg width="56" height="70" viewBox="0 0 56 70" fill="none" xmlns="http://www.w3.org/2000/svg">
							<path d="M53.2605 3.08451C52.3941 1.17426 50.8033 0 49.0835 0H27.7273H6.37205C4.65223 0 3.06147 1.17426 2.19505 3.08451L0 7.92208H27.7273H55.4545L53.2605 3.08451Z" fill="#C4C4C4" />
							<path d="M10.1384 68.144C10.1394 68.7198 10.4114 69.2478 10.8454 69.5226C11.2795 69.7973 11.8089 69.7746 12.2235 69.4616L24.0948 60.5163C26.3051 58.851 29.1485 58.851 31.3587 60.5163L43.2311 69.4616C43.6466 69.7746 44.1751 69.7985 44.6102 69.5238C45.0452 69.249 45.3151 68.7198 45.3161 68.144C45.3438 56.4569 45.3592 13.1982 45.3592 13.1982C45.3592 8.27996 46.9887 3.55282 49.9091 0H27.7283H5.54546C8.46582 3.55282 10.0953 8.28116 10.0953 13.1994C10.0953 13.1994 10.1117 56.4569 10.1384 68.144Z" fill="white" />
							<path d="M27.0489 24.9271C27.3483 24.0057 28.6517 24.0057 28.9511 24.9271L31.1432 31.6738C31.2771 32.0858 31.661 32.3647 32.0943 32.3647H39.1882C40.1569 32.3647 40.5597 33.6044 39.776 34.1738L34.0369 38.3435C33.6864 38.5981 33.5397 39.0495 33.6736 39.4615L35.8657 46.2082C36.1651 47.1295 35.1106 47.8956 34.3269 47.3262L28.5878 43.1565C28.2373 42.9019 27.7627 42.9019 27.4122 43.1565L21.6731 47.3262C20.8894 47.8956 19.8349 47.1295 20.1343 46.2082L22.3264 39.4615C22.4603 39.0495 22.3136 38.5981 21.9631 38.3435L16.2241 34.1738C15.4403 33.6044 15.8431 32.3647 16.8118 32.3647H23.9057C24.339 32.3647 24.7229 32.0858 24.8568 31.6738L27.0489 24.9271Z" fill="#162D89" />
						</svg>
					</span>
				<?php } ?>

				<div class="tt-pricing__header">
					<?php if ($settings['table_title']) : ?>
						<h2 class="tt-pricing__title"><?php esc_html_e($settings['table_title']); ?></h2>
					<?php endif; ?>

					<?php if ($settings['table_price']) : ?>
						<h3 class="tt-pricing__price">
							<?php if (!empty($settings['table_price'])) : ?>
								<span class="tt-pricing__price-wrap"><span class="currency"><?php esc_html_e($settings['currency']); ?></span><?php endif; ?><span><?php esc_html_e($settings['table_price']); ?></span><?php if ($settings['period']) : ?></span><span class="tt-pricing__period"><?php esc_html_e($settings['period']); ?></span>
							<?php endif; ?>
						</h3>
					<?php endif; ?>
				</div>

				<div class="tt-pricing__feature-lists">
					<ul class="tt-pricing__feature-list">


						<?php foreach ($settings['features'] as $item) : ?>

							<?php
							$item_class = '';

							if ($item['feature_before'] == 'include') :
								$item_class = 'include';
							elseif ($item['feature_before'] == 'exclude') :
								$item_class = 'exclude';
							endif;
							?>

							<li class="<?php echo $item_class ?>">
								<?php if ($item['feature_before'] == 'include') : ?>
									<i class="ei ei-icon_check_alt2"></i>
								<?php elseif ($item['feature_before'] == 'exclude') : ?>
									<i class="ei ei-icon_close_alt2"></i>
								<?php elseif ($item['feature_before'] == 'bullet') : ?>
									<span class="bullet"></span>
								<?php endif; ?>
								<?php esc_html_e($item['feature']); ?>
							</li>
						<?php endforeach; ?>
					</ul>
					<!-- /.tt-pricing__feature-list -->
				</div>
				<!-- /.tt-pricing__feature-lists -->

				<?php if ($settings['btn_url']['url']) : ?>
					<div class="tt-pricing__action">
						<a href="<?php echo esc_url($settings['btn_url']['url']); ?>" class="tt-btn <?php echo $settings['featured_table'] == 'yes' ? 'featured_btn' : 'btn-outline' ?> ">
							<?php esc_html_e($settings['button_text']) ?>
						</a>
					</div>
					<!-- /.gp-pricing__action -->
				<?php endif; ?>
			</div>
			<!-- /.tt-pricing -->
<?php
		}
	}
}
