<?php

namespace Quiety\Widgets;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Elementor\{Controls_Manager,
	Group_Control_Background,
	Group_Control_Border,
	Group_Control_Box_Shadow,
	Widget_Base,
	Group_Control_Typography,
	Repeater,
	Utils};

class quiety_pricing_table_tabs extends Widget_Base {

	public function get_name() {
		return 'tt-pricing-box-two';
	}

	public function get_title() {
		return esc_html__( 'Quiety Pricing Table Tabs', 'quiety-core' );
	}

	public function get_icon() {
		return 'eicon-price-table';
	}

	public function get_categories() {
		return [ 'tt-elements' ];
	}


    /**
     * Name: register_controls
     * Desc: Register controls for these widgets
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @quiety
     * Author: Themetags
     */
    protected function register_controls() {
        $this-> elementor_content_control();
        $this-> elementor_style_control();
    }

    /**
     * Name: quiety_elementor_content_control
     * Desc: Register content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @quiety
     * Author: Themetags
     */
    public function elementor_content_control() {


        //========================= Select Layout ========================//
        $this->start_controls_section( 'select_layout', [
            'label' => esc_html__( 'Select Layout', 'quiety-core' ),
        ] );

        $this->add_control(
            'layout', [
                'label' => __( 'Layout', 'quiety-core' ),
                'type' => \Elementor\Controls_Manager::SELECT,
                'default' => '1',
                'options' => [
                    '1'  => __( '01: Layout', 'quiety-core' ),
                    '2'  => __( '02: Layout', 'quiety-core' ),
                ],
            ]
        );

        $this->end_controls_section(); //End Layout


        //========================= Pricing Table Tabs =========================//
        $this->start_controls_section( 'section_price_info', [
            'label' => esc_html__( 'Pricing Info', 'quiety-core' ),
            'condition' => [
                'layout' => '1'
            ]
        ] );

        $this->start_controls_tabs('tabs_pricing_content');
        $this->start_controls_tab(
            'tab_content_primary',
            [
                'label' => __('Primary', 'quiety-core'),
            ]
        );

        $this->add_control( 'tab_primary', [
            'label'       => esc_html__( 'Primary Label', 'quiety-core' ),
            'type'        => Controls_Manager::TEXT,
            'default' => __('Monthly', 'quiety-core'),
            'placeholder' => esc_html__( 'Tab label', 'quiety-core' ),
        ] );

        $this->add_control( 'primary_title', [
            'label'       => esc_html__( 'Title', 'quiety-core' ),
            'type'        => Controls_Manager::TEXT,
            'default' => __('Pro Monthly', 'quiety-core'),
            'label_block' => true,
        ] );

        $this->add_control( 'primary_description', [
            'label'       => esc_html__( 'Title', 'quiety-core' ),
            'type'        => Controls_Manager::TEXTAREA,
            'default' => __('Professionally integrate principle-centered intellectual capital whereas equity.', 'quiety-core'),
            'label_block' => true,
            'rows' => '3'
        ] );

        $this->add_control( 'primary_price', [
            'label'       => esc_html__( 'Price', 'quiety-core' ),
            'type'        => Controls_Manager::TEXT,
            'default' => '$49',
        ] );

        $this->add_control( 'primary_period', [
            'label'       => esc_html__( 'Duration', 'quiety-core' ),
            'type'        => Controls_Manager::TEXT,
            'default' => __('/month', 'quiety-core'),
        ] );

        $this->add_control(
            'button_options',
            [
                'label' => __( 'Action Button', 'plugin-name' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control( 'primary_btn_text', [
            'label'       => esc_html__( 'Button Text', 'quiety-core' ),
            'type'        => Controls_Manager::TEXT,
            'default' => __('Start 14-Days Trial', 'quiety-core'),
        ] );

        $this->add_control(
            'primary_btn_url',
            [
                'label' => __( 'Link', 'quiety-core' ),
                'type' => \Elementor\Controls_Manager::URL,
                'placeholder' => __( 'https://your-link.com', 'quiety-core' ),
                'default' => [
                    'url' => '#',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'tab_secondary_content',
            [
                'label' => __('Secondary', 'quiety-core'),
            ]
        );

        $this->add_control( 'tab_secondary', [
            'label'       => esc_html__( 'Secondary Label', 'quiety-core' ),
            'type'        => Controls_Manager::TEXT,
            'default' => __('Yearly', 'quiety-core'),
            'placeholder' => esc_html__( 'Tab label', 'quiety-core' ),
        ] );

        $this->add_control( 'secondary_title', [
            'label'       => esc_html__( 'Title', 'quiety-core' ),
            'type'        => Controls_Manager::TEXT,
            'default' => __('Pro Yearly', 'quiety-core'),
            'label_block' => true,
        ] );

        $this->add_control( 'secondary_description', [
            'label'       => esc_html__( 'Title', 'quiety-core' ),
            'type'        => Controls_Manager::TEXTAREA,
            'default' => __('Professionally integrate principle-centered intellectual capital whereas equity.', 'quiety-core'),
            'label_block' => true,
            'rows' => '3'
        ] );

        $this->add_control( 'secondary_price', [
            'label'       => esc_html__( 'Price', 'quiety-core' ),
            'type'        => Controls_Manager::TEXT,
            'default' => '$79',
        ] );

        $this->add_control( 'secondary_period', [
            'label'       => esc_html__( 'Duration', 'quiety-core' ),
            'type'        => Controls_Manager::TEXT,
            'default' => __('/yearly', 'quiety-core'),
        ] );

        $this->add_control(
            'button_secondary_options',
            [
                'label' => __( 'Action Button', 'plugin-name' ),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );
        $this->add_control( 'secondary_btn_text', [
            'label'       => esc_html__( 'Button Text', 'quiety-core' ),
            'type'        => Controls_Manager::TEXT,
            'default' => __('Start 14-Days Trial', 'quiety-core'),
        ] );

        $this->add_control(
            'secondary_btn_url',
            [
                'label' => __( 'Link', 'quiety-core' ),
                'type' => \Elementor\Controls_Manager::URL,
                'placeholder' => __( 'https://your-link.com', 'quiety-core' ),
                'default' => [
                    'url' => '#',
                ],
            ]
        );
        $this->end_controls_tab();
        $this->end_controls_tabs();
        $this->end_controls_section(); //End Pricing Info


        //===================== Pricing Feature =====================//
        $this->start_controls_section( 'section_tab', [
            'label' => esc_html__( 'Pricing Feature', 'quiety-core' ),
            'condition' => [
                'layout' => '1'
            ]
        ] );

        $repeater = new Repeater();
        $repeater->add_control( 'icons', [
            'label'     => __( 'Icon', 'quiety-core' ),
            'type'      => Controls_Manager::ICONS,
            'default'   => [
                'value'   => 'fas fa-check',
                'library' => 'solid',
            ],
        ] );

        $repeater->add_control( 'feature_title', [
            'label'       => esc_html__( 'Feature Title', 'quiety-core' ),
            'type'        => Controls_Manager::TEXT,
            'label_block' => true,
            'placeholder' => esc_html__( 'Title', 'quiety-core' ),
        ] );

        $this->add_control( 'features', [
            'label'       => __( 'Feature List', 'quiety-core' ),
            'type'        => Controls_Manager::REPEATER,
            'fields'      => $repeater->get_controls(),
            'default'     => [
                [
                    'feature_title'   => __( 'Unlimited domains', 'quiety-core' ),
                    'icons'    => [
                        'value'   => 'fas fa-check',
                        'library' => 'solid',
                    ]
                ],
                [
                    'feature_title'   => __( 'Unlimited notifications', 'quiety-core' ),
                    'icons'    => [
                        'value'   => 'fas fa-check',
                        'library' => 'solid',
                    ]
                ],
                [
                    'feature_title'   => __( '10,000 unique visitors', 'quiety-core' ),
                    'icons'    => [
                        'value'   => 'fas fa-check',
                        'library' => 'solid',
                    ]
                ],
                [
                    'feature_title'   => __( 'Conversion analytics', 'quiety-core' ),
                    'icons'    => [
                        'value'   => 'fas fa-check',
                        'library' => 'solid',
                    ]
                ],
                [
                    'feature_title'   => __( ' Live chat support', 'quiety-core' ),
                    'icons'    => [
                        'value'   => 'fas fa-check',
                        'library' => 'solid',
                    ]
                ],
                [
                    'feature_title'   => __( 'Recent activity notification', 'quiety-core' ),
                    'icons'    => [
                        'value'   => 'fas fa-check',
                        'library' => 'solid',
                    ]
                ],
                [
                    'feature_title'   => __( 'Live visitor count notification', 'quiety-core' ),
                    'icons'    => [
                        'value'   => 'fas fa-check',
                        'library' => 'solid',
                    ]
                ],
                [
                    'feature_title'   => __( 'Send data to analytics tools', 'quiety-core' ),
                    'icons'    => [
                        'value'   => 'fas fa-check',
                        'library' => 'solid',
                    ]
                ],
            ],
            'title_field' => '{{{ feature_title }}}',
        ] );

        $this->end_controls_section(); // End Pricing Feature


        //========================= Pricing Tab Title =========================//
        $this->start_controls_section(
            'sec_table_title_tabs', [
                'label' => esc_html__( 'Table Tabs', 'textdomain' ),
                'condition' => [
                    'layout' => '2'
                ]
            ]
        );

        $this->add_control(
            'tab1_title', [
                'label' => esc_html__( 'Tab 01', 'textdomain' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => 'Monthly',
            ]
        );

        $this->add_control(
            'tab2_title', [
                'label' => esc_html__( 'Tab 02', 'textdomain' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => 'Yearly',
            ]
        );

        $this->add_control(
            'tab_shape', [
                'label' => esc_html__( 'Shape', 'textdomain' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'separator' => 'before'
            ]
        );

        $this->end_controls_section(); // End Pricing Tab Title


        //========================= Pricing Table Tabs =========================//
        $this->start_controls_section(
            'sec_pricing_table_tabs', [
                'label' => esc_html__( 'Pricing Table Tabs', 'textdomain' ),
                'condition' => [
                    'layout' => '2'
                ]
            ]
        );

        $table2 = new \Elementor\Repeater();
        // Pricing Tabs
        $table2->start_controls_tabs(
            'style_pricing_tabs'
        );

        $table2->start_controls_tab(
            'style_pricing_tab1', [
                'label' => esc_html__( 'Tab 01', 'textdomain' ),
            ]
        );

        $table2->add_control(
            'monthly_price', [
                'label' => esc_html__( 'Price', 'textdomain' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => '$99',
            ]
        );

        $table2->add_control(
            'monthly_duration', [
                'label' => esc_html__( 'Duration', 'textdomain' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => 'month',
            ]
        );

        $table2->end_controls_tab(); //End Tab 01

        $table2->start_controls_tab(
            'style_pricing_tab2', [
                'label' => esc_html__( 'Tab 02', 'textdomain' ),
            ]
        );

        $table2->add_control(
            'yearly_price', [
                'label' => esc_html__( 'Price', 'textdomain' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => '$199',
            ]
        );

        $table2->add_control(
            'yearly_duration', [
                'label' => esc_html__( 'Duration', 'textdomain' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'default' => 'year',
            ]
        );

        $table2->end_controls_tab(); //End Tab 02

        $table2->end_controls_tabs(); //End Pricing Tabs

        //-------------
        $table2->add_control(
            'icon', [
                'label' => esc_html__( 'Icon', 'textdomain' ),
                'type' => \Elementor\Controls_Manager::ICONS,
            ]
        );

        $table2->add_control(
            'icon_color', [
                'label' => esc_html__( 'Icon Background Color', 'textdomain' ),
                'type' => \Elementor\Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}} .icon-wrapper' => 'background-color: {{VALUE}}',
                ],
                'separator' => 'after'
            ]
        );

        $table2->add_control(
            'package_name', [
                'label' => esc_html__( 'Package Name', 'textdomain' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Starter Plan',
            ]
        );

        $table2->add_control(
            'contents', [
                'label' => esc_html__( 'Contents', 'textdomain' ),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
            ]
        );

        $table2->add_control(
            'list_items', [
                'label' => esc_html__( 'Pricing List Items', 'textdomain' ),
                'type' => \Elementor\Controls_Manager::TEXTAREA,
            ]
        );

        $table2->add_control(
            'btn_label', [
                'label' => esc_html__( 'Button Label', 'textdomain' ),
                'type' => \Elementor\Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Purchase Now',
            ]
        );

        $table2->add_control(
            'btn_url', [
                'label' => esc_html__( 'Button URL', 'textdomain' ),
                'type' => \Elementor\Controls_Manager::URL,
                'default' => [
                    'url' => '#'
                ],
            ]
        );

        $this->add_control(
            'pricing_tables2', [
                'label' => esc_html__( 'Add Table', 'textdomain' ),
                'type' => \Elementor\Controls_Manager::REPEATER,
                'fields' => $table2->get_controls(),
                'title_field' => '{{{ package_name }}}',
            ]
        );

        $this->end_controls_section(); //End Pricing Table Tab 02

    }


    /**
     * Name: quiety_elementor_style_control
     * Desc: Register style content
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @quiety
     * Author: Themetags
     */
    public function elementor_style_control() {

        //Title Style Section
        $this->start_controls_section( 'section_title_style', [
            'label' => esc_html__( 'Title', 'quiety-core' ),
            'tab'   => Controls_Manager::TAB_STYLE,
        ] );

        $this->add_control( 'title_color_one', [
            'label'     => esc_html__( 'Color', 'quiety-core' ),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .tt-pricing-list__title' => 'color: {{VALUE}};'
            ],
        ] );

        $this->add_group_control( Group_Control_Typography::get_type(), [
            'name'     => 'title_typography',
            'selector' => '{{WRAPPER}} .tt-pricing-list__title',
        ] );

        $this->end_controls_section();

        // Description Style Section
        $this->start_controls_section( 'section_subtitle_style', [
            'label' => esc_html__( 'Description', 'quiety-core' ),
            'tab'   => Controls_Manager::TAB_STYLE,
        ] );

        $this->add_control( 'subtitle_color', [
            'label'     => esc_html__( 'color', 'quiety-core' ),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .tt-pricing-list__description' => 'color: {{VALUE}};',
            ],
        ] );

        $this->add_group_control( Group_Control_Typography::get_type(), [
            'name'     => 'sdes_typography',
            'selector' => '{{WRAPPER}} .tt-pricing-list__description',
        ] );

        $this->end_controls_section();

        // Price Style Section
        $this->start_controls_section( 'section_price_style', [
            'label' => esc_html__( 'Price', 'quiety-core' ),
            'tab'   => Controls_Manager::TAB_STYLE,
        ] );

        $this->add_control(
            'spacing_price',
            [
                'label' => __( 'Spacing (Margin Top)', 'quiety-core' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => -15,
                        'max' => 150,
                        'step' => 5,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .tt-pricing-list__price-wrapper' => 'margin-top: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control( 'price_color', [
            'label'     => esc_html__( 'Color', 'quiety-core' ),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .tt-pricing-list__price .price' => 'color: {{VALUE}};',
            ],
        ] );

        $this->add_group_control( Group_Control_Typography::get_type(), [
            'name'     => 'price_typography',
            'selector' => '{{WRAPPER}} .tt-pricing-list__price .price',
        ] );

        $this->add_control( 'period_color', [
            'label'     => esc_html__( 'Period color', 'quiety-core' ),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .tt-pricing-list__price .pricing-period' => 'color: {{VALUE}};',
            ],
            'separator' => 'before'
        ] );

        $this->add_group_control( Group_Control_Typography::get_type(), [
            'label'     => esc_html__( 'Period Typography', 'quiety-core' ),
            'name'     => 'period_typography',
            'selector' => '{{WRAPPER}} .tt-pricing-list__price .pricing-period',
        ] );

        $this->add_control(
            'pricing_padding',
            [
                'label' => __( 'Wrapper Padding', 'quiety-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .tt-pricing-list__price-info' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );


        $this->end_controls_section();

        // Button Style Section
        //======================

        $this->start_controls_section(
            'section_button_style',
            [
                'label' => __('Button', 'quiety-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'typography',
                'label' => __('Typography', 'quiety-core'),
                'selector' => '{{WRAPPER}} .tt-btn',
            ]
        );

        $this->add_control(
            'border_radius',
            [
                'label' => __('Border Radius', 'quiety-core'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} a.tt-btn, {{WRAPPER}} .tt-btn' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'btn_padding',
            [
                'label' => __('Padding', 'quiety-core'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} a.tt-btn, {{WRAPPER}} .tt-btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->start_controls_tabs('tabs_button_style');

        $this->start_controls_tab(
            'tab_button_normal',
            [
                'label' => __('Normal', 'quiety-core'),
            ]
        );

        $this->add_control(
            'button_text_color',
            [
                'label' => __('Color', 'quiety-core'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} a.tt-btn, {{WRAPPER}} .tt-btn' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'background_color',
            [
                'label' => __('Background Color', 'quiety-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tt-btn' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'border',
                'label' => __('Border', 'quiety-core'),
                'selector' => '{{WRAPPER}} .tt-btn',
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'box_shadow',
                'label' => __( 'Box Shadow', 'quiety-core' ),
                'selector' => '{{WRAPPER}} .tt-btn',
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'tab_button_hover',
            [
                'label' => __('Hover', 'quiety-core'),
            ]
        );

        $this->add_control(
            'hover_color',
            [
                'label' => __('Color', 'quiety-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tt-btn:hover' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'background_color_hover',
            [
                'label' => __('Background Color', 'quiety-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tt-btn:hover' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'border_hover',
                'label' => __('Border', 'quiety-core'),
                'selector' => '{{WRAPPER}} .tt-btn:hover'
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'box_shadow_hover',
                'label' => __( 'Box Shadow', 'quiety-core' ),
                'selector' => '{{WRAPPER}} .tt-btn:hover',
            ]
        );

        $this->end_controls_tab();
        $this->end_controls_tabs();
        $this->end_controls_section();

        $this->start_controls_section( 'section_feature_style_tab', [
            'label' => esc_html__( 'Pricing Feature', 'quiety-core' ),
            'tab'   => Controls_Manager::TAB_STYLE,
        ] );

        $this->add_control( 'icon_color', [
            'label'     => esc_html__( 'Icon Color', 'quiety-core' ),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .tt-pricing-list__feature li i' => 'color: {{VALUE}};',
            ],
        ] );

        $this->add_control( 'icon_bg_color', [
            'label'     => esc_html__( 'Icon BG Color', 'quiety-core' ),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .tt-pricing-list__feature li i' => 'background-color: {{VALUE}};',
            ],
        ] );

        $this->add_control( 'text_color', [
            'label'     => esc_html__( 'Text Color', 'quiety-core' ),
            'type'      => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .tt-pricing-list__feature li' => 'color: {{VALUE}};',
            ],
        ] );

        $this->add_group_control( Group_Control_Typography::get_type(), [
            'label'     => esc_html__( 'Text Typography', 'quiety-core' ),
            'name'     => 'text_typography',
            'selector' => '{{WRAPPER}} .tt-pricing-list__feature li',
        ] );

        $this->add_control(
            'spacing',
            [
                'label' => __( 'Space Between', 'quiety-core' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => -15,
                        'max' => 100,
                        'step' => 1,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .tt-pricing-list__feature li:not(:last-child)' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'feature_padding',
            [
                'label' => __( 'Wrapper Padding', 'quiety-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .tt-pricing-list__info' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section( 'section_pricing_box', [
            'label' => esc_html__( 'Pricing Box', 'quiety-core' ),
            'tab'   => Controls_Manager::TAB_STYLE,
        ] );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'box_background',
                'label' => __( 'Background', 'quiety-core' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .tt-pricing-list',
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'box_border',
                'label' => __( 'Border', 'quiety-core' ),
                'selector' => '{{WRAPPER}} .tt-pricing-list',
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'box_box_shadow',
                'label' => __( 'Box Shadow', 'quiety-core' ),
                'selector' => '{{WRAPPER}} .tt-pricing-list',
            ]
        );


        $this->add_control(
            'box_border_radius',
            [
                'label' => __( 'Border Radius', 'quiety-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .tt-pricing-list' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

    }


    /**
     * Name: render
     * Desc: Widgets Render
     * Params: no params
     * Return: @void
     * Since: @1.0.0
     * Package: @quiety
     * Author: Themetags
     */
	protected function render() {
		$settings      = $this->get_settings_for_display();
        extract($settings);

		if ( ! empty( $settings['primary_btn_url']['url'] ) ) {
			$this->add_link_attributes( 'button', $settings['primary_btn_url'] );
			$this->add_render_attribute( 'button', 'class', 'tt-btn' );
		}

		if ( ! empty( $settings['secondary_btn_url']['url'] ) ) {
			$this->add_link_attributes( 'secondary_button', $settings['secondary_btn_url'] );
			$this->add_render_attribute( 'secondary_button', 'class', 'tt-btn' );
		}

        $unique_id = wp_unique_id();


        //====================== Template Parts ====================//
        require __DIR__ . '/templates/pricing-table-tabs/layout-'.$layout.'.php';

	}
}