<?php

namespace Quiety\Widgets;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Elementor\{Controls_Manager,
	Group_Control_Background,
	Group_Control_Border,
	Group_Control_Box_Shadow,
	Widget_Base,
	Group_Control_Typography,
	Repeater,
	Utils};

class Quiety_Procses_Box extends Widget_Base {

	public function get_name() {
		return 'tt-process-box';
	}

	public function get_title() {
		return esc_html__( 'Quiety Process Box', 'quiety-core' );
	}

	public function get_icon() {
		return 'eicon-icon-box';
	}

	public function get_categories() {
		return [ 'tt-elements' ];
	}

	protected function register_controls() {
		$this->start_controls_section( 'section_tab', [
			'label' => esc_html__( 'Process Box', 'quiety-core' ),
		] );

		$this->add_control(
			'layout',
			[
				'label' => __( 'Layout', 'quiety-core' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'layout1',
				'options' => [
					'layout1'  => __( 'Layout One', 'quiety-core' ),
					'layout2' => __( 'Layout Two', 'quiety-core' ),
					'layout3' => __( 'Layout Three', 'quiety-core' ),
				],
			]
		);


		$this->add_control( 'border_shape', [
			'label'        => __( 'Border Show/Hide', 'quiety-core' ),
			'type'         => Controls_Manager::SWITCHER,
			'label_on'     => __( 'Show', 'your-plugin' ),
			'label_off'    => __( 'Hide', 'your-plugin' ),
			'return_value' => 'yes',
			'default'      => 'yes',
		] );

		$repeater = new Repeater();

		$repeater->add_control( 'icon_type', [
			'label'       => esc_html__( 'Add Icon', 'quiety-core' ),
			'type'        => Controls_Manager::CHOOSE,
			'label_block' => false,
			'options'     => [
				'none'       => [
					'title' => esc_html__( 'None', 'quiety-core' ),
					'icon'  => 'eicon-ban',
				],
				'type_icon'  => [
					'title' => esc_html__( 'Icon', 'quiety-core' ),
					'icon'  => 'eicon-paint-brush',
				]
			],
			'default'     => 'type_icon',
		] );

		$repeater->add_control( 'icon_pack', [
			'label'     => esc_html__( 'Icon Pack', 'quiety-core' ),
			'type'      => Controls_Manager::SELECT,
			'condition' => [
				'icon_type' => 'type_icon',
			],
			'options'   => [
				'fontawesome' => esc_html__( 'Fontawesome', 'quiety-core' ),
				'feather'     => esc_html__( 'Feather', 'quiety-core' ),
			],
			'default'   => 'fontawesome',
		] );

		$repeater->add_control( 'box_icon', [
			'label'     => __( 'Icon', 'quiety-core' ),
			'type'      => Controls_Manager::ICONS,
			'default'   => [
				'value'   => 'fas fa-star',
				'library' => 'solid',
			],
			'condition' => [
				'icon_pack' => 'fontawesome',
				'icon_type' => 'type_icon',
			]
		] );

		$repeater->add_control( 'feather_icon', [
			'label'       => __( 'Choose Icon', 'quiety-core' ),
			'type'        => Controls_Manager::ICON,
			'options'     => tt_feather_icon(),
			'include'     => tt_include_feather_icons(),
			'default'     => 'feather-box',
			'condition'   => [
				'icon_pack' => 'feather',
				'icon_type' => 'type_icon',
			],
			'label_block' => true,
		] );

		$repeater->add_control( 'step', [
			'label'       => esc_html__( 'Step', 'quiety-core' ),
			'type'        => Controls_Manager::TEXT,
			'label_block' => true,
			'placeholder' => esc_html__( 'Step number', 'quiety-core' ),
		] );

		$repeater->add_control( 'box_title', [
			'label'       => esc_html__( 'Box Title', 'quiety-core' ),
			'type'        => Controls_Manager::TEXT,
			'label_block' => true,
			'placeholder' => esc_html__( 'Title', 'quiety-core' ),
		] );


		$repeater->add_control( 'link', [
			'label'         => __( 'Link', 'quiety-core' ),
			'type'          => Controls_Manager::URL,
			'placeholder'   => __( 'https://your-link.com', 'quiety-core' ),
			'show_external' => true,
			'default'       => [
				'url'         => '',
				'is_external' => true,
				'nofollow'    => true,
			],
		] );

		$repeater->add_control( 'description', [
			'label'       => esc_html__( 'Description', 'quiety-core' ),
			'type'        => Controls_Manager::TEXTAREA,
			'label_block' => true,
			'placeholder' => esc_html__( 'Description', 'quiety-core' ),
			'default'     => __( 'I transform thorny problems into elegant Lorem ipsum dolor amet', 'quiety-core' ),
			'separator'   => 'none',
		] );

		$repeater->add_responsive_control( 'box_align', [
			'label'   => esc_html__( 'Alignment', 'quiety-core' ),
			'type'    => Controls_Manager::CHOOSE,
			'options' => [
				'left'  => [
					'title' => esc_html__( 'Left', 'quiety-core' ),
					'icon'  => 'fa fa-align-left',
				],
				'right' => [
					'title' => esc_html__( 'Right', 'quiety-core' ),
					'icon'  => 'fa fa-align-right',
				],
			],
			'default' => 'left',
			'toggle'  => false,
		] );

		$repeater->add_control( 'icon_color', [
			'label'     => __( 'Icon Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} {{CURRENT_ITEM}} .icon-container i' => 'color: {{VALUE}}'
			],
		] );

		$repeater->add_control( 'box_single_margin', [
			'label'      => __( 'Margin', 'quiety-core' ),
			'type'       => Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%', 'em' ],
			'selectors'  => [
				'{{WRAPPER}} {{CURRENT_ITEM}}' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		] );

		$repeater->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'box_border',
				'label' => __( 'Border', 'quiety-core' ),
				'selector' => '{{WRAPPER}} {{CURRENT_ITEM}}.tt-process-box',
			]
		);

		$this->add_control( 'process_boxes', [
			'label'       => __( 'Process Box List', 'quiety-core' ),
			'type'        => Controls_Manager::REPEATER,
			'fields'      => $repeater->get_controls(),
			'default'     => [
				[
					'step'    => __('Step 1', 'quiety-core'),
					'box_title'   => __( 'Research and Content Planing', 'quiety-core' ),
					'description' => __( 'Progressively foster enterprise-wide systems whereas equity invested web-readiness harness installed base bandwidth.', 'quiety-core' ),
					'box_icon'    => [
							'value'   => 'far fa-folder-open',
							'library' => 'regular',
						]
					],
				[
					'step'        => __( 'Step 2', 'quiety-core' ),
					'box_title'   => __( 'Publishing and Execution', 'quiety-core' ),
					'description' => __( 'Progressively foster enterprise-wide systems whereas equity invested web-readiness harness installed base bandwidth.', 'quiety-core' ),
					'box_icon'    => [
						'value'   => 'fas fa-bezier-curve',
						'library' => 'solid',

					],
				],
				[
					'step'    => __('Step 3', 'quiety-core'),
					'box_title'   => __( 'Product Prototyping', 'quiety-core' ),
					'description' => __( 'Progressively foster enterprise-wide systems whereas equity invested web-readiness harness installed base bandwidth.', 'quiety-core' ),
					'box_icon'    => [
						'value'   => 'fas fa-layer-group',
						'library' => 'solid',
					]
				],
				[
					'step'    => __('Step 4', 'quiety-core'),
					'box_title'   => __( 'Deliver the Final Product', 'quiety-core' ),
					'description' => __( 'Progressively foster enterprise-wide systems whereas equity invested web-readiness harness installed base bandwidth.', 'quiety-core' ),
					'box_icon'    => [
						'value'   => 'fas fa-truck',
						'library' => 'solid',
					]
				],
			],
			'title_field' => '{{{ box_title }}}',
		] );
		$this->end_controls_section();

		// Icon Style Section
		$this->start_controls_section( 'section_icon_style', [
			'label' => esc_html__( 'Icon', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_control(
			'icon_padding',
			[
				'label' => __( 'Padding', 'quiety-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .tt-process-box .icon-container' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'icon_border',
				'label' => __( 'Border', 'quiety-core' ),
				'selector' => '{{WRAPPER}} .tt-process-box .icon-container',
			]
		);

		$this->add_control(
			'icon_border_radius',
			[
				'label' => __( 'Border Radius', 'quiety-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .tt-process-box .icon-container' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->start_controls_tabs('tabs_icon_style');

		$this->start_controls_tab(
			'tab_icon_normal',
			[
				'label' => __('Normal', 'quiety-core'),
			]
		);

		$this->add_control( 'icon_color', [
			'label'     => esc_html__( 'Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-process-box .icon-container' => 'color: {{VALUE}};'
			],
		] );

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'icon_background',
				'label' => __( 'Background', 'quiety-core' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .tt-process-box .icon-container',
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'icon_box_shadow',
				'label' => __( 'Box Shadow', 'quiety-core' ),
				'selector' => '{{WRAPPER}} .tt-process-box .icon-container',
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab(
			'tab_button_hover',
			[
				'label' => __('Hover', 'quiety-core'),
			]
		);

		$this->add_control( 'icon_color_hover', [
			'label'     => esc_html__( 'Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-process-box:hover .icon-container' => 'color: {{VALUE}};'
			],
		] );

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'icon_background_hover',
				'label' => __( 'Background', 'quiety-core' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .tt-process-box:hover .icon-container',
			]
		);

		$this->add_control( 'icon_border_color_hover', [
			'label'     => esc_html__( 'Border Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-process-box:hover .icon-container' => 'border-color: {{VALUE}};'
			],
		] );

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'icon_box_shadow_hover',
				'label' => __( 'Box Shadow', 'quiety-core' ),
				'selector' => '{{WRAPPER}} .tt-process-box:hover .icon-container',
			]
		);

		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();

		//Title Style Section
		$this->start_controls_section( 'section_title_style', [
			'label' => esc_html__( 'Title', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_control( 'title_color_one', [
			'label'     => esc_html__( 'Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-process-box .box-title,
					{{WRAPPER}} .tt-process-box .box-title a' => 'color: {{VALUE}};'
			],
		] );
		$this->add_control( 'title_color_one_hover', [
			'label'     => esc_html__( 'Hover Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-process-box .box-title:hover,
					{{WRAPPER}} .tt-process-box .box-title a:hover' => 'color: {{VALUE}};'
			],
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'title_typography',
			'selector' => '{{WRAPPER}} .tt-process-box .box-title',
		] );

		$this->end_controls_section();

		// Step Style Section
		$this->start_controls_section( 'section_step_style', [
			'label' => esc_html__( 'Step', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'step_typography',
			'selector' => '{{WRAPPER}} .tt-process_step',
		] );

		$this->add_control( 'step_color', [
			'label'     => esc_html__( 'Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-process-box .box-title,
					{{WRAPPER}} .tt-process_step' => 'color: {{VALUE}};'
			],
		] );

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'step_background',
				'label' => __( 'Background', 'quiety-core' ),
				'types' => [ 'classic', 'gradient', 'video' ],
				'selector' => '{{WRAPPER}} .tt-process_step',
			]
		);

		$this->add_control(
			'step_padding',
			[
				'label' => __( 'Padding', 'quiety-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .tt-process_step' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'step_border',
				'label' => __( 'Border', 'quiety-core' ),
				'selector' => '{{WRAPPER}} .tt-process_step',
			]
		);

		$this->add_control(
			'step_border_radius',
			[
				'label' => __( 'Border Radius', 'quiety-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .tt-process_step' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'step_box_shadow',
				'label' => __( 'Box Shadow', 'quiety-core' ),
				'selector' => '{{WRAPPER}} .tt-process_step',
			]
		);

		$this->end_controls_section();

		// Subtitle Style Section
		$this->start_controls_section( 'section_subtitle_style', [
			'label' => esc_html__( 'Description', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_control( 'subtitle_color', [
			'label'     => esc_html__( 'color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-process-box .description' => 'color: {{VALUE}};',
			],
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'sdes_typography',
			'selector' => '{{WRAPPER}} .tt-process-box .description',
		] );

		$this->end_controls_section();

		// Process Box Style Section
		$this->start_controls_section( 'section_box_style', [
			'label' => esc_html__( 'Box Container', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_control(
			'box_padding',
			[
				'label' => __( 'Padding', 'quiety-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .tt-process-box' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'box_background',
				'label' => __( 'Background', 'quiety-core' ),
				'types' => [ 'classic', 'gradient', 'video' ],
				'selector' => '{{WRAPPER}} .tt-process-box',
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'border',
				'label' => __( 'Border', 'quiety-core' ),
				'selector' => '{{WRAPPER}} .tt-process-box',
			]
		);

		$this->add_control(
			'border_radius',
			[
				'label' => __( 'Border Radius', 'quiety-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .tt-process-box' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'box_border',
				'label' => __( 'Border', 'quiety-core' ),
				'selector' => '{{WRAPPER}} .tt-process-box',
			]
		);

		$this->add_control(
			'gutters',
			[
				'label' => __( 'Gutter', 'plugin-domain' ),
				'type' => Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 50,
						'step' => 1,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .process-box-wrapper .col-md-3' => 'padding-left: {{SIZE}}{{UNIT}}; padding-right: {{SIZE}}{{UNIT}};',
				],
			]
		);

		$this->end_controls_section();
	}

	protected function render() {
		$settings      = $this->get_settings_for_display();
		$layout = $settings['layout'];
		$process_boxes = $settings['process_boxes'];
		?>
		<div class="process-box-wrapper">
			<?php require __DIR__ . '/templates/process-box/'. $layout  .'.php'; ?>
		</div>
		<!-- /.prosess-box-wrapper -->

		<?php
	}
}



