<?php

namespace Quiety\Widgets;

use Elementor\Controls_Manager;
use Elementor\Widget_Base;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Quiety_Product extends Widget_Base {
	public function get_name() {
		return 'cashop_product_list';
	}

	public function get_title() {
		return __( 'Quiety Product List', 'quiety-core' );
	}

	public function get_icon() {
		return 'eicon-products';
	}

	public function get_categories() {
		return [ 'tt-elements' ];
	}

	protected function register_controls() {

		$term  = array( '' => __( 'All Categories', "quiety-core" ) );
		if( class_exists( 'WooCommerce' ) ){
			$terms = get_terms( array(
				'taxonomy' => 'product_cat',
    			'hide_empty' => true,
			) );
			foreach ( $terms as $cat ) {
				$term[ $cat->slug ] = $cat->name;
			}
		}
		
		$number = array( '1' => 1, '2' => 2, '3' => 3, '4' => 4,  '6' => 6);

		$this->start_controls_section( 'layout_section', [
			'label' => __( 'Layout and Style', 'quiety-core' ),
			'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
		] );

		$this->add_control( 'layout', [
			'label'   => __( 'Layout', 'quiety-core' ),
			'type'    => \Elementor\Controls_Manager::SELECT,
			'default' => 'default',
			'options' => [
				'default'    => __( 'Grid', 'quiety-core' ),
				'slider'     => __( 'Slider', 'quiety-core' ),
			],
		] );

		$this->add_control( 'product_style', [
			'label'   => __( 'Style', 'quiety-core' ),
			'type'    => \Elementor\Controls_Manager::SELECT,
			'default' => 'style_one',
			'options' => [
				'style_one'   => __( 'Style One', 'quiety-core' ),
				'style_two'   => __( 'Style Two', 'quiety-core' ),
				'style_three' => __( 'Style Three', 'quiety-core' ),
				'style_four' => __( 'Style Four', 'quiety-core' ),
			],
		] );

		$this->end_controls_section();

		$this->start_controls_section( 'content_section', [
			'label' => __( 'Content', 'quiety-core' ),
			'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
		] );

		$this->add_control( 'heading', [
			'label'       => __( 'Title', 'quiety-core' ),
			'type'        => \Elementor\Controls_Manager::TEXT,
			'placeholder' => __( 'Type your title here', 'quiety-core' ),
			'label_block' => true
		] );

		$this->end_controls_section();

		$this->start_controls_section( 'query_section', [
			'label' => __( 'Query Settings', 'quiety-core' ),
			'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
		] );


		$this->add_control( 'category', [
			'label'   => __( 'Category', 'quiety-core' ),
			'type'    => \Elementor\Controls_Manager::SELECT,
			'default' => '',
			'options' => $term
		] );
		$this->add_control( 'source', [
			'label'   => __( 'Source Product', 'quiety-core' ),
			'type'    => \Elementor\Controls_Manager::SELECT,
			'default' => 'default',
			'options' => array(
				'default'   => 'Default',
				'featured'  => 'Featured Product ',
				'sale'      => 'Sale Product',
				'toprating' => 'Top Rating',
				'bestsales' => 'Best Sales',
				'childcat'  => 'Child Category'
			)
		] );
		$this->add_control( 'orderby', [
			'label'   => __( 'Order By', 'quiety-core' ),
			'type'    => \Elementor\Controls_Manager::SELECT,
			'default' => 'date',
			'options' => array(
				'name'          => 'Name',
				'author'        => 'Author',
				'date'          => 'Date',
				'title'         => 'Title',
				'modified'      => 'Modified',
				'parent'        => 'Parent',
				'ID'            => 'ID',
				'rand'          => 'Random',
				'comment_count' => 'Comment Count'
			)
		] );

		$this->add_control( 'order', [
			'label'   => __( 'Order', 'quiety-core' ),
			'type'    => \Elementor\Controls_Manager::SELECT,
			'options' => [
				'DESC' => __( 'Descending', 'quiety-core' ),
				'ASC'  => __( 'No', 'Ascending' ),
			],
			'default' => 'ASC'
		] );

		$this->add_control( 'numberposts', [
			'label'       => __( 'Items per page', 'quiety-core' ),
			'type'        => \Elementor\Controls_Manager::TEXT,
			'default'     => '5',
			'placeholder' => __( 'Number Of Products', 'quiety-core' ),
		] );

		$this->add_control( 'item_row', [
			'label'   => __( 'Number row per column', 'quiety-core' ),
			'type'    => \Elementor\Controls_Manager::SELECT,
			'default' => '',
			'options' => array( '1' => 1, '2' => 2, '3' => 3, '4' => 4, '5' => 5 ),
			'default' => 1
		] );

		$this->add_control( 'columns', [
			'label'   => __( 'Number of Columns >1440px', 'quiety-core' ),
			'type'    => \Elementor\Controls_Manager::SELECT,
			'default' => '',
			'options' => $number,
			'default' => 4
		] );

		$this->add_control( 'columns1440', [
			'label'   => __( 'Number of Columns 1200px to 1440px', 'quiety-core' ),
			'type'    => \Elementor\Controls_Manager::SELECT,
			'default' => '',
			'options' => $number,
			'default' => 1
		] );

		$this->add_control( 'columns1', [
			'label'   => __( 'Number of Columns on 992px to 1199px', 'quiety-core' ),
			'type'    => \Elementor\Controls_Manager::SELECT,
			'default' => '',
			'options' => $number,
			'default' => 1
		] );

		$this->add_control( 'columns2', [
			'label'   => __( 'Number of Columns on 768px to 991px', 'quiety-core' ),
			'type'    => \Elementor\Controls_Manager::SELECT,
			'default' => '',
			'options' => $number,
			'default' => 1
		] );

		$this->add_control( 'columns3', [
			'label'   => __( 'Number of Columns on 480px to 767px', 'quiety-core' ),
			'type'    => \Elementor\Controls_Manager::SELECT,
			'default' => '',
			'options' => $number,
			'default' => 1
		] );

		$this->add_control( 'columns4', [
			'label'   => __( 'Number of Columns in 480px or less than', 'quiety-core' ),
			'type'    => \Elementor\Controls_Manager::SELECT,
			'default' => '',
			'options' => $number,
			'default' => 1
		] );

		$this->add_control( 'time_deal', [
			'label'       => __( 'Time Coundown', 'quiety-core' ),
			'type'        => \Elementor\Controls_Manager::TEXT,
			'default'     => '',
			'placeholder' => __( 'Ex : 2022-5-01', 'quiety-core' ),
			'condition'   => [
				'layout' => [ 'list-deal', 'list-deal2', 'list-deal3' ],
			]
		] );

		$repeater = new \Elementor\Repeater();

		$repeater->add_control( 'label_list', [
			'label'       => __( 'label', 'quiety-core' ),
			'type'        => \Elementor\Controls_Manager::TEXT,
			'default'     => '',
			'placeholder' => __( 'Type your text here', 'quiety-core' ),
		] );

		$repeater->add_control( 'link_list', [
			'label'       => __( 'Link', 'quiety-core' ),
			'type'        => \Elementor\Controls_Manager::TEXT,
			'default'     => '#',
			'placeholder' => __( 'Type your link here', 'quiety-core' ),
			'condition'   => [
				'show_active' => [ "0" ],
			]
		] );

		$repeater->add_control( 'show_active', [
			'label'   => __( 'Show Active', 'quiety-core' ),
			'type'    => \Elementor\Controls_Manager::SELECT,
			'options' => [
				'1' => __( 'Yes', 'quiety-core' ),
				'0' => __( 'No', 'quiety-core' ),
			],
			'default' => '0',
		] );

		$this->end_controls_section();

		// Slider Control
		//=====================
		$this->start_controls_section( 'settingd_section', [
			'label' => esc_html__( 'Slider Control', 'quiety-core' ),
		] );

		$this->add_control( 'navigation', [
			'label'        => esc_html__( 'Navigation', 'quiety-core' ),
			'type'         => Controls_Manager::SWITCHER,
			'label_on'     => esc_html__( 'Show', 'quiety-core' ),
			'label_off'    => esc_html__( 'Hide', 'quiety-core' ),
			'return_value' => 'yes',
			'default'      => 'no'
		] );

		$this->add_control( 'pagination', [
			'label'        => esc_html__( 'Pagination', 'quiety-core' ),
			'type'         => Controls_Manager::SWITCHER,
			'label_on'     => esc_html__( 'Show', 'quiety-core' ),
			'label_off'    => esc_html__( 'Hide', 'quiety-core' ),
			'return_value' => 'yes',
			'default'      => 'yes'
		] );


		$this->add_control( 'loop', [
			'label'        => esc_html__( 'Loop', 'quiety-core' ),
			'type'         => Controls_Manager::SWITCHER,
			'label_on'     => esc_html__( 'On', 'quiety-core' ),
			'label_off'    => esc_html__( 'Off', 'quiety-core' ),
			'return_value' => 'yes',
			'default'      => 'yes'
		] );

		$this->add_control( 'speed', [
			'label'   => __( 'Speed', 'quiety-core' ),
			'type'    => Controls_Manager::NUMBER,
			'default' => 700,
		] );

		$this->add_control( 'autoplay', [
			'label'        => esc_html__( 'Autoplay', 'quiety-core' ),
			'type'         => Controls_Manager::SWITCHER,
			'label_on'     => esc_html__( 'On', 'quiety-core' ),
			'label_off'    => esc_html__( 'Off', 'quiety-core' ),
			'return_value' => 'yes',
			'default'      => 'yes'
		] );

		$this->add_control( 'autoplay_time', [
			'label'   => __( 'Autoplay Time', 'quiety-core' ),
			'type'    => Controls_Manager::NUMBER,
			'default' => 3000,
			'condition' => [
				'autoplay' => 'yes'
			]
		] );

		$this->end_controls_section();
	}

	protected function render() {
		$settings = $this->get_settings_for_display();
		$layout   = $settings['layout'];

		$this->add_render_attribute( 'wrapper', 'class', [
			'swiper-container',
			'products-slider',
		] );

		$slider_options = $this->get_slider_options( $settings );
		$this->add_render_attribute( 'wrapper', 'data-product', wp_json_encode( $slider_options ) );

		extract( shortcode_atts(
			         array(
				         'title1' => '',
				         'label_button' => '',
				         'link_button' => '#',
				         'orderby' => '',
				         'order'	=> '',
				         'category' => '',
				         'numberposts' => 5,
				         'length' => 25,
				         'item_row'=> 1,
				         'columns' => 4,
				         'columns1440' => 4,
				         'columns1' => 4,
				         'columns2' => 3,
				         'columns3' => 2,
				         'columns4' => 1,
				         'style_product' => 1,
				         'product_style' => 'style_one',
				         'time_deal' => '',
				         'show_pag'	=> '0',
				         'source'  => 'default',
				         'link' => '#',
				         'layout'  => 'default',
			         ), $settings )
		);



		switch ( $source ) {
			case 'default':
				$default = array();
				if ( $category ) {
					$default = array(
						'post_type'   => 'product',
						'tax_query'   => array(
							array(
								'taxonomy' => 'product_cat',
								'field'    => 'slug',
								'terms'    => $category
							)
						),
						'orderby'     => $orderby,
						'order'       => $order,
						'post_status' => 'publish',
						'showposts'   => $numberposts
					);
				} else {
					$default = array(
						'post_type'   => 'product',
						'orderby'     => $orderby,
						'order'       => $order,
						'post_status' => 'publish',
						'showposts'   => $numberposts
					);
				}
				$widget_id    = 'bwp_default_' . rand() . time();
				$widget_class = 'bwp_list_default';
				$list         = new \WP_Query( $default );
				break;
			case 'featured':
				$product_visibility_term_ids = wc_get_product_visibility_term_ids();
				if ( $category ) {
					$default = array(
						'post_type'           => 'product',
						'post_status'         => 'publish',
						'tax_query'           => array(
							array(
								'taxonomy' => 'product_cat',
								'field'    => 'slug',
								'terms'    => $category
							),
							array(
								'taxonomy' => 'product_visibility',
								'field'    => 'term_taxonomy_id',
								'terms'    => $product_visibility_term_ids['featured'],
							)
						),
						'ignore_sticky_posts' => 1,
						'posts_per_page'      => $numberposts,
						'orderby'             => $orderby,
						'order'               => $order
					);
				} else {
					$default = array(
						'post_type'           => 'product',
						'post_status'         => 'publish',
						'ignore_sticky_posts' => 1,
						'posts_per_page'      => $numberposts,
						'orderby'             => $orderby,
						'order'               => $order,
						'tax_query'           => array(
							array(
								'taxonomy' => 'product_visibility',
								'field'    => 'term_taxonomy_id',
								'terms'    => $product_visibility_term_ids['featured'],
							)
						)
					);
				}
				$widget_id    = 'bwp_featured_' . rand() . time();
				$widget_class = 'bwp_list_featured';
				$list         = new \WP_Query( $default );
				break;
			case 'toprating':
				//				if ( $category ) {
				//					$default = array(
				//						'post_type'     => 'product',
				//						'tax_query'     => array(
				//							array(
				//								'taxonomy' => 'product_cat',
				//								'field'    => 'slug',
				//								'terms'    => $category,
				//								'operator' => 'IN'
				//							)
				//						),
				//						'post_status'   => 'publish',
				//						'no_found_rows' => 1,
				//						'showposts'     => $numberposts
				//					);
				//				} else {
				//					$default = array(
				//						'post_type'     => 'product',
				//						'post_status'   => 'publish',
				//						'no_found_rows' => 1,
				//						'showposts'     => $numberposts
				//					);
				//				}
				//				$default['meta_query'] = WC()->query->get_meta_query();
				//				add_filter( 'posts_clauses', 'order_by_rating_post_clauses' );
				//				$widget_id    = 'bwp_toprated_' . rand() . time();
				//				$widget_class = 'bwp_list_toprated';
				//				$list         = new \WP_Query( $default );

				add_filter( 'posts_clauses', array( 'WC_Shortcodes', 'order_by_rating_post_clauses' ) );

				break;
			case 'sale':
				$product_ids_on_sale   = wc_get_product_ids_on_sale();
				$product_ids_on_sale[] = 0;
				if ( $category ) {
					$default = array(
						'post_type'           => 'product',
						'tax_query'           => array(
							array(
								'taxonomy' => 'product_cat',
								'field'    => 'slug',
								'terms'    => $category,
								'operator' => 'IN'
							)
						),
						'post__in'            => $product_ids_on_sale,
						'post_status'         => 'publish',
						'ignore_sticky_posts' => 1,
						'showposts'           => $numberposts
					);
				} else {
					$default = array(
						'post_type'           => 'product',
						'post_status'         => 'publish',
						'ignore_sticky_posts' => 1,
						'showposts'           => $numberposts,
						'post__in'            => $product_ids_on_sale
					);
				}
				$widget_id    = 'bwp_sale_product_' . rand() . time();
				$widget_class = 'bwp_sale_product';
				$list         = new \WP_Query( $default );
				break;
			case 'bestsales':
				if ( $category ) {
					$default = array(
						'post_type'           => 'product',
						'tax_query'           => array(
							array(
								'taxonomy' => 'product_cat',
								'field'    => 'slug',
								'terms'    => $category,
								'operator' => 'IN'
							)
						),
						'post_status'         => 'publish',
						'ignore_sticky_posts' => 1,
						'paged'               => 1,
						'showposts'           => $numberposts,
						'meta_key'            => 'total_sales',
						'orderby'             => 'meta_value_num'
					);
				} else {
					$default = array(
						'post_type'           => 'product',
						'post_status'         => 'publish',
						'ignore_sticky_posts' => 1,
						'showposts'           => $numberposts,
						'meta_key'            => 'total_sales',
						'orderby'             => 'meta_value_num'
					);
				}
				$widget_id    = 'bwp_bestsales_' . rand() . time();
				$widget_class = 'bwp_list_bestsales';
				$list         = new \WP_Query( $default );
				break;
			case 'childcat':
				$default   = array();
				$default   = array(
					'post_type'   => 'product',
					'tax_query'   => array(
						array(
							'taxonomy' => 'product_cat',
							'field'    => 'slug',
							'terms'    => $category
						)
					),
					'orderby'     => $orderby,
					'order'       => $order,
					'post_status' => 'publish',
					'showposts'   => $numberposts
				);
				$term      = get_term_by( 'slug', $category, 'product_cat' );
				$widget_id = 'quiety_childcat_' . rand() . time();
				$list      = new \WP_Query( $default );
				break;
		}

		include_once __DIR__ . '/templates/product/'.$layout.'.php';
	}

	protected function get_slider_options( array $settings ) {

		// Loop
		if ( $settings['loop'] == 'yes' ) {
			$slider_options['loop'] = true;
		}

		// Speed
		if ( ! empty( $settings['speed'] ) ) {
			$slider_options['speed'] = $settings['speed'];
		}

		// Breakpoints
		$slider_options['breakpoints'] = [
			'992' => [
				'slidesPerView' => '4',
			],

			'767' => [
				'slidesPerView' => '3',
			],

			'576' => [
				'slidesPerView' => 2,
			],

			'320' => [
				'slidesPerView' => 1,
			],
		];


		// Auto Play
		if ( $settings['autoplay'] == 'yes' ) {
			$slider_options['autoplay'] = [
				'delay' => $settings['autoplay_time'],
				'disableOnInteraction' => false
			];
		} else {
			$slider_options['autoplay'] = [
				'delay' => '99999999999',
			];
		}


		$slider_options['navigation'] = [
			'nextEl' => '.product-next',
			'prevEl' => '.product-prev'
		];


		if ( $settings['pagination'] == 'yes' ) {
			$slider_options['pagination'] = [
				'el'        => '.testimonial-swiper-pagination',
				'clickable' => true
			];
		}


		$slider_options['spaceBetween'] = (int) '30';

		return $slider_options;
	}
}