<?php

namespace Quiety\Widgets;

defined( 'ABSPATH' ) || exit; // Abort, if called directly.

use Elementor\{Widget_Base,
	Controls_Manager,
	Group_Control_Typography,
	Utils
};

class Quiety_Promo_Box extends Widget_Base {

	public function get_name() {
		return 'tt-promo-box';
	}

	public function get_title() {
		return esc_html__( 'Quiety Promo Box', 'quiety-core' );
	}

	public function get_icon() {
		return 'eicon-icon-box';
	}

	public function get_categories() {
		return [ 'tt-elements' ];
	}

	protected function register_controls() {
		$this->start_controls_section( 'section_tab', [
			'label' => esc_html__( 'Promo Box', 'quiety-core' ),
		] );

		// Layout
		// =====================
		$this->add_control( 'layout', [
			'label'   => esc_html__( 'Layout', 'quiety-core' ),
			'type'    => Controls_Manager::SELECT,
			'options' => [
				'1' => esc_html__( 'Layout 1', 'quiety-core' ),
				'2' => esc_html__( 'Layout 2', 'quiety-core' ),
			],
			'default' => '1',
		] );


		$this->add_control( 'promo_image', [
			'label'       => esc_html__( 'Image', 'quiety-core' ),
			'type'        => Controls_Manager::MEDIA,
			'label_block' => true,
			'default'     => [
				'url' => plugin_dir_url( __DIR__ ) . 'assets/images/promo.png'
			],
			'condition' => [
				'layout' => '1'
			]
		] );

		$this->add_control( 'promo_image_two', [
			'label'       => esc_html__( 'Bg Image', 'quiety-core' ),
			'type'        => Controls_Manager::MEDIA,
			'label_block' => true,
			'default'     => [
				'url' => plugin_dir_url( __DIR__ ) . 'assets/images/promo4.jpg'
			],
			'condition' => [
				'layout' => '2'
			]
		] );

		$this->add_control( 'promo_title', [
			'label'       => esc_html__( 'Title', 'quiety-core' ),
			'type'        => Controls_Manager::TEXT,
			'label_block' => true,
			'placeholder' => esc_html__( 'Title', 'quiety-core' ),
			'default'     => esc_html__( 'Utilize your software data', 'quiety-core' ),
		] );


		$this->add_control( 'promo_title_link', [
			'label'         => __( 'Link', 'quiety-core' ),
			'type'          => Controls_Manager::URL,
			'placeholder'   => __( 'https://your-link.com', 'quiety-core' ),
			'show_external' => true,
			'default'       => [
				'url'         => '',
				'is_external' => false,
				'nofollow'    => false,
			],
		] );

		$this->add_control( 'promo_description', [
			'label'       => esc_html__( 'Description', 'quiety-core' ),
			'type'        => Controls_Manager::TEXTAREA,
			'label_block' => true,
			'placeholder' => esc_html__( 'Description', 'quiety-core' ),
			'default'     => __( 'Up the duff hunky-dory blow off mufty owt to do.', 'quiety-core' ),
			'separator'   => 'none',
		] );

		$this->add_control( 'promo_btn_text', [
			'label'       => esc_html__( 'Button Text', 'quiety-core' ),
			'type'        => Controls_Manager::TEXT,
			'label_block' => true,
			'placeholder' => esc_html__( 'Button Text', 'quiety-core' ),
			'default'     => __( 'Learn More', 'quiety-core' ),
			'separator'   => 'before',
		] );

		$this->add_control( 'promo_link', [
			'label'         => __( 'Button Link', 'quiety-core' ),
			'type'          => Controls_Manager::URL,
			'placeholder'   => __( 'https://your-link.com', 'quiety-core' ),
			'show_external' => true,
			'default'       => [
				'url'         => '#',
				'is_external' => true,
				'nofollow'    => true,
			],
		] );

		$this->add_responsive_control( 'title_align', [
			'label'     => esc_html__( 'Alignment', 'quiety-core' ),
			'type'      => Controls_Manager::CHOOSE,
			'options'   => [

				'left'    => [
					'title' => esc_html__( 'Left', 'quiety-core' ),
					'icon'  => 'fa fa-align-left',
				],
				'center'  => [
					'title' => esc_html__( 'Center', 'quiety-core' ),
					'icon'  => 'fa fa-align-center',
				],
				'right'   => [
					'title' => esc_html__( 'Right', 'quiety-core' ),
					'icon'  => 'fa fa-align-right',
				],
				'justify' => [
					'title' => esc_html__( 'Justified', 'quiety-core' ),
					'icon'  => 'fa fa-align-justify',
				],
			],
			'selectors' => [
				'{{WRAPPER}} .tt-promo' => 'text-align: {{VALUE}};'
			],
		] );


		$this->end_controls_section();


		//Title Style Section
		$this->start_controls_section( 'section_title_style', [
			'label' => esc_html__( 'Title', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_control( 'title_color_two', [
			'label'     => esc_html__( 'Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-promo .tt-promo__title,
					{{WRAPPER}} .tt-promo .tt-promo__title a,
					{{WRAPPER}} .promo-box-two .promo-content .box-title,
					{{WRAPPER}} .promo-box-two .promo-content .box-title a' => 'color: {{VALUE}};'
			],
		] );
		$this->add_control( 'title_color_two_hover', [
			'label'     => esc_html__( 'Hover Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-promo .tt-promo__title:hover,
					{{WRAPPER}} .tt-promo .tt-promo__title a:hover' => 'color: {{VALUE}};'
			],
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'title_typography',
			'selector' => '{{WRAPPER}} .tt-promo .tt-promo__title',
		] );

		$this->end_controls_section();

		//Subtitle Style Section
		$this->start_controls_section( 'section_subtitle_style', [
			'label' => esc_html__( 'Description', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_control( 'subtitle_color', [
			'label'     => esc_html__( 'color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-promo .tt-promo__description, {{WRAPPER}} .description' => 'color: {{VALUE}};',
			],
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'promo_subtitle_typography',
			'selector' => '{{WRAPPER}} .tt-promo .tt-promo__description',
		] );

		$this->end_controls_section();

		//Background Style
		$this->start_controls_section( 'section_promo_style', [
			'label' => esc_html__( 'Background', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_control( 'service_bg_color', [
			'label'     => esc_html__( 'Background Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-promo' => 'background: {{VALUE}};'
			],
		] );

		$this->add_control( 'service_border_color', [
			'label'     => esc_html__( 'Border Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-promo' => 'border-color: {{VALUE}};'
			],
		] );

		$this->add_responsive_control( 'box_padding', [
			'label'      => __( 'Padding', 'quiety-core' ),
			'type'       => Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%', 'em' ],
			'selectors'  => [
				'{{WRAPPER}} .tt-promo' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		] );

		$this->add_responsive_control( 'box_margin', [
			'label'      => __( 'Margin', 'quiety-core' ),
			'type'       => Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%', 'em' ],
			'selectors'  => [
				'{{WRAPPER}} .tt-promo' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		] );


		$this->end_controls_section();
	}

	protected function render() {
		$settings = $this->get_settings_for_display();
		$layout = $settings['layout'];
		$target   = $settings['promo_title_link']['is_external'] ? ' target="_blank"' : '';
		$nofollow = $settings['promo_title_link']['nofollow'] ? ' rel="nofollow"' : '';

		$btn_target   = $settings['promo_link']['is_external'] ? ' target="_blank"' : '';
		$btn_nofollow = $settings['promo_link']['nofollow'] ? ' rel="nofollow"' : '';

		require __DIR__ . '/templates/promo/layout-'.$layout.'.php';
	}
}




