<?php
namespace Quiety\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Text_Shadow;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * Check URL Form
 */
class quiety_seo_check_form extends Widget_Base {
    public function get_name() {
        return 'quiety_seo_check_form';
    }

    public function get_title() {
        return __( 'Seo Checker', 'saasland-core' );
    }

    public function get_icon() {
        return 'eicon-form-horizontal';
    }

    public function get_categories() {
        return [ 'saasland-elements' ];
    }

    protected function register_controls() {

        // ------------------------------ MailChimp form ------------------------------
        $this->start_controls_section(
            'form_settings', [
                'label' => __( 'Form settings', 'saasland-core' ),
            ]
        );

        $this->add_control(
            'btn_label', [
                'label' => esc_html__( 'Submit Button Label', 'saasland-core' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Check',
            ]
        );

        $this->add_control(
            'url_name', [
                'label' => esc_html__( 'Field Condition', 'saasland-core' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'url',
                'description' => 'Please enter your input field attribute (e.g. name, url)'
            ]
        );

        $this->add_control(
            'url_placeholder', [
                'label' => esc_html__( 'Placeholder Text', 'saasland-core' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => 'Enter URL',
            ]
        );

        $this->add_control(
            'action_url', [
                'label' => esc_html__( 'Action URL', 'saasland-core' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'description' => 'You must place a valid Action URL'
            ]
        );

        $this->end_controls_section();


        /**
         * Style Tab
         */
        //------------------------------ Style Section ------------------------------
        $this->start_controls_section(
            'style_section', [
                'label' => __( 'Style section', 'saasland-core' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'bg_image', [
                'label' => esc_html__( 'Background Image 01', 'saasland-core' ),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => plugins_url( 'images/seo/cloud_bg.png', __FILE__)
                ],
            ]
        );

        $this->add_control(
            'bg_image2', [
                'label' => esc_html__( 'Background Image 02', 'saasland-core' ),
                'type' => Controls_Manager::MEDIA,
                'default' => [
                    'url' => plugins_url( 'images/seo/cloud.png', __FILE__)
                ],
            ]
        );

        $this->add_control(
            'bg_color', [
                'label' => __( 'Background Color', 'saasland-core' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .seo_subscribe_area' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'sec_padding', [
                'label' => __( 'Section padding', 'saasland-core' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .seo_subscribe_area' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'default' => [
                    'unit' => 'px', // The selected CSS Unit. 'px', '%', 'em',

                ],
            ]
        );

        $this->end_controls_section();

    }

    protected function render() {
        $settings = $this->get_settings_for_display();
        $this->add_render_attribute( 'action_url', 'action', $settings['action_url']);
        $this->add_render_attribute( 'url_placeholder', 'placeholder', "{$settings['url_placeholder']}");
        $this->add_render_attribute( 'url_name', 'name', "{$settings['url_name']}");
        ?>
        <section class="digi_seo_area">
            <form <?php echo $this->get_render_attribute_string( 'action_url' ) ?> class="seo_subscribe_form" method="get">
                <div class="position-relative digi-form">
                    <input type="search" <?php echo $this->get_render_attribute_string( 'url_name' ) ?> <?php echo $this->get_render_attribute_string( 'url_placeholder' ) ?> class="form-control" maxlength="60" autocapitalize="none">
                    <button type="submit" class="digi-button">
                        <?php echo esc_html($settings['btn_label']); ?>
                    </button>
                </div>
                <input type="hidden" name="search" value="yes">
            </form>
        </section>
        <?php
    }
}