<?php
namespace Quiety\Widgets;

if (!defined('ABSPATH')) {
	exit;
}

use Elementor\{
	Controls_Manager,
	Group_Control_Background,
	Group_Control_Box_Shadow,
	Widget_Base,
	Group_Control_Typography,
	Repeater,
	Utils
};

class Quiety_Slider extends Widget_Base {

	public function get_name() {
		return 'quiety-slider';
	}

	public function get_title() {
		return esc_html__('Quiety Slider', 'quiety-core');
	}

	public function get_icon() {
		return 'eicon-post-slider';
	}

	public function get_categories() {
		return ['tt-elements'];
	}

	protected function register_controls() {

		// Slider =========================
		$this->start_controls_section('slider_section', [
			'label' => esc_html__('Slider', 'quiety-core'),
		]);

		$repeater = new Repeater();

		$repeater->start_controls_tabs('slider_tabs');
		$repeater->start_controls_tab('slider_tab_content', [
			'label' => __('Slider Content', 'quiety-core')
		]);

		$repeater->add_control('slider_title', [
			'label'   => __('Title', 'quiety-core'),
			'type'        => Controls_Manager::TEXTAREA,
			'default'     => __('Reliable Hosting For Game <span>Solutions</span>', 'quiety-core'),
			'description'	=> __('Title wrap up the span tag for gradient color', 'quiety-core'),
			'label_block' => true,
		]);
		$repeater->add_control(
			'h_tag', [
				'label' => esc_html__('Title Tag', 'quiety-core'),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'h1',
				'options' => [
					'h1'  => esc_html__('H1', 'quiety-core'),
					'h2'  => esc_html__('H2', 'quiety-core'),
					'h3'  => esc_html__('H3', 'quiety-core'),
					'h4'  => esc_html__('H4', 'quiety-core'),
					'h5'  => esc_html__('H5', 'quiety-core'),
					'h6'  => esc_html__('H6', 'quiety-core'),
				],
			]
		);
		$repeater->add_control('slider_desc', [
			'label'       => __('Description', 'quiety-core'),
			'type'        => Controls_Manager::TEXTAREA,
			'default'     => __('Give your Website the speed, security, and uptime it deserves and become part of the fastest Web Hosting.', 'quiety-core'),
			'label_block' => true,
		]);

		$repeater->add_control('slider_btn_label', [
			'label'       => __('Button Label', 'quiety-core'),
			'type'        => Controls_Manager::TEXT,
			'default'     => __('Order Now', 'quiety-core'),
			'label_block' => true,
		]);

		$repeater->add_control('slider_btn_url', [
			'label'       => __('Button URL', 'quiety-core'),
			'type'        => Controls_Manager::TEXT,
			'default'     => '#',
			'label_block' => true,
		]);

		$repeater->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'slider_image',
				'label' => esc_html__('Slider Background', 'quiety-core'),
				'types' => ['classic', 'gradient', 'video'],
				'selector' => '{{WRAPPER}} {{CURRENT_ITEM}} .slider',
			]
		);
		$repeater->end_controls_tab();

		$repeater->start_controls_tab('slider_tab_style', [
			'label' => __('Slider Style', 'quiety-core')
		]);

		$repeater->add_control('style_title', [
			'label'       => __('Title Style', 'quiety-core'),
			'type'        => Controls_Manager::HEADING,
		]);

		$repeater->add_control('title_color', [
			'label'     => __('Color', 'quiety-core'),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} {{CURRENT_ITEM}} .slider_title' => 'color: {{VALUE}}',
			],
		]);

		$repeater->add_group_control(Group_Control_Typography::get_type(), [
			'name'     => 'title_typo',
			'label'    => __('Typography', 'quiety-core'),
			'selector' => '{{WRAPPER}} {{CURRENT_ITEM}} .slider_title',
		]);

		$repeater->add_control('style_desc', [
			'label'     => __('Description Style', 'quiety-core'),
			'type'      => Controls_Manager::HEADING,
			'separator'	=> 'before'
		]);

		$repeater->add_control('desc_color', [
			'label'     => __('Color', 'quiety-core'),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} {{CURRENT_ITEM}} p.lead' => 'color: {{VALUE}}',
			],
		]);

		$repeater->add_group_control(Group_Control_Typography::get_type(), [
			'name'     => 'desc_typo',
			'label'    => __('Typography', 'quiety-core'),
			'selector' => '{{WRAPPER}} {{CURRENT_ITEM}} p.lead',
		]);

		$repeater->add_control('style_btn', [
			'label'     => __('Button Normal','quiety-core' ),
			'type'      => Controls_Manager::HEADING,
			'separator'	=> 'before'
		]);

		$repeater->add_group_control(Group_Control_Typography::get_type(), [
			'name'     => 'slider_btn_typo',
			'label'    => __('Typography', 'quiety-core'),
			'selector' => '{{WRAPPER}} {{CURRENT_ITEM}} .hero-content .btn-gradient',
		]);
		$repeater->add_control(
			'slider_btn_padding',
			[
				'label' => esc_html__('Padding', 'plugin-name'),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => ['px', '%', 'em'],
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}} .hero-content .btn-gradient' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$repeater->add_control('slider_btn_color', [
			'label'     => __('Color', 'quiety-core'),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} {{CURRENT_ITEM}} .hero-content .btn-gradient' => 'color: {{VALUE}}',
			],
		]);
		$repeater->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'slider_btn_bg',
				'label' => esc_html__('Button Background', 'quiety-core'),
				'types' => ['classic', 'gradient'],
				'selector' => '{{WRAPPER}} {{CURRENT_ITEM}} .hero-content .btn-gradient',
			]
		);
		$repeater->add_control('style_btn_hover', [
			'label'     => __('Button Hover', 'quiety-core'),
			'type'      => Controls_Manager::HEADING,
			'separator'	=> 'before'
		]);
		$repeater->add_control('slider_btn_hover_color', [
			'label'     => __('Hover Color', 'quiety-core'),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} {{CURRENT_ITEM}} .hero-content .btn-gradient:hover' => 'color: {{VALUE}}',
			],
		]);
		$repeater->add_group_control(
			\Elementor\Group_Control_Background::get_type(),
			[
				'name' => 'slider_btn_hover_bg',
				'label' => esc_html__('Button Hover Background', 'quiety-core'),
				'show_label' => true,
				'types' => ['classic', 'gradient'],
				'selector' => '{{WRAPPER}} {{CURRENT_ITEM}} .hero-content .btn-gradient:hover',
			]
		);
		


		$repeater->end_controls_tab();
		$repeater->end_controls_tabs();

		$this->add_control('quiety_slider', [
			'label'       => __('Slider Items', 'quiety-core'),
			'type'        => Controls_Manager::REPEATER,
			'fields'      => $repeater->get_controls(),
			'default'     => [
				[
					'slider_title'		=> __('Reliable Hosting For Game <span>Solutions</span>', 'quiety-core'),
					'slider_desc'		=> __('Give your Website the speed, security, and uptime it deserves and become part of the fastest Web Hosting.', 'quiety-core'),
					'slider_btn_label'	=> __('Order Now.', 'quiety-core'),
					'slider_btn_url'	=> '#',
					'slider_image'		=> [
						'url' => Utils::get_placeholder_image_src(),
					],
				],
				[
					'slider_title'		=> __('Reliable Hosting For Game <span>Solutions</span>', 'quiety-core'),
					'slider_desc'		=> __('Give your Website the speed, security, and uptime it deserves and become part of the fastest Web Hosting.', 'quiety-core'),
					'slider_btn_label'	=> __('Order Now.', 'quiety-core'),
					'slider_btn_url'	=> '#',
					'slider_image'		=> [
						'url' => Utils::get_placeholder_image_src(),
					],
				],
			],
			'title_field' => '{{{ slider_title }}}',
		]);
		$this->end_controls_section();

		// Slider Controls ==================================
		$this->start_controls_section('slider_settings', [
			'label' => esc_html__('Slider Controls', 'quiety-core'),
		]);

		$this->add_control('navigation', [
			'label'        => esc_html__('Navigation', 'quiety-core'),
			'type'         => Controls_Manager::SWITCHER,
			'label_on'     => esc_html__('Show', 'quiety-core'),
			'label_off'    => esc_html__('Hide', 'quiety-core'),
			'return_value' => 'yes',
			'default'      => 'yes'
		]);


		$this->add_control('loop', [
			'label'        => esc_html__('Loop', 'quiety-core'),
			'type'         => Controls_Manager::SWITCHER,
			'label_on'     => esc_html__('On', 'quiety-core'),
			'label_off'    => esc_html__('Off', 'quiety-core'),
			'return_value' => 'yes',
			'default'      => 'yes'
		]);

		$this->add_control('speed', [
			'label'   => __('Speed', 'quiety-core'),
			'type'    => Controls_Manager::NUMBER,
			'default' => 700,
		]);

		$this->add_control('autoplay', [
			'label'        => esc_html__('Autoplay', 'quiety-core'),
			'type'         => Controls_Manager::SWITCHER,
			'label_on'     => esc_html__('On', 'quiety-core'),
			'label_off'    => esc_html__('Off', 'quiety-core'),
			'return_value' => 'yes',
			'default'      => 'yes'
		]);

		$this->add_control('autoplay_time', [
			'label'   => __('Autoplay Time', 'quiety-core'),
			'type'    => Controls_Manager::NUMBER,
			'default' => 3000,
			'condition' => [
				'autoplay' => 'yes'
			]
		]);

		$this->end_controls_section();
	}

	protected function render() {

		$settings     = $this->get_settings_for_display();
		extract($settings); ?>

		<div class="hero-twelve">
			<div class="swiper-container hero-slider">
				<div class="swiper-wrapper" data-loop="true">
					<?php
					if (is_array($quiety_slider) && count($quiety_slider) > 0) {
						foreach ($quiety_slider as $item) {
                            ?>
							<div class="swiper-slide elementor-repeater-item-<?php echo esc_attr($item['_id']) ?>">
								<div class="slider-one slider">
									<div class="container">
										<div class="row">
											<div class="col-lg-6">
												<div class="hero-content">
													<?php
													$h_tag = isset( $item['h_tag'] ) ? $item['h_tag'] : 'h1';
													if( !empty( $item['slider_title'] ) ){
														echo '<'.$h_tag.' class="fw-bold display-5 mb-4 slider_title" data-aos="fade-up">'. $item['slider_title'] .'</'.$h_tag.'>';
													}
													if( !empty( $item['slider_desc'] ) ){
														echo '<p class="lead m-0">'. quiety_kses_post( nl2br( $item['slider_desc'] ) ) .'</p>';
													}
													if( !empty( $item['slider_btn_label'] ) ){ 
														echo '<a href="'. esc_url( $item['slider_btn_url'] ) .'" class="btn-gradient mt-4 link-with-icon">'. esc_html( $item['slider_btn_label'] ) . '<i class="far fa-arrow-right"></i></a>';
													}
													?>
												</div>
											</div>
										</div>
									</div>
								</div>
							</div>
							<?php
						}
					}
					?>
				</div>
			</div>
		</div>
		<?php

	}

	
}
