<?php

namespace Quiety\Widgets;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Elementor\{Widget_Base,
	Controls_Manager,
	Group_Control_Typography,
	Group_Control_Border,
	Group_Control_Image_Size,
	Repeater,
	Plugin
};

class Quiety_Support extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve alert widget name.
	 *
	 * @return string Widget name.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_name() {
		return 'tt-support';
	}


	public function get_title() {
		return __( 'Quiety Support', 'quiety-core' );
	}

	public function get_icon() {
		// Icon name from the Elementor font file, as per http://dtbaker.net/web-development/creating-your-own-custom-elementor-widgets/
		return 'eicon-photo-library';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the widget categories.
	 *
	 * @return array Widget categories.
	 * @since 1.0.0
	 * @access public
	 *
	 */
	public function get_categories() {
		return [ 'tt-elements' ];
	}

	protected function register_controls() {

		$this->start_controls_section( 'section_query', [
			'label' => __( 'Support', 'quiety-core' ),
		] );

		$this->add_control( 'word_limit', [
			'label'   => esc_html__( 'Word Limit', 'quiety-core' ),
			'type'    => Controls_Manager::NUMBER,
			'default' => '15',
			'min'     => 1,
			'max'     => 100,
			'step'    => 1,
		] );

		$this->add_control( 'read_more', [
			'label'   => __( 'Read More Button Text', 'quiety-core' ),
			'type'    => \Elementor\Controls_Manager::TEXT,
			'default' => __( 'Read More', 'quiety-core' ),
			'label_block' => true

		] );

		$this->add_control( 'filter', [
			'label'        => esc_html__( 'Filter', 'quiety-core' ),
			'type'         => Controls_Manager::SWITCHER,
			'label_on'     => __( 'Yes', 'quiety-core' ),
			'label_off'    => __( 'No', 'quiety-core' ),
			'return_value' => 'yes',
			'default'      => 'yes',
		] );

		$this->end_controls_section();

		// Query Settings
		// =====================
		$this->start_controls_section( 'query_section', [
			'label' => esc_html__( 'Query', 'quiety-core' ),
		] );

		$this->add_control( 'posts_per_page', [
			'label'       => esc_html__( 'Items per page', 'quiety-core' ),
			'description' => esc_html__( 'Number of items to show per page. Input "-1" to show all posts. Leave blank to use global setting.', 'quiety-core' ),
			'type'        => Controls_Manager::NUMBER,
			'default'     => '6',
			'min'         => - 1,
			'max'         => 100,
			'step'        => 1,
		] );

		$this->add_control( 'support_cat', [
			'label'       => esc_html__( 'Select category', 'quiety-core' ),
			'type'        => Controls_Manager::SELECT2,
			'multiple'    => true,
			'label_block' => true,
			'options'     => \Quiety_Helper::quiety_category_list( 'quiety_support_cat' ),

		] );

		$this->add_control( 'order_by', [
			'label'       => __( 'Order by', 'quiety-core' ),
			'type'        => Controls_Manager::SELECT,
			'options'     => [
				'date'           => esc_html__( 'Date', 'quiety-core' ),
				'ID'             => esc_html__( 'Post ID', 'quiety-core' ),
				'author'         => esc_html__( 'Author', 'quiety-core' ),
				'title'          => esc_html__( 'Title', 'quiety-core' ),
				'modified'       => esc_html__( 'Last modified date', 'quiety-core' ),
				'parent'         => esc_html__( 'Post/page parent ID', 'quiety-core' ),
				'comment_count'  => esc_html__( 'Number of comments', 'quiety-core' ),
				'menu_order'     => esc_html__( 'Menu order/Page Order', 'quiety-core' ),
				'meta_value'     => esc_html__( 'Meta value', 'quiety-core' ),
				'meta_value_num' => esc_html__( 'Meta value number', 'quiety-core' ),
				'rand'           => esc_html__( 'Random order', 'quiety-core' ),
			],
			'default'     => 'date',
			'separator'   => 'before',
			'description' => esc_html__( "Select how to sort retrieved posts. More at ", 'quiety-core' ) . '<a href="http://codex.wordpress.org/Class_Reference/WP_Query#Order_.26_Orderby_Parameters" target="_blank">WordPress codex</a>.',
		] );

		$this->add_control( 'order', [
			'label'       => __( 'Sort Order', 'quiety-core' ),
			'type'        => Controls_Manager::SELECT,
			'options'     => [
				'ASC'  => esc_html__( 'Ascending', 'quiety-core' ),
				'DESC' => esc_html__( 'Descending', 'quiety-core' ),
			],
			'default'     => 'DESC',
			'separator'   => 'before',
			'description' => esc_html__( "Select Ascending or Descending order. More at", 'quiety-core' ) . '<a href="http://codex.wordpress.org/Class_Reference/WP_Query#Order_.26_Orderby_Parameters" target="_blank">WordPress codex</a>.',
		] );

		$this->end_controls_section();


		// Style Settings
		// =====================

		$this->start_controls_section( 'support_style_section', [
			'label' => __( 'Style', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'content_typography',
			'label'    => __( 'Title Typography', 'quiety-core' ),
			'selector' => '{{WRAPPER}} .tt-job-item .post-wrapper .job-info .job-title',
		] );

		$this->add_control( 'title_color', [
			'label'     => __( 'Title Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-job-item .post-wrapper .job-info .job-title' => 'color: {{VALUE}}',
			],
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'cat_typography',
			'label'    => __( 'Category Typography', 'quiety-core' ),
			'selector' => '{{WRAPPER}} .tt-job-item .post-wrapper .job-info .job-cat .cat',
		] );

		$this->add_control( 'cat_color', [
			'label'     => __( 'Category Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-job-item .post-wrapper .job-info .job-cat .cat' => 'color: {{VALUE}}',
			],
		] );

		$this->add_control( 'overlay_background', [
			'label'     => __( 'Overlay Background', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-job-item .post-wrapper .post-thumbnail-wrapper a:before' => 'background: {{VALUE}}',
			],
		] );

		$this->end_controls_section();

		$this->start_controls_section( 'section_style', [
			'label'     => __( 'Button', 'quiety-core' ),
			'tab'       => Controls_Manager::TAB_STYLE,
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'typography',
			'label'    => __( 'Typography', 'quiety-core' ),
			'selector' => '{{WRAPPER}} a.tt-btn, {{WRAPPER}} .tt-btn',
		] );

		$this->start_controls_tabs( 'tabs_button_style' );

		$this->start_controls_tab( 'tab_button_normal', [
			'label' => __( 'Normal', 'quiety-core' ),
		] );

		$this->add_control( 'button_text_color', [
			'label'     => __( 'Text Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'default'   => '',
			'selectors' => [
				'{{WRAPPER}} a.tt-btn, {{WRAPPER}} .tt-btn' => 'color: {{VALUE}};',
			],
		] );

		$this->add_group_control( Group_Control_Border::get_type(), [
			'name'        => 'border',
			'label'       => __( 'Border', 'quiety-core' ),
			'placeholder' => '1px',
			'default'     => '1px',
			'selector'    => '{{WRAPPER}} .tt-btn',
			'separator'   => 'before',
		] );

		$this->end_controls_tab();

		$this->start_controls_tab( 'tab_button_hover', [
			'label' => __( 'Hover', 'quiety-core' ),
		] );

		$this->add_control( 'hover_color', [
			'label'     => __( 'Text Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-btn:hover, {{WRAPPER}} .tt-btn:hover' => 'color: {{VALUE}};',
			],
		] );

		$this->add_control( 'background_color', [
			'label'     => __( 'Background Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-btn:after' => 'background-color: {{VALUE}};',
			],
		] );

		$this->add_group_control( Group_Control_Border::get_type(), [
			'name'        => 'border_hover',
			'label'       => __( 'Border', 'quiety-core' ),
			'placeholder' => '1px',
			'default'     => '1px',
			'selector'    => '{{WRAPPER}} .tt-btn:hover',
			'separator'   => 'before',
		] );

		$this->end_controls_tab();
		$this->end_controls_tabs();

		$this->add_control( 'border_radius', [
			'label'      => __( 'Border Radius', 'quiety-core' ),
			'type'       => Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%' ],
			'selectors'  => [
				'{{WRAPPER}} a.tt-btn, {{WRAPPER}} .tt-btn' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		] );


		$this->add_control( 'text_padding', [
			'label'      => __( 'Text Padding', 'quiety-core' ),
			'type'       => Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', 'em', '%' ],
			'selectors'  => [
				'{{WRAPPER}} a.tt-btn, {{WRAPPER}} .tt-btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
			'separator'  => 'before',
		] );

		$this->end_controls_section();

	}

	protected function render() {
		$settings = $this->get_settings_for_display();

		$cat_list = $settings['support_cat'];
		$_tax_query = array();

		if ( $settings['support_cat'] ) {
			$_tax_query = array(
				array(
					'taxonomy' => 'quiety_support_cat',
					'field'    => 'slug',
					'terms'    => $cat_list
				)
			);
		}

		$paged = ( get_query_var( 'paged' ) > 1 ) ? get_query_var( 'paged' ) : 1;

		$args = array(
			'post_type'      => 'quiety_support',
			'paged'          => $paged,
			'order'          => $settings['order'],
			'orderby'        => $settings['order_by'],
			'posts_per_page' => $settings['posts_per_page'],
			'tax_query'      => $_tax_query,
			'post_status'    => 'publish',
		);

		$tt_query = new \WP_Query( $args );

		$this->add_render_attribute( 'wrapper', 'class', [
			'tt-support-wrapper'
		] );

		$args  = array(
			'hide_empty' => true,
			'taxonomy'   => 'quiety_support_cat',
			'slug'       => $cat_list,
		);

		$terms = get_terms( $args );

		$form_link = quiety_option('support_form');
		$email = quiety_option('support_email');
		$chat = quiety_option('support_chat');

		?>

		<div class="row">
			<?php if ( 'yes' === $settings['filter'] ) { ?>
				<div class="col-lg-4 col-md-5 sidebar-wrap">
					<div class="quiety-filter-wrapper">
						<ul class="tt-content-filter" role="tablist" id="gallerytab">
							<li class="current  site-info">
								<a href="javascript:void(0)" class="btn-filter" data-filter="*"><?php esc_html_e( 'Show All', 'quiety-core' ) ?></a>
							</li>
							<?php foreach ( $terms as $term ) { ?>
								<li>
									<a href="javascript:void(0)" data-filter="<?php echo 'quiety_support_cat-' . $term->slug; ?>"><?php echo $term->name; ?></a>
								</li>
							<?php } ?>
						</ul>
					</div>


					<ul class="support-contact-info">
						<?php if ( ! empty( $form_link ) ) : ?>
							<li><i class="far fa-file-alt"></i><?php echo esc_html( $form_link ) ?></li>
						<?php endif; ?>

						<?php if ( ! empty( $form_link ) ) : ?>
							<li><i class="far fa-envelope"></i><?php echo esc_html( $email ) ?></li>
						<?php endif; ?>

						<?php if ( ! empty( $form_link ) ) : ?>
							<li><i class="far fa-comment-alt"></i><?php echo esc_html( $chat ) ?></li>
						<?php endif; ?>
					</ul>
					<!-- /.support-contact-info -->
				</div>
				<!-- /.col-md-4 -->
			<?php } ?>


			<div class="col-lg-8 col-md-7">
				<div <?php $this->print_render_attribute_string( 'wrapper' ); ?>>
					<?php if ( $tt_query->have_posts() ) : ?>
						<div class="support-list-items">
							<?php require __DIR__ . '/templates/support/style1.php'; ?>
						</div>
						<?php wp_reset_postdata(); ?>
					<?php endif; ?>
				</div>
			</div>
			<!-- /.col-md-8 -->
		</div>
		<!-- /.row -->
		<?php
	}
}