<?php

namespace Quiety\Widgets;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Elementor\{Controls_Manager,
	Group_Control_Background,
	Group_Control_Border,
	Group_Control_Box_Shadow,
	Group_Control_Typography,
	Repeater,
	Widget_Base};

/**
 * Quiety Tab
 *
 * Quiety widget.
 *
 * @since 2.0.0
 */
class Quiety_Tab extends Widget_Base {

	public function get_name() {
		return 'tt-tab';
	}

	public function get_title() {
		return __( 'Quiety Testimonial Tab', 'quiety-core' );
	}

	public function get_icon() {
		return 'eicon-tabs';
	}

	public function get_categories() {
		return [ 'tt-elements' ];
	}

	protected function register_controls() {

		// ------------------------------ Feature list ------------------------------
		$this->start_controls_section( 'section_tab', [
			'label' => __( 'Testimonial', 'quiety-core' ),
		] );

		$this->add_control( 'watermark_enable', [
			'label'        => esc_html__( 'Water Mark', 'hexafy-core' ),
			'type'         => Controls_Manager::SWITCHER,
			'label_on'     => esc_html__( 'Show', 'hexafy-core' ),
			'label_off'    => esc_html__( 'Hide', 'hexafy-core' ),
			'return_value' => 'yes',
			'default'      => 'yes'
		] );

		$this->add_control( 'watermark', [
			'label'   => __( 'Watermark', 'hexafy-core' ),
			'type'    => Controls_Manager::MEDIA,
			'default' => [
				'url' =>  plugin_dir_url( __DIR__ ) . 'assets/images/watermark.svg',
			],
			'condition' => [
				'watermark_enable' => 'yes'
			]
		] );

		$repeater = new Repeater();

		$repeater->add_control( 'name', [
			'label'       => __( 'Name', 'quiety-core' ),
			'type'        => Controls_Manager::TEXT,
			'label_block' => true,
		] );

		$repeater->add_control( 'designation', [
			'label'       => __( 'Designation', 'quiety-core' ),
			'type'        => Controls_Manager::TEXT,
			'label_block' => true,
		] );

		$repeater->add_control( 'rating', [
			'label'   => __( 'Rating Style', 'quiety-core' ),
			'type'    => \Elementor\Controls_Manager::SELECT,
			'default' => '50',
			'options' => [
				'10' => __( '1 Star', 'quiety-core' ),
				'20' => __( '2 Star', 'quiety-core' ),
				'30' => __( '3 Star', 'quiety-core' ),
				'40' => __( '4 Star', 'quiety-core' ),
				'50' => __( '5 Star', 'quiety-core' ),
			],
		] );

		$repeater->add_control( 'author_image', [
			'label'   => __( 'Author Image', 'quiety-core' ),
			'type'    => Controls_Manager::MEDIA,
			'default' => [
				'url' => plugin_dir_url( __DIR__ ) . 'assets/images/author1.jpg'
			],
		] );

		$repeater->add_control( 'tab_image', [
			'label'   => __( 'Tab Feature Image', 'quiety-core' ),
			'type'    => Controls_Manager::MEDIA,
			'default' => [
				'url' => plugin_dir_url( __DIR__ ) . 'assets/images/testimonial_tab_1.jpg'
			],
		] );

		$repeater->add_control( 'title', [
			'label'       => __( 'Title', 'quiety-core' ),
			'type'        => Controls_Manager::TEXT,
			'label_block' => true,
		] );

		$repeater->add_control( 'description', [
			'label'      => __( 'Content', 'quiety-core' ),
			'type'       => Controls_Manager::TEXTAREA,
			'show_label' => false,
		] );

		$repeater->add_control( 'video_btn', [
			'label'       => __( 'Video Button Text', 'quiety-core' ),
			'type'        => Controls_Manager::TEXT,
			'default' => __('Watch Video', 'quiety-core')
		] );

		$repeater->add_control(
			'video_link',
			[
				'label' => __( 'Video Link', 'quiety-core' ),
				'type' => \Elementor\Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'quiety-core' ),
				'show_external' => false,
			]
		);


		$this->add_control( 'advance_tab', [
			'label'       => __( 'Tab Lists', 'quiety-core' ),
			'type'        => Controls_Manager::REPEATER,
			'fields'      => $repeater->get_controls(),
			'default'     => [
				[
					'name'   => __( 'Joe Richard', 'quiety-core' ),
					'designation'    => __('Visual Designer', 'quiety-core'),
					'title'       => __( 'The Best Template You Got to Have it!', 'quiety-core' ),
					'description' => __( 'Appropriately disintermediate one-to-one vortals through cross functional infomediaries. Collaboratively pursue multidisciplinary systems through stand-alone architectures. Progressively transition covalent architectures whereas vertical applications procrastinate professional.', 'quiety-core' ),

				],
				[
					'name'   => __( 'Rupan Oberoi', 'quiety-core' ),
					'designation'    => __('Web Designer', 'quiety-core'),
					'title'       => __( 'Embarrassed by the First Version.', 'quiety-core' ),
					'description' => __( 'Appropriately disintermediate one-to-one vortals through cross functional infomediaries. Collaboratively pursue multidisciplinary systems through stand-alone architectures. Progressively transition covalent architectures whereas vertical applications procrastinate professional.', 'quiety-core' ),

				],
				[
					'name'   => __( 'Jon Doe', 'quiety-core' ),
					'designation'    => __('Software Engineer', 'quiety-core'),
					'title'       => __( 'Amazing Quiety template!', 'quiety-core' ),
					'description' => __( 'Appropriately disintermediate one-to-one vortals through cross functional infomediaries. Collaboratively pursue multidisciplinary systems through stand-alone architectures. Progressively transition covalent architectures whereas vertical applications procrastinate professional.', 'quiety-core' ),

				],
				[
					'name'   => __( 'Hanry Luice', 'quiety-core' ),
					'designation'    => __('App Developer', 'quiety-core'),
					'title'       => __( 'Best Template for SAAS Company!', 'quiety-core' ),
					'description' => __( 'Appropriately disintermediate one-to-one vortals through cross functional infomediaries. Collaboratively pursue multidisciplinary systems through stand-alone architectures. Progressively transition covalent architectures whereas vertical applications procrastinate professional.', 'quiety-core' ),

				],
				[
					'name'   => __( 'Ami Nijai', 'quiety-core' ),
					'designation'    => __('Customer Support', 'quiety-core'),
					'title'       => __( 'It is Undeniably Good!', 'quiety-core' ),
					'description' => __( 'Appropriately disintermediate one-to-one vortals through cross functional infomediaries. Collaboratively pursue multidisciplinary systems through stand-alone architectures. Progressively transition covalent architectures whereas vertical applications procrastinate professional.', 'quiety-core' ),

				],
			],
			'title_field' => '{{{ name }}}',
		] );

		$this->end_controls_section(); // End Buttons


		// Tab Label Style
		// =========================
		$this->start_controls_section( 'content_section', [
			'label' => __( 'Tab Label', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->start_controls_tabs( 'tabs_testimonial_style' );

		$this->start_controls_tab( 'tab_testimonial_normal', [
			'label' => __( 'Normal', 'quiety-core' ),
		] );

		$this->add_control( 'tab_name_color', [
			'label'     => __( 'Name', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tab-name' => 'color: {{VALUE}}',
			],
		] );

		$this->add_control( 'tab_designation_color', [
			'label'     => __( 'Designation Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} #tt-tabs-nav li a .tab-designation' => 'color: {{VALUE}}',
			],
		] );

		$this->add_control( 'tab_bg_color', [
			'label'     => __( 'Background Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} #tt-tabs-nav li' => 'background-color: {{VALUE}}',
			],
		] );

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'tab_border',
				'label' => __( 'Border', 'quiety-core' ),
				'selector' => '{{WRAPPER}} #tt-tabs-nav li',
			]
		);

		$this->end_controls_tab();

		$this->start_controls_tab( 'tab_testimonial_active', [
			'label' => __( 'Active', 'quiety-core' ),
		] );

		$this->add_control( 'label_active_color', [
			'label'     => __( 'Name Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} #tt-tabs-nav li.active .tab-name' => 'color: {{VALUE}}',
			],
		] );

		$this->add_control( 'tab_designation_active_color', [
			'label'     => __( 'Designation Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} #tt-tabs-nav li.active .tab-designation' => 'color: {{VALUE}}',
			],
		] );

		$this->add_control( 'tab_active_bg_color', [
			'label'     => __( 'Background Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} #tt-tabs-nav li.active' => 'background-color: {{VALUE}}',
			],
		] );

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'active_border',
				'label' => __( 'Border', 'quiety-core' ),
				'selector' => '{{WRAPPER}} #tt-tabs-nav li.active',
			]
		);

		$this->end_controls_tab();
		$this->end_controls_tabs();

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'name_typography',
			'label'    => __( 'Name Typography', 'quiety-core' ),
			'selector' => '{{WRAPPER}} #tt-tabs-nav li a .tab-name',
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'designation_typography',
			'label'    => __( 'Typography', 'quiety-core' ),
			'selector' => '{{WRAPPER}} #tt-tabs-nav li a .tab-designation',
		] );

		$this->add_control( 'tab_nav_padding', [
			'label'      => __( 'Padding', 'quiety-core' ),
			'type'       => Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%', 'em' ],
			'selectors'  => [
				'{{WRAPPER}} #tt-tabs-nav li' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		] );

		$this->add_control( 'tab_nav_active_border_radius', [
			'label'      => __( 'Border Radius', 'quiety-core' ),
			'type'       => Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%', 'em' ],
			'selectors'  => [
				'{{WRAPPER}} #tt-tabs-nav li' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		] );

		$this->end_controls_section();


		// Title Style
		// =========================
		$this->start_controls_section( 'title_style', [
			'label' => __( 'Title', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_control( 'title_color', [
			'label'     => __( ' Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tabs-content .title' => 'color: {{VALUE}}',
			],
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'title_typography',
			'label'    => __( 'Typography', 'quiety-core' ),
			'selector' => '{{WRAPPER}} .tabs-content .title',
		] );

		$this->end_controls_section();


		// Description Style
		// =========================
		$this->start_controls_section( 'description_style', [
			'label' => __( 'Review Content', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_control( 'description_color', [
			'label'     => __( ' Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-tabs-wrapper p' => 'color: {{VALUE}}',
			],
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'des_typography',
			'label'    => __( 'Typography', 'quiety-core' ),
			'selector' => '{{WRAPPER}} .tt-tabs-wrapper p',
		] );

		$this->end_controls_section();

		// Description Style
		// =========================
		$this->start_controls_section( 'author_style', [
			'label' => __( 'Author', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_control( 'author_color_name', [
			'label'     => __( ' Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-tabs-wrapper .author-info .name' => 'color: {{VALUE}}',
			],
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'author_name_typography',
			'label'    => __( 'Typography', 'quiety-core' ),
			'selector' => '{{WRAPPER}} .tt-tabs-wrapper .author-info .name',
		] );

		$this->add_control( 'author_designation_color_name', [
			'label'     => __( 'Designation Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-tabs-wrapper .author-info .designation' => 'color: {{VALUE}}',
			],
			'separator' => 'before'
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'author_designation_typography',
			'label'    => __( 'Typography', 'quiety-core' ),
			'selector' => '{{WRAPPER}} .tt-tabs-wrapper .author-info .designation',
		] );

		$this->end_controls_section();


		// Video Button Style
		//=======================
		$this->start_controls_section(
			'video_button_style',
			[
				'label' => __( 'Popup Video Button', 'quiety-core' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'video_button_typography',
				'label' => __( 'Typography', 'quiety-core' ),
				'selector' => '{{WRAPPER}} .play-button',
			]
		);

		$this->add_control(
			'video_border_radius',
			[
				'label' => esc_html__( 'Icon Border Radius', 'quiety-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%', 'em' ],
				'selectors' => [
					'{{WRAPPER}} .play-button i' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);

		$this->add_responsive_control(
			'video_text_padding',
			[
				'label' => esc_html__( 'Icon Padding', 'quiety-core' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', 'em', '%' ],
				'selectors' => [
					'{{WRAPPER}} .play-button i' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'separator' => 'before',
			]
		);

		$this->start_controls_tabs( 'tabs_video_style' );

		$this->start_controls_tab(
			'tab_button_video_normal',
			[
				'label' => esc_html__( 'Normal', 'quiety-core' ),
			]
		);

		$this->add_control(
			'video_button_color',
			[
				'label' => esc_html__( 'Color', 'quiety-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .play-button' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'video_button_icon_color',
			[
				'label' => esc_html__( 'Icon Color', 'quiety-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .play-button i' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'play_button_background',
				'label' => esc_html__( 'Icon Background', 'quiety-core' ),
				'types' => [ 'classic', 'gradient' ],
				'exclude' => [ 'image' ],
				'selector' => '{{WRAPPER}} .play-button i',
			]
		);

		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'play_button_border',
				'selector' => '{{WRAPPER}} .play-button i',
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'video_button_box_shadow',
				'selector' => '{{WRAPPER}} .play-button i ',
			]
		);
		$this->end_controls_tab();

		$this->start_controls_tab(
			'tab_video_button_hover',
			[
				'label' => esc_html__( 'Hover', 'quiety-core' ),
			]
		);

		$this->add_control(
			'video_button_hover_color',
			[
				'label' => esc_html__( 'Color', 'quiety-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .play-button:hover, {{WRAPPER}} .play-button:focus' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'video_button_hover_icon_color',
			[
				'label' => esc_html__( 'Icon Color', 'quiety-core' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .play-button:hover i, {{WRAPPER}} .play-button:focus i' => 'color: {{VALUE}};',
				],
			]
		);

		$this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'play_button_background_hover',
				'label' => esc_html__( 'Icon Background', 'quiety-core' ),
				'types' => [ 'classic', 'gradient' ],
				'exclude' => [ 'image' ],
				'selector' => '{{WRAPPER}} .play-button:hover i, {{WRAPPER}} .play-button:focus i',
			]
		);
		$this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'play_button_border_hover',
				'selector' => '{{WRAPPER}} .play-button:hover i',
			]
		);

		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'video_button_hover_box_shadow',
				'selector' => '{{WRAPPER}} .play-button:hover i',
			]
		);

		$this->end_controls_tab();
		$this->end_controls_tabs();

		$this->end_controls_section();

		// Feature Style
		// =========================
		$this->start_controls_section( 'feature_style', [
			'label' => __( 'Feature Image', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_control( 'shape_image', [
			'label'   => __( 'Shape Image', 'quiety-core' ),
			'type'    => Controls_Manager::MEDIA,
			'default' => [
				'url' => plugin_dir_url( __DIR__ ) . 'assets/images/dot.png'
			],
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'fea_typography',
			'label'    => __( 'Typography', 'quiety-core' ),
			'selector' => '{{WRAPPER}} .tt-tabs-wrapper .tt-tabs-contents .feature-items .feature .feature-content h3',
		] );

		$this->end_controls_section();

	}

	protected function render() {

		$settings    = $this->get_settings();
		$advance_tab = isset( $settings['advance_tab'] ) ? $settings['advance_tab'] : '';
		$id_int = 'tabs-id-' . substr( $this->get_id_int(), 0, 3 );

		if ($settings['watermark'] != '') {
			$watermark = $settings['watermark']['url'];
		}
		?>

		<div id="tt-tabs" class="tt-tabs wow fadeInUp">

			<div id="tt-tabs-content" class="tt-tabs-wrapper">
				<?php foreach ( $advance_tab as $key => $tabitem ) : ?>
					<div id="<?php echo esc_attr( $id_int . '-' . $key ); ?>" class="content">
						<div class="tt-tabs-contents">
							<div class="row align-items-center">
								<div class="col-md-6">
									<div class="tabs-content">

										<?php if (!empty($watermark)): ?>
											<div class="watermark">
												<img src="<?php echo esc_url($watermark) ?>" alt="<?php echo esc_attr($tabitem['name']) ?>" height="65" width="50">
											</div>
										<?php endif; ?>

										<h3 class="title"><?php echo esc_html( $tabitem['title'] ); ?></h3>

										<?php
										$rating = $tabitem['rating'];
										$this->add_render_attribute( 'star-rating', 'class', 'gp-star-rating gp-star-' . esc_attr( $rating ) );

										$rating_markup = "<div class='star-rating gp-star-". $rating."'>\n";
										$rating_markup .= "<span class=\"gp-star-1\"></span>\n";
										$rating_markup .= "<span class=\"gp-star-2\"></span>\n";
										$rating_markup .= "<span class=\"gp-star-3\"></span>\n";
										$rating_markup .= "<span class=\"gp-star-4\"></span>\n";
										$rating_markup .= "<span class=\"gp-star-5\"></span>\n";
										$rating_markup .= "</div>";

										echo $rating_markup;
										?>

										<?php if ( ! empty( $tabitem['description'] ) ) : ?>
											<p><?php echo esc_html( $tabitem['description'] ) ?></p>
										<?php endif; ?>

										<div class="author-info">
											<?php if ( ! empty($tabitem['name'])) :?>
												<h3 class="name"><?php echo esc_html( $tabitem['name'] ); ?></h3>
											<?php endif; ?>

											<?php if ( ! empty($tabitem['designation'])) :?>
												<span class="designation"><?php echo esc_html( $tabitem['designation'] ); ?></span>
											<?php endif; ?>
										</div>
										<!-- /.author-info -->
									</div>
								</div>
								<!-- /.col-md-6 -->

								<?php if ( ! empty( $tabitem['tab_image']['url'] ) ) { ?>
									<div class="col-md-6">
										<div class="tab-image-wrapper">
											<div class="tab-image">
												<img src="<?php echo esc_url( $tabitem['tab_image']['url'] ) ?>" alt="<?php echo esc_attr( $tabitem['title'] ) ?>">

												<?php if ( ! empty( $tabitem['video_link']['url'] || $tabitem['video_btn'] ) ) : ?>
													<a href="#<?php echo esc_url($tabitem['video_link']['url']); ?>" class="play-button btn-fill popup-video"><i class="fas fa-play"></i><?php echo esc_html($tabitem['video_btn']) ?></a>
												<?php endif; ?>

											</div>
											<?php if (! empty($settings['shape_image']['url'])) :?>
												<img src="<?php echo esc_url($settings['shape_image']['url']); ?>" alt="<?php echo esc_attr( $tabitem['title'] ) ?>" class="dot-shape">
											<?php endif; ?>
										</div>
										<!-- /.tab-image-wrapper -->
									</div>
									<!-- /.col-md-6 -->
								<?php } ?>
							</div>
							<!-- /.row -->
						</div>
					</div>
				<?php endforeach; ?>
			</div>
			<!-- tt-tabs-content -->


			<ul id="tt-tabs-nav">
				<?php

				foreach ( $advance_tab as $key => $tabitem ) : ?>
					<li class="elementor-repeater-item-<?php echo esc_attr( $tabitem['_id'] ); ?>">
						<a href="#<?php echo esc_attr( $id_int . '-' . $key ); ?>">
							<?php if (! empty($tabitem['author_image']['url'])) : ?>
								<div class="author-image">
									<img src="<?php echo esc_url( $tabitem['author_image']['url'] ) ?>"	alt="<?php esc_attr_e( $tabitem['name'] ) ?>">
								</div>
								<!-- /.author-image -->
							<?php endif; ?>

							<div class="author-info">
								<?php if ( ! empty($tabitem['name'])) :?>
									<h3 class="tab-name"><?php echo esc_html( $tabitem['name'] ); ?></h3>
								<?php endif; ?>

								<?php if ( ! empty($tabitem['designation'])) :?>
									<span class="tab-designation"><?php echo esc_html( $tabitem['designation'] ); ?></span>
								<?php endif; ?>
							</div>
							<!-- /.author-info -->
						</a>
					</li>
				<?php endforeach; ?>
			</ul>
		</div>
		<?php
	}
}


