<?php

namespace Quiety\Widgets;

defined( 'ABSPATH' ) || exit; // Abort, if called directly.

use Elementor\{Group_Control_Box_Shadow,
	Utils,
	Widget_Base,
	Controls_Manager,
	Group_Control_Typography,
	Group_Control_Background};

class quiety_text_content extends Widget_Base {

	public function get_name() {
		return 'tt-heading';
	}

	public function get_title() {
		return esc_html__( 'Quiety Text Contents', 'quiety-core' );
	}

	public function get_icon() {
		return 'eicon-heading';
	}

	public function get_categories() {
		return [ 'tt-elements' ];
	}

	protected function register_controls() {
		$this->start_controls_section( 'icon_tab', [
			'label' => esc_html__( 'Icon & Image', 'quiety-core' ),
		] );

		$this->add_control( 'icon_type', [
			'label'       => esc_html__( 'Add Icon/Image', 'quiety-core' ),
			'type'        => Controls_Manager::CHOOSE,
			'label_block' => false,
			'options'     => [
				'none'       => [
					'title' => esc_html__( 'None', 'quiety-core' ),
					'icon'  => 'eicon-ban',
				],
				'type_icon'  => [
					'title' => esc_html__( 'Icon', 'quiety-core' ),
					'icon'  => 'eicon-paint-brush',
				]
			],
			'default'     => 'none',
		] );

		$this->add_control( 'icon_pack', [
			'label'     => esc_html__( 'Icon Pack', 'quiety-core' ),
			'type'      => Controls_Manager::SELECT,
			'condition' => [
				'icon_type' => 'type_icon',
			],
			'options'   => [
				'fontawesome' => esc_html__( 'Fontawesome', 'quiety-core' ),
				'feather'     => esc_html__( 'Feather', 'quiety-core' ),
			],
			'default'   => 'fontawesome',
		] );

		$this->add_control( 'box_icon', [
			'label'     => __( 'Icon', 'quiety-core' ),
			'type'      => Controls_Manager::ICONS,
			'default'   => [
				'value'   => 'fas fa-star',
				'library' => 'solid',
			],
			'condition' => [
				'icon_pack' => 'fontawesome',
				'icon_type' => 'type_icon',
			]
		] );

		$this->add_control( 'feather_icon', [
			'label'       => __( 'Choose Icon', 'quiety-core' ),
			'type'        => Controls_Manager::ICON,
			'options'     => tt_feather_icon(),
			'include'     => tt_include_feather_icons(),
			'default'     => 'feather-box',
			'condition'   => [
				'icon_pack' => 'feather',
				'icon_type' => 'type_icon',
			],
			'label_block' => true,
		] );

		$this->add_control( 'icon_view', [
			'label'        => __( 'View', 'quiety-core' ),
			'type'         => Controls_Manager::SELECT,
			'default'      => 'stacked',
			'options'      => [
				'none'    => __( 'None', 'quiety-core' ),
				'stacked' => __( 'Stacked', 'quiety-core' ),
				'framed'  => __( 'Framed', 'quiety-core' ),
			],
			'prefix_class' => 'tt-view-',
		] );

		$this->add_control( 'icon_shape', [
			'label'        => __( 'Shape', 'quiety-core' ),
			'type'         => Controls_Manager::SELECT,
			'default'      => 'rounded',
			'options'      => [
				'rounded' => __( 'Rounded', 'quiety-core' ),
				'circle'  => __( 'Circle', 'quiety-core' ),
				'square'  => __( 'Square', 'quiety-core' ),

			],
			'condition'    => [
				'icon_view' => [ 'stacked', 'framed' ],
			],
			'prefix_class' => 'tt-shape-',
		] );

		$this->end_controls_section();

		// Heading Content Section
		//==========================
		$this->start_controls_section( 'section_tab', [
			'label' => esc_html__( 'Heading', 'quiety-core' ),
		] );

		$this->add_control( 'header_style', [
			'label'   => __( 'Header Style', 'quiety-core' ),
			'type'    => Controls_Manager::SELECT,
			'default' => 'style-one',
			'options' => [
				'style-one' => __( 'Style One', 'quiety-core' ),
				'style-two' => __( 'Style Two', 'quiety-core' ),
			],
		] );

		$this->add_control( 'sub_title', [
			'label'       => esc_html__( 'Sub Title', 'quiety-core' ),
			'type'        => Controls_Manager::TEXT,
			'label_block' => true,
			'placeholder' => esc_html__( 'Sub Title', 'quiety-core' ),
			'default'     => 'Sub Title',
			'separator'   => 'none',
		] );

		$this->add_responsive_control( 'space_between_subtitle', [
			'label'           => __( 'Spacing Sub Title', 'quiety-core' ),
			'type'            => Controls_Manager::SLIDER,
			'range'           => [
				'px' => [
					'min' => -0,
					'max' => 100,
				],
			],
			'devices'         => [
				'desktop',
				'tablet',
				'mobile'
			],
			'selectors'       => [
				'{{WRAPPER}} .section-heading .subtitle, {{WRAPPER}} .section-subhead .subtitle' => 'margin-bottom: {{SIZE}}{{UNIT}};',
			],
			'separator' => 'after'
		] );


		$this->add_control( 'title_text', [
			'label'       => esc_html__( 'Title', 'quiety-core' ),
			'type'        => Controls_Manager::TEXTAREA,
			'label_block' => true,
			'rows' => 2,
			'placeholder' => esc_html__( 'Title', 'quiety-core' ),
			'default'     => esc_html__( 'Section Title', 'quiety-core' ),
		] );


		$this->add_responsive_control( 'space_between_title', [
			'label'           => __( 'Spacing Title', 'quiety-core' ),
			'type'            => Controls_Manager::SLIDER,
			'range'           => [
				'px' => [
					'min' => -20,
					'max' => 150,
				],
			],
			'devices'         => [ 'desktop', 'tablet', 'mobile' ],
			'selectors'       => [
				'{{WRAPPER}} .section-heading .section-title' => 'margin-bottom: {{SIZE}}{{UNIT}};',
			],
		] );

		$this->add_control( 'title_size', [
			'label'   => __( 'Title HTML Tag', 'quiety-core' ),
			'type'    => Controls_Manager::SELECT,
			'options' => [
				'h1'   => 'H1',
				'h2'   => 'H2',
				'h3'   => 'H3',
				'h4'   => 'H4',
				'h5'   => 'H5',
				'h6'   => 'H6',
				'div'  => 'div',
				'span' => 'span',
				'p'    => 'p',
			],
			'default' => 'h2',
		] );


		$this->add_control( 'description_text', [
			'label'       => __( 'Description', 'quiety-core' ),
			'type'        => Controls_Manager::WYSIWYG,
			'placeholder' => __( 'Type your description here', 'quiety-core' ),
			'separator' => 'before'
		] );


		$this->add_responsive_control( 'title_align', [
			'label'     => esc_html__( 'Alignment', 'quiety-core' ),
			'type'      => Controls_Manager::CHOOSE,
			'options'   => [

				'left'    => [
					'title' => esc_html__( 'Left', 'quiety-core' ),
					'icon'  => 'fa fa-align-left',
				],
				'center'  => [
					'title' => esc_html__( 'Center', 'quiety-core' ),
					'icon'  => 'fa fa-align-center',
				],
				'right'   => [
					'title' => esc_html__( 'Right', 'quiety-core' ),
					'icon'  => 'fa fa-align-right',
				],
				'justify' => [
					'title' => esc_html__( 'Justified', 'quiety-core' ),
					'icon'  => 'fa fa-align-justify',
				],
			],
			'default'   => 'center',
			'selectors' => [
				'{{WRAPPER}} .section-heading' => 'text-align: {{VALUE}};'
			],
			'prefix_class' => 'tt-text-align-'
		] );


		$this->add_responsive_control( 'space_between', [
			'label'           => __( 'Spacing', 'quiety-core' ),
			'type'            => Controls_Manager::SLIDER,
			'range'           => [
				'px' => [
					'min' => -20,
					'max' => 200,
				],
			],
			'devices'         => [ 'desktop', 'tablet', 'mobile' ],
			'selectors'       => [
				'{{WRAPPER}} .section-heading' => 'margin-bottom: {{SIZE}}{{UNIT}};',
			],
		] );

		$this->end_controls_section();



		// Icon Style Section
		//======================
		$this->start_controls_section( 'section_icon_style', [
			'label' => esc_html__( 'Icon', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
			'condition' => [
				'icon_type!' => 'none',
			],
		] );


		$this->start_controls_tabs( 'tabs_icon_style' );

		$this->start_controls_tab( 'tab_icon_normal', [
			'label' => __( 'Normal', 'quiety-core' ),
		] );

		$this->add_control( 'icon_color', [
			'label'     => esc_html__( 'Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-icon-box__icon-container' => 'color: {{VALUE}};'
			],
		] );

		$this->add_control( 'icon_border_color', [
			'label'     => esc_html__( 'Border Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-icon-box__icon-container' => 'border-color: {{VALUE}};'
			],
		] );

		$this->add_control( 'icon_color_bg', [
			'label'     => esc_html__( 'Background Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-icon-box__icon-container' => 'background-color: {{VALUE}}; border-color: {{VALUE}};'
			],
		] );

		$this->add_group_control( Group_Control_Box_Shadow::get_type(), [
			'name'     => 'icon_shadow',
			'label'    => __( 'Box Shadow', 'quiety-core' ),
			'selector' => '{{WRAPPER}} .tt-icon-box__icon-container',
		] );

		$this->end_controls_tab();

		$this->start_controls_tab( 'tab_icon_hover', [
			'label' => __( 'Hover', 'quiety-core' ),
		] );

		$this->add_control( 'icon_color_hover', [
			'label'     => esc_html__( 'Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-icon-box__icon-container:hover' => 'color: {{VALUE}}; border-color: {{VALUE}};'
			],
		] );

		$this->add_control( 'icon_hover_border_color', [
			'label'     => esc_html__( 'Border Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-icon-box__icon-container:hover' => 'border-color: {{VALUE}};'
			],
		] );

		$this->add_control( 'icon_hover_bg_color', [
			'label'     => esc_html__( 'Background Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-icon-box__icon-container:hover' => 'background-color: {{VALUE}}'
			],
		] );

		$this->end_controls_tab();
		$this->end_controls_tabs();


		$this->add_responsive_control( 'icon_space', [
			'label'     => esc_html__( 'Spacing', 'quiety-core' ),
			'type'      => Controls_Manager::SLIDER,
			'range'     => [
				'px' => [
					'min' => 0,
					'max' => 100,
				],
			],
			'selectors' => [
				'{{WRAPPER}} .tt-icon-box__icon-container'   => 'margin-bottom: {{SIZE}}{{UNIT}};',
				'(mobile){{WRAPPER}} .tt-icon-box__icon-container'      => 'margin-bottom: {{SIZE}}{{UNIT}};',
			],
		] );

		$this->add_responsive_control( 'icon_size', [
			'label'     => esc_html__( 'Size', 'quiety-core' ),
			'type'      => Controls_Manager::SLIDER,
			'range'     => [
				'px' => [
					'min' => 6,
					'max' => 300,
				],
			],
			'selectors' => [
				'{{WRAPPER}} .tt-icon-box__icon-container' => 'font-size: {{SIZE}}{{UNIT}};',
			],
		] );

		$this->add_control( 'icon_padding', [
			'label'     => esc_html__( 'Padding', 'quiety-core' ),
			'type'      => Controls_Manager::SLIDER,
			'selectors' => [
				'{{WRAPPER}} .tt-icon-box__icon-container' => 'padding: {{SIZE}}{{UNIT}};',
			],
			'range'     => [
				'em' => [
					'min' => 0,
					'max' => 5,
				],
			],
			'condition' => [
				'icon_view!' => 'default',
			],
		] );

		$this->add_control( 'rotate', [
			'label'     => esc_html__( 'Rotate', 'quiety-core' ),
			'type'      => Controls_Manager::SLIDER,
			'default'   => [
				'size' => 0,
				'unit' => 'deg',
			],
			'selectors' => [
				'{{WRAPPER}} .tt-icon-box__icon-container i' => 'transform: rotate({{SIZE}}{{UNIT}});',
			],
		] );

		$this->add_control( 'icon_border_width', [
			'label'     => esc_html__( 'Border Width', 'quiety-core' ),
			'type'      => Controls_Manager::DIMENSIONS,
			'selectors' => [
				'{{WRAPPER}} .tt-icon-box__icon-container' => 'border-width: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
			'condition' => [
				'icon_view' => 'framed',
			],
		] );

		$this->add_control( 'border_radius', [
			'label'      => esc_html__( 'Border Radius', 'quiety-core' ),
			'type'       => Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%' ],
			'selectors'  => [
				'{{WRAPPER}} .tt-icon-box__icon-container' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
			'condition'  => [
				'icon_view!' => 'none',
			],
		] );

		$this->end_controls_section();

		//Title Style Section
		//=========================
		$this->start_controls_section(
            'section_title_style', [
                'label' => esc_html__( 'Title', 'quiety-core' ),
                'tab'   => Controls_Manager::TAB_STYLE,
		    ]
        );

		$this->add_control(
            'title_color_one', [
                'label'     => esc_html__( 'Title color', 'quiety-core' ),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .section-heading .section-title' => 'color: {{VALUE}};'
                ],
		    ]
        );

		$this->add_group_control(
            Group_Control_Typography::get_type(), [
                'name'     => 'title_typography',
                'selector' => '{{WRAPPER}} .section-heading .section-title',
            ]
        );

        $this->add_control(
            'highlighted_title_color_option', [
                'label'     => esc_html__( 'Highlighted Title color', 'quiety-core' ),
                'type'      => Controls_Manager::HEADING,
                'separator' => 'before'
            ]
        );

        $this->add_group_control(
            \Elementor\Group_Control_Background::get_type(), [
                'name' => 'highlighted_title_color',
                'label' => esc_html__( 'Highlighted Background', 'plugin-name' ),
                'types' => [ 'classic', 'gradient' ],
                'exclude' => ['image'],
                'selector' => '{{WRAPPER}} .section-title > span',
                'selectors' => [
                    '{{WRAPPER}} .section-title > span' => '-webkit-background-clip: text',
                ],
            ]
        );


        $this->add_control(
            'highlighted_img', [
                'label' => esc_html__( 'highlighted Image', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::MEDIA,
                'separator' => 'before'
            ]
        );

        $this->add_responsive_control(
            'highlighted_img_hr_position', [
                'label' => esc_html__( 'Horizontal Position', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => -1000,
                        'max' => 1000,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => -100,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => '',
                ],
                'selectors' => [
                    '{{WRAPPER}} .section-heading > img' => 'left: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'highlighted_img_vr_position', [
                'label' => esc_html__( 'Vertical Position', 'plugin-name' ),
                'type' => \Elementor\Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => -1000,
                        'max' => 1000,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => -100,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => 'px',
                    'size' => '',
                ],
                'selectors' => [
                    '{{WRAPPER}} .section-heading > img' => 'top: {{SIZE}}{{UNIT}};',
                ],
            ]
        );


		$this->end_controls_section();

		//Subtitle Style Section
		$this->start_controls_section( 'section_subtitle_style', [
			'label' => esc_html__( 'Sub Title', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );


		$this->add_control( 'heading_color_type', array(
			'label'        => __( 'Color Type', 'quiety-core' ),
			'type'         => Controls_Manager::SELECT,
			'options'      => array(
				'color'    => __( 'Color', 'quiety-core' ),
				'gradient' => __( 'Background', 'quiety-core' ),
			),
			'default'      => 'color',
			'prefix_class' => 'tt-heading-fill-',
		) );

		$this->add_control( 'subtitle_color', [
			'label'     => esc_html__( 'Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .section-heading .subtitle' => 'color: {{VALUE}};',
			],
			'condition' => array(
				'heading_color_type' => 'color',
			),
		] );

		$this->add_group_control( Group_Control_Background::get_type(), array(
			'name'           => 'heading_color_gradient',
			'types'          => array(
				'gradient',
				'classic'
			),
			'selector'       => '{{WRAPPER}} .section-heading .subtitle',
			'condition'      => array(
				'heading_color_type' => 'gradient',
			),
		) );

		$this->add_control( 'subtitle_bg_color', [
			'label'     => esc_html__( 'Border Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .section-heading.style-two .subtitle:after, {{WRAPPER}} .section-heading.style-two .subtitle:before' => 'background-color: {{VALUE}};'
			],
			'condition' => ['header_style' => 'style-two']
		] );


		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'subtitle_typography',
			'selector' => '{{WRAPPER}} .section-heading .subtitle',
		] );


		$this->end_controls_section();

		//Description Style Section
		$this->start_controls_section( 'section_des_style', [
			'label' => esc_html__( 'Description', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );


		$this->add_control( 'des_color', [
			'label'     => esc_html__( 'color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .section-heading .description, {{WRAPPER}} .section-heading .description p' => 'color: {{VALUE}};',
			],
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'des_typography',
			'selector' => '{{WRAPPER}} .section-heading .description',
		] );


		$this->end_controls_section();

	}

	protected function render() {
		$settings = $this->get_settings_for_display();

		$title            = $settings['title_text'];
		$sub_title        = $settings['sub_title'];
		$description_text = $settings['description_text'];

		$this->add_render_attribute( 'title_text', [
			'class'          => 'section-title'
		] );

		$this->add_render_attribute( 'sub_title', 'class', 'subtitle' );

		$this->add_inline_editing_attributes( 'title_text' );
		$this->add_inline_editing_attributes( 'sub_title' );


		$this->add_render_attribute( 'description_text', [
			'class'          => 'description',
		] );
		$this->add_inline_editing_attributes( 'description_text' );
		?>

		<div class="section-heading <?php echo $settings['header_style']; ?>">

			<?php if ( $settings['icon_type'] != 'none' ) : ?>
				<?php if ( $settings['icon_pack'] == 'fontawesome' ) : ?>
					<div class="tt-icon-box__icon-container">
						<?php if ( ! empty( $settings['box_icon'] ) ) : ?>
							<?php \Elementor\Icons_Manager::render_icon( $settings['box_icon'], [ 'aria-hidden' => 'true' ] ); ?>
						<?php endif; ?>
					</div>
				<?php  elseif ( $settings['icon_pack'] == 'feather' ) : ?>
					<div class="tt-icon-box__icon-container">
						<?php if ( ! empty( $settings['feather_icon'] ) ) : ?>
							<i class="<?php echo esc_attr( $settings['feather_icon'] ) ?>"></i>
						<?php endif; ?>
					</div>
				<?php endif; ?>
			<?php endif; ?>
			<!-- /.icon-container -->

			<?php if ( ! empty( $sub_title ) ): ?>
				<h3 <?php echo $this->get_render_attribute_string( 'sub_title' ); ?>><?php echo $sub_title; ?></h3>
			<?php endif; ?>

			<?php if ( ! empty( $title ) ) {
				$title_html = sprintf( '<%1$s %2$s>%3$s</%1$s>', Utils::validate_html_tag( $settings['title_size'] ), $this->get_render_attribute_string( 'title_text' ), $title );
				echo $title_html;

                //highlighted_img
                echo !empty( wp_get_attachment_image($settings['highlighted_img']['id'])) ? wp_get_attachment_image($settings['highlighted_img']['id'], 'full', '', ['class' => 'highlighted_img']) : '';
			} ?>

			<?php if ( ! empty( $description_text ) ): ?>
				<div <?php echo $this->get_render_attribute_string( 'description_text' ); ?>><?php echo $description_text; ?></div>
			<?php endif; ?>
		</div>

		<?php
	}

	protected function content_template() { ?>
		<#
		view.addRenderAttribute( 'title_text', 'class', 'section-title' );
		view.addInlineEditingAttributes( 'title_text', 'none' );

		view.addRenderAttribute( 'description_text', 'class', 'description' );
		view.addInlineEditingAttributes( 'description_text', 'none' );

		view.addRenderAttribute( 'sub_title', 'class', 'subtitle' );
		view.addInlineEditingAttributes( 'sub_title', 'none' );

		#>
		<div class="section-heading {{{settings.header_style}}}">

			<# var iconHTML = elementor.helpers.renderIcon( view, settings.box_icon, { 'aria-hidden': true }, 'i' , 'object' ); #>

			<# if ( settings.icon_type != 'none' ) { #>
				<# if ( settings.icon_pack == 'fontawesome' ) { #>
					<div class="tt-icon-box__icon-container">
						{{{ iconHTML.value }}}
					</div>
				<# } else if ( settings.icon_pack == 'feather' ) { #>
					<# if ( settings.feather_icon ) { #>
						<div class="tt-icon-box__icon-container">
							<i class="{{{settings.feather_icon}}}"></i>
						</div>
					<# } #>
				<# } #>
			<# } #>

			<# if(settings.sub_title) { #>
				<div {{{ view.getRenderAttributeString( 'sub_title' ) }}}>{{{ settings.sub_title }}}</div>
			<# } #>

			<#
			var title = settings.title_text;
			var headerSizeTag = elementor.helpers.validateHTMLTag( settings.title_size );
			var title_html = '<' + headerSizeTag  + ' ' + view.getRenderAttributeString( 'title_text' ) + '>' + title + '</' + headerSizeTag + '>';

			print( title_html ); #>

			<# if(settings.description_text) { #>
			<div {{{ view.getRenderAttributeString('description_text' ) }}}>{{{ settings.description_text }}}</div>
			<# } #>
		</div>
		<?php
	}
}



