<?php


namespace Quiety\Widgets;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Elementor\{Controls_Manager,
	Group_Control_Background,
	Group_Control_Box_Shadow,
	Widget_Base,
	Group_Control_Typography,
	Repeater,
	Utils
};

class Quiety_Timeline extends Widget_Base {

	public function get_name() {
		return 'tt-timeline';
	}

	public function get_title() {
		return esc_html__( 'Quiety Timeline', 'quiety-core' );
	}

	public function get_icon() {
		return 'eicon-testimonial';
	}

	public function get_categories() {
		return [ 'tt-elements' ];
	}

	protected function register_controls() {
		// Testimonial
		//=========================
		$this->start_controls_section( 'section_tab_style', [
			'label' => esc_html__( 'Timeline', 'quiety-core' ),
		] );


		$repeater = new Repeater();

		$repeater->add_control(
			'timeline_icon',
			[
				'label' => esc_html__( 'Icon', 'plugin-name' ),
				'type' => \Elementor\Controls_Manager::ICONS,
				'default' => [
					'value' => 'fas fa-star',
					'library' => 'solid',
				],
			]
		);

		$repeater->add_control( 'title', [
			'label'       => __( 'Title', 'quiety-core' ),
			'type'        => Controls_Manager::TEXT,
			'default'     => __( 'Carrie Roberts', 'quiety-core' ),
			'label_block' => true,
		] );

		$repeater->add_control( 'full_date', [
			'label'       => __( 'Full Date', 'quiety-core' ),
			'type'        => Controls_Manager::TEXT,
			'default'     => __( 'Full-Stack Developer', 'quiety-core' ),
			'label_block' => true,
		] );

		$repeater->add_control( 'year', [
			'label'       => __( 'Year', 'quiety-core' ),
			'type'        => Controls_Manager::TEXT,
			'default'     => __( '35+ minutes per session', 'quiety-core' ),
			'label_block' => true,
		] );

		$repeater->add_control( 'timeline_content', [
			'label'      => __( 'Review Content', 'quiety-core' ),
			'type'       => Controls_Manager::TEXTAREA,
			'default'    => __( 'In publishing and graphic design, Lorem used to demonstrate the visual form of relying on meaningful content.', 'quiety-core' ),
			'show_label' => false,
		] );


		$this->add_control( 'timeline', [
			'label'       => __( 'Testimonial Items', 'quiety-core' ),
			'type'        => Controls_Manager::REPEATER,
			'fields'      => $repeater->get_controls(),
			'default'     => [
				[
					'title'            => __( 'Blockchain', 'quiety-core' ),
					'full_date'        => '24.07.2017',
					'year'             => '2017',
					'timeline_content' => __( 'In publishing and graphic design, Lorem used to demonstrate the visual form of relying on meaningful content.', 'quiety-core' ),
					'layout' => 'one'
				],
				[
					'title'            => __( 'Token Bridge', 'quiety-core' ),
					'full_date'        => '24.07.2019',
					'year'             => '2018',
					'timeline_content' => __( 'In publishing and graphic design, Lorem used to demonstrate the visual form of relying on meaningful content.', 'quiety-core' ),
					'layout' => 'two'
				],
				[
					'title'            => __( 'Crypto Listings', 'quiety-core' ),
					'full_date'        => '24.07.2019',
					'year'             => '2019',
					'timeline_content' => __( 'In publishing and graphic design, Lorem used to demonstrate the visual form of relying on meaningful content.', 'quiety-core' ),
					'layout' => 'one'
				],
			],
			'title_field' => '{{{ title }}}',
		] );

		$this->end_controls_section();

		// Slider Control
		//=====================
		$this->start_controls_section( 'settingd_section', [
			'label' => esc_html__( 'Slider Control', 'quiety-core' ),
		] );

		$this->add_control( 'navigation', [
			'label'        => esc_html__( 'Navigation', 'quiety-core' ),
			'type'         => Controls_Manager::SWITCHER,
			'label_on'     => esc_html__( 'Show', 'quiety-core' ),
			'label_off'    => esc_html__( 'Hide', 'quiety-core' ),
			'return_value' => 'yes',
			'default'      => 'yes'
		] );


		$this->add_control( 'loop', [
			'label'        => esc_html__( 'Loop', 'quiety-core' ),
			'type'         => Controls_Manager::SWITCHER,
			'label_on'     => esc_html__( 'On', 'quiety-core' ),
			'label_off'    => esc_html__( 'Off', 'quiety-core' ),
			'return_value' => 'yes',
			'default'      => 'yes'
		] );

		$this->add_control( 'speed', [
			'label'   => __( 'Speed', 'quiety-core' ),
			'type'    => Controls_Manager::NUMBER,
			'default' => 700,
		] );

		$this->add_control( 'autoplay', [
			'label'        => esc_html__( 'Autoplay', 'quiety-core' ),
			'type'         => Controls_Manager::SWITCHER,
			'label_on'     => esc_html__( 'On', 'quiety-core' ),
			'label_off'    => esc_html__( 'Off', 'quiety-core' ),
			'return_value' => 'yes',
			'default'      => 'yes'
		] );

		$this->add_control( 'autoplay_time', [
			'label'     => __( 'Autoplay Time', 'quiety-core' ),
			'type'      => Controls_Manager::NUMBER,
			'default'   => 3000,
			'condition' => [
				'autoplay' => 'yes'
			]
		] );

		$this->end_controls_section();


		// Style Sections
		//=====================

		$this->start_controls_section( 'icon_style_section', [
			'label' => __( 'Icon', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_control( 'icon_color', [
			'label'     => __( 'Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-timeline__icon' => 'color: {{VALUE}}',
			],
		] );

		$this->add_control( 'icon_bg_color', [
			'label'     => __( 'Background Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-timeline__icon' => 'background: {{VALUE}}',
			],
		] );



		$this->end_controls_section();



		$this->start_controls_section( 'name_section', [
			'label' => __( 'Title', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_control( 'name_color', [
			'label'     => __( 'Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-timeline__title' => 'color: {{VALUE}}',
			],
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'name_typography',
			'label'    => __( 'Typography', 'quiety-core' ),
			'selector' => '{{WRAPPER}} .tt-timeline__title',
		] );

		$this->end_controls_section();

		$this->start_controls_section( 'designation_section', [
			'label' => __( 'Date', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_control( 'desi_color', [
			'label'     => __( 'Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-timeline__date' => 'color: {{VALUE}}',
			],
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'desi_typography',
			'label'    => __( 'Typography', 'quiety-core' ),
			'selector' => '{{WRAPPER}} .tt-timeline__date',
		] );

		$this->end_controls_section();

		$this->start_controls_section( 'title_style_section', [
			'label' => __( 'Year', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_control( 'title_color', [
			'label'     => __( 'Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-timeline__year' => 'color: {{VALUE}}',
			],
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'title_typography',
			'label'    => __( 'Typography', 'quiety-core' ),
			'selector' => '{{WRAPPER}} .tt-timeline__year',
		] );


		$this->end_controls_section();

		// Style Review Content
		//=========================
		$this->start_controls_section( 'review_section', [
			'label' => __( 'Content', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_control( 'review_color', [
			'label'     => __( 'Color', 'quiety-core' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .tt-timeline__description' => 'color: {{VALUE}}',
			],
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'review_typography',
			'label'    => __( 'Typography', 'quiety-core' ),
			'selector' => '{{WRAPPER}} .tt-timeline__description',
		] );

		$this->end_controls_section();

		// Style Slider Control Section
		//================================
		$this->start_controls_section( 'testimonial_section', [
			'label' => __( 'Timeline Container', 'quiety-core' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_group_control( Group_Control_Background::get_type(), [
			'name'     => 'testimonial_background',
			'label'    => __( 'Background', 'quiety-core' ),
			'types'    => [ 'classic', 'gradient' ],
			'exclude'  => [ 'image' ],
			'selector' => '{{WRAPPER}} .tt-timeline__content',
		] );

		$this->add_control( 'testimonial_padding', [
			'label'      => __( 'Padding', 'quiety-core' ),
			'type'       => Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%', 'em' ],
			'selectors'  => [
				'{{WRAPPER}} .tt-timeline__content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		] );

		$this->add_control( 'testimonial_border_radius', [
			'label'      => __( 'Border Radius', 'quiety-core' ),
			'type'       => Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%', 'em' ],
			'selectors'  => [
				'{{WRAPPER}} .tt-timeline__content' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		] );

		$this->add_group_control( \Elementor\Group_Control_Border::get_type(), [
			'name'     => 'testimonial_border',
			'label'    => esc_html__( 'Border', 'plugin-name' ),
			'selector' => '{{WRAPPER}} .tt-timeline__content',
		] );

		$this->add_group_control( Group_Control_Box_Shadow::get_type(), [
			'name'     => 'testimonial_shadow_hover',
			'label'    => __( 'Box Shadow', 'quiety-core' ),
			'selector' => '{{WRAPPER}} .tt-timeline__content',
		] );

		$this->end_controls_section();
	}

	protected function render() {

		$settings     = $this->get_settings_for_display();
		$timeline = $settings['timeline'];

		$this->add_render_attribute( 'wrapper', 'class', [
			'swiper-container',
			'tt-testimonial',
		] );


		$this->add_render_attribute( 'description_text', [
			'class'          => 'description wow fadeInUp',
		] );

		$this->add_inline_editing_attributes( 'description_text' );


		$slider_options = $this->get_slider_options( $settings );
		$this->add_render_attribute( 'wrapper', 'data-timeline', wp_json_encode( $slider_options ) );


		require __DIR__ . '/templates/timeline/timeline.php';

	}

	protected function get_slider_options( array $settings ) {

		// Loop
		if ( $settings['loop'] == 'yes' ) {
			$slider_options['loop'] = true;
		}

		// Speed
		if ( ! empty( $settings['speed'] ) ) {
			$slider_options['speed'] = $settings['speed'];
		}



		// Breakpoints
		$slider_options['breakpoints'] = [
			'1024' => [
				'slidesPerView' => '4',
			],

			'991' => [
				'slidesPerView' => '3',
			],

			'576' => [
				'slidesPerView' => '2',
			],


			'320' => [
				'slidesPerView' => 1,
			],
		];


		// Auto Play
		if ( $settings['autoplay'] == 'yes' ) {
			$slider_options['autoplay'] = [
				'delay'                => $settings['autoplay_time'],
				'disableOnInteraction' => false
			];
		} else {
			$slider_options['autoplay'] = [
				'delay' => '99999999999',
			];
		}

		if ( $settings['navigation'] == 'yes' ) {
			$slider_options['navigation'] = [
				'nextEl' => '.testi-next',
				'prevEl' => '.testi-prev'
			];
		}


		$slider_options['spaceBetween'] = (int) '30';

		return $slider_options;
	}

}