<?php
/**
 * Adding local_import_json and import_json param supports.
 */
if ( ! function_exists( 'quiety_after_content_import_execution' ) ) {
	function quiety_after_content_import_execution( $selected_import_files, $import_files, $selected_index ) {

		$downloader = new OCDI\Downloader();

		if( ! empty( $import_files[$selected_index]['import_json'] ) ) {

			foreach( $import_files[$selected_index]['import_json'] as $index => $import ) {
				$file_path = $downloader->download_file( $import['file_url'], 'demo-import-file-'. $index .'-'. date( 'Y-m-d__H-i-s' ) .'.json' );
				$file_raw  = OCDI\Helpers::data_from_file( $file_path );
				update_option( $import['option_name'], json_decode( $file_raw, true ) );
			}

		} else if( ! empty( $import_files[$selected_index]['local_import_json'] ) ) {

			foreach( $import_files[$selected_index]['local_import_json'] as $index => $import ) {
				$file_path = $import['file_path'];
				$file_raw  = OCDI\Helpers::data_from_file( $file_path );
				update_option( $import['option_name'], json_decode( $file_raw, true ) );
			}

		}

	}
	add_action('ocdi/after_content_import_execution', 'quiety_after_content_import_execution', 3, 99 );
}


function quiety_ocdi_intro_text( $default_text ) {
	$default_text .= '<div class="ocdi_custom-intro-text notice notice-info inline">';
	$default_text .= sprintf (
		'%1$s <a href="%2$s" target="_blank">%3$s</a> %4$s',
		esc_html__( 'Install and activate all ', 'quiety-core' ),
		get_admin_url(null, 'themes.php?page=tgmpa-install-plugins' ),
		esc_html__( 'required plugins', 'quiety-core' ),
		esc_html__( 'before you click on the "Import" button.', 'quiety-core' )
	);

	$default_text .= sprintf (
		' %1$s <a href="%2$s" target="_blank">%3$s</a> %4$s',
		esc_html__( 'You will find all the pages in ', 'quiety-core' ),
		get_admin_url(null, 'edit.php?post_type=page' ),
		esc_html__( 'Pages.', 'quiety-core' ),
		esc_html__( 'Other pages will be imported along with the main Homepage.', 'quiety-core' )
	);
	$default_text .= '<br>';
	$default_text .= '</div>';

	return $default_text;
}

function quiety_core_import_files() {
	return array(
		array(
			'import_file_name'         => esc_html__( 'Main Demo (All Pages)', 'quiety-core' ),
			'local_import_file'        => QUIETY_CORE_DIR . 'inc/demo-data/content.xml',
			'import_preview_image_url' => QUIETY_PLUGIN_URL . 'inc/demo-data/thumbnail/home-one.jpg',
			'local_import_widget_file' => QUIETY_CORE_DIR . 'inc/demo-data/widgets.wie',
			'import_notice'            => wp_kses_post( __( 'Install and activate all required plugins before you click on the "Import" button. 
            <br> All pages will be imported.', 'quiety-core' ) ),
			'preview_url'              => 'https://quiety-wp.themetags.com/',
			'local_import_json'        => array(
				array(
					'file_path'   => QUIETY_CORE_DIR . 'inc/demo-data/options.json',
					'option_name' => 'tt_framework',
				)
			),
		),
	);
}

add_filter( 'pt-ocdi/import_files', 'quiety_core_import_files' );


/**
 * Set Menu and font page
 * @param $selected_import
 */
function quiety_after_import( $selected_import ) {
	echo "This will be displayed on all after imports!";

	$main_menu = get_term_by( 'name', 'Primary Menu', 'nav_menu' );

	set_theme_mod( 'nav_menu_locations', array(
		'primary' => $main_menu->term_id,
	) );

	$front_page_id = get_page_by_title( 'Home' );
	$blog_page_id = get_page_by_title( 'Blog' );
	update_option( 'page_for_posts', $blog_page_id->ID );

	if ( isset( $front_page_id ) and is_object( $front_page_id ) ) {
		update_option( 'show_on_front', 'page' );
		update_option( 'page_on_front', $front_page_id->ID );
	}
}

add_action( 'ocdi/after_import', 'quiety_after_import' );