<?php
/**
 * Quiety_Support custom post type.
 *
 * @package Quiety Core
 * @since   1.0.0
 */

// Prevent loading this file directly
defined( 'ABSPATH' ) || exit;

class Quiety_Support {
	/**
	 * Construct function.
	 *
	 * @return  void
	 */
	function __construct() {
		add_action( 'init', array( __CLASS__, 'quiety_support_init' ) );
		add_filter( 'single_template', array( $this, 'support_single' ) );
	}

	/**
	 * Register a Quiety_Support post type.
	 *
	 * @link http://codex.wordpress.org/Function_Reference/register_post_type
	 */
	public static function quiety_support_init() {
		if ( function_exists( 'quiety_option' ) ) {
			$slug_text = quiety_option( 'support_slug' );
		}

		$slug = ! empty( $slug_text ) ? $slug_text : 'support';

		register_post_type( 'quiety_support', array(
			'public'             => true,
			'publicly_queryable' => true,
			'show_ui'            => true,
			'show_in_menu'       => true,
			'query_var'          => true,
			'rewrite'            => array( 'slug' => $slug ),
			'capability_type'    => 'post',
			'has_archive'        => false,
			'hierarchical'       => false,
			'show_in_rest'       => true,
			'menu_position'      => 20,
			'menu_icon'          => 'dashicons-info',
			'supports'           => array( 'title', 'editor', 'thumbnail', 'comments' ),
			'labels'             => array(
				'name'               => _x( 'Support', 'quiety-core' ),
				'singular_name'      => _x( 'Support', 'quiety-core' ),
				'menu_name'          => _x( 'Support', 'quiety-core' ),
				'name_admin_bar'     => _x( 'Support', 'quiety-core' ),
				'add_new'            => _x( 'Add New', 'quiety-core' ),
				'add_new_item'       => __( 'Add New Support', 'quiety-core' ),
				'new_item'           => __( 'New Support', 'quiety-core' ),
				'edit_item'          => __( 'Edit Support', 'quiety-core' ),
				'view_item'          => __( 'View Support', 'quiety-core' ),
				'all_items'          => __( 'All Supports', 'quiety-core' ),
				'search_items'       => __( 'Search Supports', 'quiety-core' ),
				'parent_item_colon'  => __( 'Parent Supports:', 'quiety-core' ),
				'not_found'          => __( 'No Support found.', 'quiety-core' ),
				'not_found_in_trash' => __( 'No Support found in Trash.', 'quiety-core' )
			),
		) );

		// Register job category
		register_taxonomy( 'quiety_support_cat', array( 'quiety_support' ), array(
			'hierarchical' => true,
			'show_ui'      => true,
			'show_in_rest' => true,

			'show_admin_column' => true,
			'query_var'         => true,
			'rewrite'           => array( 'slug' => 'job_cat' ),
			'labels'            => array(
				'name'              => _x( 'Categories', 'quiety-core' ),
				'singular_name'     => _x( 'Category', 'quiety-core' ),
				'search_items'      => __( 'Search Categories', 'quiety-core' ),
				'all_items'         => __( 'All Categories', 'quiety-core' ),
				'parent_item'       => __( 'Parent Category', 'quiety-core' ),
				'parent_item_colon' => __( 'Parent Category:', 'quiety-core' ),
				'edit_item'         => __( 'Edit Category', 'quiety-core' ),
				'update_item'       => __( 'Update Category', 'quiety-core' ),
				'add_new_item'      => __( 'Add New Category', 'quiety-core' ),
				'new_item_name'     => __( 'New Category Name', 'quiety-core' ),
				'menu_name'         => __( 'Categories', 'quiety-core' ),
			),
		) );


		//Register job tag
		register_taxonomy( 'quiety_support_tag', 'quiety_support', array(
			'hierarchical'          => true,
			'show_ui'               => true,
			'show_admin_column'     => true,
			'update_count_callback' => '_update_post_term_count',
			'query_var'             => true,
			'rewrite'               => array( 'slug' => 'quiety_support_tag' ),
			'labels'                => array(
				'name'                       => _x( 'Tags', 'quiety-core' ),
				'singular_name'              => _x( 'Tag', 'quiety-core' ),
				'search_items'               => __( 'Search Tags', 'quiety-core' ),
				'popular_items'              => __( 'Popular Tags', 'quiety-core' ),
				'all_items'                  => __( 'All Tags', 'quiety-core' ),
				'parent_item'                => null,
				'parent_item_colon'          => null,
				'edit_item'                  => __( 'Edit Tag', 'quiety-core' ),
				'update_item'                => __( 'Update Tag', 'quiety-core' ),
				'add_new_item'               => __( 'Add New Tag', 'quiety-core' ),
				'new_item_name'              => __( 'New Tag Name', 'quiety-core' ),
				'separate_items_with_commas' => __( 'Separate tag with commas', 'quiety-core' ),
				'add_or_remove_items'        => __( 'Add or remove tag', 'quiety-core' ),
				'choose_from_most_used'      => __( 'Choose from the most used tag', 'quiety-core' ),
				'not_found'                  => __( 'No tag found.', 'quiety-core' ),
				'menu_name'                  => __( 'Tags', 'quiety-core' ),
			),
		) );
	}

	/**
	 * Load single item template file for the job custom post type.
	 *
	 * @param string $template Current template file.
	 *
	 * @return  string
	 */
	function support_single( $template ) {
		global $post;

		if ( $post->post_type == 'quiety_support' ) {
			$template = QUIETY_CORE_DIR . 'inc/post-type/support/views/single.php';
		}

		return $template;
	}


	/**
	 * Define helper function to print related job.
	 *
	 * @return  array
	 */
	public static function related() {

		global $post;
		// Get the good menu tags.
		$cats = get_the_terms( $post, 'quiety_support_cat' );

		if ( $cats ) {
			$cat_ids = array();

			foreach ( $cats as $cat ) {
				$cat_ids[] = $cat->term_id;
			}

			$post_perpage = quiety_option( 'relpost_count' ) ? quiety_option( 'relpost_count' ) : (int) '3';

			$args = array(
				'post_type'      => 'quiety_support',
				'post__not_in'   => array( $post->ID ),
				'posts_per_page' => 3,
				'tax_query'      => array(
					array(
						'taxonomy' => 'quiety_support_cat',
						'field'    => 'id',
						'terms'    => $cat_ids,
					),
				)
			);

			$the_query = new WP_Query( $args );

			?>

			<div class="related-support">
				<?php if ( quiety_option( 'support_title' ) ) { ?>
					<?php if ( quiety_option( 'support_title' ) !== "" ) : ?>
						<h2 class="support-related-title"><?php echo esc_html( quiety_option( 'support_title' ) ) ?> </h2>
					<?php endif; ?>
				<?php } ?>

				<?php if ( $the_query->have_posts() ) :
					while ( $the_query->have_posts() ) :
						$the_query->the_post();
						?>
						<div <?php post_class( 'tt-support' ); ?>>

							<h3 class="tt-support__title">
								<a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
							</h3>
						</div>

					<?php endwhile;
					wp_reset_postdata();
				endif; ?>

			</div>
		<?php }
		wp_reset_postdata();
	}
}

$portfolio = new Quiety_Support;